Class: ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentUpdateRequestWithID

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/modern_treasury/models/bulk_request_create_params.rb,
sig/modern_treasury/models/bulk_request_create_params.rbs

Defined Under Namespace

Modules: AmountReconciledDirection, AmountUnreconciledDirection, Direction, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, amount_lower_bound: nil, amount_reconciled: nil, amount_reconciled_direction: nil, amount_unreconciled: nil, amount_unreconciled_direction: nil, amount_upper_bound: nil, counterparty_id: nil, currency: nil, date_lower_bound: nil, date_upper_bound: nil, description: nil, direction: nil, external_id: nil, internal_account_id: nil, metadata: nil, reconciliation_filters: nil, reconciliation_groups: nil, reconciliation_rule_variables: nil, remittance_information: nil, statement_descriptor: nil, status: nil, type: nil) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentUpdateRequestWithID for more details.

Parameters:

  • id (String) (defaults to: nil)
  • amount_lower_bound (Integer, nil) (defaults to: nil)

    The lowest amount this expected payment may be equal to. Value in specified curr

  • amount_reconciled (Integer, nil) (defaults to: nil)

    The amount reconciled for this expected payment. Value in specified currency's s

  • amount_reconciled_direction (Symbol, ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentUpdateRequestWithID::AmountReconciledDirection, nil) (defaults to: nil)

    One of credit or debit. Indicates whether amount_reconciled is a credit or debit

  • amount_unreconciled (Integer, nil) (defaults to: nil)

    The amount that remains unreconciled for this expected payment. Value in specifi

  • amount_unreconciled_direction (Symbol, ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentUpdateRequestWithID::AmountUnreconciledDirection, nil) (defaults to: nil)

    One of credit or debit. Indicates whether amount_unreconciled is a credit or deb

  • amount_upper_bound (Integer, nil) (defaults to: nil)

    The highest amount this expected payment may be equal to. Value in specified cur

  • counterparty_id (String, nil) (defaults to: nil)

    The ID of the counterparty you expect for this payment.

  • currency (Symbol, ModernTreasury::Models::Currency, nil) (defaults to: nil)

    Must conform to ISO 4217. Defaults to the currency of the internal account.

  • date_lower_bound (Date, nil) (defaults to: nil)

    The earliest date the payment may come in. Format: yyyy-mm-dd

  • date_upper_bound (Date, nil) (defaults to: nil)

    The latest date the payment may come in. Format: yyyy-mm-dd

  • description (String, nil) (defaults to: nil)

    An optional description for internal use.

  • direction (Symbol, ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentUpdateRequestWithID::Direction, nil) (defaults to: nil)

    One of credit or debit. When you are receiving money, use credit. When you are b

  • external_id (String, nil) (defaults to: nil)

    An optional user-defined 180 character unique identifier.

  • internal_account_id (String, nil) (defaults to: nil)

    The ID of the Internal Account for the expected payment.

  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    Additional data represented as key-value pairs. Both the key and value must be s

  • reconciliation_filters (Object, nil) (defaults to: nil)

    The reconciliation filters you have for this payment.

  • reconciliation_groups (Object, nil) (defaults to: nil)

    The reconciliation groups you have for this payment.

  • reconciliation_rule_variables (Array<ModernTreasury::Models::ReconciliationRule>, nil) (defaults to: nil)

    An array of reconciliation rule variables for this payment.

  • remittance_information (String, nil) (defaults to: nil)

    For ach, this field will be passed through on an addenda record. For wire pa

  • statement_descriptor (String, nil) (defaults to: nil)

    The statement description you expect to see on the transaction. For ACH payments

  • status (Symbol, ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentUpdateRequestWithID::Status, nil) (defaults to: nil)

    The Expected Payment's status can be updated from partially_reconciled to reconc

  • type (Symbol, ModernTreasury::Models::ExpectedPaymentType, nil) (defaults to: nil)

    One of: ach, au_becs, bacs, book, check, eft, rtp, sepa, wire.



# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2647

Instance Attribute Details

#amount_lower_boundInteger?

The lowest amount this expected payment may be equal to. Value in specified currency's smallest unit. e.g. $10 would be represented as 1000.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


2488
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2488

optional :amount_lower_bound, Integer, nil?: true

#amount_reconciledInteger?

The amount reconciled for this expected payment. Value in specified currency's smallest unit. e.g. $10 would be represented as 1000.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


2495
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2495

optional :amount_reconciled, Integer, nil?: true

#amount_reconciled_directionSymbol, ...

One of credit or debit. Indicates whether amount_reconciled is a credit or debit amount.

Parameters:

  • value (ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentUpdateRequestWithID::amount_reconciled_direction, nil)

Returns:



2502
2503
2504
2505
2506
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2502

optional :amount_reconciled_direction,
enum: -> {
  ModernTreasury::BulkRequestCreateParams::Resource::ExpectedPaymentUpdateRequestWithID::AmountReconciledDirection
},
nil?: true

#amount_unreconciledInteger?

The amount that remains unreconciled for this expected payment. Value in specified currency's smallest unit. e.g. $10 would be represented as 1000.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


2513
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2513

optional :amount_unreconciled, Integer, nil?: true

#amount_unreconciled_directionSymbol, ...

One of credit or debit. Indicates whether amount_unreconciled is a credit or debit amount.

Parameters:

  • value (ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentUpdateRequestWithID::amount_unreconciled_direction, nil)

Returns:



2520
2521
2522
2523
2524
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2520

optional :amount_unreconciled_direction,
enum: -> {
  ModernTreasury::BulkRequestCreateParams::Resource::ExpectedPaymentUpdateRequestWithID::AmountUnreconciledDirection
},
nil?: true

#amount_upper_boundInteger?

The highest amount this expected payment may be equal to. Value in specified currency's smallest unit. e.g. $10 would be represented as 1000.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


2531
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2531

optional :amount_upper_bound, Integer, nil?: true

#counterparty_idString?

The ID of the counterparty you expect for this payment.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2537
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2537

optional :counterparty_id, String, nil?: true

#currencySymbol, ...

Must conform to ISO 4217. Defaults to the currency of the internal account.

Parameters:

  • value (ModernTreasury::Models::currency, nil)

Returns:



2543
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2543

optional :currency, enum: -> { ModernTreasury::Currency }, nil?: true

#date_lower_boundDate?

The earliest date the payment may come in. Format: yyyy-mm-dd

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


2549
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2549

optional :date_lower_bound, Date, nil?: true

#date_upper_boundDate?

The latest date the payment may come in. Format: yyyy-mm-dd

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


2555
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2555

optional :date_upper_bound, Date, nil?: true

#descriptionString?

An optional description for internal use.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2561
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2561

optional :description, String, nil?: true

#directionSymbol, ...

One of credit or debit. When you are receiving money, use credit. When you are being charged, use debit.

Parameters:

  • value (ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentUpdateRequestWithID::direction, nil)

Returns:



2568
2569
2570
2571
2572
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2568

optional :direction,
enum: -> {
  ModernTreasury::BulkRequestCreateParams::Resource::ExpectedPaymentUpdateRequestWithID::Direction
},
nil?: true

#external_idString?

An optional user-defined 180 character unique identifier.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2578
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2578

optional :external_id, String, nil?: true

#idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


2481
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2481

optional :id, String

#internal_account_idString?

The ID of the Internal Account for the expected payment.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2584
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2584

optional :internal_account_id, String, nil?: true

#metadataHash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


2591
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2591

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#reconciliation_filtersObject?

The reconciliation filters you have for this payment.

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


2597
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2597

optional :reconciliation_filters, ModernTreasury::Internal::Type::Unknown, nil?: true

#reconciliation_groupsObject?

The reconciliation groups you have for this payment.

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


2603
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2603

optional :reconciliation_groups, ModernTreasury::Internal::Type::Unknown, nil?: true

#reconciliation_rule_variablesArray<ModernTreasury::Models::ReconciliationRule>?

An array of reconciliation rule variables for this payment.

Parameters:

Returns:



2609
2610
2611
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2609

optional :reconciliation_rule_variables,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ReconciliationRule] },
nil?: true

#remittance_informationString?

For ach, this field will be passed through on an addenda record. For wire payments the field will be passed through as the "Originator to Beneficiary Information", also known as OBI or Fedwire tag 6000.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2619
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2619

optional :remittance_information, String, nil?: true

#statement_descriptorString?

The statement description you expect to see on the transaction. For ACH payments, this will be the full line item passed from the bank. For wire payments, this will be the OBI field on the wire. For check payments, this will be the memo field.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2628
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2628

optional :statement_descriptor, String, nil?: true

#statusSymbol, ...

The Expected Payment's status can be updated from partially_reconciled to reconciled.

Parameters:

  • value (ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentUpdateRequestWithID::status, nil)

Returns:



2635
2636
2637
2638
2639
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2635

optional :status,
enum: -> {
  ModernTreasury::BulkRequestCreateParams::Resource::ExpectedPaymentUpdateRequestWithID::Status
},
nil?: true

#typeSymbol, ...

One of: ach, au_becs, bacs, book, check, eft, rtp, sepa, wire.

Parameters:

  • value (ModernTreasury::Models::expected_payment_type, nil)

Returns:



2645
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2645

optional :type, enum: -> { ModernTreasury::ExpectedPaymentType }, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2708

Instance Method Details

#to_hash{

Returns:

  • ({)


2131
# File 'sig/modern_treasury/models/bulk_request_create_params.rbs', line 2131

def to_hash: -> {