Class: ModernTreasury::Models::BulkRequestCreateParams::Resource::LedgerTransactionUpdateRequestWithID

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/modern_treasury/models/bulk_request_create_params.rb,
sig/modern_treasury/models/bulk_request_create_params.rbs

Defined Under Namespace

Modules: LedgerableType, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, description: nil, effective_at: nil, external_id: nil, ledger_entries: nil, ledgerable_id: nil, ledgerable_type: nil, metadata: nil, status: nil) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::BulkRequestCreateParams::Resource::LedgerTransactionUpdateRequestWithID for more details.

Parameters:



# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2532

Instance Attribute Details

#descriptionString?

An optional description for internal use.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2479
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2479

optional :description, String, nil?: true

#effective_atTime?

The timestamp (ISO8601 format) at which the ledger transaction happened for reporting purposes.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


2486
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2486

optional :effective_at, Time

#external_idString?

A unique string to represent the ledger transaction. Only one pending or posted ledger transaction may have this ID in the ledger.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


2493
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2493

optional :external_id, String, nil?: true

#idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


2473
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2473

optional :id, String

#ledger_entriesArray<ModernTreasury::Models::LedgerEntryCreateRequest>?

An array of ledger entry objects.



2499
2500
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2499

optional :ledger_entries,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LedgerEntryCreateRequest] }

#ledgerable_idString?

If the ledger transaction can be reconciled to another object in Modern Treasury, the id will be populated here, otherwise null.

Parameters:

  • (String)

Returns:

  • (String, nil)


2507
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2507

optional :ledgerable_id, String

#ledgerable_typeSymbol, ...

If the ledger transaction can be reconciled to another object in Modern Treasury, the type will be populated here, otherwise null. This can be one of payment_order, incoming_payment_detail, expected_payment, return, or reversal.



2515
2516
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2515

optional :ledgerable_type,
enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::LedgerTransactionUpdateRequestWithID::LedgerableType }

#metadataHash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


2523
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2523

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#statusSymbol, ...

To post a ledger transaction at creation, use posted.



2529
2530
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2529

optional :status,
enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::LedgerTransactionUpdateRequestWithID::Status }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2569

Instance Method Details

#to_hash{

Returns:

  • ({)


2052
# File 'sig/modern_treasury/models/bulk_request_create_params.rbs', line 2052

def to_hash: -> {