Class: ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/bulk_request_create_params.rb,
sig/modern_treasury/models/bulk_request_create_params.rbs

Defined Under Namespace

Modules: ChargeBearer, Direction, FallbackType, ForeignExchangeIndicator, Priority, ReconciliationStatus Classes: Accounting, LineItem, OriginatingPartyAddress, ReceivingAccount, UltimateOriginatingPartyAddress

Constant Summary collapse

ModernTreasury =

Returns:

  • (:LedgerTransactionCreateRequest)

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(country: nil, line1: nil, line2: nil, locality: nil, postal_code: nil, region: nil) ⇒ Object

Some parameter documentations has been truncated, see OriginatingPartyAddress for more details.

If present, this address will override the default originating party address used on the payment order. This works across all payment types.

Parameters:

  • country (String, nil) (defaults to: nil)

    Country code conforms to [ISO 3166-1 alpha-2]

  • line1 (String, nil) (defaults to: nil)
  • line2 (String, nil) (defaults to: nil)
  • locality (String, nil) (defaults to: nil)

    Locality or City. Use the full city name rather than an abbreviation (e.g. San F

  • postal_code (String, nil) (defaults to: nil)

    The postal code of the address.

  • region (String, nil) (defaults to: nil)

    Region or State. This field is free-form; for US states, we recommend a two-lett



# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 436

Instance Attribute Details

#accountingModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::Accounting?

Deprecated.


140
141
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 140

optional :accounting,
-> { ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::Accounting }

#accounting_category_idString?

Deprecated.

The ID of one of your accounting categories. Note that these will only be accessible if your accounting system has been connected.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


150
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 150

optional :accounting_category_id, String, nil?: true

#accounting_ledger_class_idString?

Deprecated.

The ID of one of your accounting ledger classes. Note that these will only be accessible if your accounting system has been connected.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


159
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 159

optional :accounting_ledger_class_id, String, nil?: true

#amountInteger

Value in specified currency's smallest unit. e.g. $10 would be represented as 1000 (cents). For RTP, the maximum amount allowed by the network is $10,000,000.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


111
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 111

required :amount, Integer

#charge_bearerSymbol, ...

The party that will pay the fees for the payment order. See https://docs.moderntreasury.com/payments/docs/charge-bearer to understand the differences between the options.

Parameters:

  • value (ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::charge_bearer, nil)

Returns:



167
168
169
170
171
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 167

optional :charge_bearer,
enum: -> {
  ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::ChargeBearer
},
nil?: true

#currencySymbol, ...

Defaults to the currency of the originating account.

Returns:



177
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 177

optional :currency, enum: -> { ModernTreasury::Currency }

#descriptionString?

An optional description for internal use.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


183
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 183

optional :description, String, nil?: true

#directionSymbol, ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::Direction

One of credit, debit. Describes the direction money is flowing in the transaction. A credit moves money from your account to someone else's. A debit pulls money from someone else's account to your own. Note that wire, rtp, and check payments will always be credit.

Parameters:

  • value (ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::direction)

Returns:



120
121
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 120

required :direction,
enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::Direction }

#effective_dateDate?

Date transactions are to be posted to the participants' account. Defaults to the current business day or the next business day if the current day is a bank holiday or weekend. Format: yyyy-mm-dd.

Parameters:

  • (Date)

Returns:

  • (Date, nil)


191
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 191

optional :effective_date, Date

#expires_atTime?

RFP payments require an expires_at. This value must be past the effective_date.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


197
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 197

optional :expires_at, Time, nil?: true

#external_idString?

An optional user-defined 180 character unique identifier.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


203
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 203

optional :external_id, String, nil?: true

#fallback_typeSymbol, ...

A payment type to fallback to if the original type is not valid for the receiving account. Currently, this only supports falling back from RTP to ACH (type=rtp and fallback_type=ach)



211
212
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 211

optional :fallback_type,
enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::FallbackType }

#foreign_exchange_contractString?

If present, indicates a specific foreign exchange contract number that has been generated by your financial institution.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


219
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 219

optional :foreign_exchange_contract, String, nil?: true

#foreign_exchange_indicatorSymbol, ...

Indicates the type of FX transfer to initiate, can be either variable_to_fixed, fixed_to_variable, or null if the payment order currency matches the originating account currency.

Parameters:

  • value (ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::foreign_exchange_indicator, nil)

Returns:



227
228
229
230
231
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 227

optional :foreign_exchange_indicator,
enum: -> {
  ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::ForeignExchangeIndicator
},
nil?: true

#ledger_transactionModernTreasury::Models::LedgerTransactionCreateRequest?

Specifies a ledger transaction object that will be created with the payment order. If the ledger transaction cannot be created, then the payment order creation will fail. The resulting ledger transaction will mirror the status of the payment order.



240
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 240

optional :ledger_transaction, -> { ModernTreasury::LedgerTransactionCreateRequest }

#ledger_transaction_idString?

Either ledger_transaction or ledger_transaction_id can be provided. Only a pending ledger transaction can be attached upon payment order creation. Once the payment order is created, the status of the ledger transaction tracks the payment order automatically.

Parameters:

  • (String)

Returns:

  • (String, nil)


249
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 249

optional :ledger_transaction_id, String

#line_itemsArray<ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::LineItem>?

An array of line items that must sum up to the amount of the payment order.



255
256
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 255

optional :line_items,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::LineItem] }

#metadataHash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


263
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 263

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#nsf_protectedBoolean?

A boolean to determine if NSF Protection is enabled for this payment order. Note that this setting must also be turned on in your organization settings page.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


270
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 270

optional :nsf_protected, ModernTreasury::Internal::Type::Boolean

#originating_account_idString

The ID of one of your organization's internal accounts.

Parameters:

  • value (String)

Returns:

  • (String)


127
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 127

required :originating_account_id, String

#originating_party_addressModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::OriginatingPartyAddress?

If present, this address will override the default originating party address used on the payment order. This works across all payment types.

Parameters:

  • value (ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::OriginatingPartyAddress, nil)

Returns:



277
278
279
280
281
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 277

optional :originating_party_address,
-> {
  ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::OriginatingPartyAddress
},
nil?: true

#originating_party_nameString?

If present, this will replace your default company name on receiver's bank statement. This field can only be used for ACH payments currently. For ACH, only the first 16 characters of this string will be used. Any additional characters will be truncated.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


290
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 290

optional :originating_party_name, String, nil?: true

#prioritySymbol, ...

Either normal or high. For ACH and EFT payments, high represents a same-day ACH or EFT transfer, respectively. For check payments, high can mean an overnight check rather than standard mail.



298
299
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 298

optional :priority,
enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::Priority }

#process_afterTime?

If present, Modern Treasury will not process the payment until after this time. If process_after is past the cutoff for effective_date, process_after will take precedence and effective_date will automatically update to reflect the earliest possible sending date after process_after. Format is ISO8601 timestamp.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


309
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 309

optional :process_after, Time, nil?: true

#purposeString?

For wire, this is usually the purpose which is transmitted via the "InstrForDbtrAgt" field in the ISO20022 file. For eft, this field is the 3 digit CPA Code that will be attached to the payment.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


317
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 317

optional :purpose, String, nil?: true

#receiving_accountModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::ReceivingAccount?

Either receiving_account or receiving_account_id must be present. When using receiving_account_id, you may pass the id of an external account or an internal account.



325
326
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 325

optional :receiving_account,
-> { ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::ReceivingAccount }

#receiving_account_idString?

Either receiving_account or receiving_account_id must be present. When using receiving_account_id, you may pass the id of an external account or an internal account.

Parameters:

  • (String)

Returns:

  • (String, nil)


334
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 334

optional :receiving_account_id, String

#reconciliation_statusSymbol, ...

One of unreconciled, tentatively_reconciled or reconciled.



340
341
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 340

optional :reconciliation_status,
enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::ReconciliationStatus }

#remittance_informationString?

For ach, this field will be passed through on an addenda record. For wire payments the field will be passed through as the "Originator to Beneficiary Information", also known as OBI or Fedwire tag 6000.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


349
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 349

optional :remittance_information, String, nil?: true

#send_remittance_adviceBoolean?

Send an email to the counterparty when the payment order is sent to the bank. If null, send_remittance_advice on the Counterparty is used.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


356
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 356

optional :send_remittance_advice, ModernTreasury::Internal::Type::Boolean, nil?: true

#statement_descriptorString?

An optional descriptor which will appear in the receiver's statement. For check payments this field will be used as the memo line. For ach the maximum length is 10 characters. Note that for ACH payments, the name on your bank account will be included automatically by the bank, so you can use the characters for other useful information. For eft the maximum length is 15 characters.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


367
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 367

optional :statement_descriptor, String, nil?: true

#subtypeSymbol, ...

An additional layer of classification for the type of payment order you are doing. This field is only used for ach payment orders currently. For ach payment orders, the subtype represents the SEC code. We currently support CCD, PPD, IAT, CTX, WEB, CIE, and TEL.

Parameters:

  • value (ModernTreasury::Models::payment_order_subtype, nil)

Returns:



376
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 376

optional :subtype, enum: -> { ModernTreasury::PaymentOrderSubtype }, nil?: true

#transaction_monitoring_enabledBoolean?

Deprecated.

A flag that determines whether a payment order should go through transaction monitoring.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


385
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 385

optional :transaction_monitoring_enabled, ModernTreasury::Internal::Type::Boolean

#typeSymbol, ModernTreasury::Models::PaymentOrderType

One of ach, se_bankgirot, eft, wire, check, book, rtp, sepa, bacs, au_becs, neft, nics, nz_national_clearing_code, sic, zengin.

Parameters:

  • value (ModernTreasury::Models::payment_order_type)

Returns:



134
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 134

required :type, enum: -> { ModernTreasury::PaymentOrderType }

#ultimate_originating_account_idString?

The ultimate originating account ID. Can be a virtual_account or internal_account.

Parameters:

  • (String)

Returns:

  • (String, nil)


392
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 392

optional :ultimate_originating_account_id, String

#ultimate_originating_party_addressModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::UltimateOriginatingPartyAddress?

Address of the ultimate originator of the payment order.

Parameters:

  • value (ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::UltimateOriginatingPartyAddress, nil)

Returns:



398
399
400
401
402
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 398

optional :ultimate_originating_party_address,
-> {
  ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::UltimateOriginatingPartyAddress
},
nil?: true

#ultimate_originating_party_identifierString?

Identifier of the ultimate originator of the payment order.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


408
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 408

optional :ultimate_originating_party_identifier, String, nil?: true

#ultimate_originating_party_nameString?

Name of the ultimate originator of the payment order.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


414
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 414

optional :ultimate_originating_party_name, String, nil?: true

#ultimate_receiving_party_identifierString?

Identifier of the ultimate funds recipient.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


420
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 420

optional :ultimate_receiving_party_identifier, String, nil?: true

#ultimate_receiving_party_nameString?

Name of the ultimate funds recipient.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


426
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 426

optional :ultimate_receiving_party_name, String, nil?: true

#vendor_attributesHash{Symbol=>Object}?

Additional vendor specific fields for this payment. Data must be represented as key-value pairs.

Parameters:

  • (::Hash[Symbol, top])

Returns:

  • (Hash{Symbol=>Object}, nil)


433
434
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 433

optional :vendor_attributes,
ModernTreasury::Internal::Type::HashOf[ModernTreasury::Internal::Type::Unknown]

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 535

Instance Method Details

#to_hash{

Returns:

  • ({)


311
# File 'sig/modern_treasury/models/bulk_request_create_params.rbs', line 311

def to_hash: -> {