Class: ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::Accounting Deprecated

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/modern_treasury/models/bulk_request_create_params.rb,
sig/modern_treasury/models/bulk_request_create_params.rbs

Overview

Deprecated.

See Also:

  • ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest#accounting

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeAccounting

Returns a new instance of Accounting.

Parameters:

  • account_id: (String, nil)
  • class_id: (String, nil)


370
# File 'sig/modern_treasury/models/bulk_request_create_params.rbs', line 370

def initialize: (?account_id: String?, ?class_id: String?) -> void

Instance Attribute Details

#account_idString?

Deprecated.

The ID of one of your accounting categories. Note that these will only be accessible if your accounting system has been connected.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


535
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 535

optional :account_id, String, nil?: true

#class_idString?

Deprecated.

The ID of one of the class objects in your accounting system. Class objects track segments of your business independent of client or project. Note that these will only be accessible if your accounting system has been connected.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


545
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 545

optional :class_id, String, nil?: true

Instance Method Details

#to_hash{ account_id: String?, class_id: String? }

Returns:

  • ({ account_id: String?, class_id: String? })


372
# File 'sig/modern_treasury/models/bulk_request_create_params.rbs', line 372

def to_hash: -> { account_id: String?, class_id: String? }