Class: ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::ReceivingAccount

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/modern_treasury/models/bulk_request_create_params.rb,
sig/modern_treasury/models/bulk_request_create_params.rbs

Overview

See Also:

  • ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest#receiving_account

Defined Under Namespace

Modules: PartyType Classes: AccountDetail, RoutingDetail

Constant Summary collapse

ModernTreasury =

Returns:

  • (:LedgerAccountCreateRequest)

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



575
# File 'sig/modern_treasury/models/bulk_request_create_params.rbs', line 575

def initialize: (

Instance Attribute Details

#account_details ⇒ Array<ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::ReceivingAccount::AccountDetail>?



738
739
740
741
742
743
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 738

optional :account_details,
-> do
  ModernTreasury::Internal::Type::ArrayOf[
    ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::ReceivingAccount::AccountDetail
  ]
end

#account_type ⇒ Symbol, ...

Can be checking, savings or other.



749
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 749

optional :account_type, enum: -> { ModernTreasury::ExternalAccountType }

#contact_details ⇒ Array<ModernTreasury::Models::ContactDetailCreateRequest>?



754
755
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 754

optional :contact_details,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ContactDetailCreateRequest] }

#external_id ⇒ String?

An optional user-defined 180 character unique identifier.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


761
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 761

optional :external_id, String, nil?: true

#ledger_account ⇒ ModernTreasury::Models::LedgerAccountCreateRequest?

Specifies a ledger account object that will be created with the external account. The resulting ledger account is linked to the external account for auto-ledgering Payment objects. See https://docs.moderntreasury.com/docs/linking-to-other-modern-treasury-objects for more details.



771
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 771

optional :ledger_account, -> { ModernTreasury::LedgerAccountCreateRequest }

#metadata ⇒ Hash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


778
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 778

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#name ⇒ String?

A nickname for the external account. This is only for internal usage and won't affect any payments

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


785
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 785

optional :name, String, nil?: true

#party_address ⇒ ModernTreasury::Models::AddressRequest?

Required if receiving wire payments.



791
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 791

optional :party_address, -> { ModernTreasury::AddressRequest }

#party_identifier ⇒ String?

Parameters:

  • (String)

Returns:

  • (String, nil)


796
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 796

optional :party_identifier, String

#party_name ⇒ String?

If this value isn't provided, it will be inherited from the counterparty's name.

Parameters:

  • (String)

Returns:

  • (String, nil)


802
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 802

optional :party_name, String

#party_type ⇒ Symbol, ...

Either individual or business.

Parameters:

  • value (ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::ReceivingAccount::party_type, nil)

Returns:



808
809
810
811
812
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 808

optional :party_type,
enum: -> {
  ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::ReceivingAccount::PartyType
},
nil?: true

#plaid_processor_token ⇒ String?

If you've enabled the Modern Treasury + Plaid integration in your Plaid account, you can pass the processor token in this field.

Parameters:

  • (String)

Returns:

  • (String, nil)


819
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 819

optional :plaid_processor_token, String

#routing_details ⇒ Array<ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::ReceivingAccount::RoutingDetail>?



824
825
826
827
828
829
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 824

optional :routing_details,
-> do
  ModernTreasury::Internal::Type::ArrayOf[
    ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::ReceivingAccount::RoutingDetail
  ]
end

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 902

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


591
# File 'sig/modern_treasury/models/bulk_request_create_params.rbs', line 591

def to_hash: -> {