Class: ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/modern_treasury/models/bulk_request_create_params.rb,
sig/modern_treasury/models/bulk_request_create_params.rbs

Defined Under Namespace

Modules: ChargeBearer, Direction, FallbackType, ForeignExchangeIndicator, Priority, ReconciliationStatus, Status Classes: Accounting, LineItem, OriginatingPartyAddress, ReceivingAccount

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(country: nil, line1: nil, line2: nil, locality: nil, postal_code: nil, region: nil) ⇒ Object

Some parameter documentations has been truncated, see OriginatingPartyAddress for more details.

If present, this address will override the default originating party address used on the payment order. This works across all payment types.

Parameters:

  • country (String, nil) (defaults to: nil)

    Country code conforms to [ISO 3166-1 alpha-2]

  • line1 (String, nil) (defaults to: nil)
  • line2 (String, nil) (defaults to: nil)
  • locality (String, nil) (defaults to: nil)

    Locality or City. Use the full city name rather than an abbreviation (e.g. San F

  • postal_code (String, nil) (defaults to: nil)

    The postal code of the address.

  • region (String, nil) (defaults to: nil)

    Region or State. This field is free-form; for US states, we recommend a two-lett



# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1870

Instance Attribute Details

#accountingModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::Accounting?

Deprecated.


1573
1574
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1573

optional :accounting,
-> { ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::Accounting }

#accounting_category_idString?

Deprecated.

The ID of one of your accounting categories. Note that these will only be accessible if your accounting system has been connected.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1583
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1583

optional :accounting_category_id, String, nil?: true

#accounting_ledger_class_idString?

Deprecated.

The ID of one of your accounting ledger classes. Note that these will only be accessible if your accounting system has been connected.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1592
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1592

optional :accounting_ledger_class_id, String, nil?: true

#amountInteger?

Value in specified currency's smallest unit. e.g. $10 would be represented as 1000 (cents). For RTP, the maximum amount allowed by the network is $10,000,000.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


1599
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1599

optional :amount, Integer

#charge_bearerSymbol, ...

The party that will pay the fees for the payment order. See https://docs.moderntreasury.com/payments/docs/charge-bearer to understand the differences between the options.

Parameters:

  • value (ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::charge_bearer, nil)

Returns:



1607
1608
1609
1610
1611
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1607

optional :charge_bearer,
enum: -> {
  ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ChargeBearer
},
nil?: true

#counterparty_idString?

Required when receiving_account_id is passed the ID of an external account.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1617
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1617

optional :counterparty_id, String, nil?: true

#currencySymbol, ...

Defaults to the currency of the originating account.

Returns:



1623
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1623

optional :currency, enum: -> { ModernTreasury::Currency }

#descriptionString?

An optional description for internal use.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1629
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1629

optional :description, String, nil?: true

#directionSymbol, ...

One of credit, debit. Describes the direction money is flowing in the transaction. A credit moves money from your account to someone else's. A debit pulls money from someone else's account to your own. Note that wire, rtp, and check payments will always be credit.



1638
1639
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1638

optional :direction,
enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::Direction }

#effective_dateDate?

Date transactions are to be posted to the participants' account. Defaults to the current business day or the next business day if the current day is a bank holiday or weekend. Format: yyyy-mm-dd.

Parameters:

  • (Date)

Returns:

  • (Date, nil)


1647
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1647

optional :effective_date, Date

#expires_atTime?

RFP payments require an expires_at. This value must be past the effective_date.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


1653
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1653

optional :expires_at, Time, nil?: true

#external_idString?

An optional user-defined 180 character unique identifier.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1659
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1659

optional :external_id, String, nil?: true

#fallback_typeSymbol, ...

A payment type to fallback to if the original type is not valid for the receiving account. Currently, this only supports falling back from RTP to ACH (type=rtp and fallback_type=ach)



1667
1668
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1667

optional :fallback_type,
enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::FallbackType }

#foreign_exchange_contractString?

If present, indicates a specific foreign exchange contract number that has been generated by your financial institution.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1675
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1675

optional :foreign_exchange_contract, String, nil?: true

#foreign_exchange_indicatorSymbol, ...

Indicates the type of FX transfer to initiate, can be either variable_to_fixed, fixed_to_variable, or null if the payment order currency matches the originating account currency.

Parameters:

  • value (ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::foreign_exchange_indicator, nil)

Returns:



1683
1684
1685
1686
1687
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1683

optional :foreign_exchange_indicator,
enum: -> {
  ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ForeignExchangeIndicator
},
nil?: true

#idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


1567
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1567

optional :id, String

#line_itemsArray<ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::LineItem>?

An array of line items that must sum up to the amount of the payment order.



1693
1694
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1693

optional :line_items,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::LineItem] }

#metadataHash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


1701
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1701

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#nsf_protectedBoolean?

A boolean to determine if NSF Protection is enabled for this payment order. Note that this setting must also be turned on in your organization settings page.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


1708
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1708

optional :nsf_protected, ModernTreasury::Internal::Type::Boolean

#originating_account_idString?

The ID of one of your organization's internal accounts.

Parameters:

  • (String)

Returns:

  • (String, nil)


1714
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1714

optional :originating_account_id, String

#originating_party_addressModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::OriginatingPartyAddress?

If present, this address will override the default originating party address used on the payment order. This works across all payment types.

Parameters:

  • value (ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::OriginatingPartyAddress, nil)

Returns:



1721
1722
1723
1724
1725
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1721

optional :originating_party_address,
-> {
  ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::OriginatingPartyAddress
},
nil?: true

#originating_party_nameString?

If present, this will replace your default company name on receiver's bank statement. This field can only be used for ACH payments currently. For ACH, only the first 16 characters of this string will be used. Any additional characters will be truncated.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1734
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1734

optional :originating_party_name, String, nil?: true

#prioritySymbol, ...

Either normal or high. For ACH and EFT payments, high represents a same-day ACH or EFT transfer, respectively. For check payments, high can mean an overnight check rather than standard mail.



1742
1743
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1742

optional :priority,
enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::Priority }

#process_afterTime?

If present, Modern Treasury will not process the payment until after this time. If process_after is past the cutoff for effective_date, process_after will take precedence and effective_date will automatically update to reflect the earliest possible sending date after process_after. Format is ISO8601 timestamp.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


1753
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1753

optional :process_after, Time, nil?: true

#purposeString?

For wire, this is usually the purpose which is transmitted via the "InstrForDbtrAgt" field in the ISO20022 file. For eft, this field is the 3 digit CPA Code that will be attached to the payment.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1761
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1761

optional :purpose, String, nil?: true

#receiving_accountModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ReceivingAccount?

Either receiving_account or receiving_account_id must be present. When using receiving_account_id, you may pass the id of an external account or an internal account.



1769
1770
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1769

optional :receiving_account,
-> { ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ReceivingAccount }

#receiving_account_idString?

Either receiving_account or receiving_account_id must be present. When using receiving_account_id, you may pass the id of an external account or an internal account.

Parameters:

  • (String)

Returns:

  • (String, nil)


1778
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1778

optional :receiving_account_id, String

#reconciliation_statusSymbol, ...

One of unreconciled, tentatively_reconciled or reconciled.



1784
1785
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1784

optional :reconciliation_status,
enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ReconciliationStatus }

#remittance_informationString?

For ach, this field will be passed through on an addenda record. For wire payments the field will be passed through as the "Originator to Beneficiary Information", also known as OBI or Fedwire tag 6000.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1793
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1793

optional :remittance_information, String, nil?: true

#send_remittance_adviceBoolean?

Send an email to the counterparty when the payment order is sent to the bank. If null, send_remittance_advice on the Counterparty is used.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


1800
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1800

optional :send_remittance_advice, ModernTreasury::Internal::Type::Boolean, nil?: true

#statement_descriptorString?

An optional descriptor which will appear in the receiver's statement. For check payments this field will be used as the memo line. For ach the maximum length is 10 characters. Note that for ACH payments, the name on your bank account will be included automatically by the bank, so you can use the characters for other useful information. For eft the maximum length is 15 characters.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1811
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1811

optional :statement_descriptor, String, nil?: true

#statusSymbol, ...

To cancel a payment order, use cancelled. To redraft a returned payment order, use approved. To undo approval on a denied or approved payment order, use needs_approval.



1819
1820
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1819

optional :status,
enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::Status }

#subtypeSymbol, ...

An additional layer of classification for the type of payment order you are doing. This field is only used for ach payment orders currently. For ach payment orders, the subtype represents the SEC code. We currently support CCD, PPD, IAT, CTX, WEB, CIE, and TEL.

Parameters:

  • value (ModernTreasury::Models::payment_order_subtype, nil)

Returns:



1829
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1829

optional :subtype, enum: -> { ModernTreasury::PaymentOrderSubtype }, nil?: true

#typeSymbol, ...

One of ach, se_bankgirot, eft, wire, check, book, rtp, sepa, bacs, au_becs, neft, nics, nz_national_clearing_code, sic, zengin.



1836
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1836

optional :type, enum: -> { ModernTreasury::PaymentOrderType }

#ultimate_originating_party_identifierString?

This represents the identifier by which the person is known to the receiver when using the CIE subtype for ACH payments. Only the first 22 characters of this string will be used. Any additional characters will be truncated.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1844
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1844

optional :ultimate_originating_party_identifier, String, nil?: true

#ultimate_originating_party_nameString?

This represents the name of the person that the payment is on behalf of when using the CIE subtype for ACH payments. Only the first 15 characters of this string will be used. Any additional characters will be truncated.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1852
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1852

optional :ultimate_originating_party_name, String, nil?: true

#ultimate_receiving_party_identifierString?

This represents the name of the merchant that the payment is being sent to when using the CIE subtype for ACH payments. Only the first 22 characters of this string will be used. Any additional characters will be truncated.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1860
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1860

optional :ultimate_receiving_party_identifier, String, nil?: true

#ultimate_receiving_party_nameString?

This represents the identifier by which the merchant is known to the person initiating an ACH payment with CIE subtype. Only the first 15 characters of this string will be used. Any additional characters will be truncated.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


1868
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1868

optional :ultimate_receiving_party_name, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1996

Instance Method Details

#to_hash{

Returns:

  • ({)


1469
# File 'sig/modern_treasury/models/bulk_request_create_params.rbs', line 1469

def to_hash: -> {