Module: ModernTreasury::Models::BulkResult::Entity

Extended by:
Internal::Type::Union
Defined in:
lib/modern_treasury/models/bulk_result.rb,
sig/modern_treasury/models/bulk_result.rbs

Overview

An object with type as indicated by entity_type. This is the result object that is generated by performing the requested action on the provided input request_params.

See Also:

  • ModernTreasury::Models::BulkResult#entity

Defined Under Namespace

Classes: BulkError

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.variants::Array[ModernTreasury::Models::BulkResult::entity]

Returns:

  • (::Array[ModernTreasury::Models::BulkResult::entity])


152
# File 'sig/modern_treasury/models/bulk_result.rbs', line 152

def self?.variants: -> ::Array[ModernTreasury::Models::BulkResult::entity]