Class: ModernTreasury::Models::Case::RequestedAction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/case_.rb,
sig/modern_treasury/models/case_.rbs

Defined Under Namespace

Modules: Category, Field

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, category:, created_at:, field:, instructions:, live_mode:, object:, reasons:, updated_at:) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::Case::RequestedAction for more details.

Parameters:

  • id (String)
  • category (Symbol, ModernTreasury::Models::Case::RequestedAction::Category) —

    The category of the requested action.

  • created_at (Time)
  • field (Symbol, ModernTreasury::Models::Case::RequestedAction::Field, nil) —

    The field that needs to be corrected or provided, if any.

  • instructions (String, nil) —

    Instructions on how to resolve the requested action.

  • live_mode (Boolean) —

    This field will be true if this object exists in the live environment or false i

  • object (String)
  • reasons (Array<String>) —

    The reasons the action was requested.

  • updated_at (Time)


90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/modern_treasury/models/case_.rb', line 90

class RequestedAction < ModernTreasury::Internal::Type::BaseModel
  # @!attribute id
  #
  #   @return [String]
  required :id, String

  # @!attribute category
  #   The category of the requested action.
  #
  #   @return [Symbol, ModernTreasury::Models::Case::RequestedAction::Category]
  required :category, enum: -> { ModernTreasury::Case::RequestedAction::Category }

  # @!attribute created_at
  #
  #   @return [Time]
  required :created_at, Time

  # @!attribute field
  #   The field that needs to be corrected or provided, if any.
  #
  #   @return [Symbol, ModernTreasury::Models::Case::RequestedAction::Field, nil]
  required :field, enum: -> { ModernTreasury::Case::RequestedAction::Field }, nil?: true

  # @!attribute instructions
  #   Instructions on how to resolve the requested action.
  #
  #   @return [String, nil]
  required :instructions, String, nil?: true

  # @!attribute live_mode
  #   This field will be true if this object exists in the live environment or false
  #   if it exists in the test environment.
  #
  #   @return [Boolean]
  required :live_mode, ModernTreasury::Internal::Type::Boolean

  # @!attribute object
  #
  #   @return [String]
  required :object, String

  # @!attribute reasons
  #   The reasons the action was requested.
  #
  #   @return [Array<String>]
  required :reasons, ModernTreasury::Internal::Type::ArrayOf[String]

  # @!attribute updated_at
  #
  #   @return [Time]
  required :updated_at, Time

  # @!method initialize(id:, category:, created_at:, field:, instructions:, live_mode:, object:, reasons:, updated_at:)
  #   Some parameter documentations has been truncated, see
  #   {ModernTreasury::Models::Case::RequestedAction} for more details.
  #
  #   @param id [String]
  #
  #   @param category [Symbol, ModernTreasury::Models::Case::RequestedAction::Category] The category of the requested action.
  #
  #   @param created_at [Time]
  #
  #   @param field [Symbol, ModernTreasury::Models::Case::RequestedAction::Field, nil] The field that needs to be corrected or provided, if any.
  #
  #   @param instructions [String, nil] Instructions on how to resolve the requested action.
  #
  #   @param live_mode [Boolean] This field will be true if this object exists in the live environment or false i
  #
  #   @param object [String]
  #
  #   @param reasons [Array<String>] The reasons the action was requested.
  #
  #   @param updated_at [Time]

  # The category of the requested action.
  #
  # @see ModernTreasury::Models::Case::RequestedAction#category
  module Category
    extend ModernTreasury::Internal::Type::Enum

    ONBOARDING_ARTICLES_OF_INCORPORATION_FAILURE = :onboarding_articles_of_incorporation_failure
    ONBOARDING_BUSINESS_REGISTRY_VERIFICATION_FAILURE = :onboarding_business_registry_verification_failure
    ONBOARDING_DATABASE_FAILURE = :onboarding_database_failure
    ONBOARDING_PROOF_OF_ADDRESS_FAILURE = :onboarding_proof_of_address_failure
    ONBOARDING_SSN_CHECK_FAILURE = :onboarding_ssn_check_failure
    ONBOARDING_TIN_CHECK_FAILURE = :onboarding_tin_check_failure

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # The field that needs to be corrected or provided, if any.
  #
  # @see ModernTreasury::Models::Case::RequestedAction#field
  module Field
    extend ModernTreasury::Internal::Type::Enum

    ARTICLES_OF_INCORPORATION = :articles_of_incorporation
    EIN_LETTER = :ein_letter
    LEGAL_ENTITY_DETAILS = :legal_entity_details
    PROOF_OF_ADDRESS = :proof_of_address

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#category ⇒ Symbol, ModernTreasury::Models::Case::RequestedAction::Category

The category of the requested action.

Parameters:

  • value (ModernTreasury::Models::Case::RequestedAction::category)

Returns:



100
# File 'lib/modern_treasury/models/case_.rb', line 100

required :category, enum: -> { ModernTreasury::Case::RequestedAction::Category }

#created_at ⇒ Time

Parameters:

  • value (Time)

Returns:

  • (Time)


105
# File 'lib/modern_treasury/models/case_.rb', line 105

required :created_at, Time

#field ⇒ Symbol, ...

The field that needs to be corrected or provided, if any.

Parameters:

  • value (ModernTreasury::Models::Case::RequestedAction::field, nil)

Returns:



111
# File 'lib/modern_treasury/models/case_.rb', line 111

required :field, enum: -> { ModernTreasury::Case::RequestedAction::Field }, nil?: true

#id ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


94
# File 'lib/modern_treasury/models/case_.rb', line 94

required :id, String

#instructions ⇒ String?

Instructions on how to resolve the requested action.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


117
# File 'lib/modern_treasury/models/case_.rb', line 117

required :instructions, String, nil?: true

#live_mode ⇒ Boolean

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


124
# File 'lib/modern_treasury/models/case_.rb', line 124

required :live_mode, ModernTreasury::Internal::Type::Boolean

#object ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


129
# File 'lib/modern_treasury/models/case_.rb', line 129

required :object, String

#reasons ⇒ Array<String>

The reasons the action was requested.

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


135
# File 'lib/modern_treasury/models/case_.rb', line 135

required :reasons, ModernTreasury::Internal::Type::ArrayOf[String]

#updated_at ⇒ Time

Parameters:

  • value (Time)

Returns:

  • (Time)


140
# File 'lib/modern_treasury/models/case_.rb', line 140

required :updated_at, Time

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/case_.rb', line 177

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


108
# File 'sig/modern_treasury/models/case_.rbs', line 108

def to_hash: -> {