Class: ModernTreasury::Models::CaseListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::CaseListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/case_list_params.rb,
sig/modern_treasury/models/case_list_params.rbs
Overview
Defined Under Namespace
Modules: Status, SubjectType
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ModernTreasury
Instance Attribute Summary collapse
- #after_cursor ⇒ String?
- #per_page ⇒ Integer?
-
#status ⇒ Symbol, ...
The status of the case.
-
#subject_id ⇒ String?
The ID of the object the case is about.
-
#subject_type ⇒ Symbol, ...
The type of the object the case is about.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(after_cursor: nil, per_page: nil, status: nil, subject_id: nil, subject_type: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after_cursor: nil, per_page: nil, status: nil, subject_id: nil, subject_type: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/modern_treasury/models/case_list_params.rb', line 38
|
Instance Attribute Details
#after_cursor ⇒ String?
13 |
# File 'lib/modern_treasury/models/case_list_params.rb', line 13 optional :after_cursor, String, nil?: true |
#per_page ⇒ Integer?
18 |
# File 'lib/modern_treasury/models/case_list_params.rb', line 18 optional :per_page, Integer |
#status ⇒ Symbol, ...
The status of the case.
24 |
# File 'lib/modern_treasury/models/case_list_params.rb', line 24 optional :status, enum: -> { ModernTreasury::CaseListParams::Status } |
#subject_id ⇒ String?
The ID of the object the case is about.
30 |
# File 'lib/modern_treasury/models/case_list_params.rb', line 30 optional :subject_id, String |
#subject_type ⇒ Symbol, ...
The type of the object the case is about.
36 |
# File 'lib/modern_treasury/models/case_list_params.rb', line 36 optional :subject_type, enum: -> { ModernTreasury::CaseListParams::SubjectType } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/case_list_params.rb', line 58
|
Instance Method Details
#to_hash ⇒ {
48 |
# File 'sig/modern_treasury/models/case_list_params.rbs', line 48
def to_hash: -> {
|