Class: ModernTreasury::Models::ChildLegalEntity

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/child_legal_entity.rb,
sig/modern_treasury/models/child_legal_entity.rbs

Defined Under Namespace

Modules: BusinessDesignation, LegalEntityType, LegalStructure, RiskRating, Status Classes: Address, PhoneNumber, Regulator, TermsOfUse

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(jurisdiction:, name:, registration_number:) ⇒ Object

Some parameter documentations has been truncated, see Regulator for more details.

Parameters:

  • jurisdiction (String) —

    The country code where the regulator operates in the ISO 3166-1 alpha-2 format (

  • name (String) —

    Full name of the regulatory body.

  • registration_number (String) —

    Registration or identification number with the regulator.



# File 'lib/modern_treasury/models/child_legal_entity.rb', line 594

Instance Attribute Details

#addresses ⇒ Array<ModernTreasury::Models::ChildLegalEntity::Address>

A list of addresses for the entity.

Parameters:

  • value (::Array[ModernTreasury::ChildLegalEntity::Address])

Returns:



15
16
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 15

required :addresses,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ChildLegalEntity::Address] }

#bank_settings ⇒ ModernTreasury::Models::LegalEntityBankSettings?



21
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 21

required :bank_settings, -> { ModernTreasury::LegalEntityBankSettings }, nil?: true

#business_description ⇒ String?

A description of the business.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


27
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 27

required :business_description, String, nil?: true

#business_designation ⇒ Symbol, ...

Legal designation associated with the business.

Parameters:

  • value (ModernTreasury::Models::ChildLegalEntity::business_designation, nil)

Returns:



33
34
35
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 33

required :business_designation,
enum: -> { ModernTreasury::ChildLegalEntity::BusinessDesignation },
nil?: true

#business_name ⇒ String?

The business's legal business name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


41
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 41

required :business_name, String, nil?: true

#citizenship_country ⇒ String?

The country of citizenship for an individual.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


47
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 47

required :citizenship_country, String, nil?: true

#compliance_details ⇒ Object?

Deprecated.

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


53
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 53

required :compliance_details, ModernTreasury::Internal::Type::Unknown, nil?: true

#country_of_incorporation ⇒ String?

The country where the business is incorporated, as an ISO 3166-1 alpha-2 country code (e.g. US).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


60
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 60

required :country_of_incorporation, String, nil?: true

#created_at ⇒ Time

Parameters:

  • value (Time)

Returns:

  • (Time)


65
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 65

required :created_at, Time

#date_formed ⇒ Date?

A business's formation date (YYYY-MM-DD).

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


71
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 71

required :date_formed, Date, nil?: true

#date_of_birth ⇒ Date?

An individual's date of birth (YYYY-MM-DD).

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


77
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 77

required :date_of_birth, Date, nil?: true

#discarded_at ⇒ Time?

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


82
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 82

required :discarded_at, Time, nil?: true

#documents ⇒ Array<ModernTreasury::Models::Document>

Parameters:

Returns:



87
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 87

required :documents, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::Document] }

#doing_business_as_names ⇒ Array<String>

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


92
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 92

required :doing_business_as_names, ModernTreasury::Internal::Type::ArrayOf[String]

#email ⇒ String?

The entity's primary email.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


98
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 98

required :email, String, nil?: true

#expected_activity_volume ⇒ Integer?

Monthly expected transaction volume in USD.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


104
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 104

required :expected_activity_volume, Integer, nil?: true

#external_id ⇒ String?

An optional user-defined 180 character unique identifier.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


110
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 110

required :external_id, String, nil?: true

#first_name ⇒ String?

An individual's first name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


116
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 116

required :first_name, String, nil?: true

#id ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


9
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 9

required :id, String

#identifications ⇒ Array<ModernTreasury::Models::Identification>

A list of identifications for the legal entity.

Parameters:

Returns:



122
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 122

required :identifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::Identification] }

#industry_classifications ⇒ Array<ModernTreasury::Models::LegalEntityIndustryClassification>

A list of industry classifications for the legal entity.



128
129
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 128

required :industry_classifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityIndustryClassification] }

#intended_use ⇒ String?

A description of the intended use of the legal entity.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


135
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 135

required :intended_use, String, nil?: true

#last_name ⇒ String?

An individual's last name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


141
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 141

required :last_name, String, nil?: true

The legal entity associations and its child legal entities.

Parameters:

Returns:



147
148
149
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 147

required :legal_entity_associations,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAssociation] },
nil?: true

The type of legal entity.

Parameters:

  • value (ModernTreasury::Models::ChildLegalEntity::legal_entity_type)

Returns:



155
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 155

required :legal_entity_type, enum: -> { ModernTreasury::ChildLegalEntity::LegalEntityType }

The business's legal structure.

Parameters:

  • value (ModernTreasury::Models::ChildLegalEntity::legal_structure, nil)

Returns:



161
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 161

required :legal_structure, enum: -> { ModernTreasury::ChildLegalEntity::LegalStructure }, nil?: true

#listed_exchange ⇒ String?

ISO 10383 market identifier code.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


167
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 167

required :listed_exchange, String, nil?: true

#live_mode ⇒ Boolean

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


174
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 174

required :live_mode, ModernTreasury::Internal::Type::Boolean

#metadata ⇒ Hash{Symbol=>String}

Additional data represented as key-value pairs. Both the key and value must be strings.

Parameters:

  • value (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String})


181
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 181

required :metadata, ModernTreasury::Internal::Type::HashOf[String]

#middle_name ⇒ String?

An individual's middle name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


187
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 187

required :middle_name, String, nil?: true

#object ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


192
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 192

required :object, String

#operating_jurisdictions ⇒ Array<String>

A list of countries where the business operates, as ISO 3166-1 alpha-2 country codes (e.g. ["US", "CA"]).

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


199
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 199

required :operating_jurisdictions, ModernTreasury::Internal::Type::ArrayOf[String]

#phone_numbers ⇒ Array<ModernTreasury::Models::ChildLegalEntity::PhoneNumber>

Parameters:

  • value (::Array[ModernTreasury::ChildLegalEntity::PhoneNumber])

Returns:



204
205
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 204

required :phone_numbers,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ChildLegalEntity::PhoneNumber] }

#politically_exposed_person ⇒ Boolean?

Whether the individual is a politically exposed person.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


211
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 211

required :politically_exposed_person, ModernTreasury::Internal::Type::Boolean, nil?: true

#preferred_name ⇒ String?

An individual's preferred name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


217
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 217

required :preferred_name, String, nil?: true

#prefix ⇒ String?

An individual's prefix.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


223
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 223

required :prefix, String, nil?: true

#primary_social_media_sites ⇒ Array<String>

A list of the entity's primary social media URLs.

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


229
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 229

required :primary_social_media_sites, ModernTreasury::Internal::Type::ArrayOf[String]

#regulators ⇒ Array<ModernTreasury::Models::ChildLegalEntity::Regulator>?

Array of regulatory bodies overseeing this institution.

Parameters:

  • value (::Array[ModernTreasury::ChildLegalEntity::Regulator], nil)

Returns:



235
236
237
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 235

required :regulators,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ChildLegalEntity::Regulator] },
nil?: true

#risk_rating ⇒ Symbol, ...

The risk rating of the legal entity. One of low, medium, high.

Parameters:

  • value (ModernTreasury::Models::ChildLegalEntity::risk_rating, nil)

Returns:



243
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 243

required :risk_rating, enum: -> { ModernTreasury::ChildLegalEntity::RiskRating }, nil?: true

The UUID of the parent legal entity in the service provider tree.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


249
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 249

required :service_provider_legal_entity_id, String, nil?: true

#status ⇒ Symbol, ...

The activation status of the legal entity. One of pending, active, suspended, or denied.

Parameters:

  • value (ModernTreasury::Models::ChildLegalEntity::status, nil)

Returns:



256
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 256

required :status, enum: -> { ModernTreasury::ChildLegalEntity::Status }, nil?: true

#suffix ⇒ String?

An individual's suffix.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


262
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 262

required :suffix, String, nil?: true

#terms_of_use ⇒ ModernTreasury::Models::ChildLegalEntity::TermsOfUse?

Acceptance of terms of use by the legal entity.

Parameters:

  • value (ModernTreasury::ChildLegalEntity::TermsOfUse, nil)

Returns:



268
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 268

required :terms_of_use, -> { ModernTreasury::ChildLegalEntity::TermsOfUse }, nil?: true

#third_party_verification ⇒ ModernTreasury::Models::ThirdPartyVerification?

Deprecated.

Deprecated. Use third_party_verifications instead.



276
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 276

required :third_party_verification, -> { ModernTreasury::ThirdPartyVerification }, nil?: true

#third_party_verifications ⇒ Array<ModernTreasury::Models::ThirdPartyVerification>

A list of third-party verifications run by external vendors.



282
283
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 282

required :third_party_verifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ThirdPartyVerification] }

#ticker_symbol ⇒ String?

Stock ticker symbol for publicly traded companies.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


289
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 289

required :ticker_symbol, String, nil?: true

#updated_at ⇒ Time

Parameters:

  • value (Time)

Returns:

  • (Time)


294
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 294

required :updated_at, Time

#wealth_and_employment_details ⇒ ModernTreasury::Models::LegalEntityWealthEmploymentDetail?



299
300
301
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 299

required :wealth_and_employment_details,
-> { ModernTreasury::LegalEntityWealthEmploymentDetail },
nil?: true

#website ⇒ String?

The entity's primary website URL.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


307
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 307

required :website, String, nil?: true

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/child_legal_entity.rb', line 537

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


207
# File 'sig/modern_treasury/models/child_legal_entity.rbs', line 207

def to_hash: -> {