Class: ModernTreasury::Models::ChildLegalEntity::Identification

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/child_legal_entity.rb,
sig/modern_treasury/models/child_legal_entity.rbs

Defined Under Namespace

Modules: IDType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, discarded_at:, documents:, expiration_date:, id_type:, issuing_country:, issuing_region:, live_mode:, object:, updated_at:) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::ChildLegalEntity::Identification for more details.

Parameters:

  • id (String)
  • created_at (Time)
  • discarded_at (Time, nil)
  • documents (Array<ModernTreasury::Models::Document>)
  • expiration_date (Date, nil)

    The date when the Identification is no longer considered valid by the issuing au

  • id_type (Symbol, ModernTreasury::Models::ChildLegalEntity::Identification::IDType)

    The type of ID number.

  • issuing_country (String, nil)

    The ISO 3166-1 alpha-2 country code of the country that issued the identificatio

  • issuing_region (String, nil)

    The region in which the identifcation was issued.

  • live_mode (Boolean)

    This field will be true if this object exists in the live environment or false i

  • object (String)
  • updated_at (Time)


# File 'lib/modern_treasury/models/child_legal_entity.rb', line 595

Instance Attribute Details

#created_atTime

Parameters:

  • value (Time)

Returns:

  • (Time)


540
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 540

required :created_at, Time

#discarded_atTime?

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


545
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 545

required :discarded_at, Time, nil?: true

#documentsArray<ModernTreasury::Models::Document>

Parameters:

Returns:



550
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 550

required :documents, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::Document] }

#expiration_dateDate?

The date when the Identification is no longer considered valid by the issuing authority.

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


557
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 557

required :expiration_date, Date, nil?: true

#idString

Parameters:

  • value (String)

Returns:

  • (String)


535
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 535

required :id, String

#id_typeSymbol, ModernTreasury::Models::ChildLegalEntity::Identification::IDType

The type of ID number.

Parameters:

  • value (ModernTreasury::Models::ChildLegalEntity::Identification::id_type)

Returns:



563
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 563

required :id_type, enum: -> { ModernTreasury::ChildLegalEntity::Identification::IDType }

#issuing_countryString?

The ISO 3166-1 alpha-2 country code of the country that issued the identification

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


570
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 570

required :issuing_country, String, nil?: true

#issuing_regionString?

The region in which the identifcation was issued.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


576
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 576

required :issuing_region, String, nil?: true

#live_modeBoolean

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


583
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 583

required :live_mode, ModernTreasury::Internal::Type::Boolean

#objectString

Parameters:

  • value (String)

Returns:

  • (String)


588
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 588

required :object, String

#updated_atTime

Parameters:

  • value (Time)

Returns:

  • (Time)


593
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 593

required :updated_at, Time

Instance Method Details

#to_hash{

Returns:

  • ({)


411
# File 'sig/modern_treasury/models/child_legal_entity.rbs', line 411

def to_hash: -> {