Class: ModernTreasury::Models::ChildLegalEntity::TermsOfUse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::ChildLegalEntity::TermsOfUse
- Defined in:
- lib/modern_treasury/models/child_legal_entity.rb,
sig/modern_treasury/models/child_legal_entity.rbs
Overview
Instance Attribute Summary collapse
-
#accepted_at ⇒ Time?
The ISO 8601 timestamp indicating when the terms of use were accepted.
-
#ip_address ⇒ String?
The IP address from which the terms of use were accepted.
Instance Method Summary collapse
-
#initialize(accepted_at: nil, ip_address: nil) ⇒ TermsOfUse
constructor
Some parameter documentations has been truncated, see TermsOfUse for more details.
- #to_hash ⇒ { accepted_at: Time, ip_address: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(accepted_at: nil, ip_address: nil) ⇒ TermsOfUse
Some parameter documentations has been truncated, see ModernTreasury::Models::ChildLegalEntity::TermsOfUse for more details.
Acceptance of terms of use by the legal entity.
|
|
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 850
|
Instance Attribute Details
#accepted_at ⇒ Time?
The ISO 8601 timestamp indicating when the terms of use were accepted.
841 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 841 optional :accepted_at, Time |
#ip_address ⇒ String?
The IP address from which the terms of use were accepted. Supports both IPv4 and IPv6 formats.
848 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 848 optional :ip_address, String |
Instance Method Details
#to_hash ⇒ { accepted_at: Time, ip_address: String }
738 |
# File 'sig/modern_treasury/models/child_legal_entity.rbs', line 738
def to_hash: -> { accepted_at: Time, ip_address: String }
|