Class: ModernTreasury::Models::ChildLegalEntityCreate

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/child_legal_entity_create.rb,
sig/modern_treasury/models/child_legal_entity_create.rbs

Defined Under Namespace

Modules: BusinessDesignation, LegalEntityType, LegalStructure, RiskRating Classes: Document, PhoneNumber, Regulator, TermsOfUse

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(jurisdiction:, name:, registration_number:) ⇒ Object

Some parameter documentations has been truncated, see Regulator for more details.

Parameters:

  • jurisdiction (String) —

    The country code where the regulator operates in the ISO 3166-1 alpha-2 format (

  • name (String) —

    Full name of the regulatory body.

  • registration_number (String) —

    Registration or identification number with the regulator.



# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 292

Instance Attribute Details

#addresses ⇒ Array<ModernTreasury::Models::LegalEntityAddressCreateRequest>?

A list of addresses for the entity.



10
11
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 10

optional :addresses,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAddressCreateRequest] }

#bank_settings ⇒ ModernTreasury::Models::LegalEntityBankSettings?



16
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 16

optional :bank_settings, -> { ModernTreasury::LegalEntityBankSettings }, nil?: true

#business_description ⇒ String?

A description of the business.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


22
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 22

optional :business_description, String, nil?: true

#business_designation ⇒ Symbol, ...

Legal designation associated with the business.

Parameters:

  • value (ModernTreasury::Models::ChildLegalEntityCreate::business_designation, nil)

Returns:



28
29
30
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 28

optional :business_designation,
enum: -> { ModernTreasury::ChildLegalEntityCreate::BusinessDesignation },
nil?: true

#business_name ⇒ String?

The business's legal business name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


36
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 36

optional :business_name, String, nil?: true

#citizenship_country ⇒ String?

The country of citizenship for an individual.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


42
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 42

optional :citizenship_country, String, nil?: true

#compliance_details ⇒ Object?

Deprecated.

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


48
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 48

optional :compliance_details, ModernTreasury::Internal::Type::Unknown, nil?: true

#connection_id ⇒ String?

The connection ID for the connection the legal entity is associated with. Defaults to the id of the connection designated with an is_default value of true or the id of an existing operational connection if only one is available. Pass in a value of null to prevent the connection from being associated with the legal entity.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


58
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 58

optional :connection_id, String, nil?: true

#country_of_incorporation ⇒ String?

The country where the business is incorporated, as an ISO 3166-1 alpha-2 country code (e.g. US).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


65
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 65

optional :country_of_incorporation, String, nil?: true

#date_formed ⇒ Date?

A business's formation date (YYYY-MM-DD).

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


71
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 71

optional :date_formed, Date, nil?: true

#date_of_birth ⇒ Date?

An individual's date of birth (YYYY-MM-DD).

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


77
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 77

optional :date_of_birth, Date, nil?: true

#documents ⇒ Array<ModernTreasury::Models::ChildLegalEntityCreate::Document>?

A list of documents to attach to the legal entity (e.g. articles of incorporation, certificate of good standing, proof of address).



84
85
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 84

optional :documents,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ChildLegalEntityCreate::Document] }

#doing_business_as_names ⇒ Array<String>?

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


90
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 90

optional :doing_business_as_names, ModernTreasury::Internal::Type::ArrayOf[String]

#email ⇒ String?

The entity's primary email.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


96
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 96

optional :email, String, nil?: true

#expected_activity_volume ⇒ Integer?

Monthly expected transaction volume in USD.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


102
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 102

optional :expected_activity_volume, Integer, nil?: true

#external_id ⇒ String?

An optional user-defined 180 character unique identifier.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


108
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 108

optional :external_id, String, nil?: true

#first_name ⇒ String?

An individual's first name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


114
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 114

optional :first_name, String, nil?: true

#identifications ⇒ Array<ModernTreasury::Models::IdentificationCreateRequest>?

A list of identifications for the legal entity.



120
121
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 120

optional :identifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::IdentificationCreateRequest] }

#industry_classifications ⇒ Array<ModernTreasury::Models::LegalEntityIndustryClassification>?

A list of industry classifications for the legal entity.



127
128
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 127

optional :industry_classifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityIndustryClassification] }

#intended_use ⇒ String?

A description of the intended use of the legal entity.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


134
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 134

optional :intended_use, String, nil?: true

#last_name ⇒ String?

An individual's last name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


140
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 140

optional :last_name, String, nil?: true

The legal entity associations and its child legal entities.



146
147
148
149
150
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 146

optional :legal_entity_associations,
-> {
  ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAssociationInlineCreate]
},
nil?: true

The type of legal entity.



156
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 156

optional :legal_entity_type, enum: -> { ModernTreasury::ChildLegalEntityCreate::LegalEntityType }

The business's legal structure.

Parameters:

  • value (ModernTreasury::Models::ChildLegalEntityCreate::legal_structure, nil)

Returns:



162
163
164
165
166
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 162

optional :legal_structure,
enum: -> {
  ModernTreasury::ChildLegalEntityCreate::LegalStructure
},
nil?: true

#listed_exchange ⇒ String?

ISO 10383 market identifier code.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


172
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 172

optional :listed_exchange, String, nil?: true

#metadata ⇒ Hash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


179
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 179

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#middle_name ⇒ String?

An individual's middle name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


185
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 185

optional :middle_name, String, nil?: true

#operating_jurisdictions ⇒ Array<String>?

A list of countries where the business operates, as ISO 3166-1 alpha-2 country codes (e.g. ["US", "CA"]).

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


192
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 192

optional :operating_jurisdictions, ModernTreasury::Internal::Type::ArrayOf[String]

#phone_numbers ⇒ Array<ModernTreasury::Models::ChildLegalEntityCreate::PhoneNumber>?



197
198
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 197

optional :phone_numbers,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ChildLegalEntityCreate::PhoneNumber] }

#politically_exposed_person ⇒ Boolean?

Whether the individual is a politically exposed person.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


204
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 204

optional :politically_exposed_person, ModernTreasury::Internal::Type::Boolean, nil?: true

#preferred_name ⇒ String?

An individual's preferred name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


210
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 210

optional :preferred_name, String, nil?: true

#prefix ⇒ String?

An individual's prefix.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


216
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 216

optional :prefix, String, nil?: true

#primary_social_media_sites ⇒ Array<String>?

A list of the entity's primary social media URLs.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


222
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 222

optional :primary_social_media_sites, ModernTreasury::Internal::Type::ArrayOf[String]

#regulators ⇒ Array<ModernTreasury::Models::ChildLegalEntityCreate::Regulator>?

Array of regulatory bodies overseeing this institution.

Parameters:

  • value (::Array[ModernTreasury::ChildLegalEntityCreate::Regulator], nil)

Returns:



228
229
230
231
232
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 228

optional :regulators,
-> {
  ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ChildLegalEntityCreate::Regulator]
},
nil?: true

#risk_rating ⇒ Symbol, ...

The risk rating of the legal entity. One of low, medium, high.

Parameters:

  • value (ModernTreasury::Models::ChildLegalEntityCreate::risk_rating, nil)

Returns:



238
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 238

optional :risk_rating, enum: -> { ModernTreasury::ChildLegalEntityCreate::RiskRating }, nil?: true

The UUID of the parent legal entity in the service provider tree.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


244
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 244

optional :service_provider_legal_entity_id, String, nil?: true

#suffix ⇒ String?

An individual's suffix.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


250
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 250

optional :suffix, String, nil?: true

#terms_of_use ⇒ ModernTreasury::Models::ChildLegalEntityCreate::TermsOfUse?

Acceptance of terms of use by the legal entity.

Parameters:

  • value (ModernTreasury::ChildLegalEntityCreate::TermsOfUse, nil)

Returns:



256
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 256

optional :terms_of_use, -> { ModernTreasury::ChildLegalEntityCreate::TermsOfUse }, nil?: true

#third_party_verification ⇒ ModernTreasury::Models::ThirdPartyVerification?

Deprecated.

Deprecated. Use third_party_verifications instead.



264
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 264

optional :third_party_verification, -> { ModernTreasury::ThirdPartyVerification }, nil?: true

#third_party_verifications ⇒ Array<ModernTreasury::Models::ThirdPartyVerification>?

A list of third-party verifications run by external vendors.



270
271
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 270

optional :third_party_verifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ThirdPartyVerification] }

#ticker_symbol ⇒ String?

Stock ticker symbol for publicly traded companies.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


277
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 277

optional :ticker_symbol, String, nil?: true

#wealth_and_employment_details ⇒ ModernTreasury::Models::LegalEntityWealthEmploymentDetail?



282
283
284
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 282

optional :wealth_and_employment_details,
-> { ModernTreasury::LegalEntityWealthEmploymentDetail },
nil?: true

#website ⇒ String?

The entity's primary website URL.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


290
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 290

optional :website, String, nil?: true

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 391

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


219
# File 'sig/modern_treasury/models/child_legal_entity_create.rbs', line 219

def to_hash: -> {