Class: ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::Document

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/connection_legal_entity_create_params.rb,
sig/modern_treasury/models/connection_legal_entity_create_params.rbs

Defined Under Namespace

Modules: DocumentType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(document_type:, file_data:, filename: nil) ⇒ Object

Parameters:



410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 410

class Document < ModernTreasury::Internal::Type::BaseModel
  # @!attribute document_type
  #   A category given to the document, can be `null`.
  #
  #   @return [Symbol, ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::Document::DocumentType]
  required :document_type,
           enum: -> { ModernTreasury::ConnectionLegalEntityCreateParams::LegalEntity::Document::DocumentType }

  # @!attribute file_data
  #   Base64-encoded file content for the document.
  #
  #   @return [String]
  required :file_data, String

  # @!attribute filename
  #   The original filename of the document.
  #
  #   @return [String, nil]
  optional :filename, String

  # @!method initialize(document_type:, file_data:, filename: nil)
  #   @param document_type [Symbol, ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::Document::DocumentType] A category given to the document, can be `null`.
  #
  #   @param file_data [String] Base64-encoded file content for the document.
  #
  #   @param filename [String] The original filename of the document.

  # A category given to the document, can be `null`.
  #
  # @see ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::Document#document_type
  module DocumentType
    extend ModernTreasury::Internal::Type::Enum

    ARTICLES_OF_INCORPORATION = :articles_of_incorporation
    CERTIFICATE_OF_GOOD_STANDING = :certificate_of_good_standing
    EIN_LETTER = :ein_letter
    GENERIC = :generic
    IDENTIFICATION_BACK = :identification_back
    IDENTIFICATION_FRONT = :identification_front
    PROOF_OF_ADDRESS = :proof_of_address

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#document_typeSymbol, ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::Document::DocumentType

A category given to the document, can be null.

Parameters:

  • value (ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::Document::document_type)

Returns:



415
416
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 415

required :document_type,
enum: -> { ModernTreasury::ConnectionLegalEntityCreateParams::LegalEntity::Document::DocumentType }

#file_dataString

Base64-encoded file content for the document.

Parameters:

  • value (String)

Returns:

  • (String)


422
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 422

required :file_data, String

#filenameString?

The original filename of the document.

Parameters:

  • (String)

Returns:

  • (String, nil)


428
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 428

optional :filename, String

Instance Method Details

#to_hash{

Returns:

  • ({)


320
# File 'sig/modern_treasury/models/connection_legal_entity_create_params.rbs', line 320

def to_hash: -> {