Class: ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::Regulator
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::Regulator
- Defined in:
- lib/modern_treasury/models/connection_legal_entity_create_params.rb
Instance Attribute Summary collapse
-
#jurisdiction ⇒ String
The country code where the regulator operates in the ISO 3166-1 alpha-2 format (e.g., “US”, “CA”, “GB”).
-
#name ⇒ String
Full name of the regulatory body.
-
#registration_number ⇒ String
Registration or identification number with the regulator.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from ModernTreasury::Internal::Type::BaseModel
Instance Attribute Details
#jurisdiction ⇒ String
The country code where the regulator operates in the ISO 3166-1 alpha-2 format (e.g., “US”, “CA”, “GB”).
494 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 494 required :jurisdiction, String |
#name ⇒ String
Full name of the regulatory body.
500 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 500 required :name, String |
#registration_number ⇒ String
Registration or identification number with the regulator.
506 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 506 required :registration_number, String |