Class: ModernTreasury::Models::ConnectionListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::ConnectionListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/connection_list_params.rb,
sig/modern_treasury/models/connection_list_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ModernTreasury
Instance Attribute Summary collapse
- #after_cursor ⇒ String?
-
#entity ⇒ String?
A string code representing the vendor (i.e. bank).
- #per_page ⇒ Integer?
-
#vendor_customer_id ⇒ String?
An identifier assigned by the vendor to your organization.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(after_cursor: nil, entity: nil, per_page: nil, vendor_customer_id: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after_cursor: nil, entity: nil, per_page: nil, vendor_customer_id: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/modern_treasury/models/connection_list_params.rb', line 32
|
Instance Attribute Details
#after_cursor ⇒ String?
13 |
# File 'lib/modern_treasury/models/connection_list_params.rb', line 13 optional :after_cursor, String, nil?: true |
#entity ⇒ String?
A string code representing the vendor (i.e. bank).
19 |
# File 'lib/modern_treasury/models/connection_list_params.rb', line 19 optional :entity, String |
#per_page ⇒ Integer?
24 |
# File 'lib/modern_treasury/models/connection_list_params.rb', line 24 optional :per_page, Integer |
#vendor_customer_id ⇒ String?
An identifier assigned by the vendor to your organization.
30 |
# File 'lib/modern_treasury/models/connection_list_params.rb', line 30 optional :vendor_customer_id, String |
Instance Method Details
#to_hash ⇒ {
38 |
# File 'sig/modern_treasury/models/connection_list_params.rbs', line 38
def to_hash: -> {
|