Class: ModernTreasury::Models::CounterpartyCollectAccountParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/modern_treasury/models/counterparty_collect_account_params.rb,
sig/modern_treasury/models/counterparty_collect_account_params.rbs

Overview

See Also:

  • ModernTreasury::Resources::Counterparties#collect_account

Defined Under Namespace

Modules: Field

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::ModernTreasury

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



35
# File 'sig/modern_treasury/models/counterparty_collect_account_params.rbs', line 35

def initialize: (

Instance Attribute Details

#custom_redirectString?

The URL you want your customer to visit upon filling out the form. By default, they will be sent to a Modern Treasury landing page. This must be a valid HTTPS URL if set.

Parameters:

  • (String)

Returns:

  • (String, nil)


29
# File 'lib/modern_treasury/models/counterparty_collect_account_params.rb', line 29

optional :custom_redirect, String

#directionSymbol, ModernTreasury::Models::TransactionDirection

One of credit or debit. Use credit when you want to pay a counterparty. Use debit when you need to charge a counterparty. This field helps us send a more tailored email to your counterparties."

Parameters:

  • value (ModernTreasury::Models::transaction_direction)

Returns:



21
# File 'lib/modern_treasury/models/counterparty_collect_account_params.rb', line 21

required :direction, enum: -> { ModernTreasury::TransactionDirection }

#fieldsArray<Symbol, ModernTreasury::Models::CounterpartyCollectAccountParams::Field>?

The list of fields you want on the form. This field is optional and if it is not set, will default to ["nameOnAccount", "accountType", "accountNumber", "routingNumber", "address"]. The full list of options is ["name", "nameOnAccount", "taxpayerIdentifier", "accountType", "accountNumber", "routingNumber", "address", "ibanNumber", "swiftCode"].



39
40
# File 'lib/modern_treasury/models/counterparty_collect_account_params.rb', line 39

optional :fields,
-> { ModernTreasury::Internal::Type::ArrayOf[enum: ModernTreasury::CounterpartyCollectAccountParams::Field] }

#idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/modern_treasury/models/counterparty_collect_account_params.rb', line 13

required :id, String

#send_emailBoolean?

By default, Modern Treasury will send an email to your counterparty that includes a link to the form they must fill out. However, if you would like to send the counterparty the link, you can set this parameter to false. The JSON body will include the link to the secure Modern Treasury form.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


49
# File 'lib/modern_treasury/models/counterparty_collect_account_params.rb', line 49

optional :send_email, ModernTreasury::Internal::Type::Boolean

Instance Method Details

#to_hash{

Returns:

  • ({)


44
# File 'sig/modern_treasury/models/counterparty_collect_account_params.rbs', line 44

def to_hash: -> {