Class: ModernTreasury::Models::CounterpartyCollectAccountResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::CounterpartyCollectAccountResponse
- Defined in:
- lib/modern_treasury/models/counterparty_collect_account_response.rb,
sig/modern_treasury/models/counterparty_collect_account_response.rbs
Overview
Instance Attribute Summary collapse
-
#form_link ⇒ String
This is the link to the secure Modern Treasury form.
-
#id ⇒ String
The id of the existing counterparty.
-
#is_resend ⇒ Boolean
This field will be
trueif an email requesting account details has already been sent to this counterparty.
Instance Method Summary collapse
-
#initialize(id:, form_link:, is_resend:) ⇒ CounterpartyCollectAccountResponse
constructor
Some parameter documentations has been truncated, see CounterpartyCollectAccountResponse for more details.
- #to_hash ⇒ { id: String, form_link: String, is_resend: bool }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, form_link:, is_resend:) ⇒ CounterpartyCollectAccountResponse
Some parameter documentations has been truncated, see ModernTreasury::Models::CounterpartyCollectAccountResponse for more details.
|
|
# File 'lib/modern_treasury/models/counterparty_collect_account_response.rb', line 29
|
Instance Attribute Details
#form_link ⇒ String
This is the link to the secure Modern Treasury form. By default, Modern Treasury
will send an email to your counterparty that includes a link to this form.
However, if send_email is passed as false in the body then Modern Treasury
will not send the email and you can send it to the counterparty directly.
20 |
# File 'lib/modern_treasury/models/counterparty_collect_account_response.rb', line 20 required :form_link, String |
#id ⇒ String
The id of the existing counterparty.
11 |
# File 'lib/modern_treasury/models/counterparty_collect_account_response.rb', line 11 required :id, String |
#is_resend ⇒ Boolean
This field will be true if an email requesting account details has already
been sent to this counterparty.
27 |
# File 'lib/modern_treasury/models/counterparty_collect_account_response.rb', line 27 required :is_resend, ModernTreasury::Internal::Type::Boolean |
Instance Method Details
#to_hash ⇒ { id: String, form_link: String, is_resend: bool }
15 |
# File 'sig/modern_treasury/models/counterparty_collect_account_response.rbs', line 15
def to_hash: -> { id: String, form_link: String, is_resend: bool }
|