Class: ModernTreasury::Models::CounterpartyCreateParams::LegalEntity

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/counterparty_create_params.rb,
sig/modern_treasury/models/counterparty_create_params.rbs

Defined Under Namespace

Modules: BusinessDesignation, LegalEntityType, LegalStructure, RiskRating Classes: Document, PhoneNumber, Regulator, TermsOfUse

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(jurisdiction:, name:, registration_number:) ⇒ Object

Some parameter documentations has been truncated, see Regulator for more details.

Parameters:

  • jurisdiction (String) —

    The country code where the regulator operates in the ISO 3166-1 alpha-2 format (

  • name (String) —

    Full name of the regulatory body.

  • registration_number (String) —

    Registration or identification number with the regulator.



# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 712

Instance Attribute Details

#addresses ⇒ Array<ModernTreasury::Models::LegalEntityAddressCreateRequest>?

A list of addresses for the entity.



434
435
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 434

optional :addresses,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAddressCreateRequest] }

#bank_settings ⇒ ModernTreasury::Models::LegalEntityBankSettings?



440
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 440

optional :bank_settings, -> { ModernTreasury::LegalEntityBankSettings }, nil?: true

#business_description ⇒ String?

A description of the business.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


446
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 446

optional :business_description, String, nil?: true

#business_designation ⇒ Symbol, ...

Legal designation associated with the business.

Parameters:

  • value (ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::business_designation, nil)

Returns:



452
453
454
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 452

optional :business_designation,
enum: -> { ModernTreasury::CounterpartyCreateParams::LegalEntity::BusinessDesignation },
nil?: true

#business_name ⇒ String?

The business's legal business name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


460
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 460

optional :business_name, String, nil?: true

#citizenship_country ⇒ String?

The country of citizenship for an individual.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


466
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 466

optional :citizenship_country, String, nil?: true

#compliance_details ⇒ Object?

Deprecated.

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


472
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 472

optional :compliance_details, ModernTreasury::Internal::Type::Unknown, nil?: true

#connection_id ⇒ String?

The connection ID for the connection the legal entity is associated with. Defaults to the id of the connection designated with an is_default value of true or the id of an existing operational connection if only one is available. Pass in a value of null to prevent the connection from being associated with the legal entity.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


482
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 482

optional :connection_id, String, nil?: true

#country_of_incorporation ⇒ String?

The country where the business is incorporated, as an ISO 3166-1 alpha-2 country code (e.g. US).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


489
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 489

optional :country_of_incorporation, String, nil?: true

#date_formed ⇒ Date?

A business's formation date (YYYY-MM-DD).

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


495
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 495

optional :date_formed, Date, nil?: true

#date_of_birth ⇒ Date?

An individual's date of birth (YYYY-MM-DD).

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


501
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 501

optional :date_of_birth, Date, nil?: true

#documents ⇒ Array<ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::Document>?

A list of documents to attach to the legal entity (e.g. articles of incorporation, certificate of good standing, proof of address).



508
509
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 508

optional :documents,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::CounterpartyCreateParams::LegalEntity::Document] }

#doing_business_as_names ⇒ Array<String>?

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


514
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 514

optional :doing_business_as_names, ModernTreasury::Internal::Type::ArrayOf[String]

#email ⇒ String?

The entity's primary email.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


520
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 520

optional :email, String, nil?: true

#expected_activity_volume ⇒ Integer?

Monthly expected transaction volume in USD.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


526
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 526

optional :expected_activity_volume, Integer, nil?: true

#external_id ⇒ String?

An optional user-defined 180 character unique identifier.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


532
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 532

optional :external_id, String, nil?: true

#first_name ⇒ String?

An individual's first name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


538
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 538

optional :first_name, String, nil?: true

#identifications ⇒ Array<ModernTreasury::Models::IdentificationCreateRequest>?

A list of identifications for the legal entity.



544
545
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 544

optional :identifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::IdentificationCreateRequest] }

#industry_classifications ⇒ Array<ModernTreasury::Models::LegalEntityIndustryClassification>?

A list of industry classifications for the legal entity.



551
552
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 551

optional :industry_classifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityIndustryClassification] }

#intended_use ⇒ String?

A description of the intended use of the legal entity.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


558
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 558

optional :intended_use, String, nil?: true

#last_name ⇒ String?

An individual's last name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


564
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 564

optional :last_name, String, nil?: true

The legal entity associations and its child legal entities.



570
571
572
573
574
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 570

optional :legal_entity_associations,
-> {
  ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAssociationInlineCreate]
},
nil?: true

The type of legal entity.

Parameters:

  • value (ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::legal_entity_type)

Returns:



427
428
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 427

required :legal_entity_type,
enum: -> { ModernTreasury::CounterpartyCreateParams::LegalEntity::LegalEntityType }

The business's legal structure.

Parameters:

  • value (ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::legal_structure, nil)

Returns:



580
581
582
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 580

optional :legal_structure,
enum: -> { ModernTreasury::CounterpartyCreateParams::LegalEntity::LegalStructure },
nil?: true

#listed_exchange ⇒ String?

ISO 10383 market identifier code.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


588
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 588

optional :listed_exchange, String, nil?: true

#metadata ⇒ Hash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


595
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 595

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#middle_name ⇒ String?

An individual's middle name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


601
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 601

optional :middle_name, String, nil?: true

#operating_jurisdictions ⇒ Array<String>?

A list of countries where the business operates, as ISO 3166-1 alpha-2 country codes (e.g. ["US", "CA"]).

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


608
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 608

optional :operating_jurisdictions, ModernTreasury::Internal::Type::ArrayOf[String]

#phone_numbers ⇒ Array<ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::PhoneNumber>?



613
614
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 613

optional :phone_numbers,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::CounterpartyCreateParams::LegalEntity::PhoneNumber] }

#politically_exposed_person ⇒ Boolean?

Whether the individual is a politically exposed person.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


620
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 620

optional :politically_exposed_person, ModernTreasury::Internal::Type::Boolean, nil?: true

#preferred_name ⇒ String?

An individual's preferred name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


626
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 626

optional :preferred_name, String, nil?: true

#prefix ⇒ String?

An individual's prefix.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


632
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 632

optional :prefix, String, nil?: true

#primary_social_media_sites ⇒ Array<String>?

A list of the entity's primary social media URLs.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


638
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 638

optional :primary_social_media_sites, ModernTreasury::Internal::Type::ArrayOf[String]

#regulators ⇒ Array<ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::Regulator>?

Array of regulatory bodies overseeing this institution.

Parameters:

  • value (::Array[ModernTreasury::CounterpartyCreateParams::LegalEntity::Regulator], nil)

Returns:



644
645
646
647
648
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 644

optional :regulators,
-> {
  ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::CounterpartyCreateParams::LegalEntity::Regulator]
},
nil?: true

#risk_rating ⇒ Symbol, ...

The risk rating of the legal entity. One of low, medium, high.

Parameters:

  • value (ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::risk_rating, nil)

Returns:



654
655
656
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 654

optional :risk_rating,
enum: -> { ModernTreasury::CounterpartyCreateParams::LegalEntity::RiskRating },
nil?: true

The UUID of the parent legal entity in the service provider tree.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


662
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 662

optional :service_provider_legal_entity_id, String, nil?: true

#suffix ⇒ String?

An individual's suffix.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


668
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 668

optional :suffix, String, nil?: true

#terms_of_use ⇒ ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::TermsOfUse?

Acceptance of terms of use by the legal entity.

Parameters:

  • value (ModernTreasury::CounterpartyCreateParams::LegalEntity::TermsOfUse, nil)

Returns:



674
675
676
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 674

optional :terms_of_use,
-> { ModernTreasury::CounterpartyCreateParams::LegalEntity::TermsOfUse },
nil?: true

#third_party_verification ⇒ ModernTreasury::Models::ThirdPartyVerification?

Deprecated.

Deprecated. Use third_party_verifications instead.



684
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 684

optional :third_party_verification, -> { ModernTreasury::ThirdPartyVerification }, nil?: true

#third_party_verifications ⇒ Array<ModernTreasury::Models::ThirdPartyVerification>?

A list of third-party verifications run by external vendors.



690
691
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 690

optional :third_party_verifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ThirdPartyVerification] }

#ticker_symbol ⇒ String?

Stock ticker symbol for publicly traded companies.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


697
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 697

optional :ticker_symbol, String, nil?: true

#wealth_and_employment_details ⇒ ModernTreasury::Models::LegalEntityWealthEmploymentDetail?



702
703
704
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 702

optional :wealth_and_employment_details,
-> { ModernTreasury::LegalEntityWealthEmploymentDetail },
nil?: true

#website ⇒ String?

The entity's primary website URL.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


710
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 710

optional :website, String, nil?: true

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 812

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


683
# File 'sig/modern_treasury/models/counterparty_create_params.rbs', line 683

def to_hash: -> {