Class: ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::Document
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::Document
- Defined in:
- lib/modern_treasury/models/counterparty_create_params.rb
Defined Under Namespace
Modules: DocumentType
Instance Attribute Summary collapse
-
#document_type ⇒ Symbol, ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::Document::DocumentType
A category given to the document, can be ‘null`.
-
#file_data ⇒ String
Base64-encoded file content for the document.
-
#filename ⇒ String?
The original filename of the document.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(document_type:, file_data:, filename: nil) ⇒ Object
|
|
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 825
|
Instance Attribute Details
#document_type ⇒ Symbol, ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::Document::DocumentType
A category given to the document, can be ‘null`.
810 811 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 810 required :document_type, enum: -> { ModernTreasury::CounterpartyCreateParams::LegalEntity::Document::DocumentType } |
#file_data ⇒ String
Base64-encoded file content for the document.
817 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 817 required :file_data, String |
#filename ⇒ String?
The original filename of the document.
823 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 823 optional :filename, String |