Class: ModernTreasury::Models::CounterpartyUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::CounterpartyUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/counterparty_update_params.rb
Overview
Instance Attribute Summary collapse
-
#email ⇒ String?
A new email for the counterparty.
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
- #id ⇒ String
-
#legal_entity_id ⇒ String?
The id of the legal entity.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data in the form of key-value pairs.
-
#name ⇒ String?
A new name for the counterparty.
-
#send_remittance_advice ⇒ Boolean?
If this is ‘true`, Modern Treasury will send an email to the counterparty whenever an associated payment order is sent to the bank.
-
#taxpayer_identifier ⇒ String?
Either a valid SSN or EIN.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, email: nil, external_id: nil, legal_entity_id: nil, metadata: nil, name: nil, send_remittance_advice: nil, taxpayer_identifier: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CounterpartyUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, email: nil, external_id: nil, legal_entity_id: nil, metadata: nil, name: nil, send_remittance_advice: nil, taxpayer_identifier: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::CounterpartyUpdateParams for more details.
|
|
# File 'lib/modern_treasury/models/counterparty_update_params.rb', line 59
|
Instance Attribute Details
#email ⇒ String?
A new email for the counterparty.
19 |
# File 'lib/modern_treasury/models/counterparty_update_params.rb', line 19 optional :email, String |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
25 |
# File 'lib/modern_treasury/models/counterparty_update_params.rb', line 25 optional :external_id, String, nil?: true |
#id ⇒ String
13 |
# File 'lib/modern_treasury/models/counterparty_update_params.rb', line 13 required :id, String |
#legal_entity_id ⇒ String?
The id of the legal entity.
31 |
# File 'lib/modern_treasury/models/counterparty_update_params.rb', line 31 optional :legal_entity_id, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String}?
Additional data in the form of key-value pairs. Pairs can be removed by passing an empty string or ‘null` as the value.
38 |
# File 'lib/modern_treasury/models/counterparty_update_params.rb', line 38 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#name ⇒ String?
A new name for the counterparty. Will only update if passed.
44 |
# File 'lib/modern_treasury/models/counterparty_update_params.rb', line 44 optional :name, String |
#send_remittance_advice ⇒ Boolean?
If this is ‘true`, Modern Treasury will send an email to the counterparty whenever an associated payment order is sent to the bank.
51 |
# File 'lib/modern_treasury/models/counterparty_update_params.rb', line 51 optional :send_remittance_advice, ModernTreasury::Internal::Type::Boolean |
#taxpayer_identifier ⇒ String?
Either a valid SSN or EIN.
57 |
# File 'lib/modern_treasury/models/counterparty_update_params.rb', line 57 optional :taxpayer_identifier, String |