Module: ModernTreasury::Models::ExpectedPayment::ReconciliationMethod

Extended by:
Internal::Type::Enum
Defined in:
lib/modern_treasury/models/expected_payment.rb,
sig/modern_treasury/models/expected_payment.rbs

Overview

One of manual if this expected payment was manually reconciled in the dashboard, automatic if it was automatically reconciled by Modern Treasury, or null if it is unreconciled.

See Also:

  • ModernTreasury::Models::ExpectedPayment#reconciliation_method

Constant Summary collapse

AUTOMATIC =

Returns:

  • (:automatic)
:automatic
MANUAL =

Returns:

  • (:manual)
:manual

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[ModernTreasury::Models::ExpectedPayment::reconciliation_method]

Returns:

  • (::Array[ModernTreasury::Models::ExpectedPayment::reconciliation_method])


210
# File 'sig/modern_treasury/models/expected_payment.rbs', line 210

def self?.values: -> ::Array[ModernTreasury::Models::ExpectedPayment::reconciliation_method]