Class: ModernTreasury::Models::ExpectedPaymentCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/modern_treasury/models/expected_payment_create_params.rb

Overview

Defined Under Namespace

Modules: AmountReconciledDirection, AmountUnreconciledDirection, Direction Classes: LineItem

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount_lower_bound: nil, amount_reconciled: nil, amount_reconciled_direction: nil, amount_unreconciled: nil, amount_unreconciled_direction: nil, amount_upper_bound: nil, counterparty_id: nil, currency: nil, date_lower_bound: nil, date_upper_bound: nil, description: nil, direction: nil, external_id: nil, internal_account_id: nil, ledger_transaction: nil, ledger_transaction_id: nil, line_items: nil, metadata: nil, reconciliation_filters: nil, reconciliation_groups: nil, reconciliation_rule_variables: nil, remittance_information: nil, statement_descriptor: nil, type: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::ExpectedPaymentCreateParams for more details.

Parameters:

  • amount_lower_bound (Integer, nil) (defaults to: nil)

    The lowest amount this expected payment may be equal to. Value in specified curr

  • amount_reconciled (Integer, nil) (defaults to: nil)

    The amount reconciled for this expected payment. Value in specified currency’s s

  • amount_reconciled_direction (Symbol, ModernTreasury::Models::ExpectedPaymentCreateParams::AmountReconciledDirection, nil) (defaults to: nil)

    One of credit or debit. Indicates whether amount_reconciled is a credit or debit

  • amount_unreconciled (Integer, nil) (defaults to: nil)

    The amount that remains unreconciled for this expected payment. Value in specifi

  • amount_unreconciled_direction (Symbol, ModernTreasury::Models::ExpectedPaymentCreateParams::AmountUnreconciledDirection, nil) (defaults to: nil)

    One of credit or debit. Indicates whether amount_unreconciled is a credit or deb

  • amount_upper_bound (Integer, nil) (defaults to: nil)

    The highest amount this expected payment may be equal to. Value in specified cur

  • counterparty_id (String, nil) (defaults to: nil)

    The ID of the counterparty you expect for this payment.

  • currency (Symbol, ModernTreasury::Models::Currency, nil) (defaults to: nil)

    Must conform to ISO 4217. Defaults to the currency of the internal account.

  • date_lower_bound (Date, nil) (defaults to: nil)

    The earliest date the payment may come in. Format: yyyy-mm-dd

  • date_upper_bound (Date, nil) (defaults to: nil)

    The latest date the payment may come in. Format: yyyy-mm-dd

  • description (String, nil) (defaults to: nil)

    An optional description for internal use.

  • direction (Symbol, ModernTreasury::Models::ExpectedPaymentCreateParams::Direction, nil) (defaults to: nil)

    One of credit or debit. When you are receiving money, use credit. When you are b

  • external_id (String, nil) (defaults to: nil)

    An optional user-defined 180 character unique identifier.

  • internal_account_id (String, nil) (defaults to: nil)

    The ID of the Internal Account for the expected payment.

  • ledger_transaction (ModernTreasury::Models::LedgerTransactionCreateRequest) (defaults to: nil)

    Specifies a ledger transaction object that will be created with the expected pay

  • ledger_transaction_id (String) (defaults to: nil)

    Either ledger_transaction or ledger_transaction_id can be provided. Only a pendi

  • line_items (Array<ModernTreasury::Models::ExpectedPaymentCreateParams::LineItem>) (defaults to: nil)
  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    Additional data represented as key-value pairs. Both the key and value must be s

  • reconciliation_filters (Object, nil) (defaults to: nil)

    The reconciliation filters you have for this payment.

  • reconciliation_groups (Object, nil) (defaults to: nil)

    The reconciliation groups you have for this payment.

  • reconciliation_rule_variables (Array<ModernTreasury::Models::ReconciliationRule>, nil) (defaults to: nil)

    An array of reconciliation rule variables for this payment.

  • remittance_information (String, nil) (defaults to: nil)

    For ‘ach`, this field will be passed through on an addenda record. For `wire` pa

  • statement_descriptor (String, nil) (defaults to: nil)

    The statement description you expect to see on the transaction. For ACH payments

  • type (Symbol, ModernTreasury::Models::ExpectedPaymentType, nil) (defaults to: nil)

    One of: ach, au_becs, bacs, book, check, eft, interac, provxchange, rtp, sen, se

  • request_options (ModernTreasury::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 180

Instance Attribute Details

#amount_lower_boundInteger?

The lowest amount this expected payment may be equal to. Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000.

Returns:

  • (Integer, nil)


15
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 15

optional :amount_lower_bound, Integer, nil?: true

#amount_reconciledInteger?

The amount reconciled for this expected payment. Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000.

Returns:

  • (Integer, nil)


22
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 22

optional :amount_reconciled, Integer, nil?: true

#amount_reconciled_directionSymbol, ...

One of credit or debit. Indicates whether amount_reconciled is a credit or debit amount.



29
30
31
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 29

optional :amount_reconciled_direction,
enum: -> { ModernTreasury::ExpectedPaymentCreateParams::AmountReconciledDirection },
nil?: true

#amount_unreconciledInteger?

The amount that remains unreconciled for this expected payment. Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000.

Returns:

  • (Integer, nil)


38
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 38

optional :amount_unreconciled, Integer, nil?: true

#amount_unreconciled_directionSymbol, ...

One of credit or debit. Indicates whether amount_unreconciled is a credit or debit amount.



45
46
47
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 45

optional :amount_unreconciled_direction,
enum: -> { ModernTreasury::ExpectedPaymentCreateParams::AmountUnreconciledDirection },
nil?: true

#amount_upper_boundInteger?

The highest amount this expected payment may be equal to. Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000.

Returns:

  • (Integer, nil)


54
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 54

optional :amount_upper_bound, Integer, nil?: true

#counterparty_idString?

The ID of the counterparty you expect for this payment.

Returns:

  • (String, nil)


60
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 60

optional :counterparty_id, String, nil?: true

#currencySymbol, ...

Must conform to ISO 4217. Defaults to the currency of the internal account.

Returns:



66
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 66

optional :currency, enum: -> { ModernTreasury::Currency }, nil?: true

#date_lower_boundDate?

The earliest date the payment may come in. Format: yyyy-mm-dd

Returns:

  • (Date, nil)


72
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 72

optional :date_lower_bound, Date, nil?: true

#date_upper_boundDate?

The latest date the payment may come in. Format: yyyy-mm-dd

Returns:

  • (Date, nil)


78
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 78

optional :date_upper_bound, Date, nil?: true

#descriptionString?

An optional description for internal use.

Returns:

  • (String, nil)


84
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 84

optional :description, String, nil?: true

#directionSymbol, ...

One of credit or debit. When you are receiving money, use credit. When you are being charged, use debit.



91
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 91

optional :direction, enum: -> { ModernTreasury::ExpectedPaymentCreateParams::Direction }, nil?: true

#external_idString?

An optional user-defined 180 character unique identifier.

Returns:

  • (String, nil)


97
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 97

optional :external_id, String, nil?: true

#internal_account_idString?

The ID of the Internal Account for the expected payment.

Returns:

  • (String, nil)


103
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 103

optional :internal_account_id, String, nil?: true

#ledger_transactionModernTreasury::Models::LedgerTransactionCreateRequest?

Specifies a ledger transaction object that will be created with the expected payment. If the ledger transaction cannot be created, then the expected payment creation will fail. The resulting ledger transaction will mirror the status of the expected payment.



112
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 112

optional :ledger_transaction, -> { ModernTreasury::LedgerTransactionCreateRequest }

#ledger_transaction_idString?

Either ledger_transaction or ledger_transaction_id can be provided. Only a pending ledger transaction can be attached upon expected payment creation. Once the expected payment is created, the status of the ledger transaction tracks the expected payment automatically.

Returns:

  • (String, nil)


121
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 121

optional :ledger_transaction_id, String

#line_itemsArray<ModernTreasury::Models::ExpectedPaymentCreateParams::LineItem>?



126
127
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 126

optional :line_items,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ExpectedPaymentCreateParams::LineItem] }

#metadataHash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Returns:

  • (Hash{Symbol=>String}, nil)


134
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 134

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#reconciliation_filtersObject?

The reconciliation filters you have for this payment.

Returns:

  • (Object, nil)


140
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 140

optional :reconciliation_filters, ModernTreasury::Internal::Type::Unknown, nil?: true

#reconciliation_groupsObject?

The reconciliation groups you have for this payment.

Returns:

  • (Object, nil)


146
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 146

optional :reconciliation_groups, ModernTreasury::Internal::Type::Unknown, nil?: true

#reconciliation_rule_variablesArray<ModernTreasury::Models::ReconciliationRule>?

An array of reconciliation rule variables for this payment.



152
153
154
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 152

optional :reconciliation_rule_variables,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ReconciliationRule] },
nil?: true

#remittance_informationString?

For ‘ach`, this field will be passed through on an addenda record. For `wire` payments the field will be passed through as the “Originator to Beneficiary Information”, also known as OBI or Fedwire tag 6000.

Returns:

  • (String, nil)


162
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 162

optional :remittance_information, String, nil?: true

#statement_descriptorString?

The statement description you expect to see on the transaction. For ACH payments, this will be the full line item passed from the bank. For wire payments, this will be the OBI field on the wire. For check payments, this will be the memo field.

Returns:

  • (String, nil)


171
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 171

optional :statement_descriptor, String, nil?: true

#typeSymbol, ...

One of: ach, au_becs, bacs, book, check, eft, interac, provxchange, rtp, sen, sepa, signet, wire.



178
# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 178

optional :type, enum: -> { ModernTreasury::ExpectedPaymentType }, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/expected_payment_create_params.rb', line 242