Class: ModernTreasury::Models::ExpectedPaymentListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/modern_treasury/models/expected_payment_list_params.rb,
sig/modern_treasury/models/expected_payment_list_params.rbs

Overview

See Also:

  • ModernTreasury::Resources::ExpectedPayments#list

Defined Under Namespace

Modules: Status, Type

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::ModernTreasury

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after_cursor: nil, counterparty_id: nil, created_at_lower_bound: nil, created_at_upper_bound: nil, direction: nil, external_id: nil, internal_account_id: nil, metadata: nil, per_page: nil, status: nil, type: nil, updated_at_lower_bound: nil, updated_at_upper_bound: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::ExpectedPaymentListParams for more details.

Parameters:

  • after_cursor (String, nil) (defaults to: nil)
  • counterparty_id (String) (defaults to: nil)

    Specify counterparty_id to see expected_payments for a specific account.

  • created_at_lower_bound (Time) (defaults to: nil)

    Used to return expected payments created after some datetime

  • created_at_upper_bound (Time) (defaults to: nil)

    Used to return expected payments created before some datetime

  • direction (Symbol, ModernTreasury::Models::TransactionDirection) (defaults to: nil)

    One of credit, debit

  • external_id (String) (defaults to: nil)
  • internal_account_id (String) (defaults to: nil)

    Specify internal_account_id to see expected_payments for a specific account.

  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    For example, if you want to query for records with metadata key Type and value

  • per_page (Integer) (defaults to: nil)
  • status (Symbol, ModernTreasury::Models::ExpectedPaymentListParams::Status) (defaults to: nil)

    One of unreconciled, reconciled, or archived.

  • type (Symbol, ModernTreasury::Models::ExpectedPaymentListParams::Type) (defaults to: nil)

    One of: ach, au_becs, bacs, book, check, eft, rtp, sepa, wire

  • updated_at_lower_bound (Time) (defaults to: nil)

    Used to return expected payments updated after some datetime

  • updated_at_upper_bound (Time) (defaults to: nil)

    Used to return expected payments updated before some datetime

  • request_options (ModernTreasury::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/modern_treasury/models/expected_payment_list_params.rb', line 87

Instance Attribute Details

#after_cursorString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


13
# File 'lib/modern_treasury/models/expected_payment_list_params.rb', line 13

optional :after_cursor, String, nil?: true

#counterparty_idString?

Specify counterparty_id to see expected_payments for a specific account.

Parameters:

  • (String)

Returns:

  • (String, nil)


19
# File 'lib/modern_treasury/models/expected_payment_list_params.rb', line 19

optional :counterparty_id, String

#created_at_lower_boundTime?

Used to return expected payments created after some datetime

Parameters:

  • (Time)

Returns:

  • (Time, nil)


25
# File 'lib/modern_treasury/models/expected_payment_list_params.rb', line 25

optional :created_at_lower_bound, Time

#created_at_upper_boundTime?

Used to return expected payments created before some datetime

Parameters:

  • (Time)

Returns:

  • (Time, nil)


31
# File 'lib/modern_treasury/models/expected_payment_list_params.rb', line 31

optional :created_at_upper_bound, Time

#directionSymbol, ...

One of credit, debit



37
# File 'lib/modern_treasury/models/expected_payment_list_params.rb', line 37

optional :direction, enum: -> { ModernTreasury::TransactionDirection }

#external_idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


42
# File 'lib/modern_treasury/models/expected_payment_list_params.rb', line 42

optional :external_id, String

#internal_account_idString?

Specify internal_account_id to see expected_payments for a specific account.

Parameters:

  • (String)

Returns:

  • (String, nil)


48
# File 'lib/modern_treasury/models/expected_payment_list_params.rb', line 48

optional :internal_account_id, String

#metadataHash{Symbol=>String}?

For example, if you want to query for records with metadata key Type and value Loan, the query would be metadata%5BType%5D=Loan. This encodes the query parameters.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


56
# File 'lib/modern_treasury/models/expected_payment_list_params.rb', line 56

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#per_pageInteger?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


61
# File 'lib/modern_treasury/models/expected_payment_list_params.rb', line 61

optional :per_page, Integer

#statusSymbol, ...

One of unreconciled, reconciled, or archived.



67
# File 'lib/modern_treasury/models/expected_payment_list_params.rb', line 67

optional :status, enum: -> { ModernTreasury::ExpectedPaymentListParams::Status }

#typeSymbol, ...

One of: ach, au_becs, bacs, book, check, eft, rtp, sepa, wire



73
# File 'lib/modern_treasury/models/expected_payment_list_params.rb', line 73

optional :type, enum: -> { ModernTreasury::ExpectedPaymentListParams::Type }

#updated_at_lower_boundTime?

Used to return expected payments updated after some datetime

Parameters:

  • (Time)

Returns:

  • (Time, nil)


79
# File 'lib/modern_treasury/models/expected_payment_list_params.rb', line 79

optional :updated_at_lower_bound, Time

#updated_at_upper_boundTime?

Used to return expected payments updated before some datetime

Parameters:

  • (Time)

Returns:

  • (Time, nil)


85
# File 'lib/modern_treasury/models/expected_payment_list_params.rb', line 85

optional :updated_at_upper_bound, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/expected_payment_list_params.rb', line 128

Instance Method Details

#to_hash{

Returns:

  • ({)


98
# File 'sig/modern_treasury/models/expected_payment_list_params.rbs', line 98

def to_hash: -> {