Class: ModernTreasury::Models::ForeignExchangeQuoteCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::ForeignExchangeQuoteCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/foreign_exchange_quote_create_params.rb,
sig/modern_treasury/models/foreign_exchange_quote_create_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ModernTreasury
Instance Attribute Summary collapse
-
#base_amount ⇒ Integer?
Amount in the lowest denomination of the
base_currencyto convert, often called the "sell" amount. -
#base_currency ⇒ Symbol, ...
Currency to convert, often called the "sell" currency.
-
#effective_at ⇒ Time?
The timestamp until when the quoted rate is valid.
-
#internal_account_id ⇒ String
The ID for the
InternalAccountthis quote is associated with. -
#target_amount ⇒ Integer?
Amount in the lowest denomination of the
target_currency, often called the "buy" amount. -
#target_currency ⇒ Symbol, ModernTreasury::Models::Currency
Currency to convert the
base_currencyto, often called the "buy" currency.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(internal_account_id:, target_currency:, base_amount: nil, base_currency: nil, effective_at: nil, target_amount: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ForeignExchangeQuoteCreateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(internal_account_id:, target_currency:, base_amount: nil, base_currency: nil, effective_at: nil, target_amount: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::ForeignExchangeQuoteCreateParams for more details.
|
|
# File 'lib/modern_treasury/models/foreign_exchange_quote_create_params.rb', line 48
|
Instance Attribute Details
#base_amount ⇒ Integer?
Amount in the lowest denomination of the base_currency to convert, often
called the "sell" amount.
27 |
# File 'lib/modern_treasury/models/foreign_exchange_quote_create_params.rb', line 27 optional :base_amount, Integer |
#base_currency ⇒ Symbol, ...
Currency to convert, often called the "sell" currency.
33 |
# File 'lib/modern_treasury/models/foreign_exchange_quote_create_params.rb', line 33 optional :base_currency, enum: -> { ModernTreasury::Currency } |
#effective_at ⇒ Time?
The timestamp until when the quoted rate is valid.
39 |
# File 'lib/modern_treasury/models/foreign_exchange_quote_create_params.rb', line 39 optional :effective_at, Time |
#internal_account_id ⇒ String
The ID for the InternalAccount this quote is associated with.
14 |
# File 'lib/modern_treasury/models/foreign_exchange_quote_create_params.rb', line 14 required :internal_account_id, String |
#target_amount ⇒ Integer?
Amount in the lowest denomination of the target_currency, often called the
"buy" amount.
46 |
# File 'lib/modern_treasury/models/foreign_exchange_quote_create_params.rb', line 46 optional :target_amount, Integer |
#target_currency ⇒ Symbol, ModernTreasury::Models::Currency
Currency to convert the base_currency to, often called the "buy" currency.
20 |
# File 'lib/modern_treasury/models/foreign_exchange_quote_create_params.rb', line 20 required :target_currency, enum: -> { ModernTreasury::Currency } |
Instance Method Details
#to_hash ⇒ {
50 |
# File 'sig/modern_treasury/models/foreign_exchange_quote_create_params.rbs', line 50
def to_hash: -> {
|