Class: ModernTreasury::Models::IdentificationCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/modern_treasury/models/identification_create_params.rb,
sig/modern_treasury/models/identification_create_params.rbs

Overview

See Also:

  • ModernTreasury::Resources::Identifications#create

Defined Under Namespace

Modules: IDType Classes: Document

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::ModernTreasury

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id_number:, id_type:, legal_entity_id:, documents: nil, expiration_date: nil, issuing_country: nil, issuing_region: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::IdentificationCreateParams for more details.

Parameters:

  • id_number (String) —

    The ID number of identification document.

  • id_type (Symbol, ModernTreasury::Models::IdentificationCreateParams::IDType) —

    The type of ID number.

  • legal_entity_id (String) —

    The ID of the Legal Entity the identification belongs to.

  • documents (Array<ModernTreasury::Models::IdentificationCreateParams::Document>) (defaults to: nil) —

    A list of documents to attach to the identification.

  • expiration_date (Date, nil) (defaults to: nil) —

    The date when the Identification is no longer considered valid by the issuing au

  • issuing_country (String, nil) (defaults to: nil) —

    The ISO 3166-1 alpha-2 country code of the country that issued the identificatio

  • issuing_region (String, nil) (defaults to: nil) —

    The region in which the identifcation was issued.

  • request_options (ModernTreasury::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/modern_treasury/models/identification_create_params.rb', line 55

Instance Attribute Details

#documents ⇒ Array<ModernTreasury::Models::IdentificationCreateParams::Document>?

A list of documents to attach to the identification.



32
33
# File 'lib/modern_treasury/models/identification_create_params.rb', line 32

optional :documents,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::IdentificationCreateParams::Document] }

#expiration_date ⇒ Date?

The date when the Identification is no longer considered valid by the issuing authority.

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


40
# File 'lib/modern_treasury/models/identification_create_params.rb', line 40

optional :expiration_date, Date, nil?: true

#id_number ⇒ String

The ID number of identification document.

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/modern_treasury/models/identification_create_params.rb', line 14

required :id_number, String

#id_type ⇒ Symbol, ModernTreasury::Models::IdentificationCreateParams::IDType

The type of ID number.

Parameters:

  • value (ModernTreasury::Models::IdentificationCreateParams::id_type)

Returns:



20
# File 'lib/modern_treasury/models/identification_create_params.rb', line 20

required :id_type, enum: -> { ModernTreasury::IdentificationCreateParams::IDType }

#issuing_country ⇒ String?

The ISO 3166-1 alpha-2 country code of the country that issued the identification

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


47
# File 'lib/modern_treasury/models/identification_create_params.rb', line 47

optional :issuing_country, String, nil?: true

#issuing_region ⇒ String?

The region in which the identifcation was issued.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


53
# File 'lib/modern_treasury/models/identification_create_params.rb', line 53

optional :issuing_region, String, nil?: true

The ID of the Legal Entity the identification belongs to.

Parameters:

  • value (String)

Returns:

  • (String)


26
# File 'lib/modern_treasury/models/identification_create_params.rb', line 26

required :legal_entity_id, String

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/identification_create_params.rb', line 181

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


48
# File 'sig/modern_treasury/models/identification_create_params.rbs', line 48

def to_hash: -> {