Class: ModernTreasury::Models::IdentificationCreateRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::IdentificationCreateRequest
- Defined in:
- lib/modern_treasury/models/identification_create_request.rb
Defined Under Namespace
Modules: IDType Classes: Document
Instance Attribute Summary collapse
-
#documents ⇒ Array<ModernTreasury::Models::IdentificationCreateRequest::Document>?
A list of documents to attach to the identification.
-
#expiration_date ⇒ Date?
The date when the Identification is no longer considered valid by the issuing authority.
-
#id_number ⇒ String
The ID number of identification document.
-
#id_type ⇒ Symbol, ModernTreasury::Models::IdentificationCreateRequest::IDType
The type of ID number.
-
#issuing_country ⇒ String?
The ISO 3166-1 alpha-2 country code of the country that issued the identification.
-
#issuing_region ⇒ String?
The region in which the identifcation was issued.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id_number:, id_type:, documents: nil, expiration_date: nil, issuing_country: nil, issuing_region: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see IdentificationCreateRequest for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id_number:, id_type:, documents: nil, expiration_date: nil, issuing_country: nil, issuing_region: nil) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::IdentificationCreateRequest for more details.
|
|
# File 'lib/modern_treasury/models/identification_create_request.rb', line 45
|
Instance Attribute Details
#documents ⇒ Array<ModernTreasury::Models::IdentificationCreateRequest::Document>?
A list of documents to attach to the identification.
22 23 |
# File 'lib/modern_treasury/models/identification_create_request.rb', line 22 optional :documents, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::IdentificationCreateRequest::Document] } |
#expiration_date ⇒ Date?
The date when the Identification is no longer considered valid by the issuing authority.
30 |
# File 'lib/modern_treasury/models/identification_create_request.rb', line 30 optional :expiration_date, Date, nil?: true |
#id_number ⇒ String
The ID number of identification document.
10 |
# File 'lib/modern_treasury/models/identification_create_request.rb', line 10 required :id_number, String |
#id_type ⇒ Symbol, ModernTreasury::Models::IdentificationCreateRequest::IDType
The type of ID number.
16 |
# File 'lib/modern_treasury/models/identification_create_request.rb', line 16 required :id_type, enum: -> { ModernTreasury::IdentificationCreateRequest::IDType } |
#issuing_country ⇒ String?
The ISO 3166-1 alpha-2 country code of the country that issued the identification
37 |
# File 'lib/modern_treasury/models/identification_create_request.rb', line 37 optional :issuing_country, String, nil?: true |
#issuing_region ⇒ String?
The region in which the identifcation was issued.
43 |
# File 'lib/modern_treasury/models/identification_create_request.rb', line 43 optional :issuing_region, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/identification_create_request.rb', line 92
|