Class: ModernTreasury::Models::IdentificationUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/modern_treasury/models/identification_update_params.rb,
sig/modern_treasury/models/identification_update_params.rbs

Overview

See Also:

  • ModernTreasury::Resources::Identifications#update

Defined Under Namespace

Modules: IDType

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::ModernTreasury

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, expiration_date: nil, id_number: nil, id_type: nil, issuing_country: nil, issuing_region: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::IdentificationUpdateParams for more details.

Parameters:

  • id (String)
  • expiration_date (Date, nil) (defaults to: nil) —

    The date when the Identification is no longer considered valid by the issuing au

  • id_number (String) (defaults to: nil) —

    The ID number of identification document.

  • id_type (Symbol, ModernTreasury::Models::IdentificationUpdateParams::IDType) (defaults to: nil) —

    The type of ID number.

  • issuing_country (String, nil) (defaults to: nil) —

    The ISO 3166-1 alpha-2 country code of the country that issued the identificatio

  • issuing_region (String, nil) (defaults to: nil) —

    The region in which the identifcation was issued.

  • request_options (ModernTreasury::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/modern_treasury/models/identification_update_params.rb', line 47


Instance Attribute Details

#expiration_date ⇒ Date?

The date when the Identification is no longer considered valid by the issuing authority.

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


20
# File 'lib/modern_treasury/models/identification_update_params.rb', line 20

optional :expiration_date, Date, nil?: true

#id ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/modern_treasury/models/identification_update_params.rb', line 13

required :id, String

#id_number ⇒ String?

The ID number of identification document.

Parameters:

  • (String)

Returns:

  • (String, nil)


26
# File 'lib/modern_treasury/models/identification_update_params.rb', line 26

optional :id_number, String

#id_type ⇒ Symbol, ...

The type of ID number.



32
# File 'lib/modern_treasury/models/identification_update_params.rb', line 32

optional :id_type, enum: -> { ModernTreasury::IdentificationUpdateParams::IDType }

#issuing_country ⇒ String?

The ISO 3166-1 alpha-2 country code of the country that issued the identification

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


39
# File 'lib/modern_treasury/models/identification_update_params.rb', line 39

optional :issuing_country, String, nil?: true

#issuing_region ⇒ String?

The region in which the identifcation was issued.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


45
# File 'lib/modern_treasury/models/identification_update_params.rb', line 45

optional :issuing_region, String, nil?: true

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


46
# File 'sig/modern_treasury/models/identification_update_params.rbs', line 46

def to_hash: -> {