Class: ModernTreasury::Models::IncomingPaymentDetail

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/incoming_payment_detail.rb,
sig/modern_treasury/models/incoming_payment_detail.rbs

Overview

See Also:

  • ModernTreasury::Resources::IncomingPaymentDetails#retrieve

Defined Under Namespace

Modules: OriginatingAccountNumberType, OriginatingRoutingNumberType, ReconciliationStatus, Status, Type

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, amount:, as_of_date:, created_at:, currency:, data:, direction:, internal_account_id:, ledger_transaction_id:, live_mode:, metadata:, object:, originating_account_number_safe:, originating_account_number_type:, originating_routing_number:, originating_routing_number_type:, reconciliation_status:, status:, subtype:, transaction_id:, transaction_line_item_id:, type:, updated_at:, vendor_id:, virtual_account:, virtual_account_id:, originating_account_number: nil, originating_party_address: nil, originating_party_name: nil, originating_party_vendor_identifier: nil, receiving_account_number: nil, receiving_account_number_safe: nil) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::IncomingPaymentDetail for more details.

Parameters:

  • id (String)
  • amount (Integer)

    Value in specified currency's smallest unit. e.g. $10 would be represented as 10

  • as_of_date (Date)

    The date on which the corresponding transaction will occur.

  • created_at (Time)
  • currency (Symbol, ModernTreasury::Models::Currency)

    The currency of the incoming payment detail.

  • data (Hash{Symbol=>Object})

    The raw data from the payment pre-notification file that we get from the bank.

  • direction (Symbol, ModernTreasury::Models::TransactionDirection)

    One of credit or debit.

  • internal_account_id (String)

    The ID of the Internal Account for the incoming payment detail. This is always p

  • ledger_transaction_id (String, nil)

    The ID of the ledger transaction linked to the incoming payment detail or null

  • live_mode (Boolean)

    This field will be true if this object exists in the live environment or false i

  • metadata (Hash{Symbol=>String})

    Additional data represented as key-value pairs. Both the key and value must be s

  • object (String)
  • originating_account_number_safe (String, nil)

    The last 4 digits of the originating account_number for the incoming payment det

  • originating_account_number_type (Symbol, ModernTreasury::Models::IncomingPaymentDetail::OriginatingAccountNumberType, nil)

    The type of the originating account number for the incoming payment detail.

  • originating_routing_number (String, nil)

    The routing number of the originating account for the incoming payment detail.

  • originating_routing_number_type (Symbol, ModernTreasury::Models::IncomingPaymentDetail::OriginatingRoutingNumberType, nil)

    The type of the originating routing number for the incoming payment detail.

  • reconciliation_status (Symbol, ModernTreasury::Models::IncomingPaymentDetail::ReconciliationStatus)

    One of unreconciled, tentatively_reconciled or reconciled.

  • status (Symbol, ModernTreasury::Models::IncomingPaymentDetail::Status)

    The current status of the incoming payment order. One of pending, completed,

  • subtype (String, nil)

    An additional layer of classification for the type of incoming payment detail. F

  • transaction_id (String, nil)

    The ID of the reconciled Transaction or null.

  • transaction_line_item_id (String, nil)

    The ID of the reconciled Transaction Line Item or null.

  • type (Symbol, ModernTreasury::Models::IncomingPaymentDetail::Type)

    One of: ach, book, check, eft, rtp, sepa, or wire.

  • updated_at (Time)
  • vendor_id (String, nil)

    The identifier of the vendor bank.

  • virtual_account (ModernTreasury::Models::VirtualAccount, nil)

    If the incoming payment detail is in a virtual account, the serialized virtual a

  • virtual_account_id (String, nil)

    If the incoming payment detail is in a virtual account, the ID of the Virtual Ac

  • originating_account_number (String, nil) (defaults to: nil)

    The account number of the originating account for the incoming payment detail.

  • originating_party_address (ModernTreasury::Models::Address, nil) (defaults to: nil)

    The address of the originating party for the incoming payment detail, or null.

  • originating_party_name (String, nil) (defaults to: nil)

    The name of the originating party for the incoming payment detail.

  • originating_party_vendor_identifier (String, nil) (defaults to: nil)

    The vendor-assigned identifier for the originating party of the incoming payment

  • receiving_account_number (String, nil) (defaults to: nil)

    The account number of the receiving account for the incoming payment detail, or

  • receiving_account_number_safe (String, nil) (defaults to: nil)

    The last 4 digits of the receiving account number for the incoming payment detai



# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 213

Instance Attribute Details

#amountInteger

Value in specified currency's smallest unit. e.g. $10 would be represented as 1000.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


17
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 17

required :amount, Integer

#as_of_dateDate

The date on which the corresponding transaction will occur.

Parameters:

  • value (Date)

Returns:

  • (Date)


23
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 23

required :as_of_date, Date

#created_atTime

Parameters:

  • value (Time)

Returns:

  • (Time)


28
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 28

required :created_at, Time

#currencySymbol, ModernTreasury::Models::Currency

The currency of the incoming payment detail.

Parameters:

  • value (ModernTreasury::Models::currency)

Returns:



34
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 34

required :currency, enum: -> { ModernTreasury::Currency }

#dataHash{Symbol=>Object}

The raw data from the payment pre-notification file that we get from the bank.

Parameters:

  • value (::Hash[Symbol, top])

Returns:

  • (Hash{Symbol=>Object})


40
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 40

required :data, ModernTreasury::Internal::Type::HashOf[ModernTreasury::Internal::Type::Unknown]

#directionSymbol, ModernTreasury::Models::TransactionDirection

One of credit or debit.

Parameters:

  • value (ModernTreasury::Models::transaction_direction)

Returns:



46
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 46

required :direction, enum: -> { ModernTreasury::TransactionDirection }

#idString

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 10

required :id, String

#internal_account_idString

The ID of the Internal Account for the incoming payment detail. This is always present.

Parameters:

  • value (String)

Returns:

  • (String)


53
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 53

required :internal_account_id, String

#ledger_transaction_idString?

The ID of the ledger transaction linked to the incoming payment detail or null.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


60
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 60

required :ledger_transaction_id, String, nil?: true

#live_modeBoolean

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


67
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 67

required :live_mode, ModernTreasury::Internal::Type::Boolean

#metadataHash{Symbol=>String}

Additional data represented as key-value pairs. Both the key and value must be strings.

Parameters:

  • value (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String})


74
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 74

required :metadata, ModernTreasury::Internal::Type::HashOf[String]

#objectString

Parameters:

  • value (String)

Returns:

  • (String)


79
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 79

required :object, String

#originating_account_numberString?

The account number of the originating account for the incoming payment detail.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


178
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 178

optional :originating_account_number, String, nil?: true

#originating_account_number_safeString?

The last 4 digits of the originating account_number for the incoming payment detail.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


86
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 86

required :originating_account_number_safe, String, nil?: true

#originating_account_number_typeSymbol, ...

The type of the originating account number for the incoming payment detail.

Parameters:

  • value (ModernTreasury::Models::IncomingPaymentDetail::originating_account_number_type, nil)

Returns:



92
93
94
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 92

required :originating_account_number_type,
enum: -> { ModernTreasury::IncomingPaymentDetail::OriginatingAccountNumberType },
nil?: true

#originating_party_addressModernTreasury::Models::Address?

The address of the originating party for the incoming payment detail, or null.

Parameters:

Returns:



184
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 184

optional :originating_party_address, -> { ModernTreasury::Address }, nil?: true

#originating_party_nameString?

The name of the originating party for the incoming payment detail.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


190
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 190

optional :originating_party_name, String, nil?: true

#originating_party_vendor_identifierString?

The vendor-assigned identifier for the originating party of the incoming payment detail, or null.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


197
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 197

optional :originating_party_vendor_identifier, String, nil?: true

#originating_routing_numberString?

The routing number of the originating account for the incoming payment detail.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


100
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 100

required :originating_routing_number, String, nil?: true

#originating_routing_number_typeSymbol, ...

The type of the originating routing number for the incoming payment detail.

Parameters:

  • value (ModernTreasury::Models::IncomingPaymentDetail::originating_routing_number_type, nil)

Returns:



106
107
108
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 106

required :originating_routing_number_type,
enum: -> { ModernTreasury::IncomingPaymentDetail::OriginatingRoutingNumberType },
nil?: true

#receiving_account_numberString?

The account number of the receiving account for the incoming payment detail, or null.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


204
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 204

optional :receiving_account_number, String, nil?: true

#receiving_account_number_safeString?

The last 4 digits of the receiving account number for the incoming payment detail, or null.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


211
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 211

optional :receiving_account_number_safe, String, nil?: true

#reconciliation_statusSymbol, ModernTreasury::Models::IncomingPaymentDetail::ReconciliationStatus

One of unreconciled, tentatively_reconciled or reconciled.

Parameters:

  • value (ModernTreasury::Models::IncomingPaymentDetail::reconciliation_status)

Returns:



114
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 114

required :reconciliation_status, enum: -> { ModernTreasury::IncomingPaymentDetail::ReconciliationStatus }

#statusSymbol, ModernTreasury::Models::IncomingPaymentDetail::Status

The current status of the incoming payment order. One of pending, completed, or returned.

Parameters:

  • value (ModernTreasury::Models::IncomingPaymentDetail::status)

Returns:



121
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 121

required :status, enum: -> { ModernTreasury::IncomingPaymentDetail::Status }

#subtypeString?

An additional layer of classification for the type of incoming payment detail. For example, a type of stablecoin may have a subtype of ethereum or solana.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


129
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 129

required :subtype, String, nil?: true

#transaction_idString?

The ID of the reconciled Transaction or null.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


135
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 135

required :transaction_id, String, nil?: true

#transaction_line_item_idString?

The ID of the reconciled Transaction Line Item or null.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


141
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 141

required :transaction_line_item_id, String, nil?: true

#typeSymbol, ModernTreasury::Models::IncomingPaymentDetail::Type

One of: ach, book, check, eft, rtp, sepa, or wire.

Parameters:

  • value (ModernTreasury::Models::IncomingPaymentDetail::type_)

Returns:



147
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 147

required :type, enum: -> { ModernTreasury::IncomingPaymentDetail::Type }

#updated_atTime

Parameters:

  • value (Time)

Returns:

  • (Time)


152
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 152

required :updated_at, Time

#vendor_idString?

The identifier of the vendor bank.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


158
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 158

required :vendor_id, String, nil?: true

#virtual_accountModernTreasury::Models::VirtualAccount?

If the incoming payment detail is in a virtual account, the serialized virtual account object.



165
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 165

required :virtual_account, -> { ModernTreasury::VirtualAccount }, nil?: true

#virtual_account_idString?

If the incoming payment detail is in a virtual account, the ID of the Virtual Account.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


172
# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 172

required :virtual_account_id, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/incoming_payment_detail.rb', line 303

Instance Method Details

#to_hash{

Returns:

  • ({)


139
# File 'sig/modern_treasury/models/incoming_payment_detail.rbs', line 139

def to_hash: -> {