Class: ModernTreasury::Models::IncomingPaymentDetailCreateAsyncParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/modern_treasury/models/incoming_payment_detail_create_async_params.rb,
sig/modern_treasury/models/incoming_payment_detail_create_async_params.rbs

Overview

See Also:

  • ModernTreasury::Resources::IncomingPaymentDetails#create_async

Defined Under Namespace

Modules: Direction, Type

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::ModernTreasury

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount: nil, as_of_date: nil, currency: nil, data: nil, description: nil, direction: nil, internal_account_id: nil, subtype: nil, type: nil, virtual_account_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::IncomingPaymentDetailCreateAsyncParams for more details.

Parameters:

  • amount (Integer) (defaults to: nil)

    Value in specified currency's smallest unit. e.g. $10 would be represented as 10

  • as_of_date (Date, nil) (defaults to: nil)

    Defaults to today.

  • currency (Symbol, ModernTreasury::Models::Currency, nil) (defaults to: nil)

    Defaults to the currency of the originating account.

  • data (Object, nil) (defaults to: nil)

    An object passed through to the simulated IPD that could reflect what a vendor w

  • description (String, nil) (defaults to: nil)

    Defaults to a random description.

  • direction (Symbol, ModernTreasury::Models::IncomingPaymentDetailCreateAsyncParams::Direction) (defaults to: nil)

    One of credit, debit.

  • internal_account_id (String) (defaults to: nil)

    The ID of one of your internal accounts.

  • subtype (String, nil) (defaults to: nil)

    An additional layer of classification for the type of incoming payment detail, e

  • type (Symbol, ModernTreasury::Models::IncomingPaymentDetailCreateAsyncParams::Type) (defaults to: nil)

    One of ach, wire, check.

  • virtual_account_id (String, nil) (defaults to: nil)

    An optional parameter to associate the incoming payment detail to a virtual acco

  • request_options (ModernTreasury::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/modern_treasury/models/incoming_payment_detail_create_async_params.rb', line 74

Instance Attribute Details

#amountInteger?

Value in specified currency's smallest unit. e.g. $10 would be represented as 1000.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


15
# File 'lib/modern_treasury/models/incoming_payment_detail_create_async_params.rb', line 15

optional :amount, Integer

#as_of_dateDate?

Defaults to today.

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


21
# File 'lib/modern_treasury/models/incoming_payment_detail_create_async_params.rb', line 21

optional :as_of_date, Date, nil?: true

#currencySymbol, ...

Defaults to the currency of the originating account.

Parameters:

  • value (ModernTreasury::Models::currency, nil)

Returns:



27
# File 'lib/modern_treasury/models/incoming_payment_detail_create_async_params.rb', line 27

optional :currency, enum: -> { ModernTreasury::Currency }, nil?: true

#dataObject?

An object passed through to the simulated IPD that could reflect what a vendor would pass.

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


34
# File 'lib/modern_treasury/models/incoming_payment_detail_create_async_params.rb', line 34

optional :data, ModernTreasury::Internal::Type::Unknown, nil?: true

#descriptionString?

Defaults to a random description.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


40
# File 'lib/modern_treasury/models/incoming_payment_detail_create_async_params.rb', line 40

optional :description, String, nil?: true

#directionSymbol, ...

One of credit, debit.



46
# File 'lib/modern_treasury/models/incoming_payment_detail_create_async_params.rb', line 46

optional :direction, enum: -> { ModernTreasury::IncomingPaymentDetailCreateAsyncParams::Direction }

#internal_account_idString?

The ID of one of your internal accounts.

Parameters:

  • (String)

Returns:

  • (String, nil)


52
# File 'lib/modern_treasury/models/incoming_payment_detail_create_async_params.rb', line 52

optional :internal_account_id, String

#subtypeString?

An additional layer of classification for the type of incoming payment detail, e.g. ethereum for a stablecoin type.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


59
# File 'lib/modern_treasury/models/incoming_payment_detail_create_async_params.rb', line 59

optional :subtype, String, nil?: true

#typeSymbol, ...

One of ach, wire, check.



65
# File 'lib/modern_treasury/models/incoming_payment_detail_create_async_params.rb', line 65

optional :type, enum: -> { ModernTreasury::IncomingPaymentDetailCreateAsyncParams::Type }

#virtual_account_idString?

An optional parameter to associate the incoming payment detail to a virtual account.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


72
# File 'lib/modern_treasury/models/incoming_payment_detail_create_async_params.rb', line 72

optional :virtual_account_id, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/incoming_payment_detail_create_async_params.rb', line 108

Instance Method Details

#to_hash{

Returns:

  • ({)


68
# File 'sig/modern_treasury/models/incoming_payment_detail_create_async_params.rbs', line 68

def to_hash: -> {