Class: ModernTreasury::Models::IncomingPaymentDetailListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/modern_treasury/models/incoming_payment_detail_list_params.rb,
sig/modern_treasury/models/incoming_payment_detail_list_params.rbs

Overview

See Also:

  • ModernTreasury::Resources::IncomingPaymentDetails#list

Defined Under Namespace

Modules: Status, Type

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::ModernTreasury

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after_cursor: nil, as_of_date_end: nil, as_of_date_start: nil, direction: nil, metadata: nil, per_page: nil, status: nil, subtype: nil, type: nil, virtual_account_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::IncomingPaymentDetailListParams for more details.

Parameters:

  • after_cursor (String, nil) (defaults to: nil)
  • as_of_date_end (Date) (defaults to: nil)

    Filters incoming payment details with an as_of_date starting on or before the sp

  • as_of_date_start (Date) (defaults to: nil)

    Filters incoming payment details with an as_of_date starting on or after the spe

  • direction (Symbol, ModernTreasury::Models::TransactionDirection) (defaults to: nil)

    One of credit or debit.

  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    For example, if you want to query for records with metadata key Type and value

  • per_page (Integer) (defaults to: nil)
  • status (Symbol, ModernTreasury::Models::IncomingPaymentDetailListParams::Status) (defaults to: nil)

    The current status of the incoming payment order. One of pending, completed,

  • subtype (String) (defaults to: nil)

    An additional layer of classification for the type of incoming payment detail. F

  • type (Symbol, ModernTreasury::Models::IncomingPaymentDetailListParams::Type) (defaults to: nil)

    One of: ach, book, check, eft, rtp, sepa, or wire.

  • virtual_account_id (String) (defaults to: nil)

    If the incoming payment detail is in a virtual account, the ID of the Virtual Ac

  • request_options (ModernTreasury::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/modern_treasury/models/incoming_payment_detail_list_params.rb', line 76

Instance Attribute Details

#after_cursorString?

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


13
# File 'lib/modern_treasury/models/incoming_payment_detail_list_params.rb', line 13

optional :after_cursor, String, nil?: true

#as_of_date_endDate?

Filters incoming payment details with an as_of_date starting on or before the specified date (YYYY-MM-DD).

Parameters:

  • (Date)

Returns:

  • (Date, nil)


20
# File 'lib/modern_treasury/models/incoming_payment_detail_list_params.rb', line 20

optional :as_of_date_end, Date

#as_of_date_startDate?

Filters incoming payment details with an as_of_date starting on or after the specified date (YYYY-MM-DD).

Parameters:

  • (Date)

Returns:

  • (Date, nil)


27
# File 'lib/modern_treasury/models/incoming_payment_detail_list_params.rb', line 27

optional :as_of_date_start, Date

#directionSymbol, ...

One of credit or debit.



33
# File 'lib/modern_treasury/models/incoming_payment_detail_list_params.rb', line 33

optional :direction, enum: -> { ModernTreasury::TransactionDirection }

#metadataHash{Symbol=>String}?

For example, if you want to query for records with metadata key Type and value Loan, the query would be metadata%5BType%5D=Loan. This encodes the query parameters.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


41
# File 'lib/modern_treasury/models/incoming_payment_detail_list_params.rb', line 41

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#per_pageInteger?

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


46
# File 'lib/modern_treasury/models/incoming_payment_detail_list_params.rb', line 46

optional :per_page, Integer

#statusSymbol, ...

The current status of the incoming payment order. One of pending, completed, or returned.



53
# File 'lib/modern_treasury/models/incoming_payment_detail_list_params.rb', line 53

optional :status, enum: -> { ModernTreasury::IncomingPaymentDetailListParams::Status }

#subtypeString?

An additional layer of classification for the type of incoming payment detail. For example, a type of stablecoin may have a subtype of ethereum or solana.

Parameters:

  • (String)

Returns:

  • (String, nil)


61
# File 'lib/modern_treasury/models/incoming_payment_detail_list_params.rb', line 61

optional :subtype, String

#typeSymbol, ...

One of: ach, book, check, eft, rtp, sepa, or wire.



67
# File 'lib/modern_treasury/models/incoming_payment_detail_list_params.rb', line 67

optional :type, enum: -> { ModernTreasury::IncomingPaymentDetailListParams::Type }

#virtual_account_idString?

If the incoming payment detail is in a virtual account, the ID of the Virtual Account.

Parameters:

  • (String)

Returns:

  • (String, nil)


74
# File 'lib/modern_treasury/models/incoming_payment_detail_list_params.rb', line 74

optional :virtual_account_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/incoming_payment_detail_list_params.rb', line 111

Instance Method Details

#to_hash{

Returns:

  • ({)


80
# File 'sig/modern_treasury/models/incoming_payment_detail_list_params.rbs', line 80

def to_hash: -> {