Class: ModernTreasury::Models::InternalAccount
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::InternalAccount
- Defined in:
- lib/modern_treasury/models/internal_account.rb,
sig/modern_treasury/models/internal_account.rbs
Overview
Defined Under Namespace
Modules: AccountType, PartyType, Status Classes: AccountCapability
Instance Attribute Summary collapse
-
#account_capabilities ⇒ Array<ModernTreasury::Models::InternalAccount::AccountCapability>
An array of AccountCapability objects that list the originating abilities of the internal account and any relevant information for them.
-
#account_details ⇒ Array<ModernTreasury::Models::AccountDetail>
An array of account detail objects.
-
#account_type ⇒ Symbol, ...
Can be checking, savings or other.
-
#connection ⇒ ModernTreasury::Models::Connection
Specifies which financial institution the accounts belong to.
-
#contra_ledger_account_id ⇒ String?
If the internal account links to a contra ledger account in Modern Treasury, the id of the contra ledger account will be populated here.
-
#counterparty_id ⇒ String?
The Counterparty associated to this account.
- #created_at ⇒ Time
-
#currency ⇒ Symbol, ModernTreasury::Models::Currency
The currency of the account.
-
#debitable ⇒ Boolean?
Whether this account can receive ACH debits.
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
- #id ⇒ String
-
#ledger_account_id ⇒ String?
If the internal account links to a ledger account in Modern Treasury, the id of the ledger account will be populated here.
-
#legal_entity_id ⇒ String?
The Legal Entity associated to this account.
-
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
-
#metadata ⇒ Hash{Symbol=>String}
Additional data represented as key-value pairs.
-
#name ⇒ String?
A nickname for the account.
- #object ⇒ String
-
#parent_account_id ⇒ String?
The parent InternalAccount of this account.
-
#party_address ⇒ ModernTreasury::Models::Address?
The address associated with the owner or null.
-
#party_name ⇒ String
The legal name of the entity which owns the account.
-
#party_type ⇒ Symbol, ...
Either individual or business.
-
#routing_details ⇒ Array<ModernTreasury::Models::RoutingDetail>
An array of routing detail objects.
-
#status ⇒ Symbol, ...
The internal account status.
- #updated_at ⇒ Time
-
#vendor_id ⇒ String?
The vendor ID associated with this account.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
83 |
# File 'sig/modern_treasury/models/internal_account.rbs', line 83
def initialize: (
|
Instance Attribute Details
#account_capabilities ⇒ Array<ModernTreasury::Models::InternalAccount::AccountCapability>
An array of AccountCapability objects that list the originating abilities of the internal account and any relevant information for them.
17 18 |
# File 'lib/modern_treasury/models/internal_account.rb', line 17 required :account_capabilities, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::InternalAccount::AccountCapability] } |
#account_details ⇒ Array<ModernTreasury::Models::AccountDetail>
An array of account detail objects.
24 |
# File 'lib/modern_treasury/models/internal_account.rb', line 24 required :account_details, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::AccountDetail] } |
#account_type ⇒ Symbol, ...
Can be checking, savings or other.
30 |
# File 'lib/modern_treasury/models/internal_account.rb', line 30 required :account_type, enum: -> { ModernTreasury::InternalAccount::AccountType }, nil?: true |
#connection ⇒ ModernTreasury::Models::Connection
Specifies which financial institution the accounts belong to.
36 |
# File 'lib/modern_treasury/models/internal_account.rb', line 36 required :connection, -> { ModernTreasury::Connection } |
#contra_ledger_account_id ⇒ String?
If the internal account links to a contra ledger account in Modern Treasury, the id of the contra ledger account will be populated here.
43 |
# File 'lib/modern_treasury/models/internal_account.rb', line 43 required :contra_ledger_account_id, String, nil?: true |
#counterparty_id ⇒ String?
The Counterparty associated to this account.
49 |
# File 'lib/modern_treasury/models/internal_account.rb', line 49 required :counterparty_id, String, nil?: true |
#created_at ⇒ Time
54 |
# File 'lib/modern_treasury/models/internal_account.rb', line 54 required :created_at, Time |
#currency ⇒ Symbol, ModernTreasury::Models::Currency
The currency of the account.
60 |
# File 'lib/modern_treasury/models/internal_account.rb', line 60 required :currency, enum: -> { ModernTreasury::Currency } |
#debitable ⇒ Boolean?
Whether this account can receive ACH debits. Only applicable to accounts created
under a Modern Treasury PSP connection, or null for Bring Your Own Bank
accounts. Defaults to false. Configurable only on creation. Please reach out
to your customer success manager to enable this capability for your connection.
69 |
# File 'lib/modern_treasury/models/internal_account.rb', line 69 required :debitable, ModernTreasury::Internal::Type::Boolean, nil?: true |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
75 |
# File 'lib/modern_treasury/models/internal_account.rb', line 75 required :external_id, String, nil?: true |
#id ⇒ String
10 |
# File 'lib/modern_treasury/models/internal_account.rb', line 10 required :id, String |
#ledger_account_id ⇒ String?
If the internal account links to a ledger account in Modern Treasury, the id of the ledger account will be populated here.
82 |
# File 'lib/modern_treasury/models/internal_account.rb', line 82 required :ledger_account_id, String, nil?: true |
#legal_entity_id ⇒ String?
The Legal Entity associated to this account.
88 |
# File 'lib/modern_treasury/models/internal_account.rb', line 88 required :legal_entity_id, String, nil?: true |
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
95 |
# File 'lib/modern_treasury/models/internal_account.rb', line 95 required :live_mode, ModernTreasury::Internal::Type::Boolean |
#metadata ⇒ Hash{Symbol=>String}
Additional data represented as key-value pairs. Both the key and value must be strings.
102 |
# File 'lib/modern_treasury/models/internal_account.rb', line 102 required :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#name ⇒ String?
A nickname for the account.
108 |
# File 'lib/modern_treasury/models/internal_account.rb', line 108 required :name, String, nil?: true |
#object ⇒ String
113 |
# File 'lib/modern_treasury/models/internal_account.rb', line 113 required :object, String |
#parent_account_id ⇒ String?
The parent InternalAccount of this account.
119 |
# File 'lib/modern_treasury/models/internal_account.rb', line 119 required :parent_account_id, String, nil?: true |
#party_address ⇒ ModernTreasury::Models::Address?
The address associated with the owner or null.
125 |
# File 'lib/modern_treasury/models/internal_account.rb', line 125 required :party_address, -> { ModernTreasury::Address }, nil?: true |
#party_name ⇒ String
The legal name of the entity which owns the account.
131 |
# File 'lib/modern_treasury/models/internal_account.rb', line 131 required :party_name, String |
#party_type ⇒ Symbol, ...
Either individual or business.
137 |
# File 'lib/modern_treasury/models/internal_account.rb', line 137 required :party_type, enum: -> { ModernTreasury::InternalAccount::PartyType }, nil?: true |
#routing_details ⇒ Array<ModernTreasury::Models::RoutingDetail>
An array of routing detail objects.
143 |
# File 'lib/modern_treasury/models/internal_account.rb', line 143 required :routing_details, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::RoutingDetail] } |
#status ⇒ Symbol, ...
The internal account status.
149 |
# File 'lib/modern_treasury/models/internal_account.rb', line 149 required :status, enum: -> { ModernTreasury::InternalAccount::Status }, nil?: true |
#updated_at ⇒ Time
154 |
# File 'lib/modern_treasury/models/internal_account.rb', line 154 required :updated_at, Time |
#vendor_id ⇒ String?
The vendor ID associated with this account.
160 |
# File 'lib/modern_treasury/models/internal_account.rb', line 160 required :vendor_id, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/internal_account.rb', line 325
|
Instance Method Details
#to_hash ⇒ {
111 |
# File 'sig/modern_treasury/models/internal_account.rbs', line 111
def to_hash: -> {
|