Class: ModernTreasury::Models::InternalAccount::AccountCapability
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::InternalAccount::AccountCapability
- Defined in:
- lib/modern_treasury/models/internal_account.rb,
sig/modern_treasury/models/internal_account.rbs
Defined Under Namespace
Modules: PaymentType
Instance Attribute Summary collapse
- #created_at ⇒ Time
-
#direction ⇒ Symbol, ModernTreasury::Models::TransactionDirection
One of
debitorcredit. - #discarded_at ⇒ Time?
- #id ⇒ String
-
#identifier ⇒ String?
A unique reference assigned by your bank for tracking and recognizing payment files.
-
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
- #object ⇒ String
-
#payment_type ⇒ Symbol, ModernTreasury::Models::InternalAccount::AccountCapability::PaymentType
Indicates the the type of payment this capability is responsible for originating.
- #updated_at ⇒ Time
Instance Method Summary collapse
-
#initialize(id:, created_at:, direction:, discarded_at:, identifier:, live_mode:, object:, payment_type:, updated_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see AccountCapability for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, direction:, discarded_at:, identifier:, live_mode:, object:, payment_type:, updated_at:) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::InternalAccount::AccountCapability for more details.
216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/modern_treasury/models/internal_account.rb', line 216 class AccountCapability < ModernTreasury::Internal::Type::BaseModel # @!attribute id # # @return [String] required :id, String # @!attribute created_at # # @return [Time] required :created_at, Time # @!attribute direction # One of `debit` or `credit`. Indicates the direction of money movement this # capability is responsible for. # # @return [Symbol, ModernTreasury::Models::TransactionDirection] required :direction, enum: -> { ModernTreasury::TransactionDirection } # @!attribute discarded_at # # @return [Time, nil] required :discarded_at, Time, nil?: true # @!attribute identifier # A unique reference assigned by your bank for tracking and recognizing payment # files. It is important this is formatted exactly how the bank assigned it. # # @return [String, nil] required :identifier, String, nil?: true # @!attribute live_mode # This field will be true if this object exists in the live environment or false # if it exists in the test environment. # # @return [Boolean] required :live_mode, ModernTreasury::Internal::Type::Boolean # @!attribute object # # @return [String] required :object, String # @!attribute payment_type # Indicates the the type of payment this capability is responsible for # originating. # # @return [Symbol, ModernTreasury::Models::InternalAccount::AccountCapability::PaymentType] required :payment_type, enum: -> { ModernTreasury::InternalAccount::AccountCapability::PaymentType } # @!attribute updated_at # # @return [Time] required :updated_at, Time # @!method initialize(id:, created_at:, direction:, discarded_at:, identifier:, live_mode:, object:, payment_type:, updated_at:) # Some parameter documentations has been truncated, see # {ModernTreasury::Models::InternalAccount::AccountCapability} for more details. # # @param id [String] # # @param created_at [Time] # # @param direction [Symbol, ModernTreasury::Models::TransactionDirection] One of `debit` or `credit`. Indicates the direction of money movement this capab # # @param discarded_at [Time, nil] # # @param identifier [String, nil] A unique reference assigned by your bank for tracking and recognizing payment fi # # @param live_mode [Boolean] This field will be true if this object exists in the live environment or false i # # @param object [String] # # @param payment_type [Symbol, ModernTreasury::Models::InternalAccount::AccountCapability::PaymentType] Indicates the the type of payment this capability is responsible for originating # # @param updated_at [Time] # Indicates the the type of payment this capability is responsible for # originating. # # @see ModernTreasury::Models::InternalAccount::AccountCapability#payment_type module PaymentType extend ModernTreasury::Internal::Type::Enum ACH = :ach AU_BECS = :au_becs BACS = :bacs BOOK = :book CARD = :card CHATS = :chats CHECK = :check CROSS_BORDER = :cross_border DK_NETS = :dk_nets EFT = :eft GB_FPS = :gb_fps MASAV = :masav MX_CCEN = :mx_ccen NEFT = :neft NICS = :nics NZ_BECS = :nz_becs PL_ELIXIR = :pl_elixir RTP = :rtp SE_BANKGIROT = :se_bankgirot SEPA = :sepa SG_GIRO = :sg_giro SIC = :sic STABLECOIN = :stablecoin WIRE = :wire ZENGIN = :zengin # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#created_at ⇒ Time
225 |
# File 'lib/modern_treasury/models/internal_account.rb', line 225 required :created_at, Time |
#direction ⇒ Symbol, ModernTreasury::Models::TransactionDirection
One of debit or credit. Indicates the direction of money movement this
capability is responsible for.
232 |
# File 'lib/modern_treasury/models/internal_account.rb', line 232 required :direction, enum: -> { ModernTreasury::TransactionDirection } |
#discarded_at ⇒ Time?
237 |
# File 'lib/modern_treasury/models/internal_account.rb', line 237 required :discarded_at, Time, nil?: true |
#id ⇒ String
220 |
# File 'lib/modern_treasury/models/internal_account.rb', line 220 required :id, String |
#identifier ⇒ String?
A unique reference assigned by your bank for tracking and recognizing payment files. It is important this is formatted exactly how the bank assigned it.
244 |
# File 'lib/modern_treasury/models/internal_account.rb', line 244 required :identifier, String, nil?: true |
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
251 |
# File 'lib/modern_treasury/models/internal_account.rb', line 251 required :live_mode, ModernTreasury::Internal::Type::Boolean |
#object ⇒ String
256 |
# File 'lib/modern_treasury/models/internal_account.rb', line 256 required :object, String |
#payment_type ⇒ Symbol, ModernTreasury::Models::InternalAccount::AccountCapability::PaymentType
Indicates the the type of payment this capability is responsible for originating.
263 |
# File 'lib/modern_treasury/models/internal_account.rb', line 263 required :payment_type, enum: -> { ModernTreasury::InternalAccount::AccountCapability::PaymentType } |
#updated_at ⇒ Time
268 |
# File 'lib/modern_treasury/models/internal_account.rb', line 268 required :updated_at, Time |
Instance Method Details
#to_hash ⇒ {
183 |
# File 'sig/modern_treasury/models/internal_account.rbs', line 183
def to_hash: -> {
|