Class: ModernTreasury::Models::InternalAccountCreateParams::AccountCapability
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::InternalAccountCreateParams::AccountCapability
- Defined in:
- lib/modern_treasury/models/internal_account_create_params.rb,
sig/modern_treasury/models/internal_account_create_params.rbs
Defined Under Namespace
Modules: PaymentType
Instance Attribute Summary collapse
- #created_at ⇒ Time
-
#direction ⇒ Symbol, ModernTreasury::Models::TransactionDirection
One of
debitorcredit. - #discarded_at ⇒ Time?
- #id ⇒ String
-
#identifier ⇒ String?
A unique reference assigned by your bank for tracking and recognizing payment files.
-
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
- #object ⇒ String
-
#payment_type ⇒ Symbol, ModernTreasury::Models::InternalAccountCreateParams::AccountCapability::PaymentType
Indicates the the type of payment this capability is responsible for originating.
- #updated_at ⇒ Time
Instance Method Summary collapse
-
#initialize(id:, created_at:, direction:, discarded_at:, identifier:, live_mode:, object:, payment_type:, updated_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see AccountCapability for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, direction:, discarded_at:, identifier:, live_mode:, object:, payment_type:, updated_at:) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::InternalAccountCreateParams::AccountCapability for more details.
|
|
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 208
|
Instance Attribute Details
#created_at ⇒ Time
162 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 162 required :created_at, Time |
#direction ⇒ Symbol, ModernTreasury::Models::TransactionDirection
One of debit or credit. Indicates the direction of money movement this
capability is responsible for.
169 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 169 required :direction, enum: -> { ModernTreasury::TransactionDirection } |
#discarded_at ⇒ Time?
174 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 174 required :discarded_at, Time, nil?: true |
#id ⇒ String
157 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 157 required :id, String |
#identifier ⇒ String?
A unique reference assigned by your bank for tracking and recognizing payment files. It is important this is formatted exactly how the bank assigned it.
181 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 181 required :identifier, String, nil?: true |
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
188 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 188 required :live_mode, ModernTreasury::Internal::Type::Boolean |
#object ⇒ String
193 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 193 required :object, String |
#payment_type ⇒ Symbol, ModernTreasury::Models::InternalAccountCreateParams::AccountCapability::PaymentType
Indicates the the type of payment this capability is responsible for originating.
200 201 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 200 required :payment_type, enum: -> { ModernTreasury::InternalAccountCreateParams::AccountCapability::PaymentType } |
#updated_at ⇒ Time
206 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 206 required :updated_at, Time |
Instance Method Details
#to_hash ⇒ {
173 |
# File 'sig/modern_treasury/models/internal_account_create_params.rbs', line 173
def to_hash: -> {
|