Class: ModernTreasury::Models::InternalAccounts::BalanceReport

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/internal_accounts/balance_report.rb,
sig/modern_treasury/models/internal_accounts/balance_report.rbs

Overview

See Also:

  • ModernTreasury::Resources::InternalAccounts::BalanceReports#create

Defined Under Namespace

Modules: BalanceReportType Classes: Balance

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, as_of_date:, as_of_time:, balance_report_type:, balances:, created_at:, internal_account_id:, live_mode:, object:, updated_at:) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::InternalAccounts::BalanceReport for more details.

Parameters:

  • id (String)
  • as_of_date (Date)

    The date of the balance report in local time.

  • as_of_time (Time)

    The time (24-hour clock) of the balance report in local time.

  • balance_report_type (Symbol, ModernTreasury::Models::InternalAccounts::BalanceReport::BalanceReportType)

    The specific type of balance report. One of intraday, previous_day, `real_ti

  • balances (Array<ModernTreasury::Models::InternalAccounts::BalanceReport::Balance>)

    An array of Balance objects.

  • created_at (Time)
  • internal_account_id (String)

    The ID of one of your organization's Internal Accounts.

  • live_mode (Boolean)

    This field will be true if this object exists in the live environment or false i

  • object (String)
  • updated_at (Time)


# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 68

Instance Attribute Details

#as_of_dateDate

The date of the balance report in local time.

Parameters:

  • value (Date)

Returns:

  • (Date)


17
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 17

required :as_of_date, Date

#as_of_timeTime

The time (24-hour clock) of the balance report in local time.

Parameters:

  • value (Time)

Returns:

  • (Time)


23
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 23

required :as_of_time, Time

#balance_report_typeSymbol, ModernTreasury::Models::InternalAccounts::BalanceReport::BalanceReportType

The specific type of balance report. One of intraday, previous_day, real_time, or other.

Parameters:

  • value (ModernTreasury::Models::InternalAccounts::BalanceReport::balance_report_type)

Returns:



30
31
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 30

required :balance_report_type,
enum: -> { ModernTreasury::InternalAccounts::BalanceReport::BalanceReportType }

#balancesArray<ModernTreasury::Models::InternalAccounts::BalanceReport::Balance>

An array of Balance objects.

Parameters:

  • value (::Array[ModernTreasury::InternalAccounts::BalanceReport::Balance])

Returns:



37
38
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 37

required :balances,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::InternalAccounts::BalanceReport::Balance] }

#created_atTime

Parameters:

  • value (Time)

Returns:

  • (Time)


43
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 43

required :created_at, Time

#idString

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 11

required :id, String

#internal_account_idString

The ID of one of your organization's Internal Accounts.

Parameters:

  • value (String)

Returns:

  • (String)


49
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 49

required :internal_account_id, String

#live_modeBoolean

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


56
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 56

required :live_mode, ModernTreasury::Internal::Type::Boolean

#objectString

Parameters:

  • value (String)

Returns:

  • (String)


61
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 61

required :object, String

#updated_atTime

Parameters:

  • value (Time)

Returns:

  • (Time)


66
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 66

required :updated_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 104

Instance Method Details

#to_hash{

Returns:

  • ({)


52
# File 'sig/modern_treasury/models/internal_accounts/balance_report.rbs', line 52

def to_hash: -> {