Class: ModernTreasury::Models::InternalAccounts::BalanceReportCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::InternalAccounts::BalanceReportCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb,
sig/modern_treasury/models/internal_accounts/balance_report_create_params.rbs
Overview
Defined Under Namespace
Modules: BalanceReportType Classes: Balance
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ModernTreasury
Instance Attribute Summary collapse
-
#as_of_date ⇒ Date
The date of the balance report in local time.
-
#as_of_time ⇒ String
The time (24-hour clock) of the balance report in local time.
-
#balance_report_type ⇒ Symbol, ModernTreasury::Models::InternalAccounts::BalanceReportCreateParams::BalanceReportType
The specific type of balance report.
-
#balances ⇒ Array<ModernTreasury::Models::InternalAccounts::BalanceReportCreateParams::Balance>
An array of
Balanceobjects. - #internal_account_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(internal_account_id:, as_of_date:, as_of_time:, balance_report_type:, balances:, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see BalanceReportCreateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(internal_account_id:, as_of_date:, as_of_time:, balance_report_type:, balances:, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::InternalAccounts::BalanceReportCreateParams for more details.
|
|
# File 'lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb', line 43
|
Instance Attribute Details
#as_of_date ⇒ Date
The date of the balance report in local time.
20 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb', line 20 required :as_of_date, Date |
#as_of_time ⇒ String
The time (24-hour clock) of the balance report in local time.
26 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb', line 26 required :as_of_time, String |
#balance_report_type ⇒ Symbol, ModernTreasury::Models::InternalAccounts::BalanceReportCreateParams::BalanceReportType
The specific type of balance report. One of intraday, previous_day,
real_time, or other.
33 34 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb', line 33 required :balance_report_type, enum: -> { ModernTreasury::InternalAccounts::BalanceReportCreateParams::BalanceReportType } |
#balances ⇒ Array<ModernTreasury::Models::InternalAccounts::BalanceReportCreateParams::Balance>
An array of Balance objects.
40 41 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb', line 40 required :balances, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::InternalAccounts::BalanceReportCreateParams::Balance] } |
#internal_account_id ⇒ String
14 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb', line 14 required :internal_account_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb', line 70
|
Instance Method Details
#to_hash ⇒ {
37 |
# File 'sig/modern_treasury/models/internal_accounts/balance_report_create_params.rbs', line 37
def to_hash: -> {
|