Class: ModernTreasury::Models::InternalAccounts::BalanceReportCreateParams::Balance

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb,
sig/modern_treasury/models/internal_accounts/balance_report_create_params.rbs

Defined Under Namespace

Modules: BalanceType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(balance_type:, vendor_code:, vendor_code_type:, amount: nil, amount_string: nil) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::InternalAccounts::BalanceReportCreateParams::Balance for more details.

Parameters:

  • balance_type (Symbol, ModernTreasury::Models::InternalAccounts::BalanceReportCreateParams::Balance::BalanceType)

    The specific type of balance reported. One of opening_ledger, closing_ledger

  • vendor_code (String)

    The code used by the bank when reporting this specific balance.

  • vendor_code_type (String, nil)

    The type of vendor_code being reported. Can be one of bai2, bankprov, `bnk

  • amount (Integer) (defaults to: nil)

    The balance amount.

  • amount_string (String) (defaults to: nil)

    The amount of the balance as a string, preserving full precision for values that



# File 'lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb', line 113

Instance Attribute Details

#amountInteger?

The balance amount.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


104
# File 'lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb', line 104

optional :amount, Integer

#amount_stringString?

The amount of the balance as a string, preserving full precision for values that may exceed safe integer limits in some languages.

Parameters:

  • (String)

Returns:

  • (String, nil)


111
# File 'lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb', line 111

optional :amount_string, String

#balance_typeSymbol, ModernTreasury::Models::InternalAccounts::BalanceReportCreateParams::Balance::BalanceType

The specific type of balance reported. One of opening_ledger, closing_ledger, current_ledger, opening_available, opening_available_next_business_day, closing_available, current_available, 'previously_closed_book', or other.

Parameters:

  • value (ModernTreasury::Models::InternalAccounts::BalanceReportCreateParams::Balance::balance_type)

Returns:



82
83
# File 'lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb', line 82

required :balance_type,
enum: -> { ModernTreasury::InternalAccounts::BalanceReportCreateParams::Balance::BalanceType }

#vendor_codeString

The code used by the bank when reporting this specific balance.

Parameters:

  • value (String)

Returns:

  • (String)


89
# File 'lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb', line 89

required :vendor_code, String

#vendor_code_typeString?

The type of vendor_code being reported. Can be one of bai2, bankprov, bnk_dev, cleartouch, currencycloud, cross_river, dc_bank, dwolla, evolve, goldman_sachs, iso20022, jpmc, mx, silvergate, swift, or us_bank.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


98
# File 'lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb', line 98

required :vendor_code_type, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


92
# File 'sig/modern_treasury/models/internal_accounts/balance_report_create_params.rbs', line 92

def to_hash: -> {