Module: ModernTreasury::Models::Invoice::PaymentMethod
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/modern_treasury/models/invoice.rb,
sig/modern_treasury/models/invoice.rbs
Overview
When opening an invoice, whether to show the embedded payment UI , automatically debit the recipient, or rely on manual payment from the recipient.
Constant Summary collapse
- UI =
:ui- MANUAL =
:manual- AUTOMATIC =
:automatic
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[ModernTreasury::Models::Invoice::payment_method]
360 |
# File 'sig/modern_treasury/models/invoice.rbs', line 360
def self?.values: -> ::Array[ModernTreasury::Models::Invoice::payment_method]
|