Class: ModernTreasury::Models::InvoiceCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/modern_treasury/models/invoice_create_params.rb,
sig/modern_treasury/models/invoice_create_params.rbs

Overview

See Also:

  • ModernTreasury::Resources::Invoices#create

Defined Under Namespace

Modules: PaymentMethod Classes: CounterpartyBillingAddress, CounterpartyShippingAddress, InvoiceLineItem, InvoicerAddress

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::ModernTreasury

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(country:, line1:, locality:, postal_code:, region:, line2: nil) ⇒ Object

The invoice issuer's business address.

Parameters:

  • country (String)

    Country code conforms to [ISO 3166-1 alpha-2]

  • line1 (String)
  • locality (String)

    Locality or City.

  • postal_code (String)

    The postal code of the address.

  • region (String)

    Region or State.

  • line2 (String) (defaults to: nil)


# File 'lib/modern_treasury/models/invoice_create_params.rb', line 272

Instance Attribute Details

#auto_advanceBoolean?

When true, the invoice will progress to unpaid automatically and cannot be edited after entering that state. If the invoice fails to progress to unpaid, the errors will be returned and the invoice will not be created.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


34
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 34

optional :auto_advance, ModernTreasury::Internal::Type::Boolean, nil?: true

#contact_detailsArray<ModernTreasury::Models::ContactDetail>?

The invoicer's contact details displayed at the top of the invoice.

Returns:



40
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 40

optional :contact_details, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ContactDetail] }

#counterparty_billing_addressModernTreasury::Models::InvoiceCreateParams::CounterpartyBillingAddress?

The counterparty's billing address.

Parameters:

  • value (ModernTreasury::InvoiceCreateParams::CounterpartyBillingAddress, nil)

Returns:



46
47
48
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 46

optional :counterparty_billing_address,
-> { ModernTreasury::InvoiceCreateParams::CounterpartyBillingAddress },
nil?: true

#counterparty_idString

The ID of the counterparty receiving the invoice.

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 14

required :counterparty_id, String

#counterparty_shipping_addressModernTreasury::Models::InvoiceCreateParams::CounterpartyShippingAddress?

The counterparty's shipping address where physical goods should be delivered.

Parameters:

  • value (ModernTreasury::InvoiceCreateParams::CounterpartyShippingAddress, nil)

Returns:



54
55
56
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 54

optional :counterparty_shipping_address,
-> { ModernTreasury::InvoiceCreateParams::CounterpartyShippingAddress },
nil?: true

#currencySymbol, ...

Currency that the invoice is denominated in. Defaults to USD if not provided.

Returns:



62
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 62

optional :currency, enum: -> { ModernTreasury::Currency }

#descriptionString?

A free-form description of the invoice.

Parameters:

  • (String)

Returns:

  • (String, nil)


68
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 68

optional :description, String

#due_dateTime

A future date by when the invoice needs to be paid.

Parameters:

  • value (Time)

Returns:

  • (Time)


20
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 20

required :due_date, Time

#fallback_payment_methodString?

When payment_method is automatic, the fallback payment method to use when an automatic payment fails. One of manual or ui.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


75
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 75

optional :fallback_payment_method, String, nil?: true

#invoice_line_itemsArray<ModernTreasury::Models::InvoiceCreateParams::InvoiceLineItem>?

An array of invoice line items. The API supports a maximum of 50 invoice line items per invoice. If a greater number of invoice line items is required, please contact support.

Parameters:

  • value (::Array[ModernTreasury::InvoiceCreateParams::InvoiceLineItem], nil)

Returns:



83
84
85
86
87
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 83

optional :invoice_line_items,
-> {
  ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::InvoiceCreateParams::InvoiceLineItem]
},
nil?: true

#invoicer_addressModernTreasury::Models::InvoiceCreateParams::InvoicerAddress?

The invoice issuer's business address.

Parameters:

  • value (ModernTreasury::InvoiceCreateParams::InvoicerAddress, nil)

Returns:



93
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 93

optional :invoicer_address, -> { ModernTreasury::InvoiceCreateParams::InvoicerAddress }, nil?: true

#invoicer_nameString?

The name of the issuer for the invoice. Defaults to the name of the Organization.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


100
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 100

optional :invoicer_name, String, nil?: true

#metadataHash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Parameters:

  • value (::Hash[Symbol, String], nil)

Returns:

  • (Hash{Symbol=>String}, nil)


107
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 107

optional :metadata, ModernTreasury::Internal::Type::HashOf[String], nil?: true

#notification_email_addressesArray<String>?

Emails in addition to the counterparty email to send invoice status notifications to. At least one email is required if notifications are enabled and the counterparty doesn't have an email.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


115
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 115

optional :notification_email_addresses, ModernTreasury::Internal::Type::ArrayOf[String], nil?: true

#notifications_enabledBoolean?

If true, the invoice will send email notifications to the invoice recipients about invoice status changes.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


122
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 122

optional :notifications_enabled, ModernTreasury::Internal::Type::Boolean

#originating_account_idString

The ID of the internal account the invoice should be paid to.

Parameters:

  • value (String)

Returns:

  • (String)


26
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 26

required :originating_account_id, String

#payment_effective_dateDate?

Date transactions are to be posted to the participants' account. Defaults to the current business day or the next business day if the current day is a bank holiday or weekend. Format: yyyy-mm-dd.

Parameters:

  • (Date)

Returns:

  • (Date, nil)


130
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 130

optional :payment_effective_date, Date

#payment_methodSymbol, ...

The method by which the invoice can be paid. ui will show the embedded payment collection flow. automatic will automatically initiate payment based upon the account details of the receiving_account id.\nIf the invoice amount is positive, the automatically initiated payment order's direction will be debit. If the invoice amount is negative, the automatically initiated payment order's direction will be credit. One of manual, ui, or automatic.



141
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 141

optional :payment_method, enum: -> { ModernTreasury::InvoiceCreateParams::PaymentMethod }

#payment_typeSymbol, ...

One of ach, se_bankgirot, eft, wire, check, book, rtp, sepa, bacs, au_becs, neft, nics, nz_national_clearing_code, sic, zengin.



148
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 148

optional :payment_type, enum: -> { ModernTreasury::PaymentOrderType }

#receiving_account_idString?

The receiving account ID. Can be an external_account.

Parameters:

  • (String)

Returns:

  • (String, nil)


154
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 154

optional :receiving_account_id, String

#recipient_emailString?

The email of the recipient of the invoice. Leaving this value as null will fallback to using the counterparty's name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


161
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 161

optional :recipient_email, String, nil?: true

#recipient_nameString?

The name of the recipient of the invoice. Leaving this value as null will fallback to using the counterparty's name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


168
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 168

optional :recipient_name, String, nil?: true

#remind_after_overdue_daysArray<Integer>?

Number of days after due date when overdue reminder emails will be sent out to invoice recipients.

Parameters:

  • value (::Array[Integer], nil)

Returns:

  • (Array<Integer>, nil)


175
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 175

optional :remind_after_overdue_days, ModernTreasury::Internal::Type::ArrayOf[Integer], nil?: true

#virtual_account_idString?

The ID of the virtual account the invoice should be paid to.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


181
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 181

optional :virtual_account_id, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


136
# File 'sig/modern_treasury/models/invoice_create_params.rbs', line 136

def to_hash: -> {