Module: ModernTreasury::Models::InvoiceCreateParams::PaymentMethod
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/modern_treasury/models/invoice_create_params.rb,
sig/modern_treasury/models/invoice_create_params.rbs
Overview
The method by which the invoice can be paid. ui will show the embedded payment
collection flow. automatic will automatically initiate payment based upon the
account details of the receiving_account id.\nIf the invoice amount is positive,
the automatically initiated payment order's direction will be debit. If the
invoice amount is negative, the automatically initiated payment order's
direction will be credit. One of manual, ui, or automatic.
Constant Summary collapse
- UI =
:ui- MANUAL =
:manual- AUTOMATIC =
:automatic
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/invoice_create_params.rb', line 472
|
Instance Method Details
#self?.values ⇒ ::Array[ModernTreasury::Models::InvoiceCreateParams::payment_method]
362 |
# File 'sig/modern_treasury/models/invoice_create_params.rbs', line 362
def self?.values: -> ::Array[ModernTreasury::Models::InvoiceCreateParams::payment_method]
|