Class: ModernTreasury::Models::Invoices::LineItemUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/modern_treasury/models/invoices/line_item_update_params.rb,
sig/modern_treasury/models/invoices/line_item_update_params.rbs

Overview

See Also:

  • ModernTreasury::Resources::Invoices::LineItems#update

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::ModernTreasury

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(invoice_id:, id:, description: nil, direction: nil, metadata: nil, name: nil, quantity: nil, unit_amount: nil, unit_amount_decimal: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::Invoices::LineItemUpdateParams for more details.

Parameters:

  • invoice_id (String)
  • id (String)
  • description (String) (defaults to: nil)

    An optional free-form description of the line item.

  • direction (String) (defaults to: nil)

    Either debit or credit. debit indicates that a client owes the business mo

  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    Additional data represented as key-value pairs. Both the key and value must be s

  • name (String) (defaults to: nil)

    The name of the line item, typically a product or SKU name.

  • quantity (Integer) (defaults to: nil)

    The number of units of a product or service that this line item is for.

  • unit_amount (Integer) (defaults to: nil)

    The cost per unit of the product or service that this line item is for,

  • unit_amount_decimal (String) (defaults to: nil)

    The cost per unit of the product or service that this line item is for,

  • request_options (ModernTreasury::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/modern_treasury/models/invoices/line_item_update_params.rb', line 70

Instance Attribute Details

#descriptionString?

An optional free-form description of the line item.

Parameters:

  • (String)

Returns:

  • (String, nil)


25
# File 'lib/modern_treasury/models/invoices/line_item_update_params.rb', line 25

optional :description, String

#directionString?

Either debit or credit. debit indicates that a client owes the business money and increases the invoice's total_amount due. credit has the opposite intention and effect.

Parameters:

  • (String)

Returns:

  • (String, nil)


33
# File 'lib/modern_treasury/models/invoices/line_item_update_params.rb', line 33

optional :direction, String

#idString

Parameters:

  • value (String)

Returns:

  • (String)


19
# File 'lib/modern_treasury/models/invoices/line_item_update_params.rb', line 19

required :id, String

#invoice_idString

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/modern_treasury/models/invoices/line_item_update_params.rb', line 14

required :invoice_id, String

#metadataHash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


40
# File 'lib/modern_treasury/models/invoices/line_item_update_params.rb', line 40

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#nameString?

The name of the line item, typically a product or SKU name.

Parameters:

  • (String)

Returns:

  • (String, nil)


46
# File 'lib/modern_treasury/models/invoices/line_item_update_params.rb', line 46

optional :name, String

#quantityInteger?

The number of units of a product or service that this line item is for. Must be a whole number. Defaults to 1 if not provided.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


53
# File 'lib/modern_treasury/models/invoices/line_item_update_params.rb', line 53

optional :quantity, Integer

#unit_amountInteger?

The cost per unit of the product or service that this line item is for, specified in the invoice currency's smallest unit.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


60
# File 'lib/modern_treasury/models/invoices/line_item_update_params.rb', line 60

optional :unit_amount, Integer

#unit_amount_decimalString?

The cost per unit of the product or service that this line item is for, specified in the invoice currency's smallest unit. Accepts decimal strings with up to 12 decimals

Parameters:

  • (String)

Returns:

  • (String, nil)


68
# File 'lib/modern_treasury/models/invoices/line_item_update_params.rb', line 68

optional :unit_amount_decimal, String

Instance Method Details

#to_hash{

Returns:

  • ({)


67
# File 'sig/modern_treasury/models/invoices/line_item_update_params.rbs', line 67

def to_hash: -> {