Module: ModernTreasury::Models::LedgerAccount::LedgerableType

Extended by:
Internal::Type::Enum
Defined in:
lib/modern_treasury/models/ledger_account.rb,
sig/modern_treasury/models/ledger_account.rbs

Overview

If the ledger account links to another object in Modern Treasury, the type will be populated here, otherwise null. The value is one of internal_account or external_account.

See Also:

  • ModernTreasury::Models::LedgerAccount#ledgerable_type

Constant Summary collapse

COUNTERPARTY =

Returns:

  • (:counterparty)
:counterparty
EXTERNAL_ACCOUNT =

Returns:

  • (:external_account)
:external_account
INTERNAL_ACCOUNT =

Returns:

  • (:internal_account)
:internal_account
VIRTUAL_ACCOUNT =

Returns:

  • (:virtual_account)
:virtual_account

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/ledger_account.rb', line 214

Instance Method Details

#self?.values::Array[ModernTreasury::Models::LedgerAccount::ledgerable_type]

Returns:

  • (::Array[ModernTreasury::Models::LedgerAccount::ledgerable_type])


142
# File 'sig/modern_treasury/models/ledger_account.rbs', line 142

def self?.values: -> ::Array[ModernTreasury::Models::LedgerAccount::ledgerable_type]