Class: ModernTreasury::Models::LedgerAccountBalanceMonitor::AlertCondition

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/ledger_account_balance_monitor.rb,
sig/modern_treasury/models/ledger_account_balance_monitor.rbs

Overview

See Also:

  • ModernTreasury::Models::LedgerAccountBalanceMonitor#alert_condition

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



78
# File 'sig/modern_treasury/models/ledger_account_balance_monitor.rbs', line 78

def initialize: (

Instance Attribute Details

#fieldString

One of available_balance_amount, pending_balance_amount, posted_balance_amount, ledger_account_lock_version.

Parameters:

  • value (String)

Returns:

  • (String)


105
# File 'lib/modern_treasury/models/ledger_account_balance_monitor.rb', line 105

required :field, String

#operatorString

A logical operator to compare the field against the value. One of less_than, less_than_or_equals, equals, greater_than_or_equals, greater_than.

Parameters:

  • value (String)

Returns:

  • (String)


113
# File 'lib/modern_treasury/models/ledger_account_balance_monitor.rb', line 113

required :operator, String

#valueInteger

The monitor's current_ledger_account_balance_state.triggered will be true when comparing the field to this integer value using the operator is logically true.

Parameters:

  • value (Integer)

Returns:

  • (Integer)


121
# File 'lib/modern_treasury/models/ledger_account_balance_monitor.rb', line 121

required :value, Integer

Instance Method Details

#to_hash{ field: String, operator: String, value: Integer }

Returns:

  • ({ field: String, operator: String, value: Integer })


84
# File 'sig/modern_treasury/models/ledger_account_balance_monitor.rbs', line 84

def to_hash: -> { field: String, operator: String, value: Integer }