Class: ModernTreasury::Models::LedgerAccountCategoryCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::LedgerAccountCategoryCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/ledger_account_category_create_params.rb
Overview
Instance Attribute Summary collapse
-
#currency ⇒ String
The currency of the ledger account category.
-
#currency_exponent ⇒ Integer?
The currency exponent of the ledger account category.
-
#description ⇒ String?
The description of the ledger account category.
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
-
#ledger_account_category_ids ⇒ Array<String>?
The array of ledger account category ids that this ledger account category should be a child of.
-
#ledger_id ⇒ String
The id of the ledger that this account category belongs to.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#name ⇒ String
The name of the ledger account category.
-
#normal_balance ⇒ Symbol, ModernTreasury::Models::TransactionDirection
The normal balance of the ledger account category.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(currency:, ledger_id:, name:, normal_balance:, currency_exponent: nil, description: nil, external_id: nil, ledger_account_category_ids: nil, metadata: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see LedgerAccountCategoryCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(currency:, ledger_id:, name:, normal_balance:, currency_exponent: nil, description: nil, external_id: nil, ledger_account_category_ids: nil, metadata: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::LedgerAccountCategoryCreateParams for more details.
|
|
# File 'lib/modern_treasury/models/ledger_account_category_create_params.rb', line 66
|
Instance Attribute Details
#currency ⇒ String
The currency of the ledger account category.
14 |
# File 'lib/modern_treasury/models/ledger_account_category_create_params.rb', line 14 required :currency, String |
#currency_exponent ⇒ Integer?
The currency exponent of the ledger account category.
38 |
# File 'lib/modern_treasury/models/ledger_account_category_create_params.rb', line 38 optional :currency_exponent, Integer, nil?: true |
#description ⇒ String?
The description of the ledger account category.
44 |
# File 'lib/modern_treasury/models/ledger_account_category_create_params.rb', line 44 optional :description, String, nil?: true |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
50 |
# File 'lib/modern_treasury/models/ledger_account_category_create_params.rb', line 50 optional :external_id, String, nil?: true |
#ledger_account_category_ids ⇒ Array<String>?
The array of ledger account category ids that this ledger account category should be a child of.
57 |
# File 'lib/modern_treasury/models/ledger_account_category_create_params.rb', line 57 optional :ledger_account_category_ids, ModernTreasury::Internal::Type::ArrayOf[String] |
#ledger_id ⇒ String
The id of the ledger that this account category belongs to.
20 |
# File 'lib/modern_treasury/models/ledger_account_category_create_params.rb', line 20 required :ledger_id, String |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
64 |
# File 'lib/modern_treasury/models/ledger_account_category_create_params.rb', line 64 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#name ⇒ String
The name of the ledger account category.
26 |
# File 'lib/modern_treasury/models/ledger_account_category_create_params.rb', line 26 required :name, String |
#normal_balance ⇒ Symbol, ModernTreasury::Models::TransactionDirection
The normal balance of the ledger account category.
32 |
# File 'lib/modern_treasury/models/ledger_account_category_create_params.rb', line 32 required :normal_balance, enum: -> { ModernTreasury::TransactionDirection } |