Class: ModernTreasury::Models::LedgerAccountCategoryListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::LedgerAccountCategoryListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/ledger_account_category_list_params.rb,
sig/modern_treasury/models/ledger_account_category_list_params.rbs
Overview
Defined Under Namespace
Classes: Balances
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ModernTreasury
Instance Attribute Summary collapse
- #after_cursor ⇒ String?
-
#balances ⇒ ModernTreasury::Models::LedgerAccountCategoryListParams::Balances?
For example, if you want the balances as of a particular time (ISO8601), the encoded query string would be
balances%5Beffective_at%5D=2000-12-31T12:00:00Z. - #currency ⇒ String?
- #external_id ⇒ String?
-
#id ⇒ Array<String>?
If you have specific IDs to retrieve in bulk, you can pass them as query parameters delimited with
id[]=, for example?id[]=123&id[]=abc. -
#ledger_account_id ⇒ String?
Query categories which contain a ledger account directly or through child categories.
- #ledger_id ⇒ String?
-
#metadata ⇒ Hash{Symbol=>String}?
For example, if you want to query for records with metadata key
Typeand valueLoan, the query would bemetadata%5BType%5D=Loan. - #name ⇒ String?
-
#parent_ledger_account_category_id ⇒ String?
Query categories that are nested underneath a parent category.
- #per_page ⇒ Integer?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
67 |
# File 'sig/modern_treasury/models/ledger_account_category_list_params.rbs', line 67
def initialize: (
|
Instance Attribute Details
#after_cursor ⇒ String?
20 |
# File 'lib/modern_treasury/models/ledger_account_category_list_params.rb', line 20 optional :after_cursor, String, nil?: true |
#balances ⇒ ModernTreasury::Models::LedgerAccountCategoryListParams::Balances?
For example, if you want the balances as of a particular time (ISO8601), the
encoded query string would be balances%5Beffective_at%5D=2000-12-31T12:00:00Z.
The balances as of a time are inclusive of entries with that exact time, but
with respect to the ledger accounts that are currently present in the category.
29 |
# File 'lib/modern_treasury/models/ledger_account_category_list_params.rb', line 29 optional :balances, -> { ModernTreasury::LedgerAccountCategoryListParams::Balances } |
#currency ⇒ String?
34 |
# File 'lib/modern_treasury/models/ledger_account_category_list_params.rb', line 34 optional :currency, String |
#external_id ⇒ String?
39 |
# File 'lib/modern_treasury/models/ledger_account_category_list_params.rb', line 39 optional :external_id, String |
#id ⇒ Array<String>?
If you have specific IDs to retrieve in bulk, you can pass them as query
parameters delimited with id[]=, for example ?id[]=123&id[]=abc.
15 |
# File 'lib/modern_treasury/models/ledger_account_category_list_params.rb', line 15 optional :id, ModernTreasury::Internal::Type::ArrayOf[String] |
#ledger_account_id ⇒ String?
Query categories which contain a ledger account directly or through child categories.
46 |
# File 'lib/modern_treasury/models/ledger_account_category_list_params.rb', line 46 optional :ledger_account_id, String |
#ledger_id ⇒ String?
51 |
# File 'lib/modern_treasury/models/ledger_account_category_list_params.rb', line 51 optional :ledger_id, String |
#metadata ⇒ Hash{Symbol=>String}?
For example, if you want to query for records with metadata key Type and value
Loan, the query would be metadata%5BType%5D=Loan. This encodes the query
parameters.
59 |
# File 'lib/modern_treasury/models/ledger_account_category_list_params.rb', line 59 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#name ⇒ String?
64 |
# File 'lib/modern_treasury/models/ledger_account_category_list_params.rb', line 64 optional :name, String |
#parent_ledger_account_category_id ⇒ String?
Query categories that are nested underneath a parent category
70 |
# File 'lib/modern_treasury/models/ledger_account_category_list_params.rb', line 70 optional :parent_ledger_account_category_id, String |
#per_page ⇒ Integer?
75 |
# File 'lib/modern_treasury/models/ledger_account_category_list_params.rb', line 75 optional :per_page, Integer |
Instance Method Details
#to_hash ⇒ {
82 |
# File 'sig/modern_treasury/models/ledger_account_category_list_params.rbs', line 82
def to_hash: -> {
|