Class: ModernTreasury::Models::LedgerAccountCategoryListParams::Balances
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::LedgerAccountCategoryListParams::Balances
- Defined in:
- lib/modern_treasury/models/ledger_account_category_list_params.rb,
sig/modern_treasury/models/ledger_account_category_list_params.rbs
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(effective_at: nil) ⇒ Balances
constructor
For example, if you want the balances as of a particular time (ISO8601), the encoded query string would be
balances%5Beffective_at%5D=2000-12-31T12:00:00Z. - #to_hash ⇒ { effective_at: Time }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(effective_at: nil) ⇒ Balances
For example, if you want the balances as of a particular time (ISO8601), the
encoded query string would be balances%5Beffective_at%5D=2000-12-31T12:00:00Z.
The balances as of a time are inclusive of entries with that exact time, but
with respect to the ledger accounts that are currently present in the category.
105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/modern_treasury/models/ledger_account_category_list_params.rb', line 105 class Balances < ModernTreasury::Internal::Type::BaseModel # @!attribute effective_at # # @return [Time, nil] optional :effective_at, Time # @!method initialize(effective_at: nil) # For example, if you want the balances as of a particular time (ISO8601), the # encoded query string would be `balances%5Beffective_at%5D=2000-12-31T12:00:00Z`. # The balances as of a time are inclusive of entries with that exact time, but # with respect to the ledger accounts that are currently present in the category. # # @param effective_at [Time] end |
Instance Attribute Details
#effective_at ⇒ Time?
109 |
# File 'lib/modern_treasury/models/ledger_account_category_list_params.rb', line 109 optional :effective_at, Time |
Instance Method Details
#to_hash ⇒ { effective_at: Time }
106 |
# File 'sig/modern_treasury/models/ledger_account_category_list_params.rbs', line 106
def to_hash: -> { effective_at: Time }
|