Class: ModernTreasury::Models::LedgerAccountCategoryRetrieveParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::LedgerAccountCategoryRetrieveParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/ledger_account_category_retrieve_params.rb,
sig/modern_treasury/models/ledger_account_category_retrieve_params.rbs
Overview
Defined Under Namespace
Classes: Balances
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ModernTreasury
Instance Attribute Summary collapse
-
#balances ⇒ ModernTreasury::Models::LedgerAccountCategoryRetrieveParams::Balances?
For example, if you want the balances as of a particular time (ISO8601), the encoded query string would be
balances%5Beffective_at%5D=2000-12-31T12:00:00Z. - #id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
22 |
# File 'sig/modern_treasury/models/ledger_account_category_retrieve_params.rbs', line 22
def initialize: (
|
Instance Attribute Details
#balances ⇒ ModernTreasury::Models::LedgerAccountCategoryRetrieveParams::Balances?
For example, if you want the balances as of a particular time (ISO8601), the
encoded query string would be balances%5Beffective_at%5D=2000-12-31T12:00:00Z.
The balances as of a time are inclusive of entries with that exact time, but
with respect to the ledger accounts that are currently present in the category.
22 |
# File 'lib/modern_treasury/models/ledger_account_category_retrieve_params.rb', line 22 optional :balances, -> { ModernTreasury::LedgerAccountCategoryRetrieveParams::Balances } |
#id ⇒ String
13 |
# File 'lib/modern_treasury/models/ledger_account_category_retrieve_params.rb', line 13 required :id, String |
Instance Method Details
#to_hash ⇒ {
28 |
# File 'sig/modern_treasury/models/ledger_account_category_retrieve_params.rbs', line 28
def to_hash: -> {
|