Class: ModernTreasury::Models::LedgerAccountCategoryRetrieveParams::Balances
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::LedgerAccountCategoryRetrieveParams::Balances
- Defined in:
- lib/modern_treasury/models/ledger_account_category_retrieve_params.rb,
sig/modern_treasury/models/ledger_account_category_retrieve_params.rbs
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(as_of_date: nil, effective_at: nil) ⇒ Balances
constructor
For example, if you want the balances as of a particular time (ISO8601), the encoded query string would be
balances%5Beffective_at%5D=2000-12-31T12:00:00Z. - #to_hash ⇒ { as_of_date: Date, effective_at: Time }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(as_of_date: nil, effective_at: nil) ⇒ Balances
For example, if you want the balances as of a particular time (ISO8601), the
encoded query string would be balances%5Beffective_at%5D=2000-12-31T12:00:00Z.
The balances as of a time are inclusive of entries with that exact time, but
with respect to the ledger accounts that are currently present in the category.
34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/modern_treasury/models/ledger_account_category_retrieve_params.rb', line 34 class Balances < ModernTreasury::Internal::Type::BaseModel # @!attribute as_of_date # # @return [Date, nil] optional :as_of_date, Date # @!attribute effective_at # # @return [Time, nil] optional :effective_at, Time # @!method initialize(as_of_date: nil, effective_at: nil) # For example, if you want the balances as of a particular time (ISO8601), the # encoded query string would be `balances%5Beffective_at%5D=2000-12-31T12:00:00Z`. # The balances as of a time are inclusive of entries with that exact time, but # with respect to the ledger accounts that are currently present in the category. # # @param as_of_date [Date] # @param effective_at [Time] end |
Instance Attribute Details
#as_of_date ⇒ Date?
38 |
# File 'lib/modern_treasury/models/ledger_account_category_retrieve_params.rb', line 38 optional :as_of_date, Date |
#effective_at ⇒ Time?
43 |
# File 'lib/modern_treasury/models/ledger_account_category_retrieve_params.rb', line 43 optional :effective_at, Time |
Instance Method Details
#to_hash ⇒ { as_of_date: Date, effective_at: Time }
47 |
# File 'sig/modern_treasury/models/ledger_account_category_retrieve_params.rbs', line 47
def to_hash: -> { as_of_date: Date, effective_at: Time }
|