Class: ModernTreasury::Models::LedgerAccountListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::LedgerAccountListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/ledger_account_list_params.rb,
sig/modern_treasury/models/ledger_account_list_params.rbs
Overview
Defined Under Namespace
Classes: AvailableBalanceAmount, Balances, PendingBalanceAmount, PostedBalanceAmount
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ModernTreasury
Instance Attribute Summary collapse
- #after_cursor ⇒ String?
-
#available_balance_amount ⇒ ModernTreasury::Models::LedgerAccountListParams::AvailableBalanceAmount?
Use
gt(>),gte(>=),lt(<),lte(<=),eq(=), ornot_eq(!=) to filter by balance amount. -
#balances ⇒ ModernTreasury::Models::LedgerAccountListParams::Balances?
Use
balances[effective_at_lower_bound]andbalances[effective_at_upper_bound]to get the balances change between the two timestamps. -
#created_at ⇒ Hash{Symbol=>Time}?
Use
gt(>),gte(>=),lt(<),lte(<=), oreq(=) to filter by the created at timestamp. - #currency ⇒ String?
- #external_id ⇒ String?
-
#id ⇒ Array<String>?
If you have specific IDs to retrieve in bulk, you can pass them as query parameters delimited with
id[]=, for example?id[]=123&id[]=abc. - #ledger_account_category_id ⇒ String?
- #ledger_id ⇒ String?
-
#metadata ⇒ Hash{Symbol=>String}?
For example, if you want to query for records with metadata key
Typeand valueLoan, the query would bemetadata%5BType%5D=Loan. -
#name ⇒ Array<String>?
If you have specific names to retrieve in bulk, you can pass them as query parameters delimited with
name[]=, for example?name[]=123&name[]=abc. - #normal_balance ⇒ Symbol, ...
-
#pending_balance_amount ⇒ ModernTreasury::Models::LedgerAccountListParams::PendingBalanceAmount?
Use
gt(>),gte(>=),lt(<),lte(<=),eq(=), ornot_eq(!=) to filter by balance amount. - #per_page ⇒ Integer?
-
#posted_balance_amount ⇒ ModernTreasury::Models::LedgerAccountListParams::PostedBalanceAmount?
Use
gt(>),gte(>=),lt(<),lte(<=),eq(=), ornot_eq(!=) to filter by balance amount. -
#updated_at ⇒ Hash{Symbol=>Time}?
Use
gt(>),gte(>=),lt(<),lte(<=), oreq(=) to filter by the updated at timestamp.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(eq: nil, gt: nil, gte: nil, lt: nil, lte: nil, not_eq: nil) ⇒ Object
constructor
Use
gt(>),gte(>=),lt(<),lte(<=),eq(=), ornot_eq(!=) to filter by balance amount. - #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(eq: nil, gt: nil, gte: nil, lt: nil, lte: nil, not_eq: nil) ⇒ Object
Use gt (>), gte (>=), lt (<), lte (<=), eq (=), or not_eq (!=) to
filter by balance amount.
|
|
# File 'lib/modern_treasury/models/ledger_account_list_params.rb', line 183
|
Instance Attribute Details
#after_cursor ⇒ String?
20 |
# File 'lib/modern_treasury/models/ledger_account_list_params.rb', line 20 optional :after_cursor, String, nil?: true |
#available_balance_amount ⇒ ModernTreasury::Models::LedgerAccountListParams::AvailableBalanceAmount?
Use gt (>), gte (>=), lt (<), lte (<=), eq (=), or not_eq (!=) to
filter by balance amount.
27 |
# File 'lib/modern_treasury/models/ledger_account_list_params.rb', line 27 optional :available_balance_amount, -> { ModernTreasury::LedgerAccountListParams::AvailableBalanceAmount } |
#balances ⇒ ModernTreasury::Models::LedgerAccountListParams::Balances?
Use balances[effective_at_lower_bound] and
balances[effective_at_upper_bound] to get the balances change between the two
timestamps. The lower bound is inclusive while the upper bound is exclusive of
the provided timestamps. If no value is supplied the balances will be retrieved
not including that bound.
37 |
# File 'lib/modern_treasury/models/ledger_account_list_params.rb', line 37 optional :balances, -> { ModernTreasury::LedgerAccountListParams::Balances } |
#created_at ⇒ Hash{Symbol=>Time}?
Use gt (>), gte (>=), lt (<), lte (<=), or eq (=) to filter by the
created at timestamp. For example, for all times after Jan 1 2000 12:00 UTC, use
created_at%5Bgt%5D=2000-01-01T12:00:00Z.
45 |
# File 'lib/modern_treasury/models/ledger_account_list_params.rb', line 45 optional :created_at, ModernTreasury::Internal::Type::HashOf[Time] |
#currency ⇒ String?
50 |
# File 'lib/modern_treasury/models/ledger_account_list_params.rb', line 50 optional :currency, String |
#external_id ⇒ String?
55 |
# File 'lib/modern_treasury/models/ledger_account_list_params.rb', line 55 optional :external_id, String |
#id ⇒ Array<String>?
If you have specific IDs to retrieve in bulk, you can pass them as query
parameters delimited with id[]=, for example ?id[]=123&id[]=abc.
15 |
# File 'lib/modern_treasury/models/ledger_account_list_params.rb', line 15 optional :id, ModernTreasury::Internal::Type::ArrayOf[String] |
#ledger_account_category_id ⇒ String?
60 |
# File 'lib/modern_treasury/models/ledger_account_list_params.rb', line 60 optional :ledger_account_category_id, String |
#ledger_id ⇒ String?
65 |
# File 'lib/modern_treasury/models/ledger_account_list_params.rb', line 65 optional :ledger_id, String |
#metadata ⇒ Hash{Symbol=>String}?
For example, if you want to query for records with metadata key Type and value
Loan, the query would be metadata%5BType%5D=Loan. This encodes the query
parameters.
73 |
# File 'lib/modern_treasury/models/ledger_account_list_params.rb', line 73 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#name ⇒ Array<String>?
If you have specific names to retrieve in bulk, you can pass them as query
parameters delimited with name[]=, for example ?name[]=123&name[]=abc.
80 |
# File 'lib/modern_treasury/models/ledger_account_list_params.rb', line 80 optional :name, ModernTreasury::Internal::Type::ArrayOf[String] |
#normal_balance ⇒ Symbol, ...
85 |
# File 'lib/modern_treasury/models/ledger_account_list_params.rb', line 85 optional :normal_balance, enum: -> { ModernTreasury::TransactionDirection } |
#pending_balance_amount ⇒ ModernTreasury::Models::LedgerAccountListParams::PendingBalanceAmount?
Use gt (>), gte (>=), lt (<), lte (<=), eq (=), or not_eq (!=) to
filter by balance amount.
92 |
# File 'lib/modern_treasury/models/ledger_account_list_params.rb', line 92 optional :pending_balance_amount, -> { ModernTreasury::LedgerAccountListParams::PendingBalanceAmount } |
#per_page ⇒ Integer?
97 |
# File 'lib/modern_treasury/models/ledger_account_list_params.rb', line 97 optional :per_page, Integer |
#posted_balance_amount ⇒ ModernTreasury::Models::LedgerAccountListParams::PostedBalanceAmount?
Use gt (>), gte (>=), lt (<), lte (<=), eq (=), or not_eq (!=) to
filter by balance amount.
104 |
# File 'lib/modern_treasury/models/ledger_account_list_params.rb', line 104 optional :posted_balance_amount, -> { ModernTreasury::LedgerAccountListParams::PostedBalanceAmount } |
#updated_at ⇒ Hash{Symbol=>Time}?
Use gt (>), gte (>=), lt (<), lte (<=), or eq (=) to filter by the
updated at timestamp. For example, for all times after Jan 1 2000 12:00 UTC, use
updated_at%5Bgt%5D=2000-01-01T12:00:00Z.
112 |
# File 'lib/modern_treasury/models/ledger_account_list_params.rb', line 112 optional :updated_at, ModernTreasury::Internal::Type::HashOf[Time] |
Instance Method Details
#to_hash ⇒ {
120 |
# File 'sig/modern_treasury/models/ledger_account_list_params.rbs', line 120
def to_hash: -> {
|