Class: ModernTreasury::Models::LedgerAccountRetrieveParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/modern_treasury/models/ledger_account_retrieve_params.rb,
sig/modern_treasury/models/ledger_account_retrieve_params.rbs

Overview

See Also:

  • ModernTreasury::Resources::LedgerAccounts#retrieve

Defined Under Namespace

Classes: Balances

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::ModernTreasury

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



22
# File 'sig/modern_treasury/models/ledger_account_retrieve_params.rbs', line 22

def initialize: (

Instance Attribute Details

#balancesModernTreasury::Models::LedgerAccountRetrieveParams::Balances?

Use balances[effective_at_lower_bound] and balances[effective_at_upper_bound] to get the balances change between the two timestamps. The lower bound is inclusive while the upper bound is exclusive of the provided timestamps. If no value is supplied the balances will be retrieved not including that bound. Use balances[as_of_lock_version] to retrieve a balance as of a specific Ledger Account lock_version.



24
# File 'lib/modern_treasury/models/ledger_account_retrieve_params.rb', line 24

optional :balances, -> { ModernTreasury::LedgerAccountRetrieveParams::Balances }

#idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/modern_treasury/models/ledger_account_retrieve_params.rb', line 13

required :id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


28
# File 'sig/modern_treasury/models/ledger_account_retrieve_params.rbs', line 28

def to_hash: -> {