Class: ModernTreasury::Models::LedgerAccountSettlement

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/ledger_account_settlement.rb

Overview

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, amount:, contra_ledger_account_id:, created_at:, currency:, currency_exponent:, description:, effective_at_upper_bound:, ledger_id:, ledger_transaction_id:, live_mode:, metadata:, object:, settled_ledger_account_id:, settlement_entry_direction:, status:, updated_at:) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::LedgerAccountSettlement for more details.

Parameters:

  • id (String)
  • amount (Integer, nil)

    The amount of the ledger account settlement.

  • contra_ledger_account_id (String)

    The id of the contra ledger account that sends to or receives funds from the set

  • created_at (Time)
  • currency (String)

    The currency of the ledger account settlement.

  • currency_exponent (Integer, nil)

    The currency exponent of the ledger account settlement.

  • description (String, nil)

    The description of the ledger account settlement.

  • effective_at_upper_bound (Time, nil)

    The exclusive upper bound of the effective_at timestamp of the ledger entries to

  • ledger_id (String)

    The id of the ledger that this ledger account settlement belongs to.

  • ledger_transaction_id (String, nil)

    The id of the ledger transaction that this settlement is associated with.

  • live_mode (Boolean)

    This field will be true if this object exists in the live environment or false i

  • metadata (Hash{Symbol=>String})

    Additional data represented as key-value pairs. Both the key and value must be s

  • object (String)
  • settled_ledger_account_id (String)

    The id of the settled ledger account whose ledger entries are queried against, a

  • settlement_entry_direction (String, nil)

    The direction of the ledger entry with the settlement_ledger_account.

  • status (Symbol, ModernTreasury::Models::LedgerAccountSettlement::Status)

    The status of the ledger account settlement. One of ‘processing`, `pending`, `po

  • updated_at (Time)


# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 112

Instance Attribute Details

#amountInteger?

The amount of the ledger account settlement.

Returns:

  • (Integer, nil)


16
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 16

required :amount, Integer, nil?: true

#contra_ledger_account_idString

The id of the contra ledger account that sends to or receives funds from the settled ledger account.

Returns:

  • (String)


23
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 23

required :contra_ledger_account_id, String

#created_atTime

Returns:

  • (Time)


28
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 28

required :created_at, Time

#currencyString

The currency of the ledger account settlement.

Returns:

  • (String)


34
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 34

required :currency, String

#currency_exponentInteger?

The currency exponent of the ledger account settlement.

Returns:

  • (Integer, nil)


40
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 40

required :currency_exponent, Integer, nil?: true

#descriptionString?

The description of the ledger account settlement.

Returns:

  • (String, nil)


46
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 46

required :description, String, nil?: true

#effective_at_upper_boundTime?

The exclusive upper bound of the effective_at timestamp of the ledger entries to be included in the ledger account settlement. The default value is the created_at timestamp of the ledger account settlement.

Returns:

  • (Time, nil)


54
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 54

required :effective_at_upper_bound, Time, nil?: true

#idString

Returns:

  • (String)


10
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 10

required :id, String

#ledger_idString

The id of the ledger that this ledger account settlement belongs to.

Returns:

  • (String)


60
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 60

required :ledger_id, String

#ledger_transaction_idString?

The id of the ledger transaction that this settlement is associated with.

Returns:

  • (String, nil)


66
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 66

required :ledger_transaction_id, String, nil?: true

#live_modeBoolean

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Returns:

  • (Boolean)


73
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 73

required :live_mode, ModernTreasury::Internal::Type::Boolean

#metadataHash{Symbol=>String}

Additional data represented as key-value pairs. Both the key and value must be strings.

Returns:

  • (Hash{Symbol=>String})


80
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 80

required :metadata, ModernTreasury::Internal::Type::HashOf[String]

#objectString

Returns:

  • (String)


85
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 85

required :object, String

#settled_ledger_account_idString

The id of the settled ledger account whose ledger entries are queried against, and its balance is reduced as a result.

Returns:

  • (String)


92
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 92

required :settled_ledger_account_id, String

#settlement_entry_directionString?

The direction of the ledger entry with the settlement_ledger_account.

Returns:

  • (String, nil)


98
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 98

required :settlement_entry_direction, String, nil?: true

#statusSymbol, ModernTreasury::Models::LedgerAccountSettlement::Status

The status of the ledger account settlement. One of ‘processing`, `pending`, `posted`, `archiving` or `archived`.



105
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 105

required :status, enum: -> { ModernTreasury::LedgerAccountSettlement::Status }

#updated_atTime

Returns:

  • (Time)


110
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 110

required :updated_at, Time