Class: ModernTreasury::Models::LedgerAccountSettlementListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::LedgerAccountSettlementListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/ledger_account_settlement_list_params.rb,
sig/modern_treasury/models/ledger_account_settlement_list_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ModernTreasury
Instance Attribute Summary collapse
- #after_cursor ⇒ String?
-
#created_at ⇒ Hash{Symbol=>Time}?
Use
gt(>),gte(>=),lt(<),lte(<=), oreq(=) to filter by the created at timestamp. -
#id ⇒ Array<String>?
If you have specific IDs to retrieve in bulk, you can pass them as query parameters delimited with
id[]=, for example?id[]=123&id[]=abc. - #ledger_id ⇒ String?
- #ledger_transaction_id ⇒ String?
-
#metadata ⇒ Hash{Symbol=>String}?
For example, if you want to query for records with metadata key
Typeand valueLoan, the query would bemetadata%5BType%5D=Loan. - #per_page ⇒ Integer?
- #settled_ledger_account_id ⇒ String?
- #settlement_entry_direction ⇒ String?
-
#updated_at ⇒ Hash{Symbol=>Time}?
Use
gt(>),gte(>=),lt(<),lte(<=), oreq(=) to filter by the updated at timestamp.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id: nil, after_cursor: nil, created_at: nil, ledger_id: nil, ledger_transaction_id: nil, metadata: nil, per_page: nil, settled_ledger_account_id: nil, settlement_entry_direction: nil, updated_at: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see LedgerAccountSettlementListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, after_cursor: nil, created_at: nil, ledger_id: nil, ledger_transaction_id: nil, metadata: nil, per_page: nil, settled_ledger_account_id: nil, settlement_entry_direction: nil, updated_at: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::LedgerAccountSettlementListParams for more details.
|
|
# File 'lib/modern_treasury/models/ledger_account_settlement_list_params.rb', line 71
|
Instance Attribute Details
#after_cursor ⇒ String?
20 |
# File 'lib/modern_treasury/models/ledger_account_settlement_list_params.rb', line 20 optional :after_cursor, String, nil?: true |
#created_at ⇒ Hash{Symbol=>Time}?
Use gt (>), gte (>=), lt (<), lte (<=), or eq (=) to filter by the
created at timestamp. For example, for all times after Jan 1 2000 12:00 UTC, use
created_at%5Bgt%5D=2000-01-01T12:00:00Z.
28 |
# File 'lib/modern_treasury/models/ledger_account_settlement_list_params.rb', line 28 optional :created_at, ModernTreasury::Internal::Type::HashOf[Time] |
#id ⇒ Array<String>?
If you have specific IDs to retrieve in bulk, you can pass them as query
parameters delimited with id[]=, for example ?id[]=123&id[]=abc.
15 |
# File 'lib/modern_treasury/models/ledger_account_settlement_list_params.rb', line 15 optional :id, ModernTreasury::Internal::Type::ArrayOf[String] |
#ledger_id ⇒ String?
33 |
# File 'lib/modern_treasury/models/ledger_account_settlement_list_params.rb', line 33 optional :ledger_id, String |
#ledger_transaction_id ⇒ String?
38 |
# File 'lib/modern_treasury/models/ledger_account_settlement_list_params.rb', line 38 optional :ledger_transaction_id, String |
#metadata ⇒ Hash{Symbol=>String}?
For example, if you want to query for records with metadata key Type and value
Loan, the query would be metadata%5BType%5D=Loan. This encodes the query
parameters.
46 |
# File 'lib/modern_treasury/models/ledger_account_settlement_list_params.rb', line 46 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#per_page ⇒ Integer?
51 |
# File 'lib/modern_treasury/models/ledger_account_settlement_list_params.rb', line 51 optional :per_page, Integer |
#settled_ledger_account_id ⇒ String?
56 |
# File 'lib/modern_treasury/models/ledger_account_settlement_list_params.rb', line 56 optional :settled_ledger_account_id, String |
#settlement_entry_direction ⇒ String?
61 |
# File 'lib/modern_treasury/models/ledger_account_settlement_list_params.rb', line 61 optional :settlement_entry_direction, String |
#updated_at ⇒ Hash{Symbol=>Time}?
Use gt (>), gte (>=), lt (<), lte (<=), or eq (=) to filter by the
updated at timestamp. For example, for all times after Jan 1 2000 12:00 UTC, use
updated_at%5Bgt%5D=2000-01-01T12:00:00Z.
69 |
# File 'lib/modern_treasury/models/ledger_account_settlement_list_params.rb', line 69 optional :updated_at, ModernTreasury::Internal::Type::HashOf[Time] |
Instance Method Details
#to_hash ⇒ {
74 |
# File 'sig/modern_treasury/models/ledger_account_settlement_list_params.rbs', line 74
def to_hash: -> {
|