Module: ModernTreasury::Models::LedgerTransactionCreatePartialPostParams::PostedLedgerEntry::Direction

Extended by:
Internal::Type::Enum
Defined in:
lib/modern_treasury/models/ledger_transaction_create_partial_post_params.rb,
sig/modern_treasury/models/ledger_transaction_create_partial_post_params.rbs

Overview

One of credit, debit. Describes the direction money is flowing in the transaction. A credit moves money from your account to someone else's. A debit pulls money from someone else's account to your own. Note that wire, rtp, and check payments will always be credit.

See Also:

  • ModernTreasury::Models::LedgerTransactionCreatePartialPostParams::PostedLedgerEntry#direction

Constant Summary collapse

CREDIT =

Returns:

  • (:credit)
:credit
DEBIT =

Returns:

  • (:debit)
:debit

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/ledger_transaction_create_partial_post_params.rb', line 177

Instance Method Details

#self?.values::Array[ModernTreasury::Models::LedgerTransactionCreatePartialPostParams::PostedLedgerEntry::direction]

Returns:

  • (::Array[ModernTreasury::Models::LedgerTransactionCreatePartialPostParams::PostedLedgerEntry::direction])


126
# File 'sig/modern_treasury/models/ledger_transaction_create_partial_post_params.rbs', line 126

def self?.values: -> ::Array[ModernTreasury::Models::LedgerTransactionCreatePartialPostParams::PostedLedgerEntry::direction]