Class: ModernTreasury::Models::LedgerTransactionUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::LedgerTransactionUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/ledger_transaction_update_params.rb
Overview
Defined Under Namespace
Modules: LedgerableType, Status
Instance Attribute Summary collapse
-
#description ⇒ String?
An optional description for internal use.
-
#effective_at ⇒ Time?
The timestamp (ISO8601 format) at which the ledger transaction happened for reporting purposes.
-
#external_id ⇒ String?
A unique string to represent the ledger transaction.
- #id ⇒ String
-
#ledger_entries ⇒ Array<ModernTreasury::Models::LedgerEntryCreateRequest>?
An array of ledger entry objects.
-
#ledgerable_id ⇒ String?
If the ledger transaction can be reconciled to another object in Modern Treasury, the id will be populated here, otherwise null.
-
#ledgerable_type ⇒ Symbol, ...
If the ledger transaction can be reconciled to another object in Modern Treasury, the type will be populated here, otherwise null.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#status ⇒ Symbol, ...
To post a ledger transaction at creation, use ‘posted`.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, description: nil, effective_at: nil, external_id: nil, ledger_entries: nil, ledgerable_id: nil, ledgerable_type: nil, metadata: nil, status: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see LedgerTransactionUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, description: nil, effective_at: nil, external_id: nil, ledger_entries: nil, ledgerable_id: nil, ledgerable_type: nil, metadata: nil, status: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::LedgerTransactionUpdateParams for more details.
|
|
# File 'lib/modern_treasury/models/ledger_transaction_update_params.rb', line 70
|
Instance Attribute Details
#description ⇒ String?
An optional description for internal use.
19 |
# File 'lib/modern_treasury/models/ledger_transaction_update_params.rb', line 19 optional :description, String, nil?: true |
#effective_at ⇒ Time?
The timestamp (ISO8601 format) at which the ledger transaction happened for reporting purposes.
26 |
# File 'lib/modern_treasury/models/ledger_transaction_update_params.rb', line 26 optional :effective_at, Time |
#external_id ⇒ String?
A unique string to represent the ledger transaction. Only one pending or posted ledger transaction may have this ID in the ledger.
33 |
# File 'lib/modern_treasury/models/ledger_transaction_update_params.rb', line 33 optional :external_id, String, nil?: true |
#id ⇒ String
13 |
# File 'lib/modern_treasury/models/ledger_transaction_update_params.rb', line 13 required :id, String |
#ledger_entries ⇒ Array<ModernTreasury::Models::LedgerEntryCreateRequest>?
An array of ledger entry objects.
39 40 |
# File 'lib/modern_treasury/models/ledger_transaction_update_params.rb', line 39 optional :ledger_entries, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LedgerEntryCreateRequest] } |
#ledgerable_id ⇒ String?
If the ledger transaction can be reconciled to another object in Modern Treasury, the id will be populated here, otherwise null.
47 |
# File 'lib/modern_treasury/models/ledger_transaction_update_params.rb', line 47 optional :ledgerable_id, String |
#ledgerable_type ⇒ Symbol, ...
If the ledger transaction can be reconciled to another object in Modern Treasury, the type will be populated here, otherwise null. This can be one of payment_order, incoming_payment_detail, expected_payment, return, or reversal.
55 |
# File 'lib/modern_treasury/models/ledger_transaction_update_params.rb', line 55 optional :ledgerable_type, enum: -> { ModernTreasury::LedgerTransactionUpdateParams::LedgerableType } |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
62 |
# File 'lib/modern_treasury/models/ledger_transaction_update_params.rb', line 62 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#status ⇒ Symbol, ...
To post a ledger transaction at creation, use ‘posted`.
68 |
# File 'lib/modern_treasury/models/ledger_transaction_update_params.rb', line 68 optional :status, enum: -> { ModernTreasury::LedgerTransactionUpdateParams::Status } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/ledger_transaction_update_params.rb', line 106
|