Module: ModernTreasury::Models::LedgerTransactionUpdateParams::LedgerableType

Extended by:
Internal::Type::Enum
Defined in:
lib/modern_treasury/models/ledger_transaction_update_params.rb,
sig/modern_treasury/models/ledger_transaction_update_params.rbs

Overview

If the ledger transaction can be reconciled to another object in Modern Treasury, the type will be populated here, otherwise null. This can be one of payment_order, incoming_payment_detail, expected_payment, return, or reversal.

Constant Summary collapse

EXPECTED_PAYMENT =

Returns:

  • (:expected_payment)
:expected_payment
INCOMING_PAYMENT_DETAIL =

Returns:

  • (:incoming_payment_detail)
:incoming_payment_detail
PAYMENT_ORDER =

Returns:

  • (:payment_order)
:payment_order
RETURN =

Returns:

  • (:return)
:return
REVERSAL =

Returns:

  • (:reversal)
:reversal

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[ModernTreasury::Models::LedgerTransactionUpdateParams::ledgerable_type]

Returns:

  • (::Array[ModernTreasury::Models::LedgerTransactionUpdateParams::ledgerable_type])


99
# File 'sig/modern_treasury/models/ledger_transaction_update_params.rbs', line 99

def self?.values: -> ::Array[ModernTreasury::Models::LedgerTransactionUpdateParams::ledgerable_type]