Class: ModernTreasury::Models::LegalEntity

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/legal_entity.rb

Overview

Defined Under Namespace

Modules: LegalEntityType, LegalStructure, RiskRating, Status Classes: Address, Identification, PhoneNumber, Regulator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(jurisdiction:, name:, registration_number:) ⇒ Object

Some parameter documentations has been truncated, see Regulator for more details.

Parameters:

  • jurisdiction (String)

    The country code where the regulator operates in the ISO 3166-1 alpha-2 format (

  • name (String)

    Full name of the regulatory body.

  • registration_number (String)

    Registration or identification number with the regulator.



# File 'lib/modern_treasury/models/legal_entity.rb', line 676

Instance Attribute Details

#addressesArray<ModernTreasury::Models::LegalEntity::Address>

A list of addresses for the entity.



16
# File 'lib/modern_treasury/models/legal_entity.rb', line 16

required :addresses, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntity::Address] }

#bank_settingsModernTreasury::Models::LegalEntityBankSettings?



21
# File 'lib/modern_treasury/models/legal_entity.rb', line 21

required :bank_settings, -> { ModernTreasury::LegalEntityBankSettings }, nil?: true

#business_descriptionString?

A description of the business.

Returns:

  • (String, nil)


27
# File 'lib/modern_treasury/models/legal_entity.rb', line 27

required :business_description, String, nil?: true

#business_nameString?

The business’s legal business name.

Returns:

  • (String, nil)


33
# File 'lib/modern_treasury/models/legal_entity.rb', line 33

required :business_name, String, nil?: true

#citizenship_countryString?

The country of citizenship for an individual.

Returns:

  • (String, nil)


39
# File 'lib/modern_treasury/models/legal_entity.rb', line 39

required :citizenship_country, String, nil?: true

#compliance_detailsObject?

Deprecated.

Returns:

  • (Object, nil)


45
# File 'lib/modern_treasury/models/legal_entity.rb', line 45

required :compliance_details, ModernTreasury::Internal::Type::Unknown, nil?: true

#country_of_incorporationString?

The country code where the business is incorporated in the ISO 3166-1 alpha-2 or alpha-3 formats.

Returns:

  • (String, nil)


52
# File 'lib/modern_treasury/models/legal_entity.rb', line 52

required :country_of_incorporation, String, nil?: true

#created_atTime

Returns:

  • (Time)


57
# File 'lib/modern_treasury/models/legal_entity.rb', line 57

required :created_at, Time

#date_formedDate?

A business’s formation date (YYYY-MM-DD).

Returns:

  • (Date, nil)


63
# File 'lib/modern_treasury/models/legal_entity.rb', line 63

required :date_formed, Date, nil?: true

#date_of_birthDate?

An individual’s date of birth (YYYY-MM-DD).

Returns:

  • (Date, nil)


69
# File 'lib/modern_treasury/models/legal_entity.rb', line 69

required :date_of_birth, Date, nil?: true

#discarded_atTime?

Returns:

  • (Time, nil)


74
# File 'lib/modern_treasury/models/legal_entity.rb', line 74

required :discarded_at, Time, nil?: true

#documentsArray<ModernTreasury::Models::Document>



79
# File 'lib/modern_treasury/models/legal_entity.rb', line 79

required :documents, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::Document] }

#doing_business_as_namesArray<String>

Returns:

  • (Array<String>)


84
# File 'lib/modern_treasury/models/legal_entity.rb', line 84

required :doing_business_as_names, ModernTreasury::Internal::Type::ArrayOf[String]

#emailString?

The entity’s primary email.

Returns:

  • (String, nil)


90
# File 'lib/modern_treasury/models/legal_entity.rb', line 90

required :email, String, nil?: true

#expected_activity_volumeInteger?

Monthly expected transaction volume in USD.

Returns:

  • (Integer, nil)


96
# File 'lib/modern_treasury/models/legal_entity.rb', line 96

required :expected_activity_volume, Integer, nil?: true

#external_idString?

An optional user-defined 180 character unique identifier.

Returns:

  • (String, nil)


102
# File 'lib/modern_treasury/models/legal_entity.rb', line 102

required :external_id, String, nil?: true

#first_nameString?

An individual’s first name.

Returns:

  • (String, nil)


108
# File 'lib/modern_treasury/models/legal_entity.rb', line 108

required :first_name, String, nil?: true

#idString

Returns:

  • (String)


10
# File 'lib/modern_treasury/models/legal_entity.rb', line 10

required :id, String

#identificationsArray<ModernTreasury::Models::LegalEntity::Identification>

A list of identifications for the legal entity.



114
115
# File 'lib/modern_treasury/models/legal_entity.rb', line 114

required :identifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntity::Identification] }

#industry_classificationsArray<ModernTreasury::Models::LegalEntityIndustryClassification>

A list of industry classifications for the legal entity.



121
122
# File 'lib/modern_treasury/models/legal_entity.rb', line 121

required :industry_classifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityIndustryClassification] }

#intended_useString?

A description of the intended use of the legal entity.

Returns:

  • (String, nil)


128
# File 'lib/modern_treasury/models/legal_entity.rb', line 128

required :intended_use, String, nil?: true

#last_nameString?

An individual’s last name.

Returns:

  • (String, nil)


134
# File 'lib/modern_treasury/models/legal_entity.rb', line 134

required :last_name, String, nil?: true

The legal entity associations and its child legal entities.



292
293
294
# File 'lib/modern_treasury/models/legal_entity.rb', line 292

optional :legal_entity_associations,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAssociation] },
nil?: true

The type of legal entity.



140
# File 'lib/modern_treasury/models/legal_entity.rb', line 140

required :legal_entity_type, enum: -> { ModernTreasury::LegalEntity::LegalEntityType }

The business’s legal structure.



146
# File 'lib/modern_treasury/models/legal_entity.rb', line 146

required :legal_structure, enum: -> { ModernTreasury::LegalEntity::LegalStructure }, nil?: true

#listed_exchangeString?

ISO 10383 market identifier code.

Returns:

  • (String, nil)


152
# File 'lib/modern_treasury/models/legal_entity.rb', line 152

required :listed_exchange, String, nil?: true

#live_modeBoolean

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Returns:

  • (Boolean)


159
# File 'lib/modern_treasury/models/legal_entity.rb', line 159

required :live_mode, ModernTreasury::Internal::Type::Boolean

#metadataHash{Symbol=>String}

Additional data represented as key-value pairs. Both the key and value must be strings.

Returns:

  • (Hash{Symbol=>String})


166
# File 'lib/modern_treasury/models/legal_entity.rb', line 166

required :metadata, ModernTreasury::Internal::Type::HashOf[String]

#middle_nameString?

An individual’s middle name.

Returns:

  • (String, nil)


172
# File 'lib/modern_treasury/models/legal_entity.rb', line 172

required :middle_name, String, nil?: true

#objectString

Returns:

  • (String)


177
# File 'lib/modern_treasury/models/legal_entity.rb', line 177

required :object, String

#operating_jurisdictionsArray<String>

A list of countries where the business operates (ISO 3166-1 alpha-2 or alpha-3 codes).

Returns:

  • (Array<String>)


184
# File 'lib/modern_treasury/models/legal_entity.rb', line 184

required :operating_jurisdictions, ModernTreasury::Internal::Type::ArrayOf[String]

#phone_numbersArray<ModernTreasury::Models::LegalEntity::PhoneNumber>



189
190
# File 'lib/modern_treasury/models/legal_entity.rb', line 189

required :phone_numbers,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntity::PhoneNumber] }

#politically_exposed_personBoolean?

Whether the individual is a politically exposed person.

Returns:

  • (Boolean, nil)


196
# File 'lib/modern_treasury/models/legal_entity.rb', line 196

required :politically_exposed_person, ModernTreasury::Internal::Type::Boolean, nil?: true

#preferred_nameString?

An individual’s preferred name.

Returns:

  • (String, nil)


202
# File 'lib/modern_treasury/models/legal_entity.rb', line 202

required :preferred_name, String, nil?: true

#prefixString?

An individual’s prefix.

Returns:

  • (String, nil)


208
# File 'lib/modern_treasury/models/legal_entity.rb', line 208

required :prefix, String, nil?: true

#primary_social_media_sitesArray<String>

A list of primary social media URLs for the business.

Returns:

  • (Array<String>)


214
# File 'lib/modern_treasury/models/legal_entity.rb', line 214

required :primary_social_media_sites, ModernTreasury::Internal::Type::ArrayOf[String]

#regulatorsArray<ModernTreasury::Models::LegalEntity::Regulator>?

Array of regulatory bodies overseeing this institution.



220
221
222
# File 'lib/modern_treasury/models/legal_entity.rb', line 220

required :regulators,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntity::Regulator] },
nil?: true

#risk_ratingSymbol, ...

The risk rating of the legal entity. One of low, medium, high.



228
# File 'lib/modern_treasury/models/legal_entity.rb', line 228

required :risk_rating, enum: -> { ModernTreasury::LegalEntity::RiskRating }, nil?: true

The UUID of the parent legal entity in the service provider tree.

Returns:

  • (String, nil)


234
# File 'lib/modern_treasury/models/legal_entity.rb', line 234

required :service_provider_legal_entity_id, String, nil?: true

#statusSymbol, ...

The activation status of the legal entity. One of pending, active, suspended, or denied.



241
# File 'lib/modern_treasury/models/legal_entity.rb', line 241

required :status, enum: -> { ModernTreasury::LegalEntity::Status }, nil?: true

#suffixString?

An individual’s suffix.

Returns:

  • (String, nil)


247
# File 'lib/modern_treasury/models/legal_entity.rb', line 247

required :suffix, String, nil?: true

#third_party_verificationModernTreasury::Models::ThirdPartyVerification?

Deprecated.

Deprecated. Use ‘third_party_verifications` instead.



255
# File 'lib/modern_treasury/models/legal_entity.rb', line 255

required :third_party_verification, -> { ModernTreasury::ThirdPartyVerification }, nil?: true

#third_party_verificationsArray<ModernTreasury::Models::ThirdPartyVerification>

A list of third-party verifications run by external vendors.



261
262
# File 'lib/modern_treasury/models/legal_entity.rb', line 261

required :third_party_verifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ThirdPartyVerification] }

#ticker_symbolString?

Stock ticker symbol for publicly traded companies.

Returns:

  • (String, nil)


268
# File 'lib/modern_treasury/models/legal_entity.rb', line 268

required :ticker_symbol, String, nil?: true

#updated_atTime

Returns:

  • (Time)


273
# File 'lib/modern_treasury/models/legal_entity.rb', line 273

required :updated_at, Time

#wealth_and_employment_detailsModernTreasury::Models::LegalEntityWealthEmploymentDetail?



278
279
280
# File 'lib/modern_treasury/models/legal_entity.rb', line 278

required :wealth_and_employment_details,
-> { ModernTreasury::LegalEntityWealthEmploymentDetail },
nil?: true

#websiteString?

The entity’s primary website URL.

Returns:

  • (String, nil)


286
# File 'lib/modern_treasury/models/legal_entity.rb', line 286

required :website, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/legal_entity.rb', line 508