Class: ModernTreasury::Models::LegalEntityAddressCreateRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::LegalEntityAddressCreateRequest
- Defined in:
- lib/modern_treasury/models/legal_entity_address_create_request.rb,
sig/modern_treasury/models/legal_entity_address_create_request.rbs
Defined Under Namespace
Modules: AddressType
Instance Attribute Summary collapse
-
#address_types ⇒ Array<Symbol, ModernTreasury::Models::LegalEntityAddressCreateRequest::AddressType>?
The types of this address.
-
#country ⇒ String?
Country code conforms to [ISO 3166-1 alpha-2].
- #line1 ⇒ String?
- #line2 ⇒ String?
-
#locality ⇒ String?
Locality or City.
-
#postal_code ⇒ String?
The postal code of the address.
-
#primary ⇒ Boolean?
Whether this address is the primary address for the legal entity.
-
#region ⇒ String?
Region or State.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
36 |
# File 'sig/modern_treasury/models/legal_entity_address_create_request.rbs', line 36
def initialize: (
|
Instance Attribute Details
#address_types ⇒ Array<Symbol, ModernTreasury::Models::LegalEntityAddressCreateRequest::AddressType>?
The types of this address.
39 40 |
# File 'lib/modern_treasury/models/legal_entity_address_create_request.rb', line 39 optional :address_types, -> { ModernTreasury::Internal::Type::ArrayOf[enum: ModernTreasury::LegalEntityAddressCreateRequest::AddressType] } |
#country ⇒ String?
Country code conforms to [ISO 3166-1 alpha-2]
10 |
# File 'lib/modern_treasury/models/legal_entity_address_create_request.rb', line 10 required :country, String, nil?: true |
#line1 ⇒ String?
15 |
# File 'lib/modern_treasury/models/legal_entity_address_create_request.rb', line 15 required :line1, String, nil?: true |
#line2 ⇒ String?
45 |
# File 'lib/modern_treasury/models/legal_entity_address_create_request.rb', line 45 optional :line2, String, nil?: true |
#locality ⇒ String?
Locality or City.
21 |
# File 'lib/modern_treasury/models/legal_entity_address_create_request.rb', line 21 required :locality, String, nil?: true |
#postal_code ⇒ String?
The postal code of the address.
27 |
# File 'lib/modern_treasury/models/legal_entity_address_create_request.rb', line 27 required :postal_code, String, nil?: true |
#primary ⇒ Boolean?
Whether this address is the primary address for the legal entity. Optional; when omitted it is inferred from the address types.
52 |
# File 'lib/modern_treasury/models/legal_entity_address_create_request.rb', line 52 optional :primary, ModernTreasury::Internal::Type::Boolean, nil?: true |
#region ⇒ String?
Region or State.
33 |
# File 'lib/modern_treasury/models/legal_entity_address_create_request.rb', line 33 required :region, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
47 |
# File 'sig/modern_treasury/models/legal_entity_address_create_request.rbs', line 47
def to_hash: -> {
|