Class: ModernTreasury::Models::LegalEntityAssociation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/legal_entity_association.rb,
sig/modern_treasury/models/legal_entity_association.rbs

Overview

See Also:

  • ModernTreasury::Resources::LegalEntityAssociations#create

Defined Under Namespace

Modules: RelationshipType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, child_legal_entity:, created_at:, discarded_at:, live_mode:, object:, ownership_percentage:, parent_legal_entity_id:, relationship_types:, title:, updated_at:) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::LegalEntityAssociation for more details.

Parameters:

  • id (String)
  • child_legal_entity (ModernTreasury::Models::ChildLegalEntity) —

    The child legal entity.

  • created_at (Time)
  • discarded_at (Time, nil)
  • live_mode (Boolean) —

    This field will be true if this object exists in the live environment or false i

  • object (String)
  • ownership_percentage (Integer, nil) —

    The child entity's ownership percentage iff they are a beneficial owner.

  • parent_legal_entity_id (String) —

    The ID of the parent legal entity. This must be a business legal entity.

  • relationship_types (Array<Symbol, ModernTreasury::Models::LegalEntityAssociation::RelationshipType>)
  • title (String, nil) —

    The job title of the child entity at the parent entity.

  • updated_at (Time)


# File 'lib/modern_treasury/models/legal_entity_association.rb', line 69


Instance Attribute Details

The child legal entity.



16
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 16

required :child_legal_entity, -> { ModernTreasury::ChildLegalEntity }

#created_at ⇒ Time

Parameters:

  • value (Time)

Returns:

  • (Time)


21
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 21

required :created_at, Time

#discarded_at ⇒ Time?

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


26
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 26

required :discarded_at, Time, nil?: true

#id ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


10
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 10

required :id, String

#live_mode ⇒ Boolean

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


33
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 33

required :live_mode, ModernTreasury::Internal::Type::Boolean

#object ⇒ String

Parameters:

  • value (String)

Returns:

  • (String)


38
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 38

required :object, String

#ownership_percentage ⇒ Integer?

The child entity's ownership percentage iff they are a beneficial owner.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


44
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 44

required :ownership_percentage, Integer, nil?: true

The ID of the parent legal entity. This must be a business legal entity.

Parameters:

  • value (String)

Returns:

  • (String)


50
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 50

required :parent_legal_entity_id, String

#relationship_types ⇒ Array<Symbol, ModernTreasury::Models::LegalEntityAssociation::RelationshipType>

Parameters:

  • value (::Array[ModernTreasury::Models::LegalEntityAssociation::relationship_type])

Returns:



55
56
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 55

required :relationship_types,
-> { ModernTreasury::Internal::Type::ArrayOf[enum: ModernTreasury::LegalEntityAssociation::RelationshipType] }

#title ⇒ String?

The job title of the child entity at the parent entity.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


62
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 62

required :title, String, nil?: true

#updated_at ⇒ Time

Parameters:

  • value (Time)

Returns:

  • (Time)


67
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 67

required :updated_at, Time

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


55
# File 'sig/modern_treasury/models/legal_entity_association.rbs', line 55

def to_hash: -> {