Class: ModernTreasury::Models::LegalEntityAssociationInlineCreate

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/legal_entity_association_inline_create.rb

Defined Under Namespace

Modules: RelationshipType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(relationship_types:, child_legal_entity: nil, child_legal_entity_id: nil, ownership_percentage: nil, title: nil) ⇒ Object

Parameters:



# File 'lib/modern_treasury/models/legal_entity_association_inline_create.rb', line 36

Instance Attribute Details

The child legal entity.



16
# File 'lib/modern_treasury/models/legal_entity_association_inline_create.rb', line 16

optional :child_legal_entity, -> { ModernTreasury::ChildLegalEntityCreate }

The ID of the child legal entity.

Returns:

  • (String, nil)


22
# File 'lib/modern_treasury/models/legal_entity_association_inline_create.rb', line 22

optional :child_legal_entity_id, String

#ownership_percentageInteger?

The child entity’s ownership percentage iff they are a beneficial owner.

Returns:

  • (Integer, nil)


28
# File 'lib/modern_treasury/models/legal_entity_association_inline_create.rb', line 28

optional :ownership_percentage, Integer, nil?: true

#relationship_typesArray<Symbol, ModernTreasury::Models::LegalEntityAssociationInlineCreate::RelationshipType>



9
10
# File 'lib/modern_treasury/models/legal_entity_association_inline_create.rb', line 9

required :relationship_types,
-> { ModernTreasury::Internal::Type::ArrayOf[enum: ModernTreasury::LegalEntityAssociationInlineCreate::RelationshipType] }

#titleString?

The job title of the child entity at the parent entity.

Returns:

  • (String, nil)


34
# File 'lib/modern_treasury/models/legal_entity_association_inline_create.rb', line 34

optional :title, String, nil?: true