Class: ModernTreasury::Models::LegalEntityCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/modern_treasury/models/legal_entity_create_params.rb,
sig/modern_treasury/models/legal_entity_create_params.rbs

Overview

See Also:

  • ModernTreasury::Resources::LegalEntities#create

Defined Under Namespace

Modules: BusinessDesignation, LegalEntityType, LegalStructure, RiskRating Classes: Document, PhoneNumber, Regulator, TermsOfUse

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::ModernTreasury

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(jurisdiction:, name:, registration_number:) ⇒ Object

Some parameter documentations has been truncated, see Regulator for more details.

Parameters:

  • jurisdiction (String) —

    The country code where the regulator operates in the ISO 3166-1 alpha-2 format (

  • name (String) —

    Full name of the regulatory body.

  • registration_number (String) —

    Registration or identification number with the regulator.



# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 294

Instance Attribute Details

#addresses ⇒ Array<ModernTreasury::Models::LegalEntityAddressCreateRequest>?

A list of addresses for the entity.



20
21
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 20

optional :addresses,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAddressCreateRequest] }

#bank_settings ⇒ ModernTreasury::Models::LegalEntityBankSettings?



26
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 26

optional :bank_settings, -> { ModernTreasury::LegalEntityBankSettings }, nil?: true

#business_description ⇒ String?

A description of the business.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


32
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 32

optional :business_description, String, nil?: true

#business_designation ⇒ Symbol, ...

Legal designation associated with the business.

Parameters:

  • value (ModernTreasury::Models::LegalEntityCreateParams::business_designation, nil)

Returns:



38
39
40
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 38

optional :business_designation,
enum: -> { ModernTreasury::LegalEntityCreateParams::BusinessDesignation },
nil?: true

#business_name ⇒ String?

The business's legal business name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


46
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 46

optional :business_name, String, nil?: true

#citizenship_country ⇒ String?

The country of citizenship for an individual.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


52
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 52

optional :citizenship_country, String, nil?: true

#compliance_details ⇒ Object?

Deprecated.

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


58
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 58

optional :compliance_details, ModernTreasury::Internal::Type::Unknown, nil?: true

#connection_id ⇒ String?

The connection ID for the connection the legal entity is associated with. Defaults to the id of the connection designated with an is_default value of true or the id of an existing operational connection if only one is available. Pass in a value of null to prevent the connection from being associated with the legal entity.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


68
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 68

optional :connection_id, String, nil?: true

#country_of_incorporation ⇒ String?

The country where the business is incorporated, as an ISO 3166-1 alpha-2 country code (e.g. US).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


75
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 75

optional :country_of_incorporation, String, nil?: true

#date_formed ⇒ Date?

A business's formation date (YYYY-MM-DD).

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


81
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 81

optional :date_formed, Date, nil?: true

#date_of_birth ⇒ Date?

An individual's date of birth (YYYY-MM-DD).

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


87
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 87

optional :date_of_birth, Date, nil?: true

#documents ⇒ Array<ModernTreasury::Models::LegalEntityCreateParams::Document>?

A list of documents to attach to the legal entity (e.g. articles of incorporation, certificate of good standing, proof of address).



94
95
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 94

optional :documents,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityCreateParams::Document] }

#doing_business_as_names ⇒ Array<String>?

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


100
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 100

optional :doing_business_as_names, ModernTreasury::Internal::Type::ArrayOf[String]

#email ⇒ String?

The entity's primary email.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


106
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 106

optional :email, String, nil?: true

#expected_activity_volume ⇒ Integer?

Monthly expected transaction volume in USD.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


112
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 112

optional :expected_activity_volume, Integer, nil?: true

#external_id ⇒ String?

An optional user-defined 180 character unique identifier.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


118
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 118

optional :external_id, String, nil?: true

#first_name ⇒ String?

An individual's first name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


124
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 124

optional :first_name, String, nil?: true

#identifications ⇒ Array<ModernTreasury::Models::IdentificationCreateRequest>?

A list of identifications for the legal entity.



130
131
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 130

optional :identifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::IdentificationCreateRequest] }

#industry_classifications ⇒ Array<ModernTreasury::Models::LegalEntityIndustryClassification>?

A list of industry classifications for the legal entity.



137
138
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 137

optional :industry_classifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityIndustryClassification] }

#intended_use ⇒ String?

A description of the intended use of the legal entity.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


144
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 144

optional :intended_use, String, nil?: true

#last_name ⇒ String?

An individual's last name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


150
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 150

optional :last_name, String, nil?: true

The legal entity associations and its child legal entities.



156
157
158
159
160
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 156

optional :legal_entity_associations,
-> {
  ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAssociationInlineCreate]
},
nil?: true

The type of legal entity.

Parameters:

  • value (ModernTreasury::Models::LegalEntityCreateParams::legal_entity_type)

Returns:



14
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 14

required :legal_entity_type, enum: -> { ModernTreasury::LegalEntityCreateParams::LegalEntityType }

The business's legal structure.

Parameters:

  • value (ModernTreasury::Models::LegalEntityCreateParams::legal_structure, nil)

Returns:



166
167
168
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 166

optional :legal_structure,
enum: -> { ModernTreasury::LegalEntityCreateParams::LegalStructure },
nil?: true

#listed_exchange ⇒ String?

ISO 10383 market identifier code.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


174
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 174

optional :listed_exchange, String, nil?: true

#metadata ⇒ Hash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


181
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 181

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#middle_name ⇒ String?

An individual's middle name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


187
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 187

optional :middle_name, String, nil?: true

#operating_jurisdictions ⇒ Array<String>?

A list of countries where the business operates, as ISO 3166-1 alpha-2 country codes (e.g. ["US", "CA"]).

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


194
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 194

optional :operating_jurisdictions, ModernTreasury::Internal::Type::ArrayOf[String]

#phone_numbers ⇒ Array<ModernTreasury::Models::LegalEntityCreateParams::PhoneNumber>?



199
200
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 199

optional :phone_numbers,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityCreateParams::PhoneNumber] }

#politically_exposed_person ⇒ Boolean?

Whether the individual is a politically exposed person.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


206
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 206

optional :politically_exposed_person, ModernTreasury::Internal::Type::Boolean, nil?: true

#preferred_name ⇒ String?

An individual's preferred name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


212
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 212

optional :preferred_name, String, nil?: true

#prefix ⇒ String?

An individual's prefix.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


218
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 218

optional :prefix, String, nil?: true

#primary_social_media_sites ⇒ Array<String>?

A list of the entity's primary social media URLs.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


224
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 224

optional :primary_social_media_sites, ModernTreasury::Internal::Type::ArrayOf[String]

#regulators ⇒ Array<ModernTreasury::Models::LegalEntityCreateParams::Regulator>?

Array of regulatory bodies overseeing this institution.

Parameters:

  • value (::Array[ModernTreasury::LegalEntityCreateParams::Regulator], nil)

Returns:



230
231
232
233
234
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 230

optional :regulators,
-> {
  ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityCreateParams::Regulator]
},
nil?: true

#risk_rating ⇒ Symbol, ...

The risk rating of the legal entity. One of low, medium, high.

Parameters:

  • value (ModernTreasury::Models::LegalEntityCreateParams::risk_rating, nil)

Returns:



240
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 240

optional :risk_rating, enum: -> { ModernTreasury::LegalEntityCreateParams::RiskRating }, nil?: true

The UUID of the parent legal entity in the service provider tree.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


246
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 246

optional :service_provider_legal_entity_id, String, nil?: true

#suffix ⇒ String?

An individual's suffix.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


252
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 252

optional :suffix, String, nil?: true

#terms_of_use ⇒ ModernTreasury::Models::LegalEntityCreateParams::TermsOfUse?

Acceptance of terms of use by the legal entity.

Parameters:

  • value (ModernTreasury::LegalEntityCreateParams::TermsOfUse, nil)

Returns:



258
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 258

optional :terms_of_use, -> { ModernTreasury::LegalEntityCreateParams::TermsOfUse }, nil?: true

#third_party_verification ⇒ ModernTreasury::Models::ThirdPartyVerification?

Deprecated.

Deprecated. Use third_party_verifications instead.



266
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 266

optional :third_party_verification, -> { ModernTreasury::ThirdPartyVerification }, nil?: true

#third_party_verifications ⇒ Array<ModernTreasury::Models::ThirdPartyVerification>?

A list of third-party verifications run by external vendors.



272
273
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 272

optional :third_party_verifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ThirdPartyVerification] }

#ticker_symbol ⇒ String?

Stock ticker symbol for publicly traded companies.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


279
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 279

optional :ticker_symbol, String, nil?: true

#wealth_and_employment_details ⇒ ModernTreasury::Models::LegalEntityWealthEmploymentDetail?



284
285
286
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 284

optional :wealth_and_employment_details,
-> { ModernTreasury::LegalEntityWealthEmploymentDetail },
nil?: true

#website ⇒ String?

The entity's primary website URL.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


292
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 292

optional :website, String, nil?: true

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 393

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


220
# File 'sig/modern_treasury/models/legal_entity_create_params.rbs', line 220

def to_hash: -> {