Class: ModernTreasury::Models::LegalEntityCreateParams::Document
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::LegalEntityCreateParams::Document
- Defined in:
- lib/modern_treasury/models/legal_entity_create_params.rb
Defined Under Namespace
Modules: DocumentType
Instance Attribute Summary collapse
-
#document_type ⇒ Symbol, ModernTreasury::Models::LegalEntityCreateParams::Document::DocumentType
A category given to the document, can be ‘null`.
-
#file_data ⇒ String
Base64-encoded file content for the document.
-
#filename ⇒ String?
The original filename of the document.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(document_type:, file_data:, filename: nil) ⇒ Object
|
|
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 398
|
Instance Attribute Details
#document_type ⇒ Symbol, ModernTreasury::Models::LegalEntityCreateParams::Document::DocumentType
A category given to the document, can be ‘null`.
384 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 384 required :document_type, enum: -> { ModernTreasury::LegalEntityCreateParams::Document::DocumentType } |
#file_data ⇒ String
Base64-encoded file content for the document.
390 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 390 required :file_data, String |
#filename ⇒ String?
The original filename of the document.
396 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 396 optional :filename, String |