Class: ModernTreasury::Models::LegalEntityCreateParams::TermsOfUse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/legal_entity_create_params.rb,
sig/modern_treasury/models/legal_entity_create_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(accepted_at: nil, ip_address: nil) ⇒ TermsOfUse

Some parameter documentations has been truncated, see ModernTreasury::Models::LegalEntityCreateParams::TermsOfUse for more details.

Acceptance of terms of use by the legal entity.

Parameters:

  • accepted_at (Time) (defaults to: nil)

    The ISO 8601 timestamp indicating when the terms of use were accepted.

  • ip_address (String) (defaults to: nil)

    The IP address from which the terms of use were accepted. Supports both IPv4 and

  • accepted_at: (Time) (defaults to: nil)
  • ip_address: (String) (defaults to: nil)


# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 516

Instance Attribute Details

#accepted_atTime?

The ISO 8601 timestamp indicating when the terms of use were accepted.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


507
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 507

optional :accepted_at, Time

#ip_addressString?

The IP address from which the terms of use were accepted. Supports both IPv4 and IPv6 formats.

Parameters:

  • (String)

Returns:

  • (String, nil)


514
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 514

optional :ip_address, String

Instance Method Details

#to_hash{ accepted_at: Time, ip_address: String }

Returns:

  • ({ accepted_at: Time, ip_address: String })


406
# File 'sig/modern_treasury/models/legal_entity_create_params.rbs', line 406

def to_hash: -> { accepted_at: Time, ip_address: String }