Class: ModernTreasury::Models::LegalEntityListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::LegalEntityListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/legal_entity_list_params.rb
Overview
Defined Under Namespace
Modules: LegalEntityType, Status
Instance Attribute Summary collapse
- #after_cursor ⇒ String?
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
- #legal_entity_type ⇒ Symbol, ...
-
#metadata ⇒ Hash{Symbol=>String}?
For example, if you want to query for records with metadata key ‘Type` and value `Loan`, the query would be `metadata%5BType%5D=Loan`.
- #per_page ⇒ Integer?
- #show_deleted ⇒ String?
- #status ⇒ Symbol, ...
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from ModernTreasury::Internal::Type::BaseModel
Instance Attribute Details
#after_cursor ⇒ String?
13 |
# File 'lib/modern_treasury/models/legal_entity_list_params.rb', line 13 optional :after_cursor, String, nil?: true |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
19 |
# File 'lib/modern_treasury/models/legal_entity_list_params.rb', line 19 optional :external_id, String |
#legal_entity_type ⇒ Symbol, ...
24 |
# File 'lib/modern_treasury/models/legal_entity_list_params.rb', line 24 optional :legal_entity_type, enum: -> { ModernTreasury::LegalEntityListParams::LegalEntityType } |
#metadata ⇒ Hash{Symbol=>String}?
For example, if you want to query for records with metadata key ‘Type` and value `Loan`, the query would be `metadata%5BType%5D=Loan`. This encodes the query parameters.
32 |
# File 'lib/modern_treasury/models/legal_entity_list_params.rb', line 32 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#per_page ⇒ Integer?
37 |
# File 'lib/modern_treasury/models/legal_entity_list_params.rb', line 37 optional :per_page, Integer |
#show_deleted ⇒ String?
42 |
# File 'lib/modern_treasury/models/legal_entity_list_params.rb', line 42 optional :show_deleted, String |
#status ⇒ Symbol, ...
47 |
# File 'lib/modern_treasury/models/legal_entity_list_params.rb', line 47 optional :status, enum: -> { ModernTreasury::LegalEntityListParams::Status } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/legal_entity_list_params.rb', line 75
|