Class: ModernTreasury::Models::PaymentActionCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/modern_treasury/models/payment_action_create_params.rb,
sig/modern_treasury/models/payment_action_create_params.rbs

Overview

See Also:

  • ModernTreasury::Resources::PaymentActions#create

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::ModernTreasury

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(type:, actionable_id: nil, actionable_type: nil, details: nil, internal_account_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::PaymentActionCreateParams for more details.

Parameters:

  • type (String)

    Required. The type of the payment action. Determines the action to be taken.

  • actionable_id (String) (defaults to: nil)

    Optional. The ID of the associated actionable object.

  • actionable_type (String) (defaults to: nil)

    Optional. The type of the associated actionable object. One of payment_order,

  • details (Object) (defaults to: nil)

    Optional. The specifc details of the payment action based on type.

  • internal_account_id (String) (defaults to: nil)

    Optional. The ID of one of your organization's internal accounts. Required if `a

  • request_options (ModernTreasury::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/modern_treasury/models/payment_action_create_params.rb', line 42

Instance Attribute Details

#actionable_idString?

Optional. The ID of the associated actionable object.

Parameters:

  • (String)

Returns:

  • (String, nil)


20
# File 'lib/modern_treasury/models/payment_action_create_params.rb', line 20

optional :actionable_id, String

#actionable_typeString?

Optional. The type of the associated actionable object. One of payment_order, expected_payment. Required if actionable_id is passed.

Parameters:

  • (String)

Returns:

  • (String, nil)


27
# File 'lib/modern_treasury/models/payment_action_create_params.rb', line 27

optional :actionable_type, String

#detailsObject?

Optional. The specifc details of the payment action based on type.

Parameters:

  • (top)

Returns:

  • (Object, nil)


33
# File 'lib/modern_treasury/models/payment_action_create_params.rb', line 33

optional :details, ModernTreasury::Internal::Type::Unknown

#internal_account_idString?

Optional. The ID of one of your organization's internal accounts. Required if actionable_id is not passed.

Parameters:

  • (String)

Returns:

  • (String, nil)


40
# File 'lib/modern_treasury/models/payment_action_create_params.rb', line 40

optional :internal_account_id, String

#typeString

Required. The type of the payment action. Determines the action to be taken.

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/modern_treasury/models/payment_action_create_params.rb', line 14

required :type, String

Instance Method Details

#to_hash{

Returns:

  • ({)


44
# File 'sig/modern_treasury/models/payment_action_create_params.rbs', line 44

def to_hash: -> {