Module: ModernTreasury::Models::PaymentFlow::ExternalAccountCollection

Extended by:
Internal::Type::Enum
Defined in:
lib/modern_treasury/models/payment_flow.rb,
sig/modern_treasury/models/payment_flow.rbs

Overview

When enabled, your end-user can select from an existing external account when completing the flow. When disabled, your end-user must add new payment details when completing the flow.

See Also:

  • ModernTreasury::Models::PaymentFlow#external_account_collection

Constant Summary collapse

DISABLED =

Returns:

  • (:disabled)
:disabled
ENABLED =

Returns:

  • (:enabled)
:enabled

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[ModernTreasury::Models::PaymentFlow::external_account_collection]

Returns:

  • (::Array[ModernTreasury::Models::PaymentFlow::external_account_collection])


168
# File 'sig/modern_treasury/models/payment_flow.rbs', line 168

def self?.values: -> ::Array[ModernTreasury::Models::PaymentFlow::external_account_collection]