Class: ModernTreasury::Models::PaymentOrder::Accounting Deprecated

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/payment_order.rb,
sig/modern_treasury/models/payment_order.rbs

Overview

Deprecated.

See Also:

  • ModernTreasury::Models::PaymentOrder#accounting

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeAccounting

Returns a new instance of Accounting.

Parameters:

  • account_id: (String, nil)
  • class_id: (String, nil)


276
# File 'sig/modern_treasury/models/payment_order.rbs', line 276

def initialize: (?account_id: String?, ?class_id: String?) -> void

Instance Attribute Details

#account_idString?

Deprecated.

The ID of one of your accounting categories. Note that these will only be accessible if your accounting system has been connected.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


482
# File 'lib/modern_treasury/models/payment_order.rb', line 482

optional :account_id, String, nil?: true

#class_idString?

Deprecated.

The ID of one of the class objects in your accounting system. Class objects track segments of your business independent of client or project. Note that these will only be accessible if your accounting system has been connected.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


492
# File 'lib/modern_treasury/models/payment_order.rb', line 492

optional :class_id, String, nil?: true

Instance Method Details

#to_hash{ account_id: String?, class_id: String? }

Returns:

  • ({ account_id: String?, class_id: String? })


278
# File 'sig/modern_treasury/models/payment_order.rbs', line 278

def to_hash: -> { account_id: String?, class_id: String? }