Class: ModernTreasury::Models::PaymentOrder::CurrentHold

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/payment_order.rb

Overview

See Also:

Defined Under Namespace

Modules: Object, Status, TargetType

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, object:, status:, target_id:, target_type:, updated_at:, live_mode: nil, metadata: nil, reason: nil, resolution: nil, resolved_at: nil) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::PaymentOrder::CurrentHold for more details.

If the payment order’s status is ‘held`, this will include the hold object’s data.

Parameters:



# File 'lib/modern_treasury/models/payment_order.rb', line 592

Instance Attribute Details

#created_atTime

Returns:

  • (Time)


530
# File 'lib/modern_treasury/models/payment_order.rb', line 530

required :created_at, Time

#idString

Returns:

  • (String)


525
# File 'lib/modern_treasury/models/payment_order.rb', line 525

required :id, String

#live_modeBoolean?

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Returns:

  • (Boolean, nil)


566
# File 'lib/modern_treasury/models/payment_order.rb', line 566

optional :live_mode, ModernTreasury::Internal::Type::Boolean

#metadataHash{Symbol=>String}?

Additional metadata for the hold

Returns:

  • (Hash{Symbol=>String}, nil)


572
# File 'lib/modern_treasury/models/payment_order.rb', line 572

optional :metadata, ModernTreasury::Internal::Type::HashOf[String], nil?: true

#objectSymbol, ModernTreasury::Models::PaymentOrder::CurrentHold::Object

The type of object



536
# File 'lib/modern_treasury/models/payment_order.rb', line 536

required :object, enum: -> { ModernTreasury::PaymentOrder::CurrentHold::Object }

#reasonString?

The reason for the hold

Returns:

  • (String, nil)


578
# File 'lib/modern_treasury/models/payment_order.rb', line 578

optional :reason, String, nil?: true

#resolutionString?

The resolution of the hold

Returns:

  • (String, nil)


584
# File 'lib/modern_treasury/models/payment_order.rb', line 584

optional :resolution, String, nil?: true

#resolved_atTime?

When the hold was resolved

Returns:

  • (Time, nil)


590
# File 'lib/modern_treasury/models/payment_order.rb', line 590

optional :resolved_at, Time, nil?: true

#statusSymbol, ModernTreasury::Models::PaymentOrder::CurrentHold::Status

The status of the hold



542
# File 'lib/modern_treasury/models/payment_order.rb', line 542

required :status, enum: -> { ModernTreasury::PaymentOrder::CurrentHold::Status }

#target_idString

The ID of the target being held

Returns:

  • (String)


548
# File 'lib/modern_treasury/models/payment_order.rb', line 548

required :target_id, String

#target_typeSymbol, ModernTreasury::Models::PaymentOrder::CurrentHold::TargetType

The type of target being held



554
# File 'lib/modern_treasury/models/payment_order.rb', line 554

required :target_type, enum: -> { ModernTreasury::PaymentOrder::CurrentHold::TargetType }

#updated_atTime

Returns:

  • (Time)


559
# File 'lib/modern_treasury/models/payment_order.rb', line 559

required :updated_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/payment_order.rb', line 631