Class: ModernTreasury::Models::PaymentOrderCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::PaymentOrderCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/payment_order_create_params.rb
Overview
Defined Under Namespace
Modules: ChargeBearer, Direction, FallbackType, ForeignExchangeIndicator, Priority, ReconciliationStatus Classes: Accounting, Document, LineItem, ReceivingAccount, UltimateOriginatingPartyAddress
Instance Attribute Summary collapse
- #accounting ⇒ ModernTreasury::Models::PaymentOrderCreateParams::Accounting? deprecated Deprecated.
- #accounting_category_id ⇒ String? deprecated Deprecated.
- #accounting_ledger_class_id ⇒ String? deprecated Deprecated.
-
#amount ⇒ Integer
Value in specified currency’s smallest unit.
-
#charge_bearer ⇒ Symbol, ...
The party that will pay the fees for the payment order.
-
#currency ⇒ Symbol, ...
Defaults to the currency of the originating account.
-
#description ⇒ String?
An optional description for internal use.
-
#direction ⇒ Symbol, ModernTreasury::Models::PaymentOrderCreateParams::Direction
One of ‘credit`, `debit`.
-
#documents ⇒ Array<ModernTreasury::Models::PaymentOrderCreateParams::Document>?
An array of documents to be attached to the payment order.
-
#effective_date ⇒ Date?
Date transactions are to be posted to the participants’ account.
-
#expires_at ⇒ Time?
RFP payments require an expires_at.
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
-
#fallback_type ⇒ Symbol, ...
A payment type to fallback to if the original type is not valid for the receiving account.
-
#foreign_exchange_contract ⇒ String?
If present, indicates a specific foreign exchange contract number that has been generated by your financial institution.
-
#foreign_exchange_indicator ⇒ Symbol, ...
Indicates the type of FX transfer to initiate, can be either ‘variable_to_fixed`, `fixed_to_variable`, or `null` if the payment order currency matches the originating account currency.
-
#ledger_transaction ⇒ ModernTreasury::Models::LedgerTransactionCreateRequest?
Specifies a ledger transaction object that will be created with the payment order.
-
#ledger_transaction_id ⇒ String?
Either ledger_transaction or ledger_transaction_id can be provided.
-
#line_items ⇒ Array<ModernTreasury::Models::PaymentOrderCreateParams::LineItem>?
An array of line items that must sum up to the amount of the payment order.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#nsf_protected ⇒ Boolean?
A boolean to determine if NSF Protection is enabled for this payment order.
-
#originating_account_id ⇒ String
The ID of one of your organization’s internal accounts.
-
#originating_party_name ⇒ String?
If present, this will replace your default company name on receiver’s bank statement.
-
#priority ⇒ Symbol, ...
Either ‘normal` or `high`.
-
#process_after ⇒ Time?
If present, Modern Treasury will not process the payment until after this time.
-
#purpose ⇒ String?
For ‘wire`, this is usually the purpose which is transmitted via the “InstrForDbtrAgt” field in the ISO20022 file.
-
#receiving_account ⇒ ModernTreasury::Models::PaymentOrderCreateParams::ReceivingAccount?
Either ‘receiving_account` or `receiving_account_id` must be present.
-
#receiving_account_id ⇒ String?
Either ‘receiving_account` or `receiving_account_id` must be present.
-
#reconciliation_status ⇒ Symbol, ...
One of ‘unreconciled`, `tentatively_reconciled` or `reconciled`.
-
#remittance_information ⇒ String?
For ‘ach`, this field will be passed through on an addenda record.
-
#send_remittance_advice ⇒ Boolean?
Send an email to the counterparty when the payment order is sent to the bank.
-
#statement_descriptor ⇒ String?
An optional descriptor which will appear in the receiver’s statement.
-
#subtype ⇒ Symbol, ...
An additional layer of classification for the type of payment order you are doing.
- #transaction_monitoring_enabled ⇒ Boolean? deprecated Deprecated.
-
#type ⇒ Symbol, ModernTreasury::Models::PaymentOrderType
One of ‘ach`, `se_bankgirot`, `eft`, `wire`, `check`, `sen`, `book`, `rtp`, `sepa`, `bacs`, `au_becs`, `interac`, `neft`, `nics`, `nz_national_clearing_code`, `sic`, `signet`, `provexchange`, `zengin`.
-
#ultimate_originating_account_id ⇒ String?
The ultimate originating account ID.
-
#ultimate_originating_party_address ⇒ ModernTreasury::Models::PaymentOrderCreateParams::UltimateOriginatingPartyAddress?
Address of the ultimate originator of the payment order.
-
#ultimate_originating_party_identifier ⇒ String?
Identifier of the ultimate originator of the payment order.
-
#ultimate_originating_party_name ⇒ String?
Name of the ultimate originator of the payment order.
-
#ultimate_receiving_party_identifier ⇒ String?
Identifier of the ultimate funds recipient.
-
#ultimate_receiving_party_name ⇒ String?
Name of the ultimate funds recipient.
-
#vendor_attributes ⇒ Object?
Additional vendor specific fields for this payment.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount:, accounting_category_id: nil, description: nil, metadata: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see LineItem for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, accounting_category_id: nil, description: nil, metadata: nil) ⇒ Object
Some parameter documentations has been truncated, see LineItem for more details.
|
|
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 324
|
Instance Attribute Details
#accounting ⇒ ModernTreasury::Models::PaymentOrderCreateParams::Accounting?
44 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 44 optional :accounting, -> { ModernTreasury::PaymentOrderCreateParams::Accounting } |
#accounting_category_id ⇒ String?
The ID of one of your accounting categories. Note that these will only be accessible if your accounting system has been connected.
53 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 53 optional :accounting_category_id, String, nil?: true |
#accounting_ledger_class_id ⇒ String?
The ID of one of your accounting ledger classes. Note that these will only be accessible if your accounting system has been connected.
62 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 62 optional :accounting_ledger_class_id, String, nil?: true |
#amount ⇒ Integer
Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000 (cents). For RTP, the maximum amount allowed by the network is $100,000.
15 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 15 required :amount, Integer |
#charge_bearer ⇒ Symbol, ...
The party that will pay the fees for the payment order. See docs.moderntreasury.com/payments/docs/charge-bearer to understand the differences between the options.
70 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 70 optional :charge_bearer, enum: -> { ModernTreasury::PaymentOrderCreateParams::ChargeBearer }, nil?: true |
#currency ⇒ Symbol, ...
Defaults to the currency of the originating account.
76 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 76 optional :currency, enum: -> { ModernTreasury::Currency } |
#description ⇒ String?
An optional description for internal use.
82 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 82 optional :description, String, nil?: true |
#direction ⇒ Symbol, ModernTreasury::Models::PaymentOrderCreateParams::Direction
One of ‘credit`, `debit`. Describes the direction money is flowing in the transaction. A `credit` moves money from your account to someone else’s. A ‘debit` pulls money from someone else’s account to your own. Note that wire, rtp, and check payments will always be ‘credit`.
24 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 24 required :direction, enum: -> { ModernTreasury::PaymentOrderCreateParams::Direction } |
#documents ⇒ Array<ModernTreasury::Models::PaymentOrderCreateParams::Document>?
An array of documents to be attached to the payment order. Note that if you attach documents, the request’s content type must be ‘multipart/form-data`.
89 90 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 89 optional :documents, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::PaymentOrderCreateParams::Document] } |
#effective_date ⇒ Date?
Date transactions are to be posted to the participants’ account. Defaults to the current business day or the next business day if the current day is a bank holiday or weekend. Format: yyyy-mm-dd.
98 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 98 optional :effective_date, Date |
#expires_at ⇒ Time?
RFP payments require an expires_at. This value must be past the effective_date.
104 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 104 optional :expires_at, Time, nil?: true |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
110 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 110 optional :external_id, String, nil?: true |
#fallback_type ⇒ Symbol, ...
A payment type to fallback to if the original type is not valid for the receiving account. Currently, this only supports falling back from RTP to ACH (type=rtp and fallback_type=ach)
118 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 118 optional :fallback_type, enum: -> { ModernTreasury::PaymentOrderCreateParams::FallbackType } |
#foreign_exchange_contract ⇒ String?
If present, indicates a specific foreign exchange contract number that has been generated by your financial institution.
125 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 125 optional :foreign_exchange_contract, String, nil?: true |
#foreign_exchange_indicator ⇒ Symbol, ...
Indicates the type of FX transfer to initiate, can be either ‘variable_to_fixed`, `fixed_to_variable`, or `null` if the payment order currency matches the originating account currency.
133 134 135 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 133 optional :foreign_exchange_indicator, enum: -> { ModernTreasury::PaymentOrderCreateParams::ForeignExchangeIndicator }, nil?: true |
#ledger_transaction ⇒ ModernTreasury::Models::LedgerTransactionCreateRequest?
Specifies a ledger transaction object that will be created with the payment order. If the ledger transaction cannot be created, then the payment order creation will fail. The resulting ledger transaction will mirror the status of the payment order.
144 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 144 optional :ledger_transaction, -> { ModernTreasury::LedgerTransactionCreateRequest } |
#ledger_transaction_id ⇒ String?
Either ledger_transaction or ledger_transaction_id can be provided. Only a pending ledger transaction can be attached upon payment order creation. Once the payment order is created, the status of the ledger transaction tracks the payment order automatically.
153 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 153 optional :ledger_transaction_id, String |
#line_items ⇒ Array<ModernTreasury::Models::PaymentOrderCreateParams::LineItem>?
An array of line items that must sum up to the amount of the payment order.
159 160 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 159 optional :line_items, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::PaymentOrderCreateParams::LineItem] } |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
167 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 167 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#nsf_protected ⇒ Boolean?
A boolean to determine if NSF Protection is enabled for this payment order. Note that this setting must also be turned on in your organization settings page.
174 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 174 optional :nsf_protected, ModernTreasury::Internal::Type::Boolean |
#originating_account_id ⇒ String
The ID of one of your organization’s internal accounts.
30 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 30 required :originating_account_id, String |
#originating_party_name ⇒ String?
If present, this will replace your default company name on receiver’s bank statement. This field can only be used for ACH payments currently. For ACH, only the first 16 characters of this string will be used. Any additional characters will be truncated.
183 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 183 optional :originating_party_name, String, nil?: true |
#priority ⇒ Symbol, ...
Either ‘normal` or `high`. For ACH and EFT payments, `high` represents a same-day ACH or EFT transfer, respectively. For check payments, `high` can mean an overnight check rather than standard mail.
191 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 191 optional :priority, enum: -> { ModernTreasury::PaymentOrderCreateParams::Priority } |
#process_after ⇒ Time?
If present, Modern Treasury will not process the payment until after this time. If ‘process_after` is past the cutoff for `effective_date`, `process_after` will take precedence and `effective_date` will automatically update to reflect the earliest possible sending date after `process_after`. Format is ISO8601 timestamp.
201 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 201 optional :process_after, Time, nil?: true |
#purpose ⇒ String?
For ‘wire`, this is usually the purpose which is transmitted via the “InstrForDbtrAgt” field in the ISO20022 file. For `eft`, this field is the 3 digit CPA Code that will be attached to the payment.
209 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 209 optional :purpose, String, nil?: true |
#receiving_account ⇒ ModernTreasury::Models::PaymentOrderCreateParams::ReceivingAccount?
Either ‘receiving_account` or `receiving_account_id` must be present. When using `receiving_account_id`, you may pass the id of an external account or an internal account.
217 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 217 optional :receiving_account, -> { ModernTreasury::PaymentOrderCreateParams::ReceivingAccount } |
#receiving_account_id ⇒ String?
Either ‘receiving_account` or `receiving_account_id` must be present. When using `receiving_account_id`, you may pass the id of an external account or an internal account.
225 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 225 optional :receiving_account_id, String |
#reconciliation_status ⇒ Symbol, ...
One of ‘unreconciled`, `tentatively_reconciled` or `reconciled`.
231 232 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 231 optional :reconciliation_status, enum: -> { ModernTreasury::PaymentOrderCreateParams::ReconciliationStatus } |
#remittance_information ⇒ String?
For ‘ach`, this field will be passed through on an addenda record. For `wire` payments the field will be passed through as the “Originator to Beneficiary Information”, also known as OBI or Fedwire tag 6000.
240 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 240 optional :remittance_information, String, nil?: true |
#send_remittance_advice ⇒ Boolean?
Send an email to the counterparty when the payment order is sent to the bank. If ‘null`, `send_remittance_advice` on the Counterparty is used.
247 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 247 optional :send_remittance_advice, ModernTreasury::Internal::Type::Boolean, nil?: true |
#statement_descriptor ⇒ String?
An optional descriptor which will appear in the receiver’s statement. For ‘check` payments this field will be used as the memo line. For `ach` the maximum length is 10 characters. Note that for ACH payments, the name on your bank account will be included automatically by the bank, so you can use the characters for other useful information. For `eft` the maximum length is 15 characters.
258 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 258 optional :statement_descriptor, String, nil?: true |
#subtype ⇒ Symbol, ...
An additional layer of classification for the type of payment order you are doing. This field is only used for ‘ach` payment orders currently. For `ach` payment orders, the `subtype` represents the SEC code. We currently support `CCD`, `PPD`, `IAT`, `CTX`, `WEB`, `CIE`, and `TEL`.
267 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 267 optional :subtype, enum: -> { ModernTreasury::PaymentOrderSubtype }, nil?: true |
#transaction_monitoring_enabled ⇒ Boolean?
A flag that determines whether a payment order should go through transaction monitoring.
276 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 276 optional :transaction_monitoring_enabled, ModernTreasury::Internal::Type::Boolean |
#type ⇒ Symbol, ModernTreasury::Models::PaymentOrderType
One of ‘ach`, `se_bankgirot`, `eft`, `wire`, `check`, `sen`, `book`, `rtp`, `sepa`, `bacs`, `au_becs`, `interac`, `neft`, `nics`, `nz_national_clearing_code`, `sic`, `signet`, `provexchange`, `zengin`.
38 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 38 required :type, enum: -> { ModernTreasury::PaymentOrderType } |
#ultimate_originating_account_id ⇒ String?
The ultimate originating account ID. Can be a ‘virtual_account` or `internal_account`.
283 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 283 optional :ultimate_originating_account_id, String |
#ultimate_originating_party_address ⇒ ModernTreasury::Models::PaymentOrderCreateParams::UltimateOriginatingPartyAddress?
Address of the ultimate originator of the payment order.
289 290 291 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 289 optional :ultimate_originating_party_address, -> { ModernTreasury::PaymentOrderCreateParams::UltimateOriginatingPartyAddress }, nil?: true |
#ultimate_originating_party_identifier ⇒ String?
Identifier of the ultimate originator of the payment order.
297 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 297 optional :ultimate_originating_party_identifier, String, nil?: true |
#ultimate_originating_party_name ⇒ String?
Name of the ultimate originator of the payment order.
303 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 303 optional :ultimate_originating_party_name, String, nil?: true |
#ultimate_receiving_party_identifier ⇒ String?
Identifier of the ultimate funds recipient.
309 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 309 optional :ultimate_receiving_party_identifier, String, nil?: true |
#ultimate_receiving_party_name ⇒ String?
Name of the ultimate funds recipient.
315 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 315 optional :ultimate_receiving_party_name, String, nil?: true |
#vendor_attributes ⇒ Object?
Additional vendor specific fields for this payment. Data must be represented as key-value pairs.
322 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 322 optional :vendor_attributes, ModernTreasury::Internal::Type::Unknown |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 422
|