Class: ModernTreasury::Models::PaymentOrderCreateParams::Document
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::PaymentOrderCreateParams::Document
- Defined in:
- lib/modern_treasury/models/payment_order_create_params.rb
Defined Under Namespace
Modules: DocumentableType
Instance Attribute Summary collapse
-
#document_type ⇒ String?
A category given to the document, can be ‘null`.
-
#documentable_id ⇒ String?
The unique identifier for the associated object.
- #documentable_type ⇒ Symbol, ...
- #file ⇒ Pathname, ...
Instance Method Summary collapse
- #initialize(file:, document_type: nil, documentable_id: nil, documentable_type: nil) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(file:, document_type: nil, documentable_id: nil, documentable_type: nil) ⇒ Object
|
|
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 494
|
Instance Attribute Details
#document_type ⇒ String?
A category given to the document, can be ‘null`.
480 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 480 optional :document_type, String |
#documentable_id ⇒ String?
The unique identifier for the associated object.
486 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 486 optional :documentable_id, String |
#documentable_type ⇒ Symbol, ...
491 492 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 491 optional :documentable_type, enum: -> { ModernTreasury::PaymentOrderCreateParams::Document::DocumentableType } |
#file ⇒ Pathname, ...
474 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 474 required :file, ModernTreasury::Internal::Type::FileInput |