Module: ModernTreasury::Models::PaymentOrderCreateParams::FallbackType
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/modern_treasury/models/payment_order_create_params.rb,
sig/modern_treasury/models/payment_order_create_params.rbs
Overview
A payment type to fallback to if the original type is not valid for the receiving account. Currently, this only supports falling back from RTP to ACH (type=rtp and fallback_type=ach)
Constant Summary collapse
- ACH =
:ach
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[ModernTreasury::Models::PaymentOrderCreateParams::fallback_type]
390 |
# File 'sig/modern_treasury/models/payment_order_create_params.rbs', line 390
def self?.values: -> ::Array[ModernTreasury::Models::PaymentOrderCreateParams::fallback_type]
|