Class: ModernTreasury::Models::PaymentOrderCreateParams::UltimateOriginatingPartyAddress

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/payment_order_create_params.rb,
sig/modern_treasury/models/payment_order_create_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(country: nil, line1: nil, line2: nil, locality: nil, postal_code: nil, region: nil) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::PaymentOrderCreateParams::UltimateOriginatingPartyAddress for more details.

Address of the ultimate originator of the payment order.

Parameters:

  • country (String) (defaults to: nil) —

    Country code conforms to [ISO 3166-1 alpha-2]

  • line1 (String) (defaults to: nil)
  • line2 (String) (defaults to: nil)
  • locality (String) (defaults to: nil) —

    Locality or City. Use the full city name rather than an abbreviation (e.g. San F

  • postal_code (String) (defaults to: nil) —

    The postal code of the address.

  • region (String) (defaults to: nil) —

    Region or State. This field is free-form; for US states, we recommend a two-lett



# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 984

Instance Attribute Details

#country ⇒ String?

Country code conforms to [ISO 3166-1 alpha-2]

Parameters:

  • (String)

Returns:

  • (String, nil)


952
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 952

optional :country, String

#line1 ⇒ String?

Parameters:

  • (String)

Returns:

  • (String, nil)


957
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 957

optional :line1, String

#line2 ⇒ String?

Parameters:

  • (String)

Returns:

  • (String, nil)


962
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 962

optional :line2, String

#locality ⇒ String?

Locality or City. Use the full city name rather than an abbreviation (e.g. San Francisco).

Parameters:

  • (String)

Returns:

  • (String, nil)


969
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 969

optional :locality, String

#postal_code ⇒ String?

The postal code of the address.

Parameters:

  • (String)

Returns:

  • (String, nil)


975
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 975

optional :postal_code, String

#region ⇒ String?

Region or State. This field is free-form; for US states, we recommend a two-letter code (e.g. CA). Full state names are also accepted.

Parameters:

  • (String)

Returns:

  • (String, nil)


982
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 982

optional :region, String

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


875
# File 'sig/modern_treasury/models/payment_order_create_params.rbs', line 875

def to_hash: -> {