Module: ModernTreasury::Models::PaymentOrderSubtype

Extended by:
Internal::Type::Enum
Defined in:
lib/modern_treasury/models/payment_order_subtype.rb,
sig/modern_treasury/models/payment_order_subtype.rbs

Overview

An additional layer of classification for the type of payment order you are doing. This field is only used for ach payment orders currently. For ach payment orders, the subtype represents the SEC code. We currently support CCD, PPD, IAT, CTX, WEB, CIE, and TEL.

Constant Summary collapse

BACS_NEW_INSTRUCTION =

Returns:

  • (:"0C")
:"0C"
BACS_CANCELLATION_INSTRUCTION =

Returns:

  • (:"0N")
:"0N"
BACS_CONVERSION_INSTRUCTION =

Returns:

  • (:"0S")
:"0S"
CCD =

Returns:

  • (:CCD)
:CCD
CIE =

Returns:

  • (:CIE)
:CIE
CTX =

Returns:

  • (:CTX)
:CTX
IAT =

Returns:

  • (:IAT)
:IAT
PPD =

Returns:

  • (:PPD)
:PPD
TEL =

Returns:

  • (:TEL)
:TEL
WEB =

Returns:

  • (:WEB)
:WEB
AU_BECS =

Returns:

  • (:au_becs)
:au_becs
BACS =

Returns:

  • (:bacs)
:bacs
BASE =

Returns:

  • (:base)
:base
CHATS =

Returns:

  • (:chats)
:chats
DIGITAL =

Returns:

  • (:digital)
:digital
DK_NETS =

Returns:

  • (:dk_nets)
:dk_nets
EFT =

Returns:

  • (:eft)
:eft
ETHEREUM =

Returns:

  • (:ethereum)
:ethereum
MASAV =

Returns:

  • (:masav)
:masav
MX_CCEN =

Returns:

  • (:mx_ccen)
:mx_ccen
NEFT =

Returns:

  • (:neft)
:neft
NICS =

Returns:

  • (:nics)
:nics
NZ_BECS =

Returns:

  • (:nz_becs)
:nz_becs
PL_ELIXIR =

Returns:

  • (:pl_elixir)
:pl_elixir
POLYGON =

Returns:

  • (:polygon)
:polygon
:print
SE_BANKGIROT =

Returns:

  • (:se_bankgirot)
:se_bankgirot
SEPA =

Returns:

  • (:sepa)
:sepa
SG_GIRO =

Returns:

  • (:sg_giro)
:sg_giro
SIC =

Returns:

  • (:sic)
:sic
SOLANA =

Returns:

  • (:solana)
:solana
ZENGIN =

Returns:

  • (:zengin)
:zengin

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/payment_order_subtype.rb', line 45

Instance Method Details

#self?.values::Array[ModernTreasury::Models::payment_order_subtype]

Returns:

  • (::Array[ModernTreasury::Models::payment_order_subtype])


73
# File 'sig/modern_treasury/models/payment_order_subtype.rbs', line 73

def self?.values: -> ::Array[ModernTreasury::Models::payment_order_subtype]