Class: ModernTreasury::Models::PaymentOrderUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/modern_treasury/models/payment_order_update_params.rb,
sig/modern_treasury/models/payment_order_update_params.rbs

Overview

See Also:

  • ModernTreasury::Resources::PaymentOrders#update

Defined Under Namespace

Modules: ChargeBearer, Direction, FallbackType, ForeignExchangeIndicator, Priority, ReconciliationStatus, Status Classes: Accounting, LineItem, ReceivingAccount

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::ModernTreasury

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, accounting_category_id: nil, description: nil, metadata: nil) ⇒ Object

Some parameter documentations has been truncated, see LineItem for more details.

Parameters:

  • amount (Integer)

    Value in specified currency's smallest unit. e.g. $10 would be represented as 10

  • accounting_category_id (String, nil) (defaults to: nil)

    The ID of one of your accounting categories. Note that these will only be access

  • description (String, nil) (defaults to: nil)

    A free-form description of the line item.

  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    Additional data represented as key-value pairs. Both the key and value must be s



# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 293

Instance Attribute Details

#accountingModernTreasury::Models::PaymentOrderUpdateParams::Accounting?

Deprecated.


19
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 19

optional :accounting, -> { ModernTreasury::PaymentOrderUpdateParams::Accounting }

#accounting_category_idString?

Deprecated.

The ID of one of your accounting categories. Note that these will only be accessible if your accounting system has been connected.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


28
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 28

optional :accounting_category_id, String, nil?: true

#accounting_ledger_class_idString?

Deprecated.

The ID of one of your accounting ledger classes. Note that these will only be accessible if your accounting system has been connected.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


37
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 37

optional :accounting_ledger_class_id, String, nil?: true

#amountInteger?

Value in specified currency's smallest unit. e.g. $10 would be represented as 1000 (cents). For RTP, the maximum amount allowed by the network is $10,000,000.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


44
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 44

optional :amount, Integer

#charge_bearerSymbol, ...

The party that will pay the fees for the payment order. See https://docs.moderntreasury.com/payments/docs/charge-bearer to understand the differences between the options.

Parameters:

  • value (ModernTreasury::Models::PaymentOrderUpdateParams::charge_bearer, nil)

Returns:



52
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 52

optional :charge_bearer, enum: -> { ModernTreasury::PaymentOrderUpdateParams::ChargeBearer }, nil?: true

#counterparty_idString?

Required when receiving_account_id is passed the ID of an external account.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


58
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 58

optional :counterparty_id, String, nil?: true

#currencySymbol, ...

Defaults to the currency of the originating account.

Returns:



64
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 64

optional :currency, enum: -> { ModernTreasury::Currency }

#descriptionString?

An optional description for internal use.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


70
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 70

optional :description, String, nil?: true

#directionSymbol, ...

One of credit, debit. Describes the direction money is flowing in the transaction. A credit moves money from your account to someone else's. A debit pulls money from someone else's account to your own. Note that wire, rtp, and check payments will always be credit.



79
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 79

optional :direction, enum: -> { ModernTreasury::PaymentOrderUpdateParams::Direction }

#effective_dateDate?

Date transactions are to be posted to the participants' account. Defaults to the current business day or the next business day if the current day is a bank holiday or weekend. Format: yyyy-mm-dd.

Parameters:

  • (Date)

Returns:

  • (Date, nil)


87
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 87

optional :effective_date, Date

#expires_atTime?

RFP payments require an expires_at. This value must be past the effective_date.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


93
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 93

optional :expires_at, Time, nil?: true

#external_idString?

An optional user-defined 180 character unique identifier.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


99
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 99

optional :external_id, String, nil?: true

#fallback_typeSymbol, ...

A payment type to fallback to if the original type is not valid for the receiving account. Currently, this only supports falling back from RTP to ACH (type=rtp and fallback_type=ach)



107
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 107

optional :fallback_type, enum: -> { ModernTreasury::PaymentOrderUpdateParams::FallbackType }

#foreign_exchange_contractString?

If present, indicates a specific foreign exchange contract number that has been generated by your financial institution.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


114
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 114

optional :foreign_exchange_contract, String, nil?: true

#foreign_exchange_indicatorSymbol, ...

Indicates the type of FX transfer to initiate, can be either variable_to_fixed, fixed_to_variable, or null if the payment order currency matches the originating account currency.

Parameters:

  • value (ModernTreasury::Models::PaymentOrderUpdateParams::foreign_exchange_indicator, nil)

Returns:



122
123
124
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 122

optional :foreign_exchange_indicator,
enum: -> { ModernTreasury::PaymentOrderUpdateParams::ForeignExchangeIndicator },
nil?: true

#idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 13

required :id, String

#line_itemsArray<ModernTreasury::Models::PaymentOrderUpdateParams::LineItem>?

An array of line items that must sum up to the amount of the payment order.



130
131
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 130

optional :line_items,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::PaymentOrderUpdateParams::LineItem] }

#metadataHash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


138
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 138

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#nsf_protectedBoolean?

A boolean to determine if NSF Protection is enabled for this payment order. Note that this setting must also be turned on in your organization settings page.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


145
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 145

optional :nsf_protected, ModernTreasury::Internal::Type::Boolean

#originating_account_idString?

The ID of one of your organization's internal accounts.

Parameters:

  • (String)

Returns:

  • (String, nil)


151
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 151

optional :originating_account_id, String

#originating_party_nameString?

If present, this will replace your default company name on receiver's bank statement. This field can only be used for ACH payments currently. For ACH, only the first 16 characters of this string will be used. Any additional characters will be truncated.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


160
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 160

optional :originating_party_name, String, nil?: true

#prioritySymbol, ...

Either normal or high. For ACH and EFT payments, high represents a same-day ACH or EFT transfer, respectively. For check payments, high can mean an overnight check rather than standard mail.



168
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 168

optional :priority, enum: -> { ModernTreasury::PaymentOrderUpdateParams::Priority }

#process_afterTime?

If present, Modern Treasury will not process the payment until after this time. If process_after is past the cutoff for effective_date, process_after will take precedence and effective_date will automatically update to reflect the earliest possible sending date after process_after. Format is ISO8601 timestamp.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


178
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 178

optional :process_after, Time, nil?: true

#purposeString?

For wire, this is usually the purpose which is transmitted via the "InstrForDbtrAgt" field in the ISO20022 file. For eft, this field is the 3 digit CPA Code that will be attached to the payment.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


186
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 186

optional :purpose, String, nil?: true

#receiving_accountModernTreasury::Models::PaymentOrderUpdateParams::ReceivingAccount?

Either receiving_account or receiving_account_id must be present. When using receiving_account_id, you may pass the id of an external account or an internal account.



194
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 194

optional :receiving_account, -> { ModernTreasury::PaymentOrderUpdateParams::ReceivingAccount }

#receiving_account_idString?

Either receiving_account or receiving_account_id must be present. When using receiving_account_id, you may pass the id of an external account or an internal account.

Parameters:

  • (String)

Returns:

  • (String, nil)


202
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 202

optional :receiving_account_id, String

#reconciliation_statusSymbol, ...

One of unreconciled, tentatively_reconciled or reconciled.



208
209
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 208

optional :reconciliation_status,
enum: -> { ModernTreasury::PaymentOrderUpdateParams::ReconciliationStatus }

#remittance_informationString?

For ach, this field will be passed through on an addenda record. For wire payments the field will be passed through as the "Originator to Beneficiary Information", also known as OBI or Fedwire tag 6000.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


217
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 217

optional :remittance_information, String, nil?: true

#send_remittance_adviceBoolean?

Send an email to the counterparty when the payment order is sent to the bank. If null, send_remittance_advice on the Counterparty is used.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


224
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 224

optional :send_remittance_advice, ModernTreasury::Internal::Type::Boolean, nil?: true

#statement_descriptorString?

An optional descriptor which will appear in the receiver's statement. For check payments this field will be used as the memo line. For ach the maximum length is 10 characters. Note that for ACH payments, the name on your bank account will be included automatically by the bank, so you can use the characters for other useful information. For eft the maximum length is 15 characters.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


235
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 235

optional :statement_descriptor, String, nil?: true

#statusSymbol, ...

To cancel a payment order, use cancelled. To redraft a returned payment order, use approved. To undo approval on a denied or approved payment order, use needs_approval.



243
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 243

optional :status, enum: -> { ModernTreasury::PaymentOrderUpdateParams::Status }

#subtypeSymbol, ...

An additional layer of classification for the type of payment order you are doing. This field is only used for ach payment orders currently. For ach payment orders, the subtype represents the SEC code. We currently support CCD, PPD, IAT, CTX, WEB, CIE, and TEL.

Parameters:

  • value (ModernTreasury::Models::payment_order_subtype, nil)

Returns:



252
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 252

optional :subtype, enum: -> { ModernTreasury::PaymentOrderSubtype }, nil?: true

#typeSymbol, ...

One of ach, se_bankgirot, eft, wire, check, book, rtp, sepa, bacs, au_becs, neft, nics, nz_national_clearing_code, sic, zengin.



259
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 259

optional :type, enum: -> { ModernTreasury::PaymentOrderType }

#ultimate_originating_party_identifierString?

This represents the identifier by which the person is known to the receiver when using the CIE subtype for ACH payments. Only the first 22 characters of this string will be used. Any additional characters will be truncated.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


267
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 267

optional :ultimate_originating_party_identifier, String, nil?: true

#ultimate_originating_party_nameString?

This represents the name of the person that the payment is on behalf of when using the CIE subtype for ACH payments. Only the first 15 characters of this string will be used. Any additional characters will be truncated.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


275
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 275

optional :ultimate_originating_party_name, String, nil?: true

#ultimate_receiving_party_identifierString?

This represents the name of the merchant that the payment is being sent to when using the CIE subtype for ACH payments. Only the first 22 characters of this string will be used. Any additional characters will be truncated.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


283
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 283

optional :ultimate_receiving_party_identifier, String, nil?: true

#ultimate_receiving_party_nameString?

This represents the identifier by which the merchant is known to the person initiating an ACH payment with CIE subtype. Only the first 15 characters of this string will be used. Any additional characters will be truncated.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


291
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 291

optional :ultimate_receiving_party_name, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 413

Instance Method Details

#to_hash{

Returns:

  • ({)


216
# File 'sig/modern_treasury/models/payment_order_update_params.rbs', line 216

def to_hash: -> {