Class: ModernTreasury::Models::PaymentOrderUpdateParams::ReceivingAccount
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::PaymentOrderUpdateParams::ReceivingAccount
- Defined in:
- lib/modern_treasury/models/payment_order_update_params.rb,
sig/modern_treasury/models/payment_order_update_params.rbs
Defined Under Namespace
Modules: PartyType Classes: AccountDetail, RoutingDetail
Constant Summary collapse
- ModernTreasury =
Instance Attribute Summary collapse
- #account_details ⇒ Array<ModernTreasury::Models::PaymentOrderUpdateParams::ReceivingAccount::AccountDetail>?
-
#account_type ⇒ Symbol, ...
Can be
checking,savingsorother. - #contact_details ⇒ Array<ModernTreasury::Models::ContactDetailCreateRequest>?
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
-
#ledger_account ⇒ ModernTreasury::Models::LedgerAccountCreateRequest?
Specifies a ledger account object that will be created with the external account.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#name ⇒ String?
A nickname for the external account.
-
#party_address ⇒ ModernTreasury::Models::AddressRequest?
Required if receiving wire payments.
- #party_identifier ⇒ String?
-
#party_name ⇒ String?
If this value isn't provided, it will be inherited from the counterparty's name.
-
#party_type ⇒ Symbol, ...
Either
individualorbusiness. -
#plaid_processor_token ⇒ String?
If you've enabled the Modern Treasury + Plaid integration in your Plaid account, you can pass the processor token in this field.
- #routing_details ⇒ Array<ModernTreasury::Models::PaymentOrderUpdateParams::ReceivingAccount::RoutingDetail>?
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
481 |
# File 'sig/modern_treasury/models/payment_order_update_params.rbs', line 481
def initialize: (
|
Instance Attribute Details
#account_details ⇒ Array<ModernTreasury::Models::PaymentOrderUpdateParams::ReceivingAccount::AccountDetail>?
583 584 |
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 583 optional :account_details, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::PaymentOrderUpdateParams::ReceivingAccount::AccountDetail] } |
#account_type ⇒ Symbol, ...
Can be checking, savings or other.
590 |
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 590 optional :account_type, enum: -> { ModernTreasury::ExternalAccountType } |
#contact_details ⇒ Array<ModernTreasury::Models::ContactDetailCreateRequest>?
595 596 |
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 595 optional :contact_details, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ContactDetailCreateRequest] } |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
602 |
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 602 optional :external_id, String, nil?: true |
#ledger_account ⇒ ModernTreasury::Models::LedgerAccountCreateRequest?
Specifies a ledger account object that will be created with the external account. The resulting ledger account is linked to the external account for auto-ledgering Payment objects. See https://docs.moderntreasury.com/docs/linking-to-other-modern-treasury-objects for more details.
612 |
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 612 optional :ledger_account, -> { ModernTreasury::LedgerAccountCreateRequest } |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
619 |
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 619 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#name ⇒ String?
A nickname for the external account. This is only for internal usage and won't affect any payments
626 |
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 626 optional :name, String, nil?: true |
#party_address ⇒ ModernTreasury::Models::AddressRequest?
Required if receiving wire payments.
632 |
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 632 optional :party_address, -> { ModernTreasury::AddressRequest } |
#party_identifier ⇒ String?
637 |
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 637 optional :party_identifier, String |
#party_name ⇒ String?
If this value isn't provided, it will be inherited from the counterparty's name.
643 |
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 643 optional :party_name, String |
#party_type ⇒ Symbol, ...
Either individual or business.
649 650 651 |
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 649 optional :party_type, enum: -> { ModernTreasury::PaymentOrderUpdateParams::ReceivingAccount::PartyType }, nil?: true |
#plaid_processor_token ⇒ String?
If you've enabled the Modern Treasury + Plaid integration in your Plaid account, you can pass the processor token in this field.
658 |
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 658 optional :plaid_processor_token, String |
#routing_details ⇒ Array<ModernTreasury::Models::PaymentOrderUpdateParams::ReceivingAccount::RoutingDetail>?
663 664 |
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 663 optional :routing_details, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::PaymentOrderUpdateParams::ReceivingAccount::RoutingDetail] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 737
|
Instance Method Details
#to_hash ⇒ {
497 |
# File 'sig/modern_treasury/models/payment_order_update_params.rbs', line 497
def to_hash: -> {
|