Class: ModernTreasury::Models::PaymentOrders::Reversal

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/payment_orders/reversal.rb

Overview

Defined Under Namespace

Modules: Reason, ReconciliationStatus, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, internal_account_id:, ledger_transaction_id:, live_mode:, metadata:, object:, payment_order_id:, reason:, reconciliation_status:, status:, transaction_ids:, updated_at:) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::PaymentOrders::Reversal for more details.

Parameters:

  • id (String)
  • created_at (Time)
  • internal_account_id (String, nil)

    The ID of the relevant Internal Account.

  • ledger_transaction_id (String, nil)

    The ID of the ledger transaction linked to the reversal.

  • live_mode (Boolean)

    This field will be true if this object exists in the live environment or false i

  • metadata (Hash{Symbol=>String})

    Additional data represented as key-value pairs. Both the key and value must be s

  • object (String)
  • payment_order_id (String, nil)

    The ID of the relevant Payment Order.

  • reason (Symbol, ModernTreasury::Models::PaymentOrders::Reversal::Reason)

    The reason for the reversal.

  • reconciliation_status (Symbol, ModernTreasury::Models::PaymentOrders::Reversal::ReconciliationStatus)

    One of ‘unreconciled`, `tentatively_reconciled` or `reconciled`.

  • status (Symbol, ModernTreasury::Models::PaymentOrders::Reversal::Status)

    The current status of the reversal.

  • transaction_ids (Array<String, nil>)
  • updated_at (Time)


# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 84

Instance Attribute Details

#created_atTime

Returns:

  • (Time)


16
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 16

required :created_at, Time

#idString

Returns:

  • (String)


11
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 11

required :id, String

#internal_account_idString?

The ID of the relevant Internal Account.

Returns:

  • (String, nil)


22
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 22

required :internal_account_id, String, nil?: true

#ledger_transaction_idString?

The ID of the ledger transaction linked to the reversal.

Returns:

  • (String, nil)


28
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 28

required :ledger_transaction_id, String, nil?: true

#live_modeBoolean

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Returns:

  • (Boolean)


35
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 35

required :live_mode, ModernTreasury::Internal::Type::Boolean

#metadataHash{Symbol=>String}

Additional data represented as key-value pairs. Both the key and value must be strings.

Returns:

  • (Hash{Symbol=>String})


42
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 42

required :metadata, ModernTreasury::Internal::Type::HashOf[String]

#objectString

Returns:

  • (String)


47
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 47

required :object, String

#payment_order_idString?

The ID of the relevant Payment Order.

Returns:

  • (String, nil)


53
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 53

required :payment_order_id, String, nil?: true

#reasonSymbol, ModernTreasury::Models::PaymentOrders::Reversal::Reason

The reason for the reversal.



59
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 59

required :reason, enum: -> { ModernTreasury::PaymentOrders::Reversal::Reason }

#reconciliation_statusSymbol, ModernTreasury::Models::PaymentOrders::Reversal::ReconciliationStatus

One of ‘unreconciled`, `tentatively_reconciled` or `reconciled`.



65
66
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 65

required :reconciliation_status,
enum: -> { ModernTreasury::PaymentOrders::Reversal::ReconciliationStatus }

#statusSymbol, ModernTreasury::Models::PaymentOrders::Reversal::Status

The current status of the reversal.



72
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 72

required :status, enum: -> { ModernTreasury::PaymentOrders::Reversal::Status }

#transaction_idsArray<String, nil>

Returns:

  • (Array<String, nil>)


77
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 77

required :transaction_ids, ModernTreasury::Internal::Type::ArrayOf[String, nil?: true]

#updated_atTime

Returns:

  • (Time)


82
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 82

required :updated_at, Time

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 126