Class: ModernTreasury::Models::ReturnCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::ReturnCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/return_create_params.rb,
sig/modern_treasury/models/return_create_params.rbs
Overview
Defined Under Namespace
Modules: Code, ReconciliationStatus, ReturnableType Classes: Corrections
Constant Summary collapse
- ModernTreasury =
Instance Attribute Summary collapse
-
#additional_information ⇒ String?
Some returns may include additional information from the bank.
-
#code ⇒ Symbol, ...
The return code.
-
#corrections ⇒ ModernTreasury::Models::ReturnCreateParams::Corrections?
Only relevant for ACH NOC returns.
-
#data ⇒ Object?
The raw data from the return file that we get from the bank.
-
#date_of_death ⇒ Date?
If the return code is
R14orR15this is the date the deceased counterparty passed away. -
#ledger_transaction ⇒ ModernTreasury::Models::LedgerTransactionCreateRequest?
Specifies a ledger transaction object that will be created with the return.
-
#reason ⇒ String?
An optional description of the reason for the return.
-
#reconciliation_status ⇒ Symbol, ...
One of
unreconciled,tentatively_reconciledorreconciled. -
#returnable_id ⇒ String?
The ID of the object being returned or
null. -
#returnable_type ⇒ Symbol, ModernTreasury::Models::ReturnCreateParams::ReturnableType
The type of object being returned.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account_number: nil, company_id: nil, company_name: nil, individual_identification_number: nil, routing_number: nil, transaction_code: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Corrections for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_number: nil, company_id: nil, company_name: nil, individual_identification_number: nil, routing_number: nil, transaction_code: nil) ⇒ Object
Some parameter documentations has been truncated, see Corrections for more details.
Only relevant for ACH NOC returns. This is an object containing all of the new and corrected information provided by the bank that was previously incorrect on the original outgoing payment.
|
|
# File 'lib/modern_treasury/models/return_create_params.rb', line 78
|
Instance Attribute Details
#additional_information ⇒ String?
Some returns may include additional information from the bank. In these cases, this string will be present.
28 |
# File 'lib/modern_treasury/models/return_create_params.rb', line 28 optional :additional_information, String, nil?: true |
#code ⇒ Symbol, ...
The return code. For ACH returns, this is the required ACH return code.
34 |
# File 'lib/modern_treasury/models/return_create_params.rb', line 34 optional :code, enum: -> { ModernTreasury::ReturnCreateParams::Code }, nil?: true |
#corrections ⇒ ModernTreasury::Models::ReturnCreateParams::Corrections?
Only relevant for ACH NOC returns. This is an object containing all of the new and corrected information provided by the bank that was previously incorrect on the original outgoing payment.
42 |
# File 'lib/modern_treasury/models/return_create_params.rb', line 42 optional :corrections, -> { ModernTreasury::ReturnCreateParams::Corrections }, nil?: true |
#data ⇒ Object?
The raw data from the return file that we get from the bank.
48 |
# File 'lib/modern_treasury/models/return_create_params.rb', line 48 optional :data, ModernTreasury::Internal::Type::Unknown, nil?: true |
#date_of_death ⇒ Date?
If the return code is R14 or R15 this is the date the deceased counterparty
passed away.
55 |
# File 'lib/modern_treasury/models/return_create_params.rb', line 55 optional :date_of_death, Date, nil?: true |
#ledger_transaction ⇒ ModernTreasury::Models::LedgerTransactionCreateRequest?
Specifies a ledger transaction object that will be created with the return. If the ledger transaction cannot be created, then the return creation will fail. The resulting ledger transaction will mirror the status of the return.
63 |
# File 'lib/modern_treasury/models/return_create_params.rb', line 63 optional :ledger_transaction, -> { ModernTreasury::LedgerTransactionCreateRequest } |
#reason ⇒ String?
An optional description of the reason for the return. This is for internal usage and will not be transmitted to the bank.”
70 |
# File 'lib/modern_treasury/models/return_create_params.rb', line 70 optional :reason, String, nil?: true |
#reconciliation_status ⇒ Symbol, ...
One of unreconciled, tentatively_reconciled or reconciled.
76 |
# File 'lib/modern_treasury/models/return_create_params.rb', line 76 optional :reconciliation_status, enum: -> { ModernTreasury::ReturnCreateParams::ReconciliationStatus } |
#returnable_id ⇒ String?
The ID of the object being returned or null.
14 |
# File 'lib/modern_treasury/models/return_create_params.rb', line 14 required :returnable_id, String, nil?: true |
#returnable_type ⇒ Symbol, ModernTreasury::Models::ReturnCreateParams::ReturnableType
The type of object being returned. Currently, this may only be incoming_payment_detail.
21 |
# File 'lib/modern_treasury/models/return_create_params.rb', line 21 required :returnable_type, enum: -> { ModernTreasury::ReturnCreateParams::ReturnableType } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/return_create_params.rb', line 111
|
Instance Method Details
#to_hash ⇒ {
64 |
# File 'sig/modern_treasury/models/return_create_params.rbs', line 64
def to_hash: -> {
|