Class: ModernTreasury::Models::ReturnListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::ReturnListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/return_list_params.rb,
sig/modern_treasury/models/return_list_params.rbs
Overview
Defined Under Namespace
Modules: ReturnableType
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ModernTreasury
Instance Attribute Summary collapse
- #after_cursor ⇒ String?
-
#counterparty_id ⇒ String?
Specify
counterparty_idif you wish to see returns that occurred with a specific counterparty. -
#internal_account_id ⇒ String?
Specify
internal_account_idif you wish to see returns to/from a specific account. - #per_page ⇒ Integer?
-
#returnable_id ⇒ String?
The ID of a valid returnable.
-
#returnable_type ⇒ Symbol, ...
One of
payment_order,reversal, orincoming_payment_detail.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(after_cursor: nil, counterparty_id: nil, internal_account_id: nil, per_page: nil, returnable_id: nil, returnable_type: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ReturnListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after_cursor: nil, counterparty_id: nil, internal_account_id: nil, per_page: nil, returnable_id: nil, returnable_type: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::ReturnListParams for more details.
|
|
# File 'lib/modern_treasury/models/return_list_params.rb', line 47
|
Instance Attribute Details
#after_cursor ⇒ String?
13 |
# File 'lib/modern_treasury/models/return_list_params.rb', line 13 optional :after_cursor, String, nil?: true |
#counterparty_id ⇒ String?
Specify counterparty_id if you wish to see returns that occurred with a
specific counterparty.
20 |
# File 'lib/modern_treasury/models/return_list_params.rb', line 20 optional :counterparty_id, String |
#internal_account_id ⇒ String?
Specify internal_account_id if you wish to see returns to/from a specific
account.
27 |
# File 'lib/modern_treasury/models/return_list_params.rb', line 27 optional :internal_account_id, String |
#per_page ⇒ Integer?
32 |
# File 'lib/modern_treasury/models/return_list_params.rb', line 32 optional :per_page, Integer |
#returnable_id ⇒ String?
The ID of a valid returnable. Must be accompanied by returnable_type.
38 |
# File 'lib/modern_treasury/models/return_list_params.rb', line 38 optional :returnable_id, String |
#returnable_type ⇒ Symbol, ...
One of payment_order, reversal, or incoming_payment_detail. Must be
accompanied by returnable_id.
45 |
# File 'lib/modern_treasury/models/return_list_params.rb', line 45 optional :returnable_type, enum: -> { ModernTreasury::ReturnListParams::ReturnableType } |
Instance Method Details
#to_hash ⇒ {
52 |
# File 'sig/modern_treasury/models/return_list_params.rbs', line 52
def to_hash: -> {
|