Module: ModernTreasury::Models::RoutingDetail::PaymentType
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/modern_treasury/models/routing_detail.rb,
sig/modern_treasury/models/routing_detail.rbs
Overview
If the routing detail is to be used for a specific payment type this field will be populated, otherwise null.
Constant Summary collapse
- ACH =
:ach- AU_BECS =
:au_becs- BACS =
:bacs- BOOK =
:book- CARD =
:card- CHATS =
:chats- CHECK =
:check- CROSS_BORDER =
:cross_border- DK_NETS =
:dk_nets- EFT =
:eft- GB_FPS =
:gb_fps- MASAV =
:masav- MX_CCEN =
:mx_ccen- NEFT =
:neft- NICS =
:nics- NZ_BECS =
:nz_becs- PL_ELIXIR =
:pl_elixir- RTP =
:rtp- SE_BANKGIROT =
:se_bankgirot- SEPA =
:sepa- SG_GIRO =
:sg_giro- SIC =
:sic- STABLECOIN =
:stablecoin- WIRE =
:wire- ZENGIN =
:zengin
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[ModernTreasury::Models::RoutingDetail::payment_type]
125 |
# File 'sig/modern_treasury/models/routing_detail.rbs', line 125
def self?.values: -> ::Array[ModernTreasury::Models::RoutingDetail::payment_type]
|