Class: ModernTreasury::Models::ThirdPartyVerification
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::ThirdPartyVerification
- Defined in:
- lib/modern_treasury/models/third_party_verification.rb
Defined Under Namespace
Modules: Outcome, Vendor, VerificationCategory
Instance Attribute Summary collapse
-
#comment ⇒ String?
An optional comment about the verification.
-
#outcome ⇒ Symbol, ModernTreasury::Models::ThirdPartyVerification::Outcome
The outcome of the verification.
-
#vendor ⇒ Symbol, ModernTreasury::Models::ThirdPartyVerification::Vendor
The vendor that performed the verification, e.g.
-
#vendor_verification_id ⇒ String
The identification of the third party verification in ‘vendor`’s system.
-
#verification_category ⇒ Symbol, ModernTreasury::Models::ThirdPartyVerification::VerificationCategory
The category of verification performed.
-
#verification_method ⇒ String
The method used to perform the verification.
-
#verification_time ⇒ Time
The timestamp when the verification was performed.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(outcome:, vendor:, vendor_verification_id:, verification_category:, verification_method:, verification_time:, comment: nil) ⇒ Object
|
|
# File 'lib/modern_treasury/models/third_party_verification.rb', line 48
|
Instance Attribute Details
#comment ⇒ String?
An optional comment about the verification.
46 |
# File 'lib/modern_treasury/models/third_party_verification.rb', line 46 optional :comment, String, nil?: true |
#outcome ⇒ Symbol, ModernTreasury::Models::ThirdPartyVerification::Outcome
The outcome of the verification. One of ‘passed` or `failed`.
10 |
# File 'lib/modern_treasury/models/third_party_verification.rb', line 10 required :outcome, enum: -> { ModernTreasury::ThirdPartyVerification::Outcome } |
#vendor ⇒ Symbol, ModernTreasury::Models::ThirdPartyVerification::Vendor
The vendor that performed the verification, e.g. ‘persona`.
16 |
# File 'lib/modern_treasury/models/third_party_verification.rb', line 16 required :vendor, enum: -> { ModernTreasury::ThirdPartyVerification::Vendor } |
#vendor_verification_id ⇒ String
The identification of the third party verification in ‘vendor`’s system.
22 |
# File 'lib/modern_treasury/models/third_party_verification.rb', line 22 required :vendor_verification_id, String |
#verification_category ⇒ Symbol, ModernTreasury::Models::ThirdPartyVerification::VerificationCategory
The category of verification performed.
28 |
# File 'lib/modern_treasury/models/third_party_verification.rb', line 28 required :verification_category, enum: -> { ModernTreasury::ThirdPartyVerification::VerificationCategory } |
#verification_method ⇒ String
The method used to perform the verification.
34 |
# File 'lib/modern_treasury/models/third_party_verification.rb', line 34 required :verification_method, String |
#verification_time ⇒ Time
The timestamp when the verification was performed.
40 |
# File 'lib/modern_treasury/models/third_party_verification.rb', line 40 required :verification_time, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/third_party_verification.rb', line 72
|