Class: ModernTreasury::Models::TransactionListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::TransactionListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/transaction_list_params.rb,
sig/modern_treasury/models/transaction_list_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ModernTreasury
Instance Attribute Summary collapse
- #after_cursor ⇒ String?
-
#as_of_date_end ⇒ Date?
Filters transactions with an
as_of_datestarting on or before the specified date (YYYY-MM-DD). -
#as_of_date_start ⇒ Date?
Filters transactions with an
as_of_datestarting on or after the specified date (YYYY-MM-DD). - #counterparty_id ⇒ String?
-
#description ⇒ String?
Filters for transactions including the queried string in the description.
- #direction ⇒ String?
-
#internal_account_id ⇒ String?
Specify
internal_account_idif you wish to see transactions to/from a specific account. -
#metadata ⇒ Hash{Symbol=>String}?
For example, if you want to query for records with metadata key
Typeand valueLoan, the query would bemetadata%5BType%5D=Loan. - #payment_type ⇒ String?
- #per_page ⇒ Integer?
-
#posted ⇒ Boolean?
Either
trueorfalse. - #transactable_type ⇒ String?
-
#vendor_id ⇒ String?
Filters for transactions including the queried vendor id (an identifier given to transactions by the bank).
- #virtual_account_id ⇒ String?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(after_cursor: nil, as_of_date_end: nil, as_of_date_start: nil, counterparty_id: nil, description: nil, direction: nil, internal_account_id: nil, metadata: nil, payment_type: nil, per_page: nil, posted: nil, transactable_type: nil, vendor_id: nil, virtual_account_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see TransactionListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after_cursor: nil, as_of_date_end: nil, as_of_date_start: nil, counterparty_id: nil, description: nil, direction: nil, internal_account_id: nil, metadata: nil, payment_type: nil, per_page: nil, posted: nil, transactable_type: nil, vendor_id: nil, virtual_account_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::TransactionListParams for more details.
|
|
# File 'lib/modern_treasury/models/transaction_list_params.rb', line 93
|
Instance Attribute Details
#after_cursor ⇒ String?
13 |
# File 'lib/modern_treasury/models/transaction_list_params.rb', line 13 optional :after_cursor, String, nil?: true |
#as_of_date_end ⇒ Date?
Filters transactions with an as_of_date starting on or before the specified
date (YYYY-MM-DD).
20 |
# File 'lib/modern_treasury/models/transaction_list_params.rb', line 20 optional :as_of_date_end, Date |
#as_of_date_start ⇒ Date?
Filters transactions with an as_of_date starting on or after the specified
date (YYYY-MM-DD).
27 |
# File 'lib/modern_treasury/models/transaction_list_params.rb', line 27 optional :as_of_date_start, Date |
#counterparty_id ⇒ String?
32 |
# File 'lib/modern_treasury/models/transaction_list_params.rb', line 32 optional :counterparty_id, String |
#description ⇒ String?
Filters for transactions including the queried string in the description.
38 |
# File 'lib/modern_treasury/models/transaction_list_params.rb', line 38 optional :description, String |
#direction ⇒ String?
43 |
# File 'lib/modern_treasury/models/transaction_list_params.rb', line 43 optional :direction, String |
#internal_account_id ⇒ String?
Specify internal_account_id if you wish to see transactions to/from a specific
account.
50 |
# File 'lib/modern_treasury/models/transaction_list_params.rb', line 50 optional :internal_account_id, String |
#metadata ⇒ Hash{Symbol=>String}?
For example, if you want to query for records with metadata key Type and value
Loan, the query would be metadata%5BType%5D=Loan. This encodes the query
parameters.
58 |
# File 'lib/modern_treasury/models/transaction_list_params.rb', line 58 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#payment_type ⇒ String?
63 |
# File 'lib/modern_treasury/models/transaction_list_params.rb', line 63 optional :payment_type, String |
#per_page ⇒ Integer?
68 |
# File 'lib/modern_treasury/models/transaction_list_params.rb', line 68 optional :per_page, Integer |
#posted ⇒ Boolean?
Either true or false.
74 |
# File 'lib/modern_treasury/models/transaction_list_params.rb', line 74 optional :posted, ModernTreasury::Internal::Type::Boolean |
#transactable_type ⇒ String?
79 |
# File 'lib/modern_treasury/models/transaction_list_params.rb', line 79 optional :transactable_type, String |
#vendor_id ⇒ String?
Filters for transactions including the queried vendor id (an identifier given to transactions by the bank).
86 |
# File 'lib/modern_treasury/models/transaction_list_params.rb', line 86 optional :vendor_id, String |
#virtual_account_id ⇒ String?
91 |
# File 'lib/modern_treasury/models/transaction_list_params.rb', line 91 optional :virtual_account_id, String |
Instance Method Details
#to_hash ⇒ {
98 |
# File 'sig/modern_treasury/models/transaction_list_params.rbs', line 98
def to_hash: -> {
|