Class: ModernTreasury::Models::VirtualAccountCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/modern_treasury/models/virtual_account_create_params.rb,
sig/modern_treasury/models/virtual_account_create_params.rbs

Overview

See Also:

  • ModernTreasury::Resources::VirtualAccounts#create

Defined Under Namespace

Classes: AccountDetail, RoutingDetail

Constant Summary collapse

ModernTreasury =

Returns:

  • (:LedgerAccountCreateRequest)

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize ⇒ Object



77
# File 'sig/modern_treasury/models/virtual_account_create_params.rbs', line 77

def initialize: (

Instance Attribute Details

#account_details ⇒ Array<ModernTreasury::Models::VirtualAccountCreateParams::AccountDetail>?

An array of account detail objects.



26
27
# File 'lib/modern_treasury/models/virtual_account_create_params.rb', line 26

optional :account_details,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::VirtualAccountCreateParams::AccountDetail] }

#counterparty_id ⇒ String?

The ID of the counterparty that the virtual account belongs to.

Parameters:

  • (String)

Returns:

  • (String, nil)


33
# File 'lib/modern_treasury/models/virtual_account_create_params.rb', line 33

optional :counterparty_id, String

#credit_ledger_account_id ⇒ String?

The ID of a credit normal ledger account. When money leaves the virtual account, this ledger account will be credited. Must be accompanied by a debit_ledger_account_id if present.

Parameters:

  • (String)

Returns:

  • (String, nil)


41
# File 'lib/modern_treasury/models/virtual_account_create_params.rb', line 41

optional :credit_ledger_account_id, String

#debit_ledger_account_id ⇒ String?

The ID of a debit normal ledger account. When money enters the virtual account, this ledger account will be debited. Must be accompanied by a credit_ledger_account_id if present.

Parameters:

  • (String)

Returns:

  • (String, nil)


49
# File 'lib/modern_treasury/models/virtual_account_create_params.rb', line 49

optional :debit_ledger_account_id, String

#description ⇒ String?

An optional description for internal use.

Parameters:

  • (String)

Returns:

  • (String, nil)


55
# File 'lib/modern_treasury/models/virtual_account_create_params.rb', line 55

optional :description, String

#external_id ⇒ String?

A user-defined identifier for the virtual account.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


61
# File 'lib/modern_treasury/models/virtual_account_create_params.rb', line 61

optional :external_id, String, nil?: true

#internal_account_id ⇒ String

The ID of the internal account that this virtual account is associated with.

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/modern_treasury/models/virtual_account_create_params.rb', line 14

required :internal_account_id, String

#ledger_account ⇒ ModernTreasury::Models::LedgerAccountCreateRequest?

Specifies a ledger account object that will be created with the virtual account. The resulting ledger account is linked to the virtual account for auto-ledgering IPDs.



69
# File 'lib/modern_treasury/models/virtual_account_create_params.rb', line 69

optional :ledger_account, -> { ModernTreasury::LedgerAccountCreateRequest }

#ledger_account_id ⇒ String?

The ledger account that you'd like to link to the virtual account.

Parameters:

  • (String)

Returns:

  • (String, nil)


75
# File 'lib/modern_treasury/models/virtual_account_create_params.rb', line 75

optional :ledger_account_id, String

#metadata ⇒ Hash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


82
# File 'lib/modern_treasury/models/virtual_account_create_params.rb', line 82

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#name ⇒ String

The name of the virtual account.

Parameters:

  • value (String)

Returns:

  • (String)


20
# File 'lib/modern_treasury/models/virtual_account_create_params.rb', line 20

required :name, String

#routing_details ⇒ Array<ModernTreasury::Models::VirtualAccountCreateParams::RoutingDetail>?

An array of routing detail objects.



88
89
# File 'lib/modern_treasury/models/virtual_account_create_params.rb', line 88

optional :routing_details,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::VirtualAccountCreateParams::RoutingDetail] }

#virtual_account_setting_id ⇒ String?

The ID of the virtual account setting used to allocate this virtual account.

Parameters:

  • (String)

Returns:

  • (String, nil)


95
# File 'lib/modern_treasury/models/virtual_account_create_params.rb', line 95

optional :virtual_account_setting_id, String

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/virtual_account_create_params.rb', line 178

Instance Method Details

#to_hash ⇒ {

Returns:

  • ({)


94
# File 'sig/modern_treasury/models/virtual_account_create_params.rbs', line 94

def to_hash: -> {