Class: ModernTreasury::Models::VirtualAccountCreateParams::RoutingDetail
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::VirtualAccountCreateParams::RoutingDetail
- Defined in:
- lib/modern_treasury/models/virtual_account_create_params.rb
Defined Under Namespace
Modules: PaymentType, RoutingNumberType
Instance Attribute Summary collapse
-
#payment_type ⇒ Symbol, ...
If the routing detail is to be used for a specific payment type this field will be populated, otherwise null.
-
#routing_number ⇒ String
The routing number of the bank.
-
#routing_number_type ⇒ Symbol, ModernTreasury::Models::VirtualAccountCreateParams::RoutingDetail::RoutingNumberType
The type of routing number.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(routing_number:, routing_number_type:, payment_type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see RoutingDetail for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(routing_number:, routing_number_type:, payment_type: nil) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::VirtualAccountCreateParams::RoutingDetail for more details.
|
|
# File 'lib/modern_treasury/models/virtual_account_create_params.rb', line 182
|
Instance Attribute Details
#payment_type ⇒ Symbol, ...
If the routing detail is to be used for a specific payment type this field will be populated, otherwise null.
178 179 180 |
# File 'lib/modern_treasury/models/virtual_account_create_params.rb', line 178 optional :payment_type, enum: -> { ModernTreasury::VirtualAccountCreateParams::RoutingDetail::PaymentType }, nil?: true |
#routing_number ⇒ String
The routing number of the bank.
162 |
# File 'lib/modern_treasury/models/virtual_account_create_params.rb', line 162 required :routing_number, String |
#routing_number_type ⇒ Symbol, ModernTreasury::Models::VirtualAccountCreateParams::RoutingDetail::RoutingNumberType
The type of routing number. See docs.moderntreasury.com/platform/reference/routing-detail-object for more details.
170 171 |
# File 'lib/modern_treasury/models/virtual_account_create_params.rb', line 170 required :routing_number_type, enum: -> { ModernTreasury::VirtualAccountCreateParams::RoutingDetail::RoutingNumberType } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/virtual_account_create_params.rb', line 224
|