Class: ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentCreateRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentCreateRequest
- Defined in:
- lib/modern_treasury/models/bulk_request_create_params.rb,
sig/modern_treasury/models/bulk_request_create_params.rbs
Defined Under Namespace
Modules: AmountReconciledDirection, AmountUnreconciledDirection, Direction Classes: LineItem
Constant Summary collapse
- ModernTreasury =
Instance Attribute Summary collapse
-
#amount_lower_bound ⇒ Integer?
The lowest amount this expected payment may be equal to.
-
#amount_reconciled ⇒ Integer?
The amount reconciled for this expected payment.
-
#amount_reconciled_direction ⇒ Symbol, ...
One of credit or debit.
-
#amount_unreconciled ⇒ Integer?
The amount that remains unreconciled for this expected payment.
-
#amount_unreconciled_direction ⇒ Symbol, ...
One of credit or debit.
-
#amount_upper_bound ⇒ Integer?
The highest amount this expected payment may be equal to.
-
#counterparty_id ⇒ String?
The ID of the counterparty you expect for this payment.
-
#currency ⇒ Symbol, ...
Must conform to ISO 4217.
-
#date_lower_bound ⇒ Date?
The earliest date the payment may come in.
-
#date_upper_bound ⇒ Date?
The latest date the payment may come in.
-
#description ⇒ String?
An optional description for internal use.
-
#direction ⇒ Symbol, ...
One of credit or debit.
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
-
#internal_account_id ⇒ String?
The ID of the Internal Account for the expected payment.
-
#ledger_transaction ⇒ ModernTreasury::Models::LedgerTransactionCreateRequest?
Specifies a ledger transaction object that will be created with the expected payment.
-
#ledger_transaction_id ⇒ String?
Either ledger_transaction or ledger_transaction_id can be provided.
- #line_items ⇒ Array<ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentCreateRequest::LineItem>?
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#reconciliation_filters ⇒ Object?
The reconciliation filters you have for this payment.
-
#reconciliation_groups ⇒ Object?
The reconciliation groups you have for this payment.
-
#reconciliation_rule_variables ⇒ Array<ModernTreasury::Models::ReconciliationRule>?
An array of reconciliation rule variables for this payment.
-
#remittance_information ⇒ String?
For
ach, this field will be passed through on an addenda record. -
#statement_descriptor ⇒ String?
The statement description you expect to see on the transaction.
-
#type ⇒ Symbol, ...
One of: ach, au_becs, bacs, book, check, eft, rtp, sepa, wire.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount_lower_bound: nil, amount_reconciled: nil, amount_reconciled_direction: nil, amount_unreconciled: nil, amount_unreconciled_direction: nil, amount_upper_bound: nil, counterparty_id: nil, currency: nil, date_lower_bound: nil, date_upper_bound: nil, description: nil, direction: nil, external_id: nil, internal_account_id: nil, ledger_transaction: nil, ledger_transaction_id: nil, line_items: nil, metadata: nil, reconciliation_filters: nil, reconciliation_groups: nil, reconciliation_rule_variables: nil, remittance_information: nil, statement_descriptor: nil, type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExpectedPaymentCreateRequest for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount_lower_bound: nil, amount_reconciled: nil, amount_reconciled_direction: nil, amount_unreconciled: nil, amount_unreconciled_direction: nil, amount_upper_bound: nil, counterparty_id: nil, currency: nil, date_lower_bound: nil, date_upper_bound: nil, description: nil, direction: nil, external_id: nil, internal_account_id: nil, ledger_transaction: nil, ledger_transaction_id: nil, line_items: nil, metadata: nil, reconciliation_filters: nil, reconciliation_groups: nil, reconciliation_rule_variables: nil, remittance_information: nil, statement_descriptor: nil, type: nil) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentCreateRequest for more details.
|
|
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1259
|
Instance Attribute Details
#amount_lower_bound ⇒ Integer?
The lowest amount this expected payment may be equal to. Value in specified currency's smallest unit. e.g. $10 would be represented as 1000.
1087 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1087 optional :amount_lower_bound, Integer, nil?: true |
#amount_reconciled ⇒ Integer?
The amount reconciled for this expected payment. Value in specified currency's smallest unit. e.g. $10 would be represented as 1000.
1094 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1094 optional :amount_reconciled, Integer, nil?: true |
#amount_reconciled_direction ⇒ Symbol, ...
One of credit or debit. Indicates whether amount_reconciled is a credit or debit amount.
1101 1102 1103 1104 1105 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1101 optional :amount_reconciled_direction, enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::ExpectedPaymentCreateRequest::AmountReconciledDirection }, nil?: true |
#amount_unreconciled ⇒ Integer?
The amount that remains unreconciled for this expected payment. Value in specified currency's smallest unit. e.g. $10 would be represented as 1000.
1112 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1112 optional :amount_unreconciled, Integer, nil?: true |
#amount_unreconciled_direction ⇒ Symbol, ...
One of credit or debit. Indicates whether amount_unreconciled is a credit or debit amount.
1119 1120 1121 1122 1123 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1119 optional :amount_unreconciled_direction, enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::ExpectedPaymentCreateRequest::AmountUnreconciledDirection }, nil?: true |
#amount_upper_bound ⇒ Integer?
The highest amount this expected payment may be equal to. Value in specified currency's smallest unit. e.g. $10 would be represented as 1000.
1130 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1130 optional :amount_upper_bound, Integer, nil?: true |
#counterparty_id ⇒ String?
The ID of the counterparty you expect for this payment.
1136 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1136 optional :counterparty_id, String, nil?: true |
#currency ⇒ Symbol, ...
Must conform to ISO 4217. Defaults to the currency of the internal account.
1142 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1142 optional :currency, enum: -> { ModernTreasury::Currency }, nil?: true |
#date_lower_bound ⇒ Date?
The earliest date the payment may come in. Format: yyyy-mm-dd
1148 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1148 optional :date_lower_bound, Date, nil?: true |
#date_upper_bound ⇒ Date?
The latest date the payment may come in. Format: yyyy-mm-dd
1154 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1154 optional :date_upper_bound, Date, nil?: true |
#description ⇒ String?
An optional description for internal use.
1160 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1160 optional :description, String, nil?: true |
#direction ⇒ Symbol, ...
One of credit or debit. When you are receiving money, use credit. When you are being charged, use debit.
1167 1168 1169 1170 1171 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1167 optional :direction, enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::ExpectedPaymentCreateRequest::Direction }, nil?: true |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
1177 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1177 optional :external_id, String, nil?: true |
#internal_account_id ⇒ String?
The ID of the Internal Account for the expected payment.
1183 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1183 optional :internal_account_id, String, nil?: true |
#ledger_transaction ⇒ ModernTreasury::Models::LedgerTransactionCreateRequest?
Specifies a ledger transaction object that will be created with the expected payment. If the ledger transaction cannot be created, then the expected payment creation will fail. The resulting ledger transaction will mirror the status of the expected payment.
1192 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1192 optional :ledger_transaction, -> { ModernTreasury::LedgerTransactionCreateRequest } |
#ledger_transaction_id ⇒ String?
Either ledger_transaction or ledger_transaction_id can be provided. Only a pending ledger transaction can be attached upon expected payment creation. Once the expected payment is created, the status of the ledger transaction tracks the expected payment automatically.
1201 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1201 optional :ledger_transaction_id, String |
#line_items ⇒ Array<ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentCreateRequest::LineItem>?
1206 1207 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1206 optional :line_items, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::BulkRequestCreateParams::Resource::ExpectedPaymentCreateRequest::LineItem] } |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
1214 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1214 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#reconciliation_filters ⇒ Object?
The reconciliation filters you have for this payment.
1220 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1220 optional :reconciliation_filters, ModernTreasury::Internal::Type::Unknown, nil?: true |
#reconciliation_groups ⇒ Object?
The reconciliation groups you have for this payment.
1226 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1226 optional :reconciliation_groups, ModernTreasury::Internal::Type::Unknown, nil?: true |
#reconciliation_rule_variables ⇒ Array<ModernTreasury::Models::ReconciliationRule>?
An array of reconciliation rule variables for this payment.
1232 1233 1234 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1232 optional :reconciliation_rule_variables, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ReconciliationRule] }, nil?: true |
#remittance_information ⇒ String?
For ach, this field will be passed through on an addenda record. For wire
payments the field will be passed through as the "Originator to Beneficiary
Information", also known as OBI or Fedwire tag 6000.
1242 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1242 optional :remittance_information, String, nil?: true |
#statement_descriptor ⇒ String?
The statement description you expect to see on the transaction. For ACH payments, this will be the full line item passed from the bank. For wire payments, this will be the OBI field on the wire. For check payments, this will be the memo field.
1251 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1251 optional :statement_descriptor, String, nil?: true |
#type ⇒ Symbol, ...
One of: ach, au_becs, bacs, book, check, eft, rtp, sepa, wire.
1257 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1257 optional :type, enum: -> { ModernTreasury::ExpectedPaymentType }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1322
|
Instance Method Details
#to_hash ⇒ {
1007 |
# File 'sig/modern_treasury/models/bulk_request_create_params.rbs', line 1007
def to_hash: -> {
|