Class: ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentCreateRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/bulk_request_create_params.rb

Defined Under Namespace

Modules: AmountReconciledDirection, AmountUnreconciledDirection, Direction Classes: LineItem

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount_lower_bound: nil, amount_reconciled: nil, amount_reconciled_direction: nil, amount_unreconciled: nil, amount_unreconciled_direction: nil, amount_upper_bound: nil, counterparty_id: nil, currency: nil, date_lower_bound: nil, date_upper_bound: nil, description: nil, direction: nil, external_id: nil, internal_account_id: nil, ledger_transaction: nil, ledger_transaction_id: nil, line_items: nil, metadata: nil, reconciliation_filters: nil, reconciliation_groups: nil, reconciliation_rule_variables: nil, remittance_information: nil, statement_descriptor: nil, type: nil) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentCreateRequest for more details.

Parameters:

  • amount_lower_bound (Integer, nil) (defaults to: nil)

    The lowest amount this expected payment may be equal to. Value in specified curr

  • amount_reconciled (Integer, nil) (defaults to: nil)

    The amount reconciled for this expected payment. Value in specified currency’s s

  • amount_reconciled_direction (Symbol, ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentCreateRequest::AmountReconciledDirection, nil) (defaults to: nil)

    One of credit or debit. Indicates whether amount_reconciled is a credit or debit

  • amount_unreconciled (Integer, nil) (defaults to: nil)

    The amount that remains unreconciled for this expected payment. Value in specifi

  • amount_unreconciled_direction (Symbol, ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentCreateRequest::AmountUnreconciledDirection, nil) (defaults to: nil)

    One of credit or debit. Indicates whether amount_unreconciled is a credit or deb

  • amount_upper_bound (Integer, nil) (defaults to: nil)

    The highest amount this expected payment may be equal to. Value in specified cur

  • counterparty_id (String, nil) (defaults to: nil)

    The ID of the counterparty you expect for this payment.

  • currency (Symbol, ModernTreasury::Models::Currency, nil) (defaults to: nil)

    Must conform to ISO 4217. Defaults to the currency of the internal account.

  • date_lower_bound (Date, nil) (defaults to: nil)

    The earliest date the payment may come in. Format: yyyy-mm-dd

  • date_upper_bound (Date, nil) (defaults to: nil)

    The latest date the payment may come in. Format: yyyy-mm-dd

  • description (String, nil) (defaults to: nil)

    An optional description for internal use.

  • direction (Symbol, ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentCreateRequest::Direction, nil) (defaults to: nil)

    One of credit or debit. When you are receiving money, use credit. When you are b

  • external_id (String, nil) (defaults to: nil)

    An optional user-defined 180 character unique identifier.

  • internal_account_id (String, nil) (defaults to: nil)

    The ID of the Internal Account for the expected payment.

  • ledger_transaction (ModernTreasury::Models::LedgerTransactionCreateRequest) (defaults to: nil)

    Specifies a ledger transaction object that will be created with the expected pay

  • ledger_transaction_id (String) (defaults to: nil)

    Either ledger_transaction or ledger_transaction_id can be provided. Only a pendi

  • line_items (Array<ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentCreateRequest::LineItem>) (defaults to: nil)
  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    Additional data represented as key-value pairs. Both the key and value must be s

  • reconciliation_filters (Object, nil) (defaults to: nil)

    The reconciliation filters you have for this payment.

  • reconciliation_groups (Object, nil) (defaults to: nil)

    The reconciliation groups you have for this payment.

  • reconciliation_rule_variables (Array<ModernTreasury::Models::ReconciliationRule>, nil) (defaults to: nil)

    An array of reconciliation rule variables for this payment.

  • remittance_information (String, nil) (defaults to: nil)

    For ‘ach`, this field will be passed through on an addenda record. For `wire` pa

  • statement_descriptor (String, nil) (defaults to: nil)

    The statement description you expect to see on the transaction. For ACH payments

  • type (Symbol, ModernTreasury::Models::ExpectedPaymentType, nil) (defaults to: nil)

    One of: ach, au_becs, bacs, book, check, eft, interac, provxchange, rtp, sen, se



# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1188

Instance Attribute Details

#amount_lower_boundInteger?

The lowest amount this expected payment may be equal to. Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000.

Returns:

  • (Integer, nil)


1015
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1015

optional :amount_lower_bound, Integer, nil?: true

#amount_reconciledInteger?

The amount reconciled for this expected payment. Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000.

Returns:

  • (Integer, nil)


1022
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1022

optional :amount_reconciled, Integer, nil?: true

#amount_reconciled_directionSymbol, ...

One of credit or debit. Indicates whether amount_reconciled is a credit or debit amount.



1029
1030
1031
1032
1033
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1029

optional :amount_reconciled_direction,
enum: -> {
  ModernTreasury::BulkRequestCreateParams::Resource::ExpectedPaymentCreateRequest::AmountReconciledDirection
},
nil?: true

#amount_unreconciledInteger?

The amount that remains unreconciled for this expected payment. Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000.

Returns:

  • (Integer, nil)


1040
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1040

optional :amount_unreconciled, Integer, nil?: true

#amount_unreconciled_directionSymbol, ...

One of credit or debit. Indicates whether amount_unreconciled is a credit or debit amount.



1047
1048
1049
1050
1051
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1047

optional :amount_unreconciled_direction,
enum: -> {
  ModernTreasury::BulkRequestCreateParams::Resource::ExpectedPaymentCreateRequest::AmountUnreconciledDirection
},
nil?: true

#amount_upper_boundInteger?

The highest amount this expected payment may be equal to. Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000.

Returns:

  • (Integer, nil)


1058
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1058

optional :amount_upper_bound, Integer, nil?: true

#counterparty_idString?

The ID of the counterparty you expect for this payment.

Returns:

  • (String, nil)


1064
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1064

optional :counterparty_id, String, nil?: true

#currencySymbol, ...

Must conform to ISO 4217. Defaults to the currency of the internal account.

Returns:



1070
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1070

optional :currency, enum: -> { ModernTreasury::Currency }, nil?: true

#date_lower_boundDate?

The earliest date the payment may come in. Format: yyyy-mm-dd

Returns:

  • (Date, nil)


1076
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1076

optional :date_lower_bound, Date, nil?: true

#date_upper_boundDate?

The latest date the payment may come in. Format: yyyy-mm-dd

Returns:

  • (Date, nil)


1082
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1082

optional :date_upper_bound, Date, nil?: true

#descriptionString?

An optional description for internal use.

Returns:

  • (String, nil)


1088
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1088

optional :description, String, nil?: true

#directionSymbol, ...

One of credit or debit. When you are receiving money, use credit. When you are being charged, use debit.



1095
1096
1097
1098
1099
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1095

optional :direction,
enum: -> {
  ModernTreasury::BulkRequestCreateParams::Resource::ExpectedPaymentCreateRequest::Direction
},
nil?: true

#external_idString?

An optional user-defined 180 character unique identifier.

Returns:

  • (String, nil)


1105
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1105

optional :external_id, String, nil?: true

#internal_account_idString?

The ID of the Internal Account for the expected payment.

Returns:

  • (String, nil)


1111
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1111

optional :internal_account_id, String, nil?: true

#ledger_transactionModernTreasury::Models::LedgerTransactionCreateRequest?

Specifies a ledger transaction object that will be created with the expected payment. If the ledger transaction cannot be created, then the expected payment creation will fail. The resulting ledger transaction will mirror the status of the expected payment.



1120
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1120

optional :ledger_transaction, -> { ModernTreasury::LedgerTransactionCreateRequest }

#ledger_transaction_idString?

Either ledger_transaction or ledger_transaction_id can be provided. Only a pending ledger transaction can be attached upon expected payment creation. Once the expected payment is created, the status of the ledger transaction tracks the expected payment automatically.

Returns:

  • (String, nil)


1129
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1129

optional :ledger_transaction_id, String

#line_itemsArray<ModernTreasury::Models::BulkRequestCreateParams::Resource::ExpectedPaymentCreateRequest::LineItem>?



1134
1135
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1134

optional :line_items,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::BulkRequestCreateParams::Resource::ExpectedPaymentCreateRequest::LineItem] }

#metadataHash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Returns:

  • (Hash{Symbol=>String}, nil)


1142
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1142

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#reconciliation_filtersObject?

The reconciliation filters you have for this payment.

Returns:

  • (Object, nil)


1148
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1148

optional :reconciliation_filters, ModernTreasury::Internal::Type::Unknown, nil?: true

#reconciliation_groupsObject?

The reconciliation groups you have for this payment.

Returns:

  • (Object, nil)


1154
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1154

optional :reconciliation_groups, ModernTreasury::Internal::Type::Unknown, nil?: true

#reconciliation_rule_variablesArray<ModernTreasury::Models::ReconciliationRule>?

An array of reconciliation rule variables for this payment.



1160
1161
1162
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1160

optional :reconciliation_rule_variables,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ReconciliationRule] },
nil?: true

#remittance_informationString?

For ‘ach`, this field will be passed through on an addenda record. For `wire` payments the field will be passed through as the “Originator to Beneficiary Information”, also known as OBI or Fedwire tag 6000.

Returns:

  • (String, nil)


1170
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1170

optional :remittance_information, String, nil?: true

#statement_descriptorString?

The statement description you expect to see on the transaction. For ACH payments, this will be the full line item passed from the bank. For wire payments, this will be the OBI field on the wire. For check payments, this will be the memo field.

Returns:

  • (String, nil)


1179
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1179

optional :statement_descriptor, String, nil?: true

#typeSymbol, ...

One of: ach, au_becs, bacs, book, check, eft, interac, provxchange, rtp, sen, sepa, signet, wire.



1186
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1186

optional :type, enum: -> { ModernTreasury::ExpectedPaymentType }, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 1251