Class: ModernTreasury::Models::BulkRequestCreateParams::Resource::LedgerTransactionUpdateRequestWithID
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::BulkRequestCreateParams::Resource::LedgerTransactionUpdateRequestWithID
- Defined in:
- lib/modern_treasury/models/bulk_request_create_params.rb,
sig/modern_treasury/models/bulk_request_create_params.rbs
Defined Under Namespace
Modules: LedgerableType, Status
Instance Attribute Summary collapse
-
#description ⇒ String?
An optional description for internal use.
-
#effective_at ⇒ Time?
The timestamp (ISO8601 format) at which the ledger transaction happened for reporting purposes.
-
#external_id ⇒ String?
A unique string to represent the ledger transaction.
- #id ⇒ String?
-
#ledger_entries ⇒ Array<ModernTreasury::Models::LedgerEntryCreateRequest>?
An array of ledger entry objects.
-
#ledgerable_id ⇒ String?
If the ledger transaction can be reconciled to another object in Modern Treasury, the id will be populated here, otherwise null.
-
#ledgerable_type ⇒ Symbol, ...
If the ledger transaction can be reconciled to another object in Modern Treasury, the type will be populated here, otherwise null.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#status ⇒ Symbol, ...
To post a ledger transaction at creation, use
posted.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: nil, description: nil, effective_at: nil, external_id: nil, ledger_entries: nil, ledgerable_id: nil, ledgerable_type: nil, metadata: nil, status: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see LedgerTransactionUpdateRequestWithID for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, description: nil, effective_at: nil, external_id: nil, ledger_entries: nil, ledgerable_id: nil, ledgerable_type: nil, metadata: nil, status: nil) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::BulkRequestCreateParams::Resource::LedgerTransactionUpdateRequestWithID for more details.
|
|
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2532
|
Instance Attribute Details
#description ⇒ String?
An optional description for internal use.
2479 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2479 optional :description, String, nil?: true |
#effective_at ⇒ Time?
The timestamp (ISO8601 format) at which the ledger transaction happened for reporting purposes.
2486 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2486 optional :effective_at, Time |
#external_id ⇒ String?
A unique string to represent the ledger transaction. Only one pending or posted ledger transaction may have this ID in the ledger.
2493 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2493 optional :external_id, String, nil?: true |
#id ⇒ String?
2473 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2473 optional :id, String |
#ledger_entries ⇒ Array<ModernTreasury::Models::LedgerEntryCreateRequest>?
An array of ledger entry objects.
2499 2500 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2499 optional :ledger_entries, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LedgerEntryCreateRequest] } |
#ledgerable_id ⇒ String?
If the ledger transaction can be reconciled to another object in Modern Treasury, the id will be populated here, otherwise null.
2507 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2507 optional :ledgerable_id, String |
#ledgerable_type ⇒ Symbol, ...
If the ledger transaction can be reconciled to another object in Modern Treasury, the type will be populated here, otherwise null. This can be one of payment_order, incoming_payment_detail, expected_payment, return, or reversal.
2515 2516 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2515 optional :ledgerable_type, enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::LedgerTransactionUpdateRequestWithID::LedgerableType } |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
2523 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2523 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#status ⇒ Symbol, ...
To post a ledger transaction at creation, use posted.
2529 2530 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2529 optional :status, enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::LedgerTransactionUpdateRequestWithID::Status } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2569
|
Instance Method Details
#to_hash ⇒ {
2052 |
# File 'sig/modern_treasury/models/bulk_request_create_params.rbs', line 2052
def to_hash: -> {
|