Class: ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/bulk_request_create_params.rb

Defined Under Namespace

Modules: ChargeBearer, Direction, FallbackType, ForeignExchangeIndicator, Priority, ReconciliationStatus Classes: Accounting, LineItem, ReceivingAccount, UltimateOriginatingPartyAddress

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, accounting_category_id: nil, description: nil, metadata: nil) ⇒ Object

Some parameter documentations has been truncated, see LineItem for more details.

Parameters:

  • amount (Integer)

    Value in specified currency’s smallest unit. e.g. $10 would be represented as 10

  • accounting_category_id (String, nil) (defaults to: nil)

    The ID of one of your accounting categories. Note that these will only be access

  • description (String, nil) (defaults to: nil)

    A free-form description of the line item.

  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    Additional data represented as key-value pairs. Both the key and value must be s



# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 422

Instance Attribute Details

#accountingModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::Accounting?

Deprecated.


138
139
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 138

optional :accounting,
-> { ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::Accounting }

#accounting_category_idString?

Deprecated.

The ID of one of your accounting categories. Note that these will only be accessible if your accounting system has been connected.

Returns:

  • (String, nil)


148
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 148

optional :accounting_category_id, String, nil?: true

#accounting_ledger_class_idString?

Deprecated.

The ID of one of your accounting ledger classes. Note that these will only be accessible if your accounting system has been connected.

Returns:

  • (String, nil)


157
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 157

optional :accounting_ledger_class_id, String, nil?: true

#amountInteger

Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000 (cents). For RTP, the maximum amount allowed by the network is $100,000.

Returns:

  • (Integer)


108
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 108

required :amount, Integer

#charge_bearerSymbol, ...

The party that will pay the fees for the payment order. See docs.moderntreasury.com/payments/docs/charge-bearer to understand the differences between the options.



165
166
167
168
169
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 165

optional :charge_bearer,
enum: -> {
  ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::ChargeBearer
},
nil?: true

#currencySymbol, ...

Defaults to the currency of the originating account.

Returns:



175
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 175

optional :currency, enum: -> { ModernTreasury::Currency }

#descriptionString?

An optional description for internal use.

Returns:

  • (String, nil)


181
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 181

optional :description, String, nil?: true

#directionSymbol, ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::Direction

One of ‘credit`, `debit`. Describes the direction money is flowing in the transaction. A `credit` moves money from your account to someone else’s. A ‘debit` pulls money from someone else’s account to your own. Note that wire, rtp, and check payments will always be ‘credit`.



117
118
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 117

required :direction,
enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::Direction }

#effective_dateDate?

Date transactions are to be posted to the participants’ account. Defaults to the current business day or the next business day if the current day is a bank holiday or weekend. Format: yyyy-mm-dd.

Returns:

  • (Date, nil)


189
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 189

optional :effective_date, Date

#expires_atTime?

RFP payments require an expires_at. This value must be past the effective_date.

Returns:

  • (Time, nil)


195
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 195

optional :expires_at, Time, nil?: true

#external_idString?

An optional user-defined 180 character unique identifier.

Returns:

  • (String, nil)


201
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 201

optional :external_id, String, nil?: true

#fallback_typeSymbol, ...

A payment type to fallback to if the original type is not valid for the receiving account. Currently, this only supports falling back from RTP to ACH (type=rtp and fallback_type=ach)



209
210
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 209

optional :fallback_type,
enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::FallbackType }

#foreign_exchange_contractString?

If present, indicates a specific foreign exchange contract number that has been generated by your financial institution.

Returns:

  • (String, nil)


217
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 217

optional :foreign_exchange_contract, String, nil?: true

#foreign_exchange_indicatorSymbol, ...

Indicates the type of FX transfer to initiate, can be either ‘variable_to_fixed`, `fixed_to_variable`, or `null` if the payment order currency matches the originating account currency.



225
226
227
228
229
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 225

optional :foreign_exchange_indicator,
enum: -> {
  ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::ForeignExchangeIndicator
},
nil?: true

#ledger_transactionModernTreasury::Models::LedgerTransactionCreateRequest?

Specifies a ledger transaction object that will be created with the payment order. If the ledger transaction cannot be created, then the payment order creation will fail. The resulting ledger transaction will mirror the status of the payment order.



238
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 238

optional :ledger_transaction, -> { ModernTreasury::LedgerTransactionCreateRequest }

#ledger_transaction_idString?

Either ledger_transaction or ledger_transaction_id can be provided. Only a pending ledger transaction can be attached upon payment order creation. Once the payment order is created, the status of the ledger transaction tracks the payment order automatically.

Returns:

  • (String, nil)


247
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 247

optional :ledger_transaction_id, String

#line_itemsArray<ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::LineItem>?

An array of line items that must sum up to the amount of the payment order.



253
254
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 253

optional :line_items,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::LineItem] }

#metadataHash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Returns:

  • (Hash{Symbol=>String}, nil)


261
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 261

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#nsf_protectedBoolean?

A boolean to determine if NSF Protection is enabled for this payment order. Note that this setting must also be turned on in your organization settings page.

Returns:

  • (Boolean, nil)


268
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 268

optional :nsf_protected, ModernTreasury::Internal::Type::Boolean

#originating_account_idString

The ID of one of your organization’s internal accounts.

Returns:

  • (String)


124
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 124

required :originating_account_id, String

#originating_party_nameString?

If present, this will replace your default company name on receiver’s bank statement. This field can only be used for ACH payments currently. For ACH, only the first 16 characters of this string will be used. Any additional characters will be truncated.

Returns:

  • (String, nil)


277
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 277

optional :originating_party_name, String, nil?: true

#prioritySymbol, ...

Either ‘normal` or `high`. For ACH and EFT payments, `high` represents a same-day ACH or EFT transfer, respectively. For check payments, `high` can mean an overnight check rather than standard mail.



285
286
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 285

optional :priority,
enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::Priority }

#process_afterTime?

If present, Modern Treasury will not process the payment until after this time. If ‘process_after` is past the cutoff for `effective_date`, `process_after` will take precedence and `effective_date` will automatically update to reflect the earliest possible sending date after `process_after`. Format is ISO8601 timestamp.

Returns:

  • (Time, nil)


296
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 296

optional :process_after, Time, nil?: true

#purposeString?

For ‘wire`, this is usually the purpose which is transmitted via the “InstrForDbtrAgt” field in the ISO20022 file. For `eft`, this field is the 3 digit CPA Code that will be attached to the payment.

Returns:

  • (String, nil)


304
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 304

optional :purpose, String, nil?: true

#receiving_accountModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::ReceivingAccount?

Either ‘receiving_account` or `receiving_account_id` must be present. When using `receiving_account_id`, you may pass the id of an external account or an internal account.



312
313
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 312

optional :receiving_account,
-> { ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::ReceivingAccount }

#receiving_account_idString?

Either ‘receiving_account` or `receiving_account_id` must be present. When using `receiving_account_id`, you may pass the id of an external account or an internal account.

Returns:

  • (String, nil)


321
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 321

optional :receiving_account_id, String

#reconciliation_statusSymbol, ...

One of ‘unreconciled`, `tentatively_reconciled` or `reconciled`.



327
328
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 327

optional :reconciliation_status,
enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::ReconciliationStatus }

#remittance_informationString?

For ‘ach`, this field will be passed through on an addenda record. For `wire` payments the field will be passed through as the “Originator to Beneficiary Information”, also known as OBI or Fedwire tag 6000.

Returns:

  • (String, nil)


336
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 336

optional :remittance_information, String, nil?: true

#send_remittance_adviceBoolean?

Send an email to the counterparty when the payment order is sent to the bank. If ‘null`, `send_remittance_advice` on the Counterparty is used.

Returns:

  • (Boolean, nil)


343
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 343

optional :send_remittance_advice, ModernTreasury::Internal::Type::Boolean, nil?: true

#statement_descriptorString?

An optional descriptor which will appear in the receiver’s statement. For ‘check` payments this field will be used as the memo line. For `ach` the maximum length is 10 characters. Note that for ACH payments, the name on your bank account will be included automatically by the bank, so you can use the characters for other useful information. For `eft` the maximum length is 15 characters.

Returns:

  • (String, nil)


354
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 354

optional :statement_descriptor, String, nil?: true

#subtypeSymbol, ...

An additional layer of classification for the type of payment order you are doing. This field is only used for ‘ach` payment orders currently. For `ach` payment orders, the `subtype` represents the SEC code. We currently support `CCD`, `PPD`, `IAT`, `CTX`, `WEB`, `CIE`, and `TEL`.



363
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 363

optional :subtype, enum: -> { ModernTreasury::PaymentOrderSubtype }, nil?: true

#transaction_monitoring_enabledBoolean?

Deprecated.

A flag that determines whether a payment order should go through transaction monitoring.

Returns:

  • (Boolean, nil)


372
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 372

optional :transaction_monitoring_enabled, ModernTreasury::Internal::Type::Boolean

#typeSymbol, ModernTreasury::Models::PaymentOrderType

One of ‘ach`, `se_bankgirot`, `eft`, `wire`, `check`, `sen`, `book`, `rtp`, `sepa`, `bacs`, `au_becs`, `interac`, `neft`, `nics`, `nz_national_clearing_code`, `sic`, `signet`, `provexchange`, `zengin`.



132
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 132

required :type, enum: -> { ModernTreasury::PaymentOrderType }

#ultimate_originating_account_idString?

The ultimate originating account ID. Can be a ‘virtual_account` or `internal_account`.

Returns:

  • (String, nil)


379
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 379

optional :ultimate_originating_account_id, String

#ultimate_originating_party_addressModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::UltimateOriginatingPartyAddress?

Address of the ultimate originator of the payment order.



385
386
387
388
389
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 385

optional :ultimate_originating_party_address,
-> {
  ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderAsyncCreateRequest::UltimateOriginatingPartyAddress
},
nil?: true

#ultimate_originating_party_identifierString?

Identifier of the ultimate originator of the payment order.

Returns:

  • (String, nil)


395
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 395

optional :ultimate_originating_party_identifier, String, nil?: true

#ultimate_originating_party_nameString?

Name of the ultimate originator of the payment order.

Returns:

  • (String, nil)


401
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 401

optional :ultimate_originating_party_name, String, nil?: true

#ultimate_receiving_party_identifierString?

Identifier of the ultimate funds recipient.

Returns:

  • (String, nil)


407
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 407

optional :ultimate_receiving_party_identifier, String, nil?: true

#ultimate_receiving_party_nameString?

Name of the ultimate funds recipient.

Returns:

  • (String, nil)


413
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 413

optional :ultimate_receiving_party_name, String, nil?: true

#vendor_attributesObject?

Additional vendor specific fields for this payment. Data must be represented as key-value pairs.

Returns:

  • (Object, nil)


420
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 420

optional :vendor_attributes, ModernTreasury::Internal::Type::Unknown

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 519