Class: ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ReceivingAccount
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ReceivingAccount
- Defined in:
- lib/modern_treasury/models/bulk_request_create_params.rb,
sig/modern_treasury/models/bulk_request_create_params.rbs
Overview
Defined Under Namespace
Modules: PartyType Classes: AccountDetail, RoutingDetail
Constant Summary collapse
- ModernTreasury =
Instance Attribute Summary collapse
- #account_details ⇒ Array<ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ReceivingAccount::AccountDetail>?
-
#account_type ⇒ Symbol, ...
Can be
checking,savingsorother. - #contact_details ⇒ Array<ModernTreasury::Models::ContactDetailCreateRequest>?
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
-
#ledger_account ⇒ ModernTreasury::Models::LedgerAccountCreateRequest?
Specifies a ledger account object that will be created with the external account.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#name ⇒ String?
A nickname for the external account.
-
#party_address ⇒ ModernTreasury::Models::AddressRequest?
Required if receiving wire payments.
- #party_identifier ⇒ String?
-
#party_name ⇒ String?
If this value isn't provided, it will be inherited from the counterparty's name.
-
#party_type ⇒ Symbol, ...
Either
individualorbusiness. -
#plaid_processor_token ⇒ String?
If you've enabled the Modern Treasury + Plaid integration in your Plaid account, you can pass the processor token in this field.
- #routing_details ⇒ Array<ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ReceivingAccount::RoutingDetail>?
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
1730 |
# File 'sig/modern_treasury/models/bulk_request_create_params.rbs', line 1730
def initialize: (
|
Instance Attribute Details
#account_details ⇒ Array<ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ReceivingAccount::AccountDetail>?
2166 2167 2168 2169 2170 2171 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2166 optional :account_details, -> do ModernTreasury::Internal::Type::ArrayOf[ ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ReceivingAccount::AccountDetail ] end |
#account_type ⇒ Symbol, ...
Can be checking, savings or other.
2177 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2177 optional :account_type, enum: -> { ModernTreasury::ExternalAccountType } |
#contact_details ⇒ Array<ModernTreasury::Models::ContactDetailCreateRequest>?
2182 2183 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2182 optional :contact_details, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ContactDetailCreateRequest] } |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
2189 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2189 optional :external_id, String, nil?: true |
#ledger_account ⇒ ModernTreasury::Models::LedgerAccountCreateRequest?
Specifies a ledger account object that will be created with the external account. The resulting ledger account is linked to the external account for auto-ledgering Payment objects. See https://docs.moderntreasury.com/docs/linking-to-other-modern-treasury-objects for more details.
2199 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2199 optional :ledger_account, -> { ModernTreasury::LedgerAccountCreateRequest } |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
2206 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2206 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#name ⇒ String?
A nickname for the external account. This is only for internal usage and won't affect any payments
2213 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2213 optional :name, String, nil?: true |
#party_address ⇒ ModernTreasury::Models::AddressRequest?
Required if receiving wire payments.
2219 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2219 optional :party_address, -> { ModernTreasury::AddressRequest } |
#party_identifier ⇒ String?
2224 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2224 optional :party_identifier, String |
#party_name ⇒ String?
If this value isn't provided, it will be inherited from the counterparty's name.
2230 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2230 optional :party_name, String |
#party_type ⇒ Symbol, ...
Either individual or business.
2236 2237 2238 2239 2240 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2236 optional :party_type, enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ReceivingAccount::PartyType }, nil?: true |
#plaid_processor_token ⇒ String?
If you've enabled the Modern Treasury + Plaid integration in your Plaid account, you can pass the processor token in this field.
2247 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2247 optional :plaid_processor_token, String |
#routing_details ⇒ Array<ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ReceivingAccount::RoutingDetail>?
2252 2253 2254 2255 2256 2257 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2252 optional :routing_details, -> do ModernTreasury::Internal::Type::ArrayOf[ ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ReceivingAccount::RoutingDetail ] end |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2330
|
Instance Method Details
#to_hash ⇒ {
1746 |
# File 'sig/modern_treasury/models/bulk_request_create_params.rbs', line 1746
def to_hash: -> {
|