Class: ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ReceivingAccount
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ReceivingAccount
- Defined in:
- lib/modern_treasury/models/bulk_request_create_params.rb
Overview
Defined Under Namespace
Modules: PartyType Classes: AccountDetail, RoutingDetail
Instance Attribute Summary collapse
- #account_details ⇒ Array<ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ReceivingAccount::AccountDetail>?
-
#account_type ⇒ Symbol, ...
Can be ‘checking`, `savings` or `other`.
- #contact_details ⇒ Array<ModernTreasury::Models::ContactDetailCreateRequest>?
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
-
#ledger_account ⇒ ModernTreasury::Models::LedgerAccountCreateRequest?
Specifies a ledger account object that will be created with the external account.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#name ⇒ String?
A nickname for the external account.
-
#party_address ⇒ ModernTreasury::Models::AddressRequest?
Required if receiving wire payments.
- #party_identifier ⇒ String?
-
#party_name ⇒ String?
If this value isn’t provided, it will be inherited from the counterparty’s name.
-
#party_type ⇒ Symbol, ...
Either ‘individual` or `business`.
-
#plaid_processor_token ⇒ String?
If you’ve enabled the Modern Treasury + Plaid integration in your Plaid account, you can pass the processor token in this field.
- #routing_details ⇒ Array<ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ReceivingAccount::RoutingDetail>?
Class Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from ModernTreasury::Internal::Type::BaseModel
Instance Attribute Details
#account_details ⇒ Array<ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ReceivingAccount::AccountDetail>?
2020 2021 2022 2023 2024 2025 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2020 optional :account_details, -> do ModernTreasury::Internal::Type::ArrayOf[ ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ReceivingAccount::AccountDetail ] end |
#account_type ⇒ Symbol, ...
Can be ‘checking`, `savings` or `other`.
2031 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2031 optional :account_type, enum: -> { ModernTreasury::ExternalAccountType } |
#contact_details ⇒ Array<ModernTreasury::Models::ContactDetailCreateRequest>?
2036 2037 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2036 optional :contact_details, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ContactDetailCreateRequest] } |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
2043 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2043 optional :external_id, String, nil?: true |
#ledger_account ⇒ ModernTreasury::Models::LedgerAccountCreateRequest?
Specifies a ledger account object that will be created with the external account. The resulting ledger account is linked to the external account for auto-ledgering Payment objects. See docs.moderntreasury.com/docs/linking-to-other-modern-treasury-objects for more details.
2053 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2053 optional :ledger_account, -> { ModernTreasury::LedgerAccountCreateRequest } |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
2060 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2060 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#name ⇒ String?
A nickname for the external account. This is only for internal usage and won’t affect any payments
2067 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2067 optional :name, String, nil?: true |
#party_address ⇒ ModernTreasury::Models::AddressRequest?
Required if receiving wire payments.
2073 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2073 optional :party_address, -> { ModernTreasury::AddressRequest } |
#party_identifier ⇒ String?
2078 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2078 optional :party_identifier, String |
#party_name ⇒ String?
If this value isn’t provided, it will be inherited from the counterparty’s name.
2084 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2084 optional :party_name, String |
#party_type ⇒ Symbol, ...
Either ‘individual` or `business`.
2090 2091 2092 2093 2094 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2090 optional :party_type, enum: -> { ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ReceivingAccount::PartyType }, nil?: true |
#plaid_processor_token ⇒ String?
If you’ve enabled the Modern Treasury + Plaid integration in your Plaid account, you can pass the processor token in this field.
2101 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2101 optional :plaid_processor_token, String |
#routing_details ⇒ Array<ModernTreasury::Models::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ReceivingAccount::RoutingDetail>?
2106 2107 2108 2109 2110 2111 |
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2106 optional :routing_details, -> do ModernTreasury::Internal::Type::ArrayOf[ ModernTreasury::BulkRequestCreateParams::Resource::PaymentOrderUpdateRequestWithID::ReceivingAccount::RoutingDetail ] end |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/bulk_request_create_params.rb', line 2184
|