Class: ModernTreasury::Models::Case::ResolvedAction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::Case::ResolvedAction
- Defined in:
- lib/modern_treasury/models/case_.rb,
sig/modern_treasury/models/case_.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#category ⇒ Symbol, ModernTreasury::Models::Case::ResolvedAction::Category
The category of the requested action.
- #created_at ⇒ Time
-
#field ⇒ Symbol, ...
The field that needs to be corrected or provided, if any.
- #id ⇒ String
-
#instructions ⇒ String?
Instructions on how to resolve the requested action.
-
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
- #object ⇒ String
-
#reasons ⇒ Array<String>
The reasons the action was requested.
- #updated_at ⇒ Time
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, category:, created_at:, field:, instructions:, live_mode:, object:, reasons:, updated_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ResolvedAction for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, category:, created_at:, field:, instructions:, live_mode:, object:, reasons:, updated_at:) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::Case::ResolvedAction for more details.
|
|
# File 'lib/modern_treasury/models/case_.rb', line 249
|
Instance Attribute Details
#category ⇒ Symbol, ModernTreasury::Models::Case::ResolvedAction::Category
The category of the requested action.
207 |
# File 'lib/modern_treasury/models/case_.rb', line 207 required :category, enum: -> { ModernTreasury::Case::ResolvedAction::Category } |
#created_at ⇒ Time
212 |
# File 'lib/modern_treasury/models/case_.rb', line 212 required :created_at, Time |
#field ⇒ Symbol, ...
The field that needs to be corrected or provided, if any.
218 |
# File 'lib/modern_treasury/models/case_.rb', line 218 required :field, enum: -> { ModernTreasury::Case::ResolvedAction::Field }, nil?: true |
#id ⇒ String
201 |
# File 'lib/modern_treasury/models/case_.rb', line 201 required :id, String |
#instructions ⇒ String?
Instructions on how to resolve the requested action.
224 |
# File 'lib/modern_treasury/models/case_.rb', line 224 required :instructions, String, nil?: true |
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
231 |
# File 'lib/modern_treasury/models/case_.rb', line 231 required :live_mode, ModernTreasury::Internal::Type::Boolean |
#object ⇒ String
236 |
# File 'lib/modern_treasury/models/case_.rb', line 236 required :object, String |
#reasons ⇒ Array<String>
The reasons the action was requested.
242 |
# File 'lib/modern_treasury/models/case_.rb', line 242 required :reasons, ModernTreasury::Internal::Type::ArrayOf[String] |
#updated_at ⇒ Time
247 |
# File 'lib/modern_treasury/models/case_.rb', line 247 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/case_.rb', line 284
|
Instance Method Details
#to_hash ⇒ {
203 |
# File 'sig/modern_treasury/models/case_.rbs', line 203
def to_hash: -> {
|