Class: ModernTreasury::Models::ChildLegalEntity
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::ChildLegalEntity
- Defined in:
- lib/modern_treasury/models/child_legal_entity.rb
Defined Under Namespace
Modules: LegalEntityType, LegalStructure, RiskRating, Status Classes: Address, Identification, PhoneNumber, Regulator
Instance Attribute Summary collapse
-
#addresses ⇒ Array<ModernTreasury::Models::ChildLegalEntity::Address>
A list of addresses for the entity.
- #bank_settings ⇒ ModernTreasury::Models::LegalEntityBankSettings?
-
#business_description ⇒ String?
A description of the business.
-
#business_name ⇒ String?
The business’s legal business name.
-
#citizenship_country ⇒ String?
The country of citizenship for an individual.
- #compliance_details ⇒ Object? deprecated Deprecated.
-
#country_of_incorporation ⇒ String?
The country code where the business is incorporated in the ISO 3166-1 alpha-2 or alpha-3 formats.
- #created_at ⇒ Time
-
#date_formed ⇒ Date?
A business’s formation date (YYYY-MM-DD).
-
#date_of_birth ⇒ Date?
An individual’s date of birth (YYYY-MM-DD).
- #discarded_at ⇒ Time?
- #documents ⇒ Array<ModernTreasury::Models::Document>
- #doing_business_as_names ⇒ Array<String>
-
#email ⇒ String?
The entity’s primary email.
-
#expected_activity_volume ⇒ Integer?
Monthly expected transaction volume in USD.
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
-
#first_name ⇒ String?
An individual’s first name.
- #id ⇒ String
-
#identifications ⇒ Array<ModernTreasury::Models::ChildLegalEntity::Identification>
A list of identifications for the legal entity.
-
#industry_classifications ⇒ Array<ModernTreasury::Models::LegalEntityIndustryClassification>
A list of industry classifications for the legal entity.
-
#intended_use ⇒ String?
A description of the intended use of the legal entity.
-
#last_name ⇒ String?
An individual’s last name.
-
#legal_entity_associations ⇒ Array<ModernTreasury::Models::LegalEntityAssociation>?
The legal entity associations and its child legal entities.
-
#legal_entity_type ⇒ Symbol, ModernTreasury::Models::ChildLegalEntity::LegalEntityType
The type of legal entity.
-
#legal_structure ⇒ Symbol, ...
The business’s legal structure.
-
#listed_exchange ⇒ String?
ISO 10383 market identifier code.
-
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
-
#metadata ⇒ Hash{Symbol=>String}
Additional data represented as key-value pairs.
-
#middle_name ⇒ String?
An individual’s middle name.
- #object ⇒ String
-
#operating_jurisdictions ⇒ Array<String>
A list of countries where the business operates (ISO 3166-1 alpha-2 or alpha-3 codes).
- #phone_numbers ⇒ Array<ModernTreasury::Models::ChildLegalEntity::PhoneNumber>
-
#politically_exposed_person ⇒ Boolean?
Whether the individual is a politically exposed person.
-
#preferred_name ⇒ String?
An individual’s preferred name.
-
#prefix ⇒ String?
An individual’s prefix.
-
#primary_social_media_sites ⇒ Array<String>
A list of primary social media URLs for the business.
-
#regulators ⇒ Array<ModernTreasury::Models::ChildLegalEntity::Regulator>?
Array of regulatory bodies overseeing this institution.
-
#risk_rating ⇒ Symbol, ...
The risk rating of the legal entity.
-
#service_provider_legal_entity_id ⇒ String?
The UUID of the parent legal entity in the service provider tree.
-
#status ⇒ Symbol, ...
The activation status of the legal entity.
-
#suffix ⇒ String?
An individual’s suffix.
- #third_party_verification ⇒ ModernTreasury::Models::ThirdPartyVerification? deprecated Deprecated.
-
#third_party_verifications ⇒ Array<ModernTreasury::Models::ThirdPartyVerification>
A list of third-party verifications run by external vendors.
-
#ticker_symbol ⇒ String?
Stock ticker symbol for publicly traded companies.
- #updated_at ⇒ Time
- #wealth_and_employment_details ⇒ ModernTreasury::Models::LegalEntityWealthEmploymentDetail?
-
#website ⇒ String?
The entity’s primary website URL.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(jurisdiction:, name:, registration_number:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Regulator for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(jurisdiction:, name:, registration_number:) ⇒ Object
Some parameter documentations has been truncated, see Regulator for more details.
|
|
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 676
|
Instance Attribute Details
#addresses ⇒ Array<ModernTreasury::Models::ChildLegalEntity::Address>
A list of addresses for the entity.
15 16 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 15 required :addresses, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ChildLegalEntity::Address] } |
#bank_settings ⇒ ModernTreasury::Models::LegalEntityBankSettings?
21 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 21 required :bank_settings, -> { ModernTreasury::LegalEntityBankSettings }, nil?: true |
#business_description ⇒ String?
A description of the business.
27 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 27 required :business_description, String, nil?: true |
#business_name ⇒ String?
The business’s legal business name.
33 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 33 required :business_name, String, nil?: true |
#citizenship_country ⇒ String?
The country of citizenship for an individual.
39 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 39 required :citizenship_country, String, nil?: true |
#compliance_details ⇒ Object?
45 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 45 required :compliance_details, ModernTreasury::Internal::Type::Unknown, nil?: true |
#country_of_incorporation ⇒ String?
The country code where the business is incorporated in the ISO 3166-1 alpha-2 or alpha-3 formats.
52 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 52 required :country_of_incorporation, String, nil?: true |
#created_at ⇒ Time
57 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 57 required :created_at, Time |
#date_formed ⇒ Date?
A business’s formation date (YYYY-MM-DD).
63 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 63 required :date_formed, Date, nil?: true |
#date_of_birth ⇒ Date?
An individual’s date of birth (YYYY-MM-DD).
69 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 69 required :date_of_birth, Date, nil?: true |
#discarded_at ⇒ Time?
74 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 74 required :discarded_at, Time, nil?: true |
#documents ⇒ Array<ModernTreasury::Models::Document>
79 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 79 required :documents, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::Document] } |
#doing_business_as_names ⇒ Array<String>
84 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 84 required :doing_business_as_names, ModernTreasury::Internal::Type::ArrayOf[String] |
#email ⇒ String?
The entity’s primary email.
90 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 90 required :email, String, nil?: true |
#expected_activity_volume ⇒ Integer?
Monthly expected transaction volume in USD.
96 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 96 required :expected_activity_volume, Integer, nil?: true |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
102 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 102 required :external_id, String, nil?: true |
#first_name ⇒ String?
An individual’s first name.
108 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 108 required :first_name, String, nil?: true |
#id ⇒ String
9 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 9 required :id, String |
#identifications ⇒ Array<ModernTreasury::Models::ChildLegalEntity::Identification>
A list of identifications for the legal entity.
114 115 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 114 required :identifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ChildLegalEntity::Identification] } |
#industry_classifications ⇒ Array<ModernTreasury::Models::LegalEntityIndustryClassification>
A list of industry classifications for the legal entity.
121 122 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 121 required :industry_classifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityIndustryClassification] } |
#intended_use ⇒ String?
A description of the intended use of the legal entity.
128 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 128 required :intended_use, String, nil?: true |
#last_name ⇒ String?
An individual’s last name.
134 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 134 required :last_name, String, nil?: true |
#legal_entity_associations ⇒ Array<ModernTreasury::Models::LegalEntityAssociation>?
The legal entity associations and its child legal entities.
140 141 142 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 140 required :legal_entity_associations, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAssociation] }, nil?: true |
#legal_entity_type ⇒ Symbol, ModernTreasury::Models::ChildLegalEntity::LegalEntityType
The type of legal entity.
148 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 148 required :legal_entity_type, enum: -> { ModernTreasury::ChildLegalEntity::LegalEntityType } |
#legal_structure ⇒ Symbol, ...
The business’s legal structure.
154 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 154 required :legal_structure, enum: -> { ModernTreasury::ChildLegalEntity::LegalStructure }, nil?: true |
#listed_exchange ⇒ String?
ISO 10383 market identifier code.
160 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 160 required :listed_exchange, String, nil?: true |
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
167 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 167 required :live_mode, ModernTreasury::Internal::Type::Boolean |
#metadata ⇒ Hash{Symbol=>String}
Additional data represented as key-value pairs. Both the key and value must be strings.
174 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 174 required :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#middle_name ⇒ String?
An individual’s middle name.
180 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 180 required :middle_name, String, nil?: true |
#object ⇒ String
185 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 185 required :object, String |
#operating_jurisdictions ⇒ Array<String>
A list of countries where the business operates (ISO 3166-1 alpha-2 or alpha-3 codes).
192 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 192 required :operating_jurisdictions, ModernTreasury::Internal::Type::ArrayOf[String] |
#phone_numbers ⇒ Array<ModernTreasury::Models::ChildLegalEntity::PhoneNumber>
197 198 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 197 required :phone_numbers, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ChildLegalEntity::PhoneNumber] } |
#politically_exposed_person ⇒ Boolean?
Whether the individual is a politically exposed person.
204 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 204 required :politically_exposed_person, ModernTreasury::Internal::Type::Boolean, nil?: true |
#preferred_name ⇒ String?
An individual’s preferred name.
210 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 210 required :preferred_name, String, nil?: true |
#prefix ⇒ String?
An individual’s prefix.
216 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 216 required :prefix, String, nil?: true |
#primary_social_media_sites ⇒ Array<String>
A list of primary social media URLs for the business.
222 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 222 required :primary_social_media_sites, ModernTreasury::Internal::Type::ArrayOf[String] |
#regulators ⇒ Array<ModernTreasury::Models::ChildLegalEntity::Regulator>?
Array of regulatory bodies overseeing this institution.
228 229 230 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 228 required :regulators, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ChildLegalEntity::Regulator] }, nil?: true |
#risk_rating ⇒ Symbol, ...
The risk rating of the legal entity. One of low, medium, high.
236 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 236 required :risk_rating, enum: -> { ModernTreasury::ChildLegalEntity::RiskRating }, nil?: true |
#service_provider_legal_entity_id ⇒ String?
The UUID of the parent legal entity in the service provider tree.
242 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 242 required :service_provider_legal_entity_id, String, nil?: true |
#status ⇒ Symbol, ...
The activation status of the legal entity. One of pending, active, suspended, or denied.
249 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 249 required :status, enum: -> { ModernTreasury::ChildLegalEntity::Status }, nil?: true |
#suffix ⇒ String?
An individual’s suffix.
255 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 255 required :suffix, String, nil?: true |
#third_party_verification ⇒ ModernTreasury::Models::ThirdPartyVerification?
Deprecated. Use ‘third_party_verifications` instead.
263 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 263 required :third_party_verification, -> { ModernTreasury::ThirdPartyVerification }, nil?: true |
#third_party_verifications ⇒ Array<ModernTreasury::Models::ThirdPartyVerification>
A list of third-party verifications run by external vendors.
269 270 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 269 required :third_party_verifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ThirdPartyVerification] } |
#ticker_symbol ⇒ String?
Stock ticker symbol for publicly traded companies.
276 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 276 required :ticker_symbol, String, nil?: true |
#updated_at ⇒ Time
281 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 281 required :updated_at, Time |
#wealth_and_employment_details ⇒ ModernTreasury::Models::LegalEntityWealthEmploymentDetail?
286 287 288 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 286 required :wealth_and_employment_details, -> { ModernTreasury::LegalEntityWealthEmploymentDetail }, nil?: true |
#website ⇒ String?
The entity’s primary website URL.
294 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 294 required :website, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 508
|