Class: ModernTreasury::Models::ChildLegalEntity
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::ChildLegalEntity
- Defined in:
- lib/modern_treasury/models/child_legal_entity.rb,
sig/modern_treasury/models/child_legal_entity.rbs
Defined Under Namespace
Modules: BusinessDesignation, LegalEntityType, LegalStructure, RiskRating, Status Classes: Address, PhoneNumber, Regulator, TermsOfUse
Instance Attribute Summary collapse
-
#addresses ⇒ Array<ModernTreasury::Models::ChildLegalEntity::Address>
A list of addresses for the entity.
- #bank_settings ⇒ ModernTreasury::Models::LegalEntityBankSettings?
-
#business_description ⇒ String?
A description of the business.
-
#business_designation ⇒ Symbol, ...
Legal designation associated with the business.
-
#business_name ⇒ String?
The business's legal business name.
-
#citizenship_country ⇒ String?
The country of citizenship for an individual.
- #compliance_details ⇒ Object? deprecated Deprecated.
-
#country_of_incorporation ⇒ String?
The country where the business is incorporated, as an ISO 3166-1 alpha-2 country code (e.g. US).
- #created_at ⇒ Time
-
#date_formed ⇒ Date?
A business's formation date (YYYY-MM-DD).
-
#date_of_birth ⇒ Date?
An individual's date of birth (YYYY-MM-DD).
- #discarded_at ⇒ Time?
- #documents ⇒ Array<ModernTreasury::Models::Document>
- #doing_business_as_names ⇒ Array<String>
-
#email ⇒ String?
The entity's primary email.
-
#expected_activity_volume ⇒ Integer?
Monthly expected transaction volume in USD.
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
-
#first_name ⇒ String?
An individual's first name.
- #id ⇒ String
-
#identifications ⇒ Array<ModernTreasury::Models::Identification>
A list of identifications for the legal entity.
-
#industry_classifications ⇒ Array<ModernTreasury::Models::LegalEntityIndustryClassification>
A list of industry classifications for the legal entity.
-
#intended_use ⇒ String?
A description of the intended use of the legal entity.
-
#last_name ⇒ String?
An individual's last name.
-
#legal_entity_associations ⇒ Array<ModernTreasury::Models::LegalEntityAssociation>?
The legal entity associations and its child legal entities.
-
#legal_entity_type ⇒ Symbol, ModernTreasury::Models::ChildLegalEntity::LegalEntityType
The type of legal entity.
-
#legal_structure ⇒ Symbol, ...
The business's legal structure.
-
#listed_exchange ⇒ String?
ISO 10383 market identifier code.
-
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
-
#metadata ⇒ Hash{Symbol=>String}
Additional data represented as key-value pairs.
-
#middle_name ⇒ String?
An individual's middle name.
- #object ⇒ String
-
#operating_jurisdictions ⇒ Array<String>
A list of countries where the business operates, as ISO 3166-1 alpha-2 country codes (e.g. ["US", "CA"]).
- #phone_numbers ⇒ Array<ModernTreasury::Models::ChildLegalEntity::PhoneNumber>
-
#politically_exposed_person ⇒ Boolean?
Whether the individual is a politically exposed person.
-
#preferred_name ⇒ String?
An individual's preferred name.
-
#prefix ⇒ String?
An individual's prefix.
-
#primary_social_media_sites ⇒ Array<String>
A list of the entity's primary social media URLs.
-
#regulators ⇒ Array<ModernTreasury::Models::ChildLegalEntity::Regulator>?
Array of regulatory bodies overseeing this institution.
-
#risk_rating ⇒ Symbol, ...
The risk rating of the legal entity.
-
#service_provider_legal_entity_id ⇒ String?
The UUID of the parent legal entity in the service provider tree.
-
#status ⇒ Symbol, ...
The activation status of the legal entity.
-
#suffix ⇒ String?
An individual's suffix.
-
#terms_of_use ⇒ ModernTreasury::Models::ChildLegalEntity::TermsOfUse?
Acceptance of terms of use by the legal entity.
- #third_party_verification ⇒ ModernTreasury::Models::ThirdPartyVerification? deprecated Deprecated.
-
#third_party_verifications ⇒ Array<ModernTreasury::Models::ThirdPartyVerification>
A list of third-party verifications run by external vendors.
-
#ticker_symbol ⇒ String?
Stock ticker symbol for publicly traded companies.
- #updated_at ⇒ Time
- #wealth_and_employment_details ⇒ ModernTreasury::Models::LegalEntityWealthEmploymentDetail?
-
#website ⇒ String?
The entity's primary website URL.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(jurisdiction:, name:, registration_number:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Regulator for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(jurisdiction:, name:, registration_number:) ⇒ Object
Some parameter documentations has been truncated, see Regulator for more details.
|
|
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 594
|
Instance Attribute Details
#addresses ⇒ Array<ModernTreasury::Models::ChildLegalEntity::Address>
A list of addresses for the entity.
15 16 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 15 required :addresses, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ChildLegalEntity::Address] } |
#bank_settings ⇒ ModernTreasury::Models::LegalEntityBankSettings?
21 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 21 required :bank_settings, -> { ModernTreasury::LegalEntityBankSettings }, nil?: true |
#business_description ⇒ String?
A description of the business.
27 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 27 required :business_description, String, nil?: true |
#business_designation ⇒ Symbol, ...
Legal designation associated with the business.
33 34 35 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 33 required :business_designation, enum: -> { ModernTreasury::ChildLegalEntity::BusinessDesignation }, nil?: true |
#business_name ⇒ String?
The business's legal business name.
41 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 41 required :business_name, String, nil?: true |
#citizenship_country ⇒ String?
The country of citizenship for an individual.
47 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 47 required :citizenship_country, String, nil?: true |
#compliance_details ⇒ Object?
53 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 53 required :compliance_details, ModernTreasury::Internal::Type::Unknown, nil?: true |
#country_of_incorporation ⇒ String?
The country where the business is incorporated, as an ISO 3166-1 alpha-2 country code (e.g. US).
60 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 60 required :country_of_incorporation, String, nil?: true |
#created_at ⇒ Time
65 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 65 required :created_at, Time |
#date_formed ⇒ Date?
A business's formation date (YYYY-MM-DD).
71 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 71 required :date_formed, Date, nil?: true |
#date_of_birth ⇒ Date?
An individual's date of birth (YYYY-MM-DD).
77 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 77 required :date_of_birth, Date, nil?: true |
#discarded_at ⇒ Time?
82 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 82 required :discarded_at, Time, nil?: true |
#documents ⇒ Array<ModernTreasury::Models::Document>
87 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 87 required :documents, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::Document] } |
#doing_business_as_names ⇒ Array<String>
92 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 92 required :doing_business_as_names, ModernTreasury::Internal::Type::ArrayOf[String] |
#email ⇒ String?
The entity's primary email.
98 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 98 required :email, String, nil?: true |
#expected_activity_volume ⇒ Integer?
Monthly expected transaction volume in USD.
104 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 104 required :expected_activity_volume, Integer, nil?: true |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
110 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 110 required :external_id, String, nil?: true |
#first_name ⇒ String?
An individual's first name.
116 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 116 required :first_name, String, nil?: true |
#id ⇒ String
9 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 9 required :id, String |
#identifications ⇒ Array<ModernTreasury::Models::Identification>
A list of identifications for the legal entity.
122 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 122 required :identifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::Identification] } |
#industry_classifications ⇒ Array<ModernTreasury::Models::LegalEntityIndustryClassification>
A list of industry classifications for the legal entity.
128 129 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 128 required :industry_classifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityIndustryClassification] } |
#intended_use ⇒ String?
A description of the intended use of the legal entity.
135 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 135 required :intended_use, String, nil?: true |
#last_name ⇒ String?
An individual's last name.
141 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 141 required :last_name, String, nil?: true |
#legal_entity_associations ⇒ Array<ModernTreasury::Models::LegalEntityAssociation>?
The legal entity associations and its child legal entities.
147 148 149 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 147 required :legal_entity_associations, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAssociation] }, nil?: true |
#legal_entity_type ⇒ Symbol, ModernTreasury::Models::ChildLegalEntity::LegalEntityType
The type of legal entity.
155 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 155 required :legal_entity_type, enum: -> { ModernTreasury::ChildLegalEntity::LegalEntityType } |
#legal_structure ⇒ Symbol, ...
The business's legal structure.
161 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 161 required :legal_structure, enum: -> { ModernTreasury::ChildLegalEntity::LegalStructure }, nil?: true |
#listed_exchange ⇒ String?
ISO 10383 market identifier code.
167 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 167 required :listed_exchange, String, nil?: true |
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
174 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 174 required :live_mode, ModernTreasury::Internal::Type::Boolean |
#metadata ⇒ Hash{Symbol=>String}
Additional data represented as key-value pairs. Both the key and value must be strings.
181 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 181 required :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#middle_name ⇒ String?
An individual's middle name.
187 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 187 required :middle_name, String, nil?: true |
#object ⇒ String
192 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 192 required :object, String |
#operating_jurisdictions ⇒ Array<String>
A list of countries where the business operates, as ISO 3166-1 alpha-2 country codes (e.g. ["US", "CA"]).
199 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 199 required :operating_jurisdictions, ModernTreasury::Internal::Type::ArrayOf[String] |
#phone_numbers ⇒ Array<ModernTreasury::Models::ChildLegalEntity::PhoneNumber>
204 205 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 204 required :phone_numbers, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ChildLegalEntity::PhoneNumber] } |
#politically_exposed_person ⇒ Boolean?
Whether the individual is a politically exposed person.
211 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 211 required :politically_exposed_person, ModernTreasury::Internal::Type::Boolean, nil?: true |
#preferred_name ⇒ String?
An individual's preferred name.
217 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 217 required :preferred_name, String, nil?: true |
#prefix ⇒ String?
An individual's prefix.
223 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 223 required :prefix, String, nil?: true |
#primary_social_media_sites ⇒ Array<String>
A list of the entity's primary social media URLs.
229 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 229 required :primary_social_media_sites, ModernTreasury::Internal::Type::ArrayOf[String] |
#regulators ⇒ Array<ModernTreasury::Models::ChildLegalEntity::Regulator>?
Array of regulatory bodies overseeing this institution.
235 236 237 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 235 required :regulators, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ChildLegalEntity::Regulator] }, nil?: true |
#risk_rating ⇒ Symbol, ...
The risk rating of the legal entity. One of low, medium, high.
243 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 243 required :risk_rating, enum: -> { ModernTreasury::ChildLegalEntity::RiskRating }, nil?: true |
#service_provider_legal_entity_id ⇒ String?
The UUID of the parent legal entity in the service provider tree.
249 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 249 required :service_provider_legal_entity_id, String, nil?: true |
#status ⇒ Symbol, ...
The activation status of the legal entity. One of pending, active, suspended, or denied.
256 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 256 required :status, enum: -> { ModernTreasury::ChildLegalEntity::Status }, nil?: true |
#suffix ⇒ String?
An individual's suffix.
262 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 262 required :suffix, String, nil?: true |
#terms_of_use ⇒ ModernTreasury::Models::ChildLegalEntity::TermsOfUse?
Acceptance of terms of use by the legal entity.
268 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 268 required :terms_of_use, -> { ModernTreasury::ChildLegalEntity::TermsOfUse }, nil?: true |
#third_party_verification ⇒ ModernTreasury::Models::ThirdPartyVerification?
Deprecated. Use third_party_verifications instead.
276 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 276 required :third_party_verification, -> { ModernTreasury::ThirdPartyVerification }, nil?: true |
#third_party_verifications ⇒ Array<ModernTreasury::Models::ThirdPartyVerification>
A list of third-party verifications run by external vendors.
282 283 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 282 required :third_party_verifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ThirdPartyVerification] } |
#ticker_symbol ⇒ String?
Stock ticker symbol for publicly traded companies.
289 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 289 required :ticker_symbol, String, nil?: true |
#updated_at ⇒ Time
294 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 294 required :updated_at, Time |
#wealth_and_employment_details ⇒ ModernTreasury::Models::LegalEntityWealthEmploymentDetail?
299 300 301 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 299 required :wealth_and_employment_details, -> { ModernTreasury::LegalEntityWealthEmploymentDetail }, nil?: true |
#website ⇒ String?
The entity's primary website URL.
307 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 307 required :website, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 537
|
Instance Method Details
#to_hash ⇒ {
207 |
# File 'sig/modern_treasury/models/child_legal_entity.rbs', line 207
def to_hash: -> {
|