Class: ModernTreasury::Models::ChildLegalEntity::Identification

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/child_legal_entity.rb

Defined Under Namespace

Modules: IDType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, discarded_at:, documents:, expiration_date:, id_type:, issuing_country:, issuing_region:, live_mode:, object:, updated_at:) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::ChildLegalEntity::Identification for more details.

Parameters:

  • id (String)
  • created_at (Time)
  • discarded_at (Time, nil)
  • documents (Array<ModernTreasury::Models::Document>)
  • expiration_date (Date, nil)

    The date when the Identification is no longer considered valid by the issuing au

  • id_type (Symbol, ModernTreasury::Models::ChildLegalEntity::Identification::IDType)

    The type of ID number.

  • issuing_country (String, nil)

    The ISO 3166-1 alpha-2 country code of the country that issued the identificatio

  • issuing_region (String, nil)

    The region in which the identifcation was issued.

  • live_mode (Boolean)

    This field will be true if this object exists in the live environment or false i

  • object (String)
  • updated_at (Time)


# File 'lib/modern_treasury/models/child_legal_entity.rb', line 577

Instance Attribute Details

#created_atTime

Returns:

  • (Time)


522
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 522

required :created_at, Time

#discarded_atTime?

Returns:

  • (Time, nil)


527
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 527

required :discarded_at, Time, nil?: true

#documentsArray<ModernTreasury::Models::Document>



532
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 532

required :documents, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::Document] }

#expiration_dateDate?

The date when the Identification is no longer considered valid by the issuing authority.

Returns:

  • (Date, nil)


539
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 539

required :expiration_date, Date, nil?: true

#idString

Returns:

  • (String)


517
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 517

required :id, String

#id_typeSymbol, ModernTreasury::Models::ChildLegalEntity::Identification::IDType

The type of ID number.



545
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 545

required :id_type, enum: -> { ModernTreasury::ChildLegalEntity::Identification::IDType }

#issuing_countryString?

The ISO 3166-1 alpha-2 country code of the country that issued the identification

Returns:

  • (String, nil)


552
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 552

required :issuing_country, String, nil?: true

#issuing_regionString?

The region in which the identifcation was issued.

Returns:

  • (String, nil)


558
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 558

required :issuing_region, String, nil?: true

#live_modeBoolean

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Returns:

  • (Boolean)


565
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 565

required :live_mode, ModernTreasury::Internal::Type::Boolean

#objectString

Returns:

  • (String)


570
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 570

required :object, String

#updated_atTime

Returns:

  • (Time)


575
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 575

required :updated_at, Time