Class: ModernTreasury::Models::ChildLegalEntity::Identification
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::ChildLegalEntity::Identification
- Defined in:
- lib/modern_treasury/models/child_legal_entity.rb
Defined Under Namespace
Modules: IDType
Instance Attribute Summary collapse
- #created_at ⇒ Time
- #discarded_at ⇒ Time?
- #documents ⇒ Array<ModernTreasury::Models::Document>
-
#expiration_date ⇒ Date?
The date when the Identification is no longer considered valid by the issuing authority.
- #id ⇒ String
-
#id_type ⇒ Symbol, ModernTreasury::Models::ChildLegalEntity::Identification::IDType
The type of ID number.
-
#issuing_country ⇒ String?
The ISO 3166-1 alpha-2 country code of the country that issued the identification.
-
#issuing_region ⇒ String?
The region in which the identifcation was issued.
-
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
- #object ⇒ String
- #updated_at ⇒ Time
Instance Method Summary collapse
-
#initialize(id:, created_at:, discarded_at:, documents:, expiration_date:, id_type:, issuing_country:, issuing_region:, live_mode:, object:, updated_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Identification for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, discarded_at:, documents:, expiration_date:, id_type:, issuing_country:, issuing_region:, live_mode:, object:, updated_at:) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::ChildLegalEntity::Identification for more details.
|
|
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 577
|
Instance Attribute Details
#created_at ⇒ Time
522 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 522 required :created_at, Time |
#discarded_at ⇒ Time?
527 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 527 required :discarded_at, Time, nil?: true |
#documents ⇒ Array<ModernTreasury::Models::Document>
532 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 532 required :documents, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::Document] } |
#expiration_date ⇒ Date?
The date when the Identification is no longer considered valid by the issuing authority.
539 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 539 required :expiration_date, Date, nil?: true |
#id ⇒ String
517 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 517 required :id, String |
#id_type ⇒ Symbol, ModernTreasury::Models::ChildLegalEntity::Identification::IDType
The type of ID number.
545 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 545 required :id_type, enum: -> { ModernTreasury::ChildLegalEntity::Identification::IDType } |
#issuing_country ⇒ String?
The ISO 3166-1 alpha-2 country code of the country that issued the identification
552 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 552 required :issuing_country, String, nil?: true |
#issuing_region ⇒ String?
The region in which the identifcation was issued.
558 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 558 required :issuing_region, String, nil?: true |
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
565 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 565 required :live_mode, ModernTreasury::Internal::Type::Boolean |
#object ⇒ String
570 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 570 required :object, String |
#updated_at ⇒ Time
575 |
# File 'lib/modern_treasury/models/child_legal_entity.rb', line 575 required :updated_at, Time |