Class: ModernTreasury::Models::ChildLegalEntityCreate::Document
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::ChildLegalEntityCreate::Document
- Defined in:
- lib/modern_treasury/models/child_legal_entity_create.rb
Defined Under Namespace
Modules: DocumentType
Instance Attribute Summary collapse
-
#document_type ⇒ Symbol, ModernTreasury::Models::ChildLegalEntityCreate::Document::DocumentType
A category given to the document, can be ‘null`.
-
#file_data ⇒ String
Base64-encoded file content for the document.
-
#filename ⇒ String?
The original filename of the document.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(document_type:, file_data:, filename: nil) ⇒ Object
364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 364 class Document < ModernTreasury::Internal::Type::BaseModel # @!attribute document_type # A category given to the document, can be `null`. # # @return [Symbol, ModernTreasury::Models::ChildLegalEntityCreate::Document::DocumentType] required :document_type, enum: -> { ModernTreasury::ChildLegalEntityCreate::Document::DocumentType } # @!attribute file_data # Base64-encoded file content for the document. # # @return [String] required :file_data, String # @!attribute filename # The original filename of the document. # # @return [String, nil] optional :filename, String # @!method initialize(document_type:, file_data:, filename: nil) # @param document_type [Symbol, ModernTreasury::Models::ChildLegalEntityCreate::Document::DocumentType] A category given to the document, can be `null`. # # @param file_data [String] Base64-encoded file content for the document. # # @param filename [String] The original filename of the document. # A category given to the document, can be `null`. # # @see ModernTreasury::Models::ChildLegalEntityCreate::Document#document_type module DocumentType extend ModernTreasury::Internal::Type::Enum ARTICLES_OF_INCORPORATION = :articles_of_incorporation CERTIFICATE_OF_GOOD_STANDING = :certificate_of_good_standing EIN_LETTER = :ein_letter GENERIC = :generic IDENTIFICATION_BACK = :identification_back IDENTIFICATION_FRONT = :identification_front PROOF_OF_ADDRESS = :proof_of_address # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#document_type ⇒ Symbol, ModernTreasury::Models::ChildLegalEntityCreate::Document::DocumentType
A category given to the document, can be ‘null`.
369 |
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 369 required :document_type, enum: -> { ModernTreasury::ChildLegalEntityCreate::Document::DocumentType } |
#file_data ⇒ String
Base64-encoded file content for the document.
375 |
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 375 required :file_data, String |
#filename ⇒ String?
The original filename of the document.
381 |
# File 'lib/modern_treasury/models/child_legal_entity_create.rb', line 381 optional :filename, String |