Class: ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity
- Defined in:
- lib/modern_treasury/models/connection_legal_entity_create_params.rb
Defined Under Namespace
Modules: LegalEntityType, LegalStructure, RiskRating Classes: Document, PhoneNumber, Regulator
Instance Attribute Summary collapse
-
#addresses ⇒ Array<ModernTreasury::Models::LegalEntityAddressCreateRequest>?
A list of addresses for the entity.
- #bank_settings ⇒ ModernTreasury::Models::LegalEntityBankSettings?
-
#business_description ⇒ String?
A description of the business.
-
#business_name ⇒ String?
The business’s legal business name.
-
#citizenship_country ⇒ String?
The country of citizenship for an individual.
- #compliance_details ⇒ Object? deprecated Deprecated.
-
#connection_id ⇒ String?
The connection ID for the connection the legal entity is associated with.
-
#country_of_incorporation ⇒ String?
The country code where the business is incorporated in the ISO 3166-1 alpha-2 or alpha-3 formats.
-
#date_formed ⇒ Date?
A business’s formation date (YYYY-MM-DD).
-
#date_of_birth ⇒ Date?
An individual’s date of birth (YYYY-MM-DD).
-
#documents ⇒ Array<ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::Document>?
A list of documents to attach to the legal entity (e.g. articles of incorporation, certificate of good standing, proof of address).
- #doing_business_as_names ⇒ Array<String>?
-
#email ⇒ String?
The entity’s primary email.
-
#expected_activity_volume ⇒ Integer?
Monthly expected transaction volume in USD.
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
-
#first_name ⇒ String?
An individual’s first name.
-
#identifications ⇒ Array<ModernTreasury::Models::IdentificationCreateRequest>?
A list of identifications for the legal entity.
-
#industry_classifications ⇒ Array<ModernTreasury::Models::LegalEntityIndustryClassification>?
A list of industry classifications for the legal entity.
-
#intended_use ⇒ String?
A description of the intended use of the legal entity.
-
#last_name ⇒ String?
An individual’s last name.
-
#legal_entity_associations ⇒ Array<ModernTreasury::Models::LegalEntityAssociationInlineCreate>?
The legal entity associations and its child legal entities.
-
#legal_entity_type ⇒ Symbol, ...
The type of legal entity.
-
#legal_structure ⇒ Symbol, ...
The business’s legal structure.
-
#listed_exchange ⇒ String?
ISO 10383 market identifier code.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#middle_name ⇒ String?
An individual’s middle name.
-
#operating_jurisdictions ⇒ Array<String>?
A list of countries where the business operates (ISO 3166-1 alpha-2 or alpha-3 codes).
- #phone_numbers ⇒ Array<ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::PhoneNumber>?
-
#politically_exposed_person ⇒ Boolean?
Whether the individual is a politically exposed person.
-
#preferred_name ⇒ String?
An individual’s preferred name.
-
#prefix ⇒ String?
An individual’s prefix.
-
#primary_social_media_sites ⇒ Array<String>?
A list of primary social media URLs for the business.
-
#regulators ⇒ Array<ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::Regulator>?
Array of regulatory bodies overseeing this institution.
-
#risk_rating ⇒ Symbol, ...
The risk rating of the legal entity.
-
#service_provider_legal_entity_id ⇒ String?
The UUID of the parent legal entity in the service provider tree.
-
#suffix ⇒ String?
An individual’s suffix.
- #third_party_verification ⇒ ModernTreasury::Models::ThirdPartyVerification? deprecated Deprecated.
-
#third_party_verifications ⇒ Array<ModernTreasury::Models::ThirdPartyVerification>?
A list of third-party verifications run by external vendors.
-
#ticker_symbol ⇒ String?
Stock ticker symbol for publicly traded companies.
- #wealth_and_employment_details ⇒ ModernTreasury::Models::LegalEntityWealthEmploymentDetail?
-
#website ⇒ String?
The entity’s primary website URL.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(jurisdiction:, name:, registration_number:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Regulator for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(jurisdiction:, name:, registration_number:) ⇒ Object
Some parameter documentations has been truncated, see Regulator for more details.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 37 class LegalEntity < ModernTreasury::Internal::Type::BaseModel # @!attribute addresses # A list of addresses for the entity. # # @return [Array<ModernTreasury::Models::LegalEntityAddressCreateRequest>, nil] optional :addresses, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAddressCreateRequest] } # @!attribute bank_settings # # @return [ModernTreasury::Models::LegalEntityBankSettings, nil] optional :bank_settings, -> { ModernTreasury::LegalEntityBankSettings }, nil?: true # @!attribute business_description # A description of the business. # # @return [String, nil] optional :business_description, String, nil?: true # @!attribute business_name # The business's legal business name. # # @return [String, nil] optional :business_name, String, nil?: true # @!attribute citizenship_country # The country of citizenship for an individual. # # @return [String, nil] optional :citizenship_country, String, nil?: true # @!attribute compliance_details # @deprecated # # @return [Object, nil] optional :compliance_details, ModernTreasury::Internal::Type::Unknown, nil?: true # @!attribute connection_id # The connection ID for the connection the legal entity is associated with. # Defaults to the id of the connection designated with an is_default value of true # or the id of an existing operational connection if only one is available. Pass # in a value of null to prevent the connection from being associated with the # legal entity. # # @return [String, nil] optional :connection_id, String, nil?: true # @!attribute country_of_incorporation # The country code where the business is incorporated in the ISO 3166-1 alpha-2 or # alpha-3 formats. # # @return [String, nil] optional :country_of_incorporation, String, nil?: true # @!attribute date_formed # A business's formation date (YYYY-MM-DD). # # @return [Date, nil] optional :date_formed, Date, nil?: true # @!attribute date_of_birth # An individual's date of birth (YYYY-MM-DD). # # @return [Date, nil] optional :date_of_birth, Date, nil?: true # @!attribute documents # A list of documents to attach to the legal entity (e.g. articles of # incorporation, certificate of good standing, proof of address). # # @return [Array<ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::Document>, nil] optional :documents, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ConnectionLegalEntityCreateParams::LegalEntity::Document] } # @!attribute doing_business_as_names # # @return [Array<String>, nil] optional :doing_business_as_names, ModernTreasury::Internal::Type::ArrayOf[String] # @!attribute email # The entity's primary email. # # @return [String, nil] optional :email, String, nil?: true # @!attribute expected_activity_volume # Monthly expected transaction volume in USD. # # @return [Integer, nil] optional :expected_activity_volume, Integer, nil?: true # @!attribute external_id # An optional user-defined 180 character unique identifier. # # @return [String, nil] optional :external_id, String, nil?: true # @!attribute first_name # An individual's first name. # # @return [String, nil] optional :first_name, String, nil?: true # @!attribute identifications # A list of identifications for the legal entity. # # @return [Array<ModernTreasury::Models::IdentificationCreateRequest>, nil] optional :identifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::IdentificationCreateRequest] } # @!attribute industry_classifications # A list of industry classifications for the legal entity. # # @return [Array<ModernTreasury::Models::LegalEntityIndustryClassification>, nil] optional :industry_classifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityIndustryClassification] } # @!attribute intended_use # A description of the intended use of the legal entity. # # @return [String, nil] optional :intended_use, String, nil?: true # @!attribute last_name # An individual's last name. # # @return [String, nil] optional :last_name, String, nil?: true # @!attribute legal_entity_associations # The legal entity associations and its child legal entities. # # @return [Array<ModernTreasury::Models::LegalEntityAssociationInlineCreate>, nil] optional :legal_entity_associations, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAssociationInlineCreate] }, nil?: true # @!attribute legal_entity_type # The type of legal entity. # # @return [Symbol, ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::LegalEntityType, nil] optional :legal_entity_type, enum: -> { ModernTreasury::ConnectionLegalEntityCreateParams::LegalEntity::LegalEntityType } # @!attribute legal_structure # The business's legal structure. # # @return [Symbol, ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::LegalStructure, nil] optional :legal_structure, enum: -> { ModernTreasury::ConnectionLegalEntityCreateParams::LegalEntity::LegalStructure }, nil?: true # @!attribute listed_exchange # ISO 10383 market identifier code. # # @return [String, nil] optional :listed_exchange, String, nil?: true # @!attribute metadata # Additional data represented as key-value pairs. Both the key and value must be # strings. # # @return [Hash{Symbol=>String}, nil] optional :metadata, ModernTreasury::Internal::Type::HashOf[String] # @!attribute middle_name # An individual's middle name. # # @return [String, nil] optional :middle_name, String, nil?: true # @!attribute operating_jurisdictions # A list of countries where the business operates (ISO 3166-1 alpha-2 or alpha-3 # codes). # # @return [Array<String>, nil] optional :operating_jurisdictions, ModernTreasury::Internal::Type::ArrayOf[String] # @!attribute phone_numbers # # @return [Array<ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::PhoneNumber>, nil] optional :phone_numbers, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ConnectionLegalEntityCreateParams::LegalEntity::PhoneNumber] } # @!attribute politically_exposed_person # Whether the individual is a politically exposed person. # # @return [Boolean, nil] optional :politically_exposed_person, ModernTreasury::Internal::Type::Boolean, nil?: true # @!attribute preferred_name # An individual's preferred name. # # @return [String, nil] optional :preferred_name, String, nil?: true # @!attribute prefix # An individual's prefix. # # @return [String, nil] optional :prefix, String, nil?: true # @!attribute primary_social_media_sites # A list of primary social media URLs for the business. # # @return [Array<String>, nil] optional :primary_social_media_sites, ModernTreasury::Internal::Type::ArrayOf[String] # @!attribute regulators # Array of regulatory bodies overseeing this institution. # # @return [Array<ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::Regulator>, nil] optional :regulators, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ConnectionLegalEntityCreateParams::LegalEntity::Regulator] }, nil?: true # @!attribute risk_rating # The risk rating of the legal entity. One of low, medium, high. # # @return [Symbol, ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::RiskRating, nil] optional :risk_rating, enum: -> { ModernTreasury::ConnectionLegalEntityCreateParams::LegalEntity::RiskRating }, nil?: true # @!attribute service_provider_legal_entity_id # The UUID of the parent legal entity in the service provider tree. # # @return [String, nil] optional :service_provider_legal_entity_id, String, nil?: true # @!attribute suffix # An individual's suffix. # # @return [String, nil] optional :suffix, String, nil?: true # @!attribute third_party_verification # @deprecated # # Deprecated. Use `third_party_verifications` instead. # # @return [ModernTreasury::Models::ThirdPartyVerification, nil] optional :third_party_verification, -> { ModernTreasury::ThirdPartyVerification }, nil?: true # @!attribute third_party_verifications # A list of third-party verifications run by external vendors. # # @return [Array<ModernTreasury::Models::ThirdPartyVerification>, nil] optional :third_party_verifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ThirdPartyVerification] } # @!attribute ticker_symbol # Stock ticker symbol for publicly traded companies. # # @return [String, nil] optional :ticker_symbol, String, nil?: true # @!attribute wealth_and_employment_details # # @return [ModernTreasury::Models::LegalEntityWealthEmploymentDetail, nil] optional :wealth_and_employment_details, -> { ModernTreasury::LegalEntityWealthEmploymentDetail }, nil?: true # @!attribute website # The entity's primary website URL. # # @return [String, nil] optional :website, String, nil?: true # @!method initialize(addresses: nil, bank_settings: nil, business_description: nil, business_name: nil, citizenship_country: nil, compliance_details: nil, connection_id: nil, country_of_incorporation: nil, date_formed: nil, date_of_birth: nil, documents: nil, doing_business_as_names: nil, email: nil, expected_activity_volume: nil, external_id: nil, first_name: nil, identifications: nil, industry_classifications: nil, intended_use: nil, last_name: nil, legal_entity_associations: nil, legal_entity_type: nil, legal_structure: nil, listed_exchange: nil, metadata: nil, middle_name: nil, operating_jurisdictions: nil, phone_numbers: nil, politically_exposed_person: nil, preferred_name: nil, prefix: nil, primary_social_media_sites: nil, regulators: nil, risk_rating: nil, service_provider_legal_entity_id: nil, suffix: nil, third_party_verification: nil, third_party_verifications: nil, ticker_symbol: nil, wealth_and_employment_details: nil, website: nil) # Some parameter documentations has been truncated, see # {ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity} for # more details. # # The legal entity. # # @param addresses [Array<ModernTreasury::Models::LegalEntityAddressCreateRequest>] A list of addresses for the entity. # # @param bank_settings [ModernTreasury::Models::LegalEntityBankSettings, nil] # # @param business_description [String, nil] A description of the business. # # @param business_name [String, nil] The business's legal business name. # # @param citizenship_country [String, nil] The country of citizenship for an individual. # # @param compliance_details [Object, nil] # # @param connection_id [String, nil] The connection ID for the connection the legal entity is associated with. Defaul # # @param country_of_incorporation [String, nil] The country code where the business is incorporated in the ISO 3166-1 alpha-2 or # # @param date_formed [Date, nil] A business's formation date (YYYY-MM-DD). # # @param date_of_birth [Date, nil] An individual's date of birth (YYYY-MM-DD). # # @param documents [Array<ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::Document>] A list of documents to attach to the legal entity (e.g. articles of incorporatio # # @param doing_business_as_names [Array<String>] # # @param email [String, nil] The entity's primary email. # # @param expected_activity_volume [Integer, nil] Monthly expected transaction volume in USD. # # @param external_id [String, nil] An optional user-defined 180 character unique identifier. # # @param first_name [String, nil] An individual's first name. # # @param identifications [Array<ModernTreasury::Models::IdentificationCreateRequest>] A list of identifications for the legal entity. # # @param industry_classifications [Array<ModernTreasury::Models::LegalEntityIndustryClassification>] A list of industry classifications for the legal entity. # # @param intended_use [String, nil] A description of the intended use of the legal entity. # # @param last_name [String, nil] An individual's last name. # # @param legal_entity_associations [Array<ModernTreasury::Models::LegalEntityAssociationInlineCreate>, nil] The legal entity associations and its child legal entities. # # @param legal_entity_type [Symbol, ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::LegalEntityType] The type of legal entity. # # @param legal_structure [Symbol, ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::LegalStructure, nil] The business's legal structure. # # @param listed_exchange [String, nil] ISO 10383 market identifier code. # # @param metadata [Hash{Symbol=>String}] Additional data represented as key-value pairs. Both the key and value must be s # # @param middle_name [String, nil] An individual's middle name. # # @param operating_jurisdictions [Array<String>] A list of countries where the business operates (ISO 3166-1 alpha-2 or alpha-3 c # # @param phone_numbers [Array<ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::PhoneNumber>] # # @param politically_exposed_person [Boolean, nil] Whether the individual is a politically exposed person. # # @param preferred_name [String, nil] An individual's preferred name. # # @param prefix [String, nil] An individual's prefix. # # @param primary_social_media_sites [Array<String>] A list of primary social media URLs for the business. # # @param regulators [Array<ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::Regulator>, nil] Array of regulatory bodies overseeing this institution. # # @param risk_rating [Symbol, ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::RiskRating, nil] The risk rating of the legal entity. One of low, medium, high. # # @param service_provider_legal_entity_id [String, nil] The UUID of the parent legal entity in the service provider tree. # # @param suffix [String, nil] An individual's suffix. # # @param third_party_verification [ModernTreasury::Models::ThirdPartyVerification, nil] Deprecated. Use `third_party_verifications` instead. # # @param third_party_verifications [Array<ModernTreasury::Models::ThirdPartyVerification>] A list of third-party verifications run by external vendors. # # @param ticker_symbol [String, nil] Stock ticker symbol for publicly traded companies. # # @param wealth_and_employment_details [ModernTreasury::Models::LegalEntityWealthEmploymentDetail, nil] # # @param website [String, nil] The entity's primary website URL. class Document < ModernTreasury::Internal::Type::BaseModel # @!attribute document_type # A category given to the document, can be `null`. # # @return [Symbol, ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::Document::DocumentType] required :document_type, enum: -> { ModernTreasury::ConnectionLegalEntityCreateParams::LegalEntity::Document::DocumentType } # @!attribute file_data # Base64-encoded file content for the document. # # @return [String] required :file_data, String # @!attribute filename # The original filename of the document. # # @return [String, nil] optional :filename, String # @!method initialize(document_type:, file_data:, filename: nil) # @param document_type [Symbol, ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::Document::DocumentType] A category given to the document, can be `null`. # # @param file_data [String] Base64-encoded file content for the document. # # @param filename [String] The original filename of the document. # A category given to the document, can be `null`. # # @see ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::Document#document_type module DocumentType extend ModernTreasury::Internal::Type::Enum ARTICLES_OF_INCORPORATION = :articles_of_incorporation CERTIFICATE_OF_GOOD_STANDING = :certificate_of_good_standing EIN_LETTER = :ein_letter GENERIC = :generic IDENTIFICATION_BACK = :identification_back IDENTIFICATION_FRONT = :identification_front PROOF_OF_ADDRESS = :proof_of_address # @!method self.values # @return [Array<Symbol>] end end # The type of legal entity. # # @see ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity#legal_entity_type module LegalEntityType extend ModernTreasury::Internal::Type::Enum BUSINESS = :business INDIVIDUAL = :individual # @!method self.values # @return [Array<Symbol>] end # The business's legal structure. # # @see ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity#legal_structure module LegalStructure extend ModernTreasury::Internal::Type::Enum CORPORATION = :corporation LLC = :llc NON_PROFIT = :non_profit PARTNERSHIP = :partnership SOLE_PROPRIETORSHIP = :sole_proprietorship TRUST = :trust # @!method self.values # @return [Array<Symbol>] end class PhoneNumber < ModernTreasury::Internal::Type::BaseModel # @!attribute phone_number # # @return [String, nil] optional :phone_number, String # @!method initialize(phone_number: nil) # A list of phone numbers in E.164 format. # # @param phone_number [String] end class Regulator < ModernTreasury::Internal::Type::BaseModel # @!attribute jurisdiction # The country code where the regulator operates in the ISO 3166-1 alpha-2 format # (e.g., "US", "CA", "GB"). # # @return [String] required :jurisdiction, String # @!attribute name # Full name of the regulatory body. # # @return [String] required :name, String # @!attribute registration_number # Registration or identification number with the regulator. # # @return [String] required :registration_number, String # @!method initialize(jurisdiction:, name:, registration_number:) # Some parameter documentations has been truncated, see # {ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::Regulator} # for more details. # # @param jurisdiction [String] The country code where the regulator operates in the ISO 3166-1 alpha-2 format ( # # @param name [String] Full name of the regulatory body. # # @param registration_number [String] Registration or identification number with the regulator. end # The risk rating of the legal entity. One of low, medium, high. # # @see ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity#risk_rating module RiskRating extend ModernTreasury::Internal::Type::Enum LOW = :low MEDIUM = :medium HIGH = :high # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#addresses ⇒ Array<ModernTreasury::Models::LegalEntityAddressCreateRequest>?
A list of addresses for the entity.
42 43 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 42 optional :addresses, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAddressCreateRequest] } |
#bank_settings ⇒ ModernTreasury::Models::LegalEntityBankSettings?
48 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 48 optional :bank_settings, -> { ModernTreasury::LegalEntityBankSettings }, nil?: true |
#business_description ⇒ String?
A description of the business.
54 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 54 optional :business_description, String, nil?: true |
#business_name ⇒ String?
The business’s legal business name.
60 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 60 optional :business_name, String, nil?: true |
#citizenship_country ⇒ String?
The country of citizenship for an individual.
66 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 66 optional :citizenship_country, String, nil?: true |
#compliance_details ⇒ Object?
72 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 72 optional :compliance_details, ModernTreasury::Internal::Type::Unknown, nil?: true |
#connection_id ⇒ String?
The connection ID for the connection the legal entity is associated with. Defaults to the id of the connection designated with an is_default value of true or the id of an existing operational connection if only one is available. Pass in a value of null to prevent the connection from being associated with the legal entity.
82 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 82 optional :connection_id, String, nil?: true |
#country_of_incorporation ⇒ String?
The country code where the business is incorporated in the ISO 3166-1 alpha-2 or alpha-3 formats.
89 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 89 optional :country_of_incorporation, String, nil?: true |
#date_formed ⇒ Date?
A business’s formation date (YYYY-MM-DD).
95 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 95 optional :date_formed, Date, nil?: true |
#date_of_birth ⇒ Date?
An individual’s date of birth (YYYY-MM-DD).
101 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 101 optional :date_of_birth, Date, nil?: true |
#documents ⇒ Array<ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::Document>?
A list of documents to attach to the legal entity (e.g. articles of incorporation, certificate of good standing, proof of address).
108 109 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 108 optional :documents, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ConnectionLegalEntityCreateParams::LegalEntity::Document] } |
#doing_business_as_names ⇒ Array<String>?
114 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 114 optional :doing_business_as_names, ModernTreasury::Internal::Type::ArrayOf[String] |
#email ⇒ String?
The entity’s primary email.
120 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 120 optional :email, String, nil?: true |
#expected_activity_volume ⇒ Integer?
Monthly expected transaction volume in USD.
126 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 126 optional :expected_activity_volume, Integer, nil?: true |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
132 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 132 optional :external_id, String, nil?: true |
#first_name ⇒ String?
An individual’s first name.
138 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 138 optional :first_name, String, nil?: true |
#identifications ⇒ Array<ModernTreasury::Models::IdentificationCreateRequest>?
A list of identifications for the legal entity.
144 145 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 144 optional :identifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::IdentificationCreateRequest] } |
#industry_classifications ⇒ Array<ModernTreasury::Models::LegalEntityIndustryClassification>?
A list of industry classifications for the legal entity.
151 152 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 151 optional :industry_classifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityIndustryClassification] } |
#intended_use ⇒ String?
A description of the intended use of the legal entity.
158 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 158 optional :intended_use, String, nil?: true |
#last_name ⇒ String?
An individual’s last name.
164 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 164 optional :last_name, String, nil?: true |
#legal_entity_associations ⇒ Array<ModernTreasury::Models::LegalEntityAssociationInlineCreate>?
The legal entity associations and its child legal entities.
170 171 172 173 174 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 170 optional :legal_entity_associations, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAssociationInlineCreate] }, nil?: true |
#legal_entity_type ⇒ Symbol, ...
The type of legal entity.
180 181 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 180 optional :legal_entity_type, enum: -> { ModernTreasury::ConnectionLegalEntityCreateParams::LegalEntity::LegalEntityType } |
#legal_structure ⇒ Symbol, ...
The business’s legal structure.
187 188 189 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 187 optional :legal_structure, enum: -> { ModernTreasury::ConnectionLegalEntityCreateParams::LegalEntity::LegalStructure }, nil?: true |
#listed_exchange ⇒ String?
ISO 10383 market identifier code.
195 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 195 optional :listed_exchange, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
202 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 202 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#middle_name ⇒ String?
An individual’s middle name.
208 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 208 optional :middle_name, String, nil?: true |
#operating_jurisdictions ⇒ Array<String>?
A list of countries where the business operates (ISO 3166-1 alpha-2 or alpha-3 codes).
215 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 215 optional :operating_jurisdictions, ModernTreasury::Internal::Type::ArrayOf[String] |
#phone_numbers ⇒ Array<ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::PhoneNumber>?
220 221 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 220 optional :phone_numbers, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ConnectionLegalEntityCreateParams::LegalEntity::PhoneNumber] } |
#politically_exposed_person ⇒ Boolean?
Whether the individual is a politically exposed person.
227 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 227 optional :politically_exposed_person, ModernTreasury::Internal::Type::Boolean, nil?: true |
#preferred_name ⇒ String?
An individual’s preferred name.
233 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 233 optional :preferred_name, String, nil?: true |
#prefix ⇒ String?
An individual’s prefix.
239 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 239 optional :prefix, String, nil?: true |
#primary_social_media_sites ⇒ Array<String>?
A list of primary social media URLs for the business.
245 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 245 optional :primary_social_media_sites, ModernTreasury::Internal::Type::ArrayOf[String] |
#regulators ⇒ Array<ModernTreasury::Models::ConnectionLegalEntityCreateParams::LegalEntity::Regulator>?
Array of regulatory bodies overseeing this institution.
251 252 253 254 255 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 251 optional :regulators, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ConnectionLegalEntityCreateParams::LegalEntity::Regulator] }, nil?: true |
#risk_rating ⇒ Symbol, ...
The risk rating of the legal entity. One of low, medium, high.
261 262 263 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 261 optional :risk_rating, enum: -> { ModernTreasury::ConnectionLegalEntityCreateParams::LegalEntity::RiskRating }, nil?: true |
#service_provider_legal_entity_id ⇒ String?
The UUID of the parent legal entity in the service provider tree.
269 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 269 optional :service_provider_legal_entity_id, String, nil?: true |
#suffix ⇒ String?
An individual’s suffix.
275 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 275 optional :suffix, String, nil?: true |
#third_party_verification ⇒ ModernTreasury::Models::ThirdPartyVerification?
Deprecated. Use ‘third_party_verifications` instead.
283 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 283 optional :third_party_verification, -> { ModernTreasury::ThirdPartyVerification }, nil?: true |
#third_party_verifications ⇒ Array<ModernTreasury::Models::ThirdPartyVerification>?
A list of third-party verifications run by external vendors.
289 290 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 289 optional :third_party_verifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ThirdPartyVerification] } |
#ticker_symbol ⇒ String?
Stock ticker symbol for publicly traded companies.
296 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 296 optional :ticker_symbol, String, nil?: true |
#wealth_and_employment_details ⇒ ModernTreasury::Models::LegalEntityWealthEmploymentDetail?
301 302 303 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 301 optional :wealth_and_employment_details, -> { ModernTreasury::LegalEntityWealthEmploymentDetail }, nil?: true |
#website ⇒ String?
The entity’s primary website URL.
309 |
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 309 optional :website, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/connection_legal_entity_create_params.rb', line 441
|