Class: ModernTreasury::Models::CounterpartyCreateParams::LegalEntity

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/counterparty_create_params.rb,
sig/modern_treasury/models/counterparty_create_params.rbs

Defined Under Namespace

Modules: LegalEntityType, LegalStructure, RiskRating Classes: Document, PhoneNumber, Regulator, TermsOfUse

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(jurisdiction:, name:, registration_number:) ⇒ Object

Some parameter documentations has been truncated, see Regulator for more details.

Parameters:

  • jurisdiction (String)

    The country code where the regulator operates in the ISO 3166-1 alpha-2 format (

  • name (String)

    Full name of the regulatory body.

  • registration_number (String)

    Registration or identification number with the regulator.



# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 704

Instance Attribute Details

#addressesArray<ModernTreasury::Models::LegalEntityAddressCreateRequest>?

A list of addresses for the entity.



434
435
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 434

optional :addresses,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAddressCreateRequest] }

#bank_settingsModernTreasury::Models::LegalEntityBankSettings?



440
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 440

optional :bank_settings, -> { ModernTreasury::LegalEntityBankSettings }, nil?: true

#business_descriptionString?

A description of the business.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


446
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 446

optional :business_description, String, nil?: true

#business_nameString?

The business's legal business name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


452
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 452

optional :business_name, String, nil?: true

#citizenship_countryString?

The country of citizenship for an individual.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


458
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 458

optional :citizenship_country, String, nil?: true

#compliance_detailsObject?

Deprecated.

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


464
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 464

optional :compliance_details, ModernTreasury::Internal::Type::Unknown, nil?: true

#connection_idString?

The connection ID for the connection the legal entity is associated with. Defaults to the id of the connection designated with an is_default value of true or the id of an existing operational connection if only one is available. Pass in a value of null to prevent the connection from being associated with the legal entity.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


474
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 474

optional :connection_id, String, nil?: true

#country_of_incorporationString?

The country code where the business is incorporated in the ISO 3166-1 alpha-2 or alpha-3 formats.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


481
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 481

optional :country_of_incorporation, String, nil?: true

#date_formedDate?

A business's formation date (YYYY-MM-DD).

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


487
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 487

optional :date_formed, Date, nil?: true

#date_of_birthDate?

An individual's date of birth (YYYY-MM-DD).

Parameters:

  • value (Date, nil)

Returns:

  • (Date, nil)


493
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 493

optional :date_of_birth, Date, nil?: true

#documentsArray<ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::Document>?

A list of documents to attach to the legal entity (e.g. articles of incorporation, certificate of good standing, proof of address).



500
501
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 500

optional :documents,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::CounterpartyCreateParams::LegalEntity::Document] }

#doing_business_as_namesArray<String>?

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


506
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 506

optional :doing_business_as_names, ModernTreasury::Internal::Type::ArrayOf[String]

#emailString?

The entity's primary email.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


512
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 512

optional :email, String, nil?: true

#expected_activity_volumeInteger?

Monthly expected transaction volume in USD.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


518
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 518

optional :expected_activity_volume, Integer, nil?: true

#external_idString?

An optional user-defined 180 character unique identifier.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


524
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 524

optional :external_id, String, nil?: true

#first_nameString?

An individual's first name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


530
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 530

optional :first_name, String, nil?: true

#identificationsArray<ModernTreasury::Models::IdentificationCreateRequest>?

A list of identifications for the legal entity.



536
537
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 536

optional :identifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::IdentificationCreateRequest] }

#industry_classificationsArray<ModernTreasury::Models::LegalEntityIndustryClassification>?

A list of industry classifications for the legal entity.



543
544
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 543

optional :industry_classifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityIndustryClassification] }

#intended_useString?

A description of the intended use of the legal entity.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


550
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 550

optional :intended_use, String, nil?: true

#last_nameString?

An individual's last name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


556
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 556

optional :last_name, String, nil?: true

The legal entity associations and its child legal entities.



562
563
564
565
566
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 562

optional :legal_entity_associations,
-> {
  ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAssociationInlineCreate]
},
nil?: true

The type of legal entity.

Parameters:

  • value (ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::legal_entity_type)

Returns:



427
428
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 427

required :legal_entity_type,
enum: -> { ModernTreasury::CounterpartyCreateParams::LegalEntity::LegalEntityType }

The business's legal structure.

Parameters:

  • value (ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::legal_structure, nil)

Returns:



572
573
574
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 572

optional :legal_structure,
enum: -> { ModernTreasury::CounterpartyCreateParams::LegalEntity::LegalStructure },
nil?: true

#listed_exchangeString?

ISO 10383 market identifier code.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


580
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 580

optional :listed_exchange, String, nil?: true

#metadataHash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


587
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 587

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#middle_nameString?

An individual's middle name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


593
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 593

optional :middle_name, String, nil?: true

#operating_jurisdictionsArray<String>?

A list of countries where the business operates (ISO 3166-1 alpha-2 or alpha-3 codes).

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


600
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 600

optional :operating_jurisdictions, ModernTreasury::Internal::Type::ArrayOf[String]

#phone_numbersArray<ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::PhoneNumber>?



605
606
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 605

optional :phone_numbers,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::CounterpartyCreateParams::LegalEntity::PhoneNumber] }

#politically_exposed_personBoolean?

Whether the individual is a politically exposed person.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


612
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 612

optional :politically_exposed_person, ModernTreasury::Internal::Type::Boolean, nil?: true

#preferred_nameString?

An individual's preferred name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


618
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 618

optional :preferred_name, String, nil?: true

#prefixString?

An individual's prefix.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


624
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 624

optional :prefix, String, nil?: true

#primary_social_media_sitesArray<String>?

A list of primary social media URLs for the business.

Parameters:

  • (::Array[String])

Returns:

  • (Array<String>, nil)


630
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 630

optional :primary_social_media_sites, ModernTreasury::Internal::Type::ArrayOf[String]

#regulatorsArray<ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::Regulator>?

Array of regulatory bodies overseeing this institution.

Parameters:

  • value (::Array[ModernTreasury::CounterpartyCreateParams::LegalEntity::Regulator], nil)

Returns:



636
637
638
639
640
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 636

optional :regulators,
-> {
  ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::CounterpartyCreateParams::LegalEntity::Regulator]
},
nil?: true

#risk_ratingSymbol, ...

The risk rating of the legal entity. One of low, medium, high.

Parameters:

  • value (ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::risk_rating, nil)

Returns:



646
647
648
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 646

optional :risk_rating,
enum: -> { ModernTreasury::CounterpartyCreateParams::LegalEntity::RiskRating },
nil?: true

The UUID of the parent legal entity in the service provider tree.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


654
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 654

optional :service_provider_legal_entity_id, String, nil?: true

#suffixString?

An individual's suffix.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


660
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 660

optional :suffix, String, nil?: true

#terms_of_useModernTreasury::Models::CounterpartyCreateParams::LegalEntity::TermsOfUse?

Acceptance of terms of use by the legal entity.

Parameters:

  • value (ModernTreasury::CounterpartyCreateParams::LegalEntity::TermsOfUse, nil)

Returns:



666
667
668
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 666

optional :terms_of_use,
-> { ModernTreasury::CounterpartyCreateParams::LegalEntity::TermsOfUse },
nil?: true

#third_party_verificationModernTreasury::Models::ThirdPartyVerification?

Deprecated.

Deprecated. Use third_party_verifications instead.



676
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 676

optional :third_party_verification, -> { ModernTreasury::ThirdPartyVerification }, nil?: true

#third_party_verificationsArray<ModernTreasury::Models::ThirdPartyVerification>?

A list of third-party verifications run by external vendors.



682
683
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 682

optional :third_party_verifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ThirdPartyVerification] }

#ticker_symbolString?

Stock ticker symbol for publicly traded companies.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


689
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 689

optional :ticker_symbol, String, nil?: true

#wealth_and_employment_detailsModernTreasury::Models::LegalEntityWealthEmploymentDetail?



694
695
696
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 694

optional :wealth_and_employment_details,
-> { ModernTreasury::LegalEntityWealthEmploymentDetail },
nil?: true

#websiteString?

The entity's primary website URL.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


702
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 702

optional :website, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 802

Instance Method Details

#to_hash{

Returns:

  • ({)


679
# File 'sig/modern_treasury/models/counterparty_create_params.rbs', line 679

def to_hash: -> {