Class: ModernTreasury::Models::CounterpartyCreateParams::LegalEntity
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::CounterpartyCreateParams::LegalEntity
- Defined in:
- lib/modern_treasury/models/counterparty_create_params.rb,
sig/modern_treasury/models/counterparty_create_params.rbs
Defined Under Namespace
Modules: LegalEntityType, LegalStructure, RiskRating Classes: Document, PhoneNumber, Regulator, TermsOfUse
Instance Attribute Summary collapse
-
#addresses ⇒ Array<ModernTreasury::Models::LegalEntityAddressCreateRequest>?
A list of addresses for the entity.
- #bank_settings ⇒ ModernTreasury::Models::LegalEntityBankSettings?
-
#business_description ⇒ String?
A description of the business.
-
#business_name ⇒ String?
The business's legal business name.
-
#citizenship_country ⇒ String?
The country of citizenship for an individual.
- #compliance_details ⇒ Object? deprecated Deprecated.
-
#connection_id ⇒ String?
The connection ID for the connection the legal entity is associated with.
-
#country_of_incorporation ⇒ String?
The country code where the business is incorporated in the ISO 3166-1 alpha-2 or alpha-3 formats.
-
#date_formed ⇒ Date?
A business's formation date (YYYY-MM-DD).
-
#date_of_birth ⇒ Date?
An individual's date of birth (YYYY-MM-DD).
-
#documents ⇒ Array<ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::Document>?
A list of documents to attach to the legal entity (e.g. articles of incorporation, certificate of good standing, proof of address).
- #doing_business_as_names ⇒ Array<String>?
-
#email ⇒ String?
The entity's primary email.
-
#expected_activity_volume ⇒ Integer?
Monthly expected transaction volume in USD.
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
-
#first_name ⇒ String?
An individual's first name.
-
#identifications ⇒ Array<ModernTreasury::Models::IdentificationCreateRequest>?
A list of identifications for the legal entity.
-
#industry_classifications ⇒ Array<ModernTreasury::Models::LegalEntityIndustryClassification>?
A list of industry classifications for the legal entity.
-
#intended_use ⇒ String?
A description of the intended use of the legal entity.
-
#last_name ⇒ String?
An individual's last name.
-
#legal_entity_associations ⇒ Array<ModernTreasury::Models::LegalEntityAssociationInlineCreate>?
The legal entity associations and its child legal entities.
-
#legal_entity_type ⇒ Symbol, ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::LegalEntityType
The type of legal entity.
-
#legal_structure ⇒ Symbol, ...
The business's legal structure.
-
#listed_exchange ⇒ String?
ISO 10383 market identifier code.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#middle_name ⇒ String?
An individual's middle name.
-
#operating_jurisdictions ⇒ Array<String>?
A list of countries where the business operates (ISO 3166-1 alpha-2 or alpha-3 codes).
- #phone_numbers ⇒ Array<ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::PhoneNumber>?
-
#politically_exposed_person ⇒ Boolean?
Whether the individual is a politically exposed person.
-
#preferred_name ⇒ String?
An individual's preferred name.
-
#prefix ⇒ String?
An individual's prefix.
-
#primary_social_media_sites ⇒ Array<String>?
A list of primary social media URLs for the business.
-
#regulators ⇒ Array<ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::Regulator>?
Array of regulatory bodies overseeing this institution.
-
#risk_rating ⇒ Symbol, ...
The risk rating of the legal entity.
-
#service_provider_legal_entity_id ⇒ String?
The UUID of the parent legal entity in the service provider tree.
-
#suffix ⇒ String?
An individual's suffix.
-
#terms_of_use ⇒ ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::TermsOfUse?
Acceptance of terms of use by the legal entity.
- #third_party_verification ⇒ ModernTreasury::Models::ThirdPartyVerification? deprecated Deprecated.
-
#third_party_verifications ⇒ Array<ModernTreasury::Models::ThirdPartyVerification>?
A list of third-party verifications run by external vendors.
-
#ticker_symbol ⇒ String?
Stock ticker symbol for publicly traded companies.
- #wealth_and_employment_details ⇒ ModernTreasury::Models::LegalEntityWealthEmploymentDetail?
-
#website ⇒ String?
The entity's primary website URL.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(jurisdiction:, name:, registration_number:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Regulator for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(jurisdiction:, name:, registration_number:) ⇒ Object
Some parameter documentations has been truncated, see Regulator for more details.
|
|
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 704
|
Instance Attribute Details
#addresses ⇒ Array<ModernTreasury::Models::LegalEntityAddressCreateRequest>?
A list of addresses for the entity.
434 435 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 434 optional :addresses, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAddressCreateRequest] } |
#bank_settings ⇒ ModernTreasury::Models::LegalEntityBankSettings?
440 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 440 optional :bank_settings, -> { ModernTreasury::LegalEntityBankSettings }, nil?: true |
#business_description ⇒ String?
A description of the business.
446 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 446 optional :business_description, String, nil?: true |
#business_name ⇒ String?
The business's legal business name.
452 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 452 optional :business_name, String, nil?: true |
#citizenship_country ⇒ String?
The country of citizenship for an individual.
458 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 458 optional :citizenship_country, String, nil?: true |
#compliance_details ⇒ Object?
464 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 464 optional :compliance_details, ModernTreasury::Internal::Type::Unknown, nil?: true |
#connection_id ⇒ String?
The connection ID for the connection the legal entity is associated with. Defaults to the id of the connection designated with an is_default value of true or the id of an existing operational connection if only one is available. Pass in a value of null to prevent the connection from being associated with the legal entity.
474 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 474 optional :connection_id, String, nil?: true |
#country_of_incorporation ⇒ String?
The country code where the business is incorporated in the ISO 3166-1 alpha-2 or alpha-3 formats.
481 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 481 optional :country_of_incorporation, String, nil?: true |
#date_formed ⇒ Date?
A business's formation date (YYYY-MM-DD).
487 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 487 optional :date_formed, Date, nil?: true |
#date_of_birth ⇒ Date?
An individual's date of birth (YYYY-MM-DD).
493 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 493 optional :date_of_birth, Date, nil?: true |
#documents ⇒ Array<ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::Document>?
A list of documents to attach to the legal entity (e.g. articles of incorporation, certificate of good standing, proof of address).
500 501 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 500 optional :documents, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::CounterpartyCreateParams::LegalEntity::Document] } |
#doing_business_as_names ⇒ Array<String>?
506 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 506 optional :doing_business_as_names, ModernTreasury::Internal::Type::ArrayOf[String] |
#email ⇒ String?
The entity's primary email.
512 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 512 optional :email, String, nil?: true |
#expected_activity_volume ⇒ Integer?
Monthly expected transaction volume in USD.
518 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 518 optional :expected_activity_volume, Integer, nil?: true |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
524 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 524 optional :external_id, String, nil?: true |
#first_name ⇒ String?
An individual's first name.
530 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 530 optional :first_name, String, nil?: true |
#identifications ⇒ Array<ModernTreasury::Models::IdentificationCreateRequest>?
A list of identifications for the legal entity.
536 537 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 536 optional :identifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::IdentificationCreateRequest] } |
#industry_classifications ⇒ Array<ModernTreasury::Models::LegalEntityIndustryClassification>?
A list of industry classifications for the legal entity.
543 544 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 543 optional :industry_classifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityIndustryClassification] } |
#intended_use ⇒ String?
A description of the intended use of the legal entity.
550 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 550 optional :intended_use, String, nil?: true |
#last_name ⇒ String?
An individual's last name.
556 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 556 optional :last_name, String, nil?: true |
#legal_entity_associations ⇒ Array<ModernTreasury::Models::LegalEntityAssociationInlineCreate>?
The legal entity associations and its child legal entities.
562 563 564 565 566 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 562 optional :legal_entity_associations, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAssociationInlineCreate] }, nil?: true |
#legal_entity_type ⇒ Symbol, ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::LegalEntityType
The type of legal entity.
427 428 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 427 required :legal_entity_type, enum: -> { ModernTreasury::CounterpartyCreateParams::LegalEntity::LegalEntityType } |
#legal_structure ⇒ Symbol, ...
The business's legal structure.
572 573 574 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 572 optional :legal_structure, enum: -> { ModernTreasury::CounterpartyCreateParams::LegalEntity::LegalStructure }, nil?: true |
#listed_exchange ⇒ String?
ISO 10383 market identifier code.
580 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 580 optional :listed_exchange, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
587 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 587 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#middle_name ⇒ String?
An individual's middle name.
593 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 593 optional :middle_name, String, nil?: true |
#operating_jurisdictions ⇒ Array<String>?
A list of countries where the business operates (ISO 3166-1 alpha-2 or alpha-3 codes).
600 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 600 optional :operating_jurisdictions, ModernTreasury::Internal::Type::ArrayOf[String] |
#phone_numbers ⇒ Array<ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::PhoneNumber>?
605 606 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 605 optional :phone_numbers, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::CounterpartyCreateParams::LegalEntity::PhoneNumber] } |
#politically_exposed_person ⇒ Boolean?
Whether the individual is a politically exposed person.
612 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 612 optional :politically_exposed_person, ModernTreasury::Internal::Type::Boolean, nil?: true |
#preferred_name ⇒ String?
An individual's preferred name.
618 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 618 optional :preferred_name, String, nil?: true |
#prefix ⇒ String?
An individual's prefix.
624 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 624 optional :prefix, String, nil?: true |
#primary_social_media_sites ⇒ Array<String>?
A list of primary social media URLs for the business.
630 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 630 optional :primary_social_media_sites, ModernTreasury::Internal::Type::ArrayOf[String] |
#regulators ⇒ Array<ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::Regulator>?
Array of regulatory bodies overseeing this institution.
636 637 638 639 640 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 636 optional :regulators, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::CounterpartyCreateParams::LegalEntity::Regulator] }, nil?: true |
#risk_rating ⇒ Symbol, ...
The risk rating of the legal entity. One of low, medium, high.
646 647 648 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 646 optional :risk_rating, enum: -> { ModernTreasury::CounterpartyCreateParams::LegalEntity::RiskRating }, nil?: true |
#service_provider_legal_entity_id ⇒ String?
The UUID of the parent legal entity in the service provider tree.
654 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 654 optional :service_provider_legal_entity_id, String, nil?: true |
#suffix ⇒ String?
An individual's suffix.
660 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 660 optional :suffix, String, nil?: true |
#terms_of_use ⇒ ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::TermsOfUse?
Acceptance of terms of use by the legal entity.
666 667 668 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 666 optional :terms_of_use, -> { ModernTreasury::CounterpartyCreateParams::LegalEntity::TermsOfUse }, nil?: true |
#third_party_verification ⇒ ModernTreasury::Models::ThirdPartyVerification?
Deprecated. Use third_party_verifications instead.
676 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 676 optional :third_party_verification, -> { ModernTreasury::ThirdPartyVerification }, nil?: true |
#third_party_verifications ⇒ Array<ModernTreasury::Models::ThirdPartyVerification>?
A list of third-party verifications run by external vendors.
682 683 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 682 optional :third_party_verifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ThirdPartyVerification] } |
#ticker_symbol ⇒ String?
Stock ticker symbol for publicly traded companies.
689 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 689 optional :ticker_symbol, String, nil?: true |
#wealth_and_employment_details ⇒ ModernTreasury::Models::LegalEntityWealthEmploymentDetail?
694 695 696 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 694 optional :wealth_and_employment_details, -> { ModernTreasury::LegalEntityWealthEmploymentDetail }, nil?: true |
#website ⇒ String?
The entity's primary website URL.
702 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 702 optional :website, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 802
|
Instance Method Details
#to_hash ⇒ {
679 |
# File 'sig/modern_treasury/models/counterparty_create_params.rbs', line 679
def to_hash: -> {
|