Class: ModernTreasury::Models::CounterpartyCreateParams::LegalEntity

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/counterparty_create_params.rb

Defined Under Namespace

Modules: LegalEntityType, LegalStructure, RiskRating Classes: Document, PhoneNumber, Regulator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(jurisdiction:, name:, registration_number:) ⇒ Object

Some parameter documentations has been truncated, see Regulator for more details.

Parameters:

  • jurisdiction (String)

    The country code where the regulator operates in the ISO 3166-1 alpha-2 format (

  • name (String)

    Full name of the regulatory body.

  • registration_number (String)

    Registration or identification number with the regulator.



# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 705

Instance Attribute Details

#addressesArray<ModernTreasury::Models::LegalEntityAddressCreateRequest>?

A list of addresses for the entity.



443
444
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 443

optional :addresses,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAddressCreateRequest] }

#bank_settingsModernTreasury::Models::LegalEntityBankSettings?



449
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 449

optional :bank_settings, -> { ModernTreasury::LegalEntityBankSettings }, nil?: true

#business_descriptionString?

A description of the business.

Returns:

  • (String, nil)


455
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 455

optional :business_description, String, nil?: true

#business_nameString?

The business’s legal business name.

Returns:

  • (String, nil)


461
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 461

optional :business_name, String, nil?: true

#citizenship_countryString?

The country of citizenship for an individual.

Returns:

  • (String, nil)


467
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 467

optional :citizenship_country, String, nil?: true

#compliance_detailsObject?

Deprecated.

Returns:

  • (Object, nil)


473
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 473

optional :compliance_details, ModernTreasury::Internal::Type::Unknown, nil?: true

#connection_idString?

The connection ID for the connection the legal entity is associated with. Defaults to the id of the connection designated with an is_default value of true or the id of an existing operational connection if only one is available. Pass in a value of null to prevent the connection from being associated with the legal entity.

Returns:

  • (String, nil)


483
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 483

optional :connection_id, String, nil?: true

#country_of_incorporationString?

The country code where the business is incorporated in the ISO 3166-1 alpha-2 or alpha-3 formats.

Returns:

  • (String, nil)


490
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 490

optional :country_of_incorporation, String, nil?: true

#date_formedDate?

A business’s formation date (YYYY-MM-DD).

Returns:

  • (Date, nil)


496
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 496

optional :date_formed, Date, nil?: true

#date_of_birthDate?

An individual’s date of birth (YYYY-MM-DD).

Returns:

  • (Date, nil)


502
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 502

optional :date_of_birth, Date, nil?: true

#documentsArray<ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::Document>?

A list of documents to attach to the legal entity (e.g. articles of incorporation, certificate of good standing, proof of address).



509
510
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 509

optional :documents,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::CounterpartyCreateParams::LegalEntity::Document] }

#doing_business_as_namesArray<String>?

Returns:

  • (Array<String>, nil)


515
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 515

optional :doing_business_as_names, ModernTreasury::Internal::Type::ArrayOf[String]

#emailString?

The entity’s primary email.

Returns:

  • (String, nil)


521
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 521

optional :email, String, nil?: true

#expected_activity_volumeInteger?

Monthly expected transaction volume in USD.

Returns:

  • (Integer, nil)


527
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 527

optional :expected_activity_volume, Integer, nil?: true

#external_idString?

An optional user-defined 180 character unique identifier.

Returns:

  • (String, nil)


533
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 533

optional :external_id, String, nil?: true

#first_nameString?

An individual’s first name.

Returns:

  • (String, nil)


539
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 539

optional :first_name, String, nil?: true

#identificationsArray<ModernTreasury::Models::IdentificationCreateRequest>?

A list of identifications for the legal entity.



545
546
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 545

optional :identifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::IdentificationCreateRequest] }

#industry_classificationsArray<ModernTreasury::Models::LegalEntityIndustryClassification>?

A list of industry classifications for the legal entity.



552
553
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 552

optional :industry_classifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityIndustryClassification] }

#intended_useString?

A description of the intended use of the legal entity.

Returns:

  • (String, nil)


559
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 559

optional :intended_use, String, nil?: true

#last_nameString?

An individual’s last name.

Returns:

  • (String, nil)


565
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 565

optional :last_name, String, nil?: true

The legal entity associations and its child legal entities.



571
572
573
574
575
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 571

optional :legal_entity_associations,
-> {
  ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAssociationInlineCreate]
},
nil?: true

The type of legal entity.



436
437
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 436

required :legal_entity_type,
enum: -> { ModernTreasury::CounterpartyCreateParams::LegalEntity::LegalEntityType }

The business’s legal structure.



581
582
583
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 581

optional :legal_structure,
enum: -> { ModernTreasury::CounterpartyCreateParams::LegalEntity::LegalStructure },
nil?: true

#listed_exchangeString?

ISO 10383 market identifier code.

Returns:

  • (String, nil)


589
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 589

optional :listed_exchange, String, nil?: true

#metadataHash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Returns:

  • (Hash{Symbol=>String}, nil)


596
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 596

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#middle_nameString?

An individual’s middle name.

Returns:

  • (String, nil)


602
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 602

optional :middle_name, String, nil?: true

#operating_jurisdictionsArray<String>?

A list of countries where the business operates (ISO 3166-1 alpha-2 or alpha-3 codes).

Returns:

  • (Array<String>, nil)


609
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 609

optional :operating_jurisdictions, ModernTreasury::Internal::Type::ArrayOf[String]

#phone_numbersArray<ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::PhoneNumber>?



614
615
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 614

optional :phone_numbers,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::CounterpartyCreateParams::LegalEntity::PhoneNumber] }

#politically_exposed_personBoolean?

Whether the individual is a politically exposed person.

Returns:

  • (Boolean, nil)


621
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 621

optional :politically_exposed_person, ModernTreasury::Internal::Type::Boolean, nil?: true

#preferred_nameString?

An individual’s preferred name.

Returns:

  • (String, nil)


627
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 627

optional :preferred_name, String, nil?: true

#prefixString?

An individual’s prefix.

Returns:

  • (String, nil)


633
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 633

optional :prefix, String, nil?: true

#primary_social_media_sitesArray<String>?

A list of primary social media URLs for the business.

Returns:

  • (Array<String>, nil)


639
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 639

optional :primary_social_media_sites, ModernTreasury::Internal::Type::ArrayOf[String]

#regulatorsArray<ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::Regulator>?

Array of regulatory bodies overseeing this institution.



645
646
647
648
649
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 645

optional :regulators,
-> {
  ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::CounterpartyCreateParams::LegalEntity::Regulator]
},
nil?: true

#risk_ratingSymbol, ...

The risk rating of the legal entity. One of low, medium, high.



655
656
657
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 655

optional :risk_rating,
enum: -> { ModernTreasury::CounterpartyCreateParams::LegalEntity::RiskRating },
nil?: true

The UUID of the parent legal entity in the service provider tree.

Returns:

  • (String, nil)


663
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 663

optional :service_provider_legal_entity_id, String, nil?: true

#suffixString?

An individual’s suffix.

Returns:

  • (String, nil)


669
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 669

optional :suffix, String, nil?: true

#third_party_verificationModernTreasury::Models::ThirdPartyVerification?

Deprecated.

Deprecated. Use ‘third_party_verifications` instead.



677
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 677

optional :third_party_verification, -> { ModernTreasury::ThirdPartyVerification }, nil?: true

#third_party_verificationsArray<ModernTreasury::Models::ThirdPartyVerification>?

A list of third-party verifications run by external vendors.



683
684
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 683

optional :third_party_verifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ThirdPartyVerification] }

#ticker_symbolString?

Stock ticker symbol for publicly traded companies.

Returns:

  • (String, nil)


690
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 690

optional :ticker_symbol, String, nil?: true

#wealth_and_employment_detailsModernTreasury::Models::LegalEntityWealthEmploymentDetail?



695
696
697
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 695

optional :wealth_and_employment_details,
-> { ModernTreasury::LegalEntityWealthEmploymentDetail },
nil?: true

#websiteString?

The entity’s primary website URL.

Returns:

  • (String, nil)


703
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 703

optional :website, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 801