Class: ModernTreasury::Models::CounterpartyCreateParams::LegalEntity
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::CounterpartyCreateParams::LegalEntity
- Defined in:
- lib/modern_treasury/models/counterparty_create_params.rb
Defined Under Namespace
Modules: LegalEntityType, LegalStructure, RiskRating Classes: Document, PhoneNumber, Regulator
Instance Attribute Summary collapse
-
#addresses ⇒ Array<ModernTreasury::Models::LegalEntityAddressCreateRequest>?
A list of addresses for the entity.
- #bank_settings ⇒ ModernTreasury::Models::LegalEntityBankSettings?
-
#business_description ⇒ String?
A description of the business.
-
#business_name ⇒ String?
The business’s legal business name.
-
#citizenship_country ⇒ String?
The country of citizenship for an individual.
- #compliance_details ⇒ Object? deprecated Deprecated.
-
#connection_id ⇒ String?
The connection ID for the connection the legal entity is associated with.
-
#country_of_incorporation ⇒ String?
The country code where the business is incorporated in the ISO 3166-1 alpha-2 or alpha-3 formats.
-
#date_formed ⇒ Date?
A business’s formation date (YYYY-MM-DD).
-
#date_of_birth ⇒ Date?
An individual’s date of birth (YYYY-MM-DD).
-
#documents ⇒ Array<ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::Document>?
A list of documents to attach to the legal entity (e.g. articles of incorporation, certificate of good standing, proof of address).
- #doing_business_as_names ⇒ Array<String>?
-
#email ⇒ String?
The entity’s primary email.
-
#expected_activity_volume ⇒ Integer?
Monthly expected transaction volume in USD.
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
-
#first_name ⇒ String?
An individual’s first name.
-
#identifications ⇒ Array<ModernTreasury::Models::IdentificationCreateRequest>?
A list of identifications for the legal entity.
-
#industry_classifications ⇒ Array<ModernTreasury::Models::LegalEntityIndustryClassification>?
A list of industry classifications for the legal entity.
-
#intended_use ⇒ String?
A description of the intended use of the legal entity.
-
#last_name ⇒ String?
An individual’s last name.
-
#legal_entity_associations ⇒ Array<ModernTreasury::Models::LegalEntityAssociationInlineCreate>?
The legal entity associations and its child legal entities.
-
#legal_entity_type ⇒ Symbol, ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::LegalEntityType
The type of legal entity.
-
#legal_structure ⇒ Symbol, ...
The business’s legal structure.
-
#listed_exchange ⇒ String?
ISO 10383 market identifier code.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#middle_name ⇒ String?
An individual’s middle name.
-
#operating_jurisdictions ⇒ Array<String>?
A list of countries where the business operates (ISO 3166-1 alpha-2 or alpha-3 codes).
- #phone_numbers ⇒ Array<ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::PhoneNumber>?
-
#politically_exposed_person ⇒ Boolean?
Whether the individual is a politically exposed person.
-
#preferred_name ⇒ String?
An individual’s preferred name.
-
#prefix ⇒ String?
An individual’s prefix.
-
#primary_social_media_sites ⇒ Array<String>?
A list of primary social media URLs for the business.
-
#regulators ⇒ Array<ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::Regulator>?
Array of regulatory bodies overseeing this institution.
-
#risk_rating ⇒ Symbol, ...
The risk rating of the legal entity.
-
#service_provider_legal_entity_id ⇒ String?
The UUID of the parent legal entity in the service provider tree.
-
#suffix ⇒ String?
An individual’s suffix.
- #third_party_verification ⇒ ModernTreasury::Models::ThirdPartyVerification? deprecated Deprecated.
-
#third_party_verifications ⇒ Array<ModernTreasury::Models::ThirdPartyVerification>?
A list of third-party verifications run by external vendors.
-
#ticker_symbol ⇒ String?
Stock ticker symbol for publicly traded companies.
- #wealth_and_employment_details ⇒ ModernTreasury::Models::LegalEntityWealthEmploymentDetail?
-
#website ⇒ String?
The entity’s primary website URL.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(jurisdiction:, name:, registration_number:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Regulator for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(jurisdiction:, name:, registration_number:) ⇒ Object
Some parameter documentations has been truncated, see Regulator for more details.
|
|
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 705
|
Instance Attribute Details
#addresses ⇒ Array<ModernTreasury::Models::LegalEntityAddressCreateRequest>?
A list of addresses for the entity.
443 444 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 443 optional :addresses, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAddressCreateRequest] } |
#bank_settings ⇒ ModernTreasury::Models::LegalEntityBankSettings?
449 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 449 optional :bank_settings, -> { ModernTreasury::LegalEntityBankSettings }, nil?: true |
#business_description ⇒ String?
A description of the business.
455 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 455 optional :business_description, String, nil?: true |
#business_name ⇒ String?
The business’s legal business name.
461 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 461 optional :business_name, String, nil?: true |
#citizenship_country ⇒ String?
The country of citizenship for an individual.
467 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 467 optional :citizenship_country, String, nil?: true |
#compliance_details ⇒ Object?
473 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 473 optional :compliance_details, ModernTreasury::Internal::Type::Unknown, nil?: true |
#connection_id ⇒ String?
The connection ID for the connection the legal entity is associated with. Defaults to the id of the connection designated with an is_default value of true or the id of an existing operational connection if only one is available. Pass in a value of null to prevent the connection from being associated with the legal entity.
483 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 483 optional :connection_id, String, nil?: true |
#country_of_incorporation ⇒ String?
The country code where the business is incorporated in the ISO 3166-1 alpha-2 or alpha-3 formats.
490 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 490 optional :country_of_incorporation, String, nil?: true |
#date_formed ⇒ Date?
A business’s formation date (YYYY-MM-DD).
496 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 496 optional :date_formed, Date, nil?: true |
#date_of_birth ⇒ Date?
An individual’s date of birth (YYYY-MM-DD).
502 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 502 optional :date_of_birth, Date, nil?: true |
#documents ⇒ Array<ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::Document>?
A list of documents to attach to the legal entity (e.g. articles of incorporation, certificate of good standing, proof of address).
509 510 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 509 optional :documents, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::CounterpartyCreateParams::LegalEntity::Document] } |
#doing_business_as_names ⇒ Array<String>?
515 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 515 optional :doing_business_as_names, ModernTreasury::Internal::Type::ArrayOf[String] |
#email ⇒ String?
The entity’s primary email.
521 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 521 optional :email, String, nil?: true |
#expected_activity_volume ⇒ Integer?
Monthly expected transaction volume in USD.
527 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 527 optional :expected_activity_volume, Integer, nil?: true |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
533 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 533 optional :external_id, String, nil?: true |
#first_name ⇒ String?
An individual’s first name.
539 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 539 optional :first_name, String, nil?: true |
#identifications ⇒ Array<ModernTreasury::Models::IdentificationCreateRequest>?
A list of identifications for the legal entity.
545 546 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 545 optional :identifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::IdentificationCreateRequest] } |
#industry_classifications ⇒ Array<ModernTreasury::Models::LegalEntityIndustryClassification>?
A list of industry classifications for the legal entity.
552 553 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 552 optional :industry_classifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityIndustryClassification] } |
#intended_use ⇒ String?
A description of the intended use of the legal entity.
559 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 559 optional :intended_use, String, nil?: true |
#last_name ⇒ String?
An individual’s last name.
565 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 565 optional :last_name, String, nil?: true |
#legal_entity_associations ⇒ Array<ModernTreasury::Models::LegalEntityAssociationInlineCreate>?
The legal entity associations and its child legal entities.
571 572 573 574 575 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 571 optional :legal_entity_associations, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAssociationInlineCreate] }, nil?: true |
#legal_entity_type ⇒ Symbol, ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::LegalEntityType
The type of legal entity.
436 437 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 436 required :legal_entity_type, enum: -> { ModernTreasury::CounterpartyCreateParams::LegalEntity::LegalEntityType } |
#legal_structure ⇒ Symbol, ...
The business’s legal structure.
581 582 583 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 581 optional :legal_structure, enum: -> { ModernTreasury::CounterpartyCreateParams::LegalEntity::LegalStructure }, nil?: true |
#listed_exchange ⇒ String?
ISO 10383 market identifier code.
589 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 589 optional :listed_exchange, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
596 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 596 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#middle_name ⇒ String?
An individual’s middle name.
602 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 602 optional :middle_name, String, nil?: true |
#operating_jurisdictions ⇒ Array<String>?
A list of countries where the business operates (ISO 3166-1 alpha-2 or alpha-3 codes).
609 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 609 optional :operating_jurisdictions, ModernTreasury::Internal::Type::ArrayOf[String] |
#phone_numbers ⇒ Array<ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::PhoneNumber>?
614 615 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 614 optional :phone_numbers, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::CounterpartyCreateParams::LegalEntity::PhoneNumber] } |
#politically_exposed_person ⇒ Boolean?
Whether the individual is a politically exposed person.
621 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 621 optional :politically_exposed_person, ModernTreasury::Internal::Type::Boolean, nil?: true |
#preferred_name ⇒ String?
An individual’s preferred name.
627 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 627 optional :preferred_name, String, nil?: true |
#prefix ⇒ String?
An individual’s prefix.
633 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 633 optional :prefix, String, nil?: true |
#primary_social_media_sites ⇒ Array<String>?
A list of primary social media URLs for the business.
639 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 639 optional :primary_social_media_sites, ModernTreasury::Internal::Type::ArrayOf[String] |
#regulators ⇒ Array<ModernTreasury::Models::CounterpartyCreateParams::LegalEntity::Regulator>?
Array of regulatory bodies overseeing this institution.
645 646 647 648 649 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 645 optional :regulators, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::CounterpartyCreateParams::LegalEntity::Regulator] }, nil?: true |
#risk_rating ⇒ Symbol, ...
The risk rating of the legal entity. One of low, medium, high.
655 656 657 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 655 optional :risk_rating, enum: -> { ModernTreasury::CounterpartyCreateParams::LegalEntity::RiskRating }, nil?: true |
#service_provider_legal_entity_id ⇒ String?
The UUID of the parent legal entity in the service provider tree.
663 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 663 optional :service_provider_legal_entity_id, String, nil?: true |
#suffix ⇒ String?
An individual’s suffix.
669 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 669 optional :suffix, String, nil?: true |
#third_party_verification ⇒ ModernTreasury::Models::ThirdPartyVerification?
Deprecated. Use ‘third_party_verifications` instead.
677 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 677 optional :third_party_verification, -> { ModernTreasury::ThirdPartyVerification }, nil?: true |
#third_party_verifications ⇒ Array<ModernTreasury::Models::ThirdPartyVerification>?
A list of third-party verifications run by external vendors.
683 684 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 683 optional :third_party_verifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ThirdPartyVerification] } |
#ticker_symbol ⇒ String?
Stock ticker symbol for publicly traded companies.
690 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 690 optional :ticker_symbol, String, nil?: true |
#wealth_and_employment_details ⇒ ModernTreasury::Models::LegalEntityWealthEmploymentDetail?
695 696 697 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 695 optional :wealth_and_employment_details, -> { ModernTreasury::LegalEntityWealthEmploymentDetail }, nil?: true |
#website ⇒ String?
The entity’s primary website URL.
703 |
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 703 optional :website, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/counterparty_create_params.rb', line 801
|