Class: ModernTreasury::Models::ExpectedPayment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::ExpectedPayment
- Defined in:
- lib/modern_treasury/models/expected_payment.rb
Overview
Defined Under Namespace
Modules: AmountReconciledDirection, AmountUnreconciledDirection, Direction, ReconciliationMethod, Status
Instance Attribute Summary collapse
-
#amount_lower_bound ⇒ Integer?
The lowest amount this expected payment may be equal to.
-
#amount_reconciled ⇒ Integer?
The amount reconciled for this expected payment.
-
#amount_reconciled_direction ⇒ Symbol, ...
One of credit or debit.
-
#amount_unreconciled ⇒ Integer?
The amount that remains unreconciled for this expected payment.
-
#amount_unreconciled_direction ⇒ Symbol, ...
One of credit or debit.
-
#amount_upper_bound ⇒ Integer?
The highest amount this expected payment may be equal to.
-
#counterparty_id ⇒ String?
The ID of the counterparty you expect for this payment.
- #created_at ⇒ Time
-
#currency ⇒ Symbol, ...
Must conform to ISO 4217.
-
#date_lower_bound ⇒ Date?
The earliest date the payment may come in.
-
#date_upper_bound ⇒ Date?
The latest date the payment may come in.
-
#description ⇒ String?
An optional description for internal use.
-
#direction ⇒ Symbol, ...
One of credit or debit.
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
- #id ⇒ String
-
#internal_account_id ⇒ String?
The ID of the Internal Account for the expected payment.
-
#ledger_transaction_id ⇒ String?
The ID of the ledger transaction linked to the expected payment.
-
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
-
#metadata ⇒ Hash{Symbol=>String}
Additional data represented as key-value pairs.
- #object ⇒ String
-
#reconciliation_filters ⇒ Object?
The reconciliation filters you have for this payment.
-
#reconciliation_groups ⇒ Object?
The reconciliation groups you have for this payment.
-
#reconciliation_method ⇒ Symbol, ...
One of manual if this expected payment was manually reconciled in the dashboard, automatic if it was automatically reconciled by Modern Treasury, or null if it is unreconciled.
-
#reconciliation_rule_variables ⇒ Array<ModernTreasury::Models::ReconciliationRule>?
An array of reconciliation rule variables for this payment.
-
#remittance_information ⇒ String?
For ‘ach`, this field will be passed through on an addenda record.
-
#statement_descriptor ⇒ String?
The statement description you expect to see on the transaction.
-
#status ⇒ Symbol, ModernTreasury::Models::ExpectedPayment::Status
One of unreconciled, partially_reconciled, reconciled, or archived.
-
#transaction_id ⇒ String?
The ID of the Transaction this expected payment object has been matched to.
-
#transaction_line_item_id ⇒ String?
The ID of the Transaction Line Item this expected payment has been matched to.
-
#type ⇒ Symbol, ...
One of: ach, au_becs, bacs, book, check, eft, interac, provxchange, rtp, sen, sepa, signet, wire.
- #updated_at ⇒ Time
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, amount_lower_bound:, amount_reconciled:, amount_reconciled_direction:, amount_unreconciled:, amount_unreconciled_direction:, amount_upper_bound:, counterparty_id:, created_at:, currency:, date_lower_bound:, date_upper_bound:, description:, direction:, external_id:, internal_account_id:, ledger_transaction_id:, live_mode:, metadata:, object:, reconciliation_filters:, reconciliation_groups:, reconciliation_method:, reconciliation_rule_variables:, remittance_information:, statement_descriptor:, status:, transaction_id:, transaction_line_item_id:, type:, updated_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExpectedPayment for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, amount_lower_bound:, amount_reconciled:, amount_reconciled_direction:, amount_unreconciled:, amount_unreconciled_direction:, amount_upper_bound:, counterparty_id:, created_at:, currency:, date_lower_bound:, date_upper_bound:, description:, direction:, external_id:, internal_account_id:, ledger_transaction_id:, live_mode:, metadata:, object:, reconciliation_filters:, reconciliation_groups:, reconciliation_method:, reconciliation_rule_variables:, remittance_information:, statement_descriptor:, status:, transaction_id:, transaction_line_item_id:, type:, updated_at:) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::ExpectedPayment for more details.
|
|
# File 'lib/modern_treasury/models/expected_payment.rb', line 214
|
Instance Attribute Details
#amount_lower_bound ⇒ Integer?
The lowest amount this expected payment may be equal to. Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000.
17 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 17 required :amount_lower_bound, Integer, nil?: true |
#amount_reconciled ⇒ Integer?
The amount reconciled for this expected payment. Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000.
24 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 24 required :amount_reconciled, Integer, nil?: true |
#amount_reconciled_direction ⇒ Symbol, ...
One of credit or debit. Indicates whether amount_reconciled is a credit or debit amount.
31 32 33 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 31 required :amount_reconciled_direction, enum: -> { ModernTreasury::ExpectedPayment::AmountReconciledDirection }, nil?: true |
#amount_unreconciled ⇒ Integer?
The amount that remains unreconciled for this expected payment. Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000.
40 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 40 required :amount_unreconciled, Integer, nil?: true |
#amount_unreconciled_direction ⇒ Symbol, ...
One of credit or debit. Indicates whether amount_unreconciled is a credit or debit amount.
47 48 49 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 47 required :amount_unreconciled_direction, enum: -> { ModernTreasury::ExpectedPayment::AmountUnreconciledDirection }, nil?: true |
#amount_upper_bound ⇒ Integer?
The highest amount this expected payment may be equal to. Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000.
56 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 56 required :amount_upper_bound, Integer, nil?: true |
#counterparty_id ⇒ String?
The ID of the counterparty you expect for this payment.
62 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 62 required :counterparty_id, String, nil?: true |
#created_at ⇒ Time
67 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 67 required :created_at, Time |
#currency ⇒ Symbol, ...
Must conform to ISO 4217. Defaults to the currency of the internal account.
73 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 73 required :currency, enum: -> { ModernTreasury::Currency }, nil?: true |
#date_lower_bound ⇒ Date?
The earliest date the payment may come in. Format: yyyy-mm-dd
79 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 79 required :date_lower_bound, Date, nil?: true |
#date_upper_bound ⇒ Date?
The latest date the payment may come in. Format: yyyy-mm-dd
85 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 85 required :date_upper_bound, Date, nil?: true |
#description ⇒ String?
An optional description for internal use.
91 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 91 required :description, String, nil?: true |
#direction ⇒ Symbol, ...
One of credit or debit. When you are receiving money, use credit. When you are being charged, use debit.
98 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 98 required :direction, enum: -> { ModernTreasury::ExpectedPayment::Direction }, nil?: true |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
104 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 104 required :external_id, String, nil?: true |
#id ⇒ String
10 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 10 required :id, String |
#internal_account_id ⇒ String?
The ID of the Internal Account for the expected payment.
110 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 110 required :internal_account_id, String, nil?: true |
#ledger_transaction_id ⇒ String?
The ID of the ledger transaction linked to the expected payment.
116 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 116 required :ledger_transaction_id, String, nil?: true |
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
123 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 123 required :live_mode, ModernTreasury::Internal::Type::Boolean |
#metadata ⇒ Hash{Symbol=>String}
Additional data represented as key-value pairs. Both the key and value must be strings.
130 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 130 required :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#object ⇒ String
135 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 135 required :object, String |
#reconciliation_filters ⇒ Object?
The reconciliation filters you have for this payment.
141 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 141 required :reconciliation_filters, ModernTreasury::Internal::Type::Unknown, nil?: true |
#reconciliation_groups ⇒ Object?
The reconciliation groups you have for this payment.
147 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 147 required :reconciliation_groups, ModernTreasury::Internal::Type::Unknown, nil?: true |
#reconciliation_method ⇒ Symbol, ...
One of manual if this expected payment was manually reconciled in the dashboard, automatic if it was automatically reconciled by Modern Treasury, or null if it is unreconciled.
155 156 157 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 155 required :reconciliation_method, enum: -> { ModernTreasury::ExpectedPayment::ReconciliationMethod }, nil?: true |
#reconciliation_rule_variables ⇒ Array<ModernTreasury::Models::ReconciliationRule>?
An array of reconciliation rule variables for this payment.
163 164 165 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 163 required :reconciliation_rule_variables, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ReconciliationRule] }, nil?: true |
#remittance_information ⇒ String?
For ‘ach`, this field will be passed through on an addenda record. For `wire` payments the field will be passed through as the “Originator to Beneficiary Information”, also known as OBI or Fedwire tag 6000.
173 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 173 required :remittance_information, String, nil?: true |
#statement_descriptor ⇒ String?
The statement description you expect to see on the transaction. For ACH payments, this will be the full line item passed from the bank. For wire payments, this will be the OBI field on the wire. For check payments, this will be the memo field.
182 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 182 required :statement_descriptor, String, nil?: true |
#status ⇒ Symbol, ModernTreasury::Models::ExpectedPayment::Status
One of unreconciled, partially_reconciled, reconciled, or archived.
188 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 188 required :status, enum: -> { ModernTreasury::ExpectedPayment::Status } |
#transaction_id ⇒ String?
The ID of the Transaction this expected payment object has been matched to.
194 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 194 required :transaction_id, String, nil?: true |
#transaction_line_item_id ⇒ String?
The ID of the Transaction Line Item this expected payment has been matched to.
200 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 200 required :transaction_line_item_id, String, nil?: true |
#type ⇒ Symbol, ...
One of: ach, au_becs, bacs, book, check, eft, interac, provxchange, rtp, sen, sepa, signet, wire.
207 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 207 required :type, enum: -> { ModernTreasury::ExpectedPaymentType }, nil?: true |
#updated_at ⇒ Time
212 |
# File 'lib/modern_treasury/models/expected_payment.rb', line 212 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/expected_payment.rb', line 290
|