Class: ModernTreasury::Models::ExpectedPaymentUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/modern_treasury/models/expected_payment_update_params.rb

Overview

Defined Under Namespace

Modules: AmountReconciledDirection, AmountUnreconciledDirection, Direction, Status

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, amount_lower_bound: nil, amount_reconciled: nil, amount_reconciled_direction: nil, amount_unreconciled: nil, amount_unreconciled_direction: nil, amount_upper_bound: nil, counterparty_id: nil, currency: nil, date_lower_bound: nil, date_upper_bound: nil, description: nil, direction: nil, external_id: nil, internal_account_id: nil, metadata: nil, reconciliation_filters: nil, reconciliation_groups: nil, reconciliation_rule_variables: nil, remittance_information: nil, statement_descriptor: nil, status: nil, type: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::ExpectedPaymentUpdateParams for more details.

Parameters:

  • id (String)
  • amount_lower_bound (Integer, nil) (defaults to: nil)

    The lowest amount this expected payment may be equal to. Value in specified curr

  • amount_reconciled (Integer, nil) (defaults to: nil)

    The amount reconciled for this expected payment. Value in specified currency’s s

  • amount_reconciled_direction (Symbol, ModernTreasury::Models::ExpectedPaymentUpdateParams::AmountReconciledDirection, nil) (defaults to: nil)

    One of credit or debit. Indicates whether amount_reconciled is a credit or debit

  • amount_unreconciled (Integer, nil) (defaults to: nil)

    The amount that remains unreconciled for this expected payment. Value in specifi

  • amount_unreconciled_direction (Symbol, ModernTreasury::Models::ExpectedPaymentUpdateParams::AmountUnreconciledDirection, nil) (defaults to: nil)

    One of credit or debit. Indicates whether amount_unreconciled is a credit or deb

  • amount_upper_bound (Integer, nil) (defaults to: nil)

    The highest amount this expected payment may be equal to. Value in specified cur

  • counterparty_id (String, nil) (defaults to: nil)

    The ID of the counterparty you expect for this payment.

  • currency (Symbol, ModernTreasury::Models::Currency, nil) (defaults to: nil)

    Must conform to ISO 4217. Defaults to the currency of the internal account.

  • date_lower_bound (Date, nil) (defaults to: nil)

    The earliest date the payment may come in. Format: yyyy-mm-dd

  • date_upper_bound (Date, nil) (defaults to: nil)

    The latest date the payment may come in. Format: yyyy-mm-dd

  • description (String, nil) (defaults to: nil)

    An optional description for internal use.

  • direction (Symbol, ModernTreasury::Models::ExpectedPaymentUpdateParams::Direction, nil) (defaults to: nil)

    One of credit or debit. When you are receiving money, use credit. When you are b

  • external_id (String, nil) (defaults to: nil)

    An optional user-defined 180 character unique identifier.

  • internal_account_id (String, nil) (defaults to: nil)

    The ID of the Internal Account for the expected payment.

  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    Additional data represented as key-value pairs. Both the key and value must be s

  • reconciliation_filters (Object, nil) (defaults to: nil)

    The reconciliation filters you have for this payment.

  • reconciliation_groups (Object, nil) (defaults to: nil)

    The reconciliation groups you have for this payment.

  • reconciliation_rule_variables (Array<ModernTreasury::Models::ReconciliationRule>, nil) (defaults to: nil)

    An array of reconciliation rule variables for this payment.

  • remittance_information (String, nil) (defaults to: nil)

    For ‘ach`, this field will be passed through on an addenda record. For `wire` pa

  • statement_descriptor (String, nil) (defaults to: nil)

    The statement description you expect to see on the transaction. For ACH payments

  • status (Symbol, ModernTreasury::Models::ExpectedPaymentUpdateParams::Status, nil) (defaults to: nil)

    The Expected Payment’s status can be updated from partially_reconciled to reconc

  • type (Symbol, ModernTreasury::Models::ExpectedPaymentType, nil) (defaults to: nil)

    One of: ach, au_becs, bacs, book, check, eft, interac, provxchange, rtp, sen, se

  • request_options (ModernTreasury::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 168

Instance Attribute Details

#amount_lower_boundInteger?

The lowest amount this expected payment may be equal to. Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000.

Returns:

  • (Integer, nil)


20
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 20

optional :amount_lower_bound, Integer, nil?: true

#amount_reconciledInteger?

The amount reconciled for this expected payment. Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000.

Returns:

  • (Integer, nil)


27
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 27

optional :amount_reconciled, Integer, nil?: true

#amount_reconciled_directionSymbol, ...

One of credit or debit. Indicates whether amount_reconciled is a credit or debit amount.



34
35
36
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 34

optional :amount_reconciled_direction,
enum: -> { ModernTreasury::ExpectedPaymentUpdateParams::AmountReconciledDirection },
nil?: true

#amount_unreconciledInteger?

The amount that remains unreconciled for this expected payment. Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000.

Returns:

  • (Integer, nil)


43
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 43

optional :amount_unreconciled, Integer, nil?: true

#amount_unreconciled_directionSymbol, ...

One of credit or debit. Indicates whether amount_unreconciled is a credit or debit amount.



50
51
52
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 50

optional :amount_unreconciled_direction,
enum: -> { ModernTreasury::ExpectedPaymentUpdateParams::AmountUnreconciledDirection },
nil?: true

#amount_upper_boundInteger?

The highest amount this expected payment may be equal to. Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000.

Returns:

  • (Integer, nil)


59
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 59

optional :amount_upper_bound, Integer, nil?: true

#counterparty_idString?

The ID of the counterparty you expect for this payment.

Returns:

  • (String, nil)


65
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 65

optional :counterparty_id, String, nil?: true

#currencySymbol, ...

Must conform to ISO 4217. Defaults to the currency of the internal account.

Returns:



71
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 71

optional :currency, enum: -> { ModernTreasury::Currency }, nil?: true

#date_lower_boundDate?

The earliest date the payment may come in. Format: yyyy-mm-dd

Returns:

  • (Date, nil)


77
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 77

optional :date_lower_bound, Date, nil?: true

#date_upper_boundDate?

The latest date the payment may come in. Format: yyyy-mm-dd

Returns:

  • (Date, nil)


83
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 83

optional :date_upper_bound, Date, nil?: true

#descriptionString?

An optional description for internal use.

Returns:

  • (String, nil)


89
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 89

optional :description, String, nil?: true

#directionSymbol, ...

One of credit or debit. When you are receiving money, use credit. When you are being charged, use debit.



96
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 96

optional :direction, enum: -> { ModernTreasury::ExpectedPaymentUpdateParams::Direction }, nil?: true

#external_idString?

An optional user-defined 180 character unique identifier.

Returns:

  • (String, nil)


102
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 102

optional :external_id, String, nil?: true

#idString

Returns:

  • (String)


13
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 13

required :id, String

#internal_account_idString?

The ID of the Internal Account for the expected payment.

Returns:

  • (String, nil)


108
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 108

optional :internal_account_id, String, nil?: true

#metadataHash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Returns:

  • (Hash{Symbol=>String}, nil)


115
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 115

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#reconciliation_filtersObject?

The reconciliation filters you have for this payment.

Returns:

  • (Object, nil)


121
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 121

optional :reconciliation_filters, ModernTreasury::Internal::Type::Unknown, nil?: true

#reconciliation_groupsObject?

The reconciliation groups you have for this payment.

Returns:

  • (Object, nil)


127
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 127

optional :reconciliation_groups, ModernTreasury::Internal::Type::Unknown, nil?: true

#reconciliation_rule_variablesArray<ModernTreasury::Models::ReconciliationRule>?

An array of reconciliation rule variables for this payment.



133
134
135
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 133

optional :reconciliation_rule_variables,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ReconciliationRule] },
nil?: true

#remittance_informationString?

For ‘ach`, this field will be passed through on an addenda record. For `wire` payments the field will be passed through as the “Originator to Beneficiary Information”, also known as OBI or Fedwire tag 6000.

Returns:

  • (String, nil)


143
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 143

optional :remittance_information, String, nil?: true

#statement_descriptorString?

The statement description you expect to see on the transaction. For ACH payments, this will be the full line item passed from the bank. For wire payments, this will be the OBI field on the wire. For check payments, this will be the memo field.

Returns:

  • (String, nil)


152
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 152

optional :statement_descriptor, String, nil?: true

#statusSymbol, ...

The Expected Payment’s status can be updated from partially_reconciled to reconciled.



159
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 159

optional :status, enum: -> { ModernTreasury::ExpectedPaymentUpdateParams::Status }, nil?: true

#typeSymbol, ...

One of: ach, au_becs, bacs, book, check, eft, interac, provxchange, rtp, sen, sepa, signet, wire.



166
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 166

optional :type, enum: -> { ModernTreasury::ExpectedPaymentType }, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 228