Class: ModernTreasury::Models::ExpectedPaymentUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::ExpectedPaymentUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/expected_payment_update_params.rb
Overview
Defined Under Namespace
Modules: AmountReconciledDirection, AmountUnreconciledDirection, Direction, Status
Instance Attribute Summary collapse
-
#amount_lower_bound ⇒ Integer?
The lowest amount this expected payment may be equal to.
-
#amount_reconciled ⇒ Integer?
The amount reconciled for this expected payment.
-
#amount_reconciled_direction ⇒ Symbol, ...
One of credit or debit.
-
#amount_unreconciled ⇒ Integer?
The amount that remains unreconciled for this expected payment.
-
#amount_unreconciled_direction ⇒ Symbol, ...
One of credit or debit.
-
#amount_upper_bound ⇒ Integer?
The highest amount this expected payment may be equal to.
-
#counterparty_id ⇒ String?
The ID of the counterparty you expect for this payment.
-
#currency ⇒ Symbol, ...
Must conform to ISO 4217.
-
#date_lower_bound ⇒ Date?
The earliest date the payment may come in.
-
#date_upper_bound ⇒ Date?
The latest date the payment may come in.
-
#description ⇒ String?
An optional description for internal use.
-
#direction ⇒ Symbol, ...
One of credit or debit.
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
- #id ⇒ String
-
#internal_account_id ⇒ String?
The ID of the Internal Account for the expected payment.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#reconciliation_filters ⇒ Object?
The reconciliation filters you have for this payment.
-
#reconciliation_groups ⇒ Object?
The reconciliation groups you have for this payment.
-
#reconciliation_rule_variables ⇒ Array<ModernTreasury::Models::ReconciliationRule>?
An array of reconciliation rule variables for this payment.
-
#remittance_information ⇒ String?
For ‘ach`, this field will be passed through on an addenda record.
-
#statement_descriptor ⇒ String?
The statement description you expect to see on the transaction.
-
#status ⇒ Symbol, ...
The Expected Payment’s status can be updated from partially_reconciled to reconciled.
-
#type ⇒ Symbol, ...
One of: ach, au_becs, bacs, book, check, eft, interac, provxchange, rtp, sen, sepa, signet, wire.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, amount_lower_bound: nil, amount_reconciled: nil, amount_reconciled_direction: nil, amount_unreconciled: nil, amount_unreconciled_direction: nil, amount_upper_bound: nil, counterparty_id: nil, currency: nil, date_lower_bound: nil, date_upper_bound: nil, description: nil, direction: nil, external_id: nil, internal_account_id: nil, metadata: nil, reconciliation_filters: nil, reconciliation_groups: nil, reconciliation_rule_variables: nil, remittance_information: nil, statement_descriptor: nil, status: nil, type: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ExpectedPaymentUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, amount_lower_bound: nil, amount_reconciled: nil, amount_reconciled_direction: nil, amount_unreconciled: nil, amount_unreconciled_direction: nil, amount_upper_bound: nil, counterparty_id: nil, currency: nil, date_lower_bound: nil, date_upper_bound: nil, description: nil, direction: nil, external_id: nil, internal_account_id: nil, metadata: nil, reconciliation_filters: nil, reconciliation_groups: nil, reconciliation_rule_variables: nil, remittance_information: nil, statement_descriptor: nil, status: nil, type: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::ExpectedPaymentUpdateParams for more details.
|
|
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 168
|
Instance Attribute Details
#amount_lower_bound ⇒ Integer?
The lowest amount this expected payment may be equal to. Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000.
20 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 20 optional :amount_lower_bound, Integer, nil?: true |
#amount_reconciled ⇒ Integer?
The amount reconciled for this expected payment. Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000.
27 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 27 optional :amount_reconciled, Integer, nil?: true |
#amount_reconciled_direction ⇒ Symbol, ...
One of credit or debit. Indicates whether amount_reconciled is a credit or debit amount.
34 35 36 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 34 optional :amount_reconciled_direction, enum: -> { ModernTreasury::ExpectedPaymentUpdateParams::AmountReconciledDirection }, nil?: true |
#amount_unreconciled ⇒ Integer?
The amount that remains unreconciled for this expected payment. Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000.
43 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 43 optional :amount_unreconciled, Integer, nil?: true |
#amount_unreconciled_direction ⇒ Symbol, ...
One of credit or debit. Indicates whether amount_unreconciled is a credit or debit amount.
50 51 52 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 50 optional :amount_unreconciled_direction, enum: -> { ModernTreasury::ExpectedPaymentUpdateParams::AmountUnreconciledDirection }, nil?: true |
#amount_upper_bound ⇒ Integer?
The highest amount this expected payment may be equal to. Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000.
59 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 59 optional :amount_upper_bound, Integer, nil?: true |
#counterparty_id ⇒ String?
The ID of the counterparty you expect for this payment.
65 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 65 optional :counterparty_id, String, nil?: true |
#currency ⇒ Symbol, ...
Must conform to ISO 4217. Defaults to the currency of the internal account.
71 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 71 optional :currency, enum: -> { ModernTreasury::Currency }, nil?: true |
#date_lower_bound ⇒ Date?
The earliest date the payment may come in. Format: yyyy-mm-dd
77 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 77 optional :date_lower_bound, Date, nil?: true |
#date_upper_bound ⇒ Date?
The latest date the payment may come in. Format: yyyy-mm-dd
83 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 83 optional :date_upper_bound, Date, nil?: true |
#description ⇒ String?
An optional description for internal use.
89 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 89 optional :description, String, nil?: true |
#direction ⇒ Symbol, ...
One of credit or debit. When you are receiving money, use credit. When you are being charged, use debit.
96 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 96 optional :direction, enum: -> { ModernTreasury::ExpectedPaymentUpdateParams::Direction }, nil?: true |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
102 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 102 optional :external_id, String, nil?: true |
#id ⇒ String
13 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 13 required :id, String |
#internal_account_id ⇒ String?
The ID of the Internal Account for the expected payment.
108 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 108 optional :internal_account_id, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
115 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 115 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#reconciliation_filters ⇒ Object?
The reconciliation filters you have for this payment.
121 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 121 optional :reconciliation_filters, ModernTreasury::Internal::Type::Unknown, nil?: true |
#reconciliation_groups ⇒ Object?
The reconciliation groups you have for this payment.
127 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 127 optional :reconciliation_groups, ModernTreasury::Internal::Type::Unknown, nil?: true |
#reconciliation_rule_variables ⇒ Array<ModernTreasury::Models::ReconciliationRule>?
An array of reconciliation rule variables for this payment.
133 134 135 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 133 optional :reconciliation_rule_variables, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ReconciliationRule] }, nil?: true |
#remittance_information ⇒ String?
For ‘ach`, this field will be passed through on an addenda record. For `wire` payments the field will be passed through as the “Originator to Beneficiary Information”, also known as OBI or Fedwire tag 6000.
143 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 143 optional :remittance_information, String, nil?: true |
#statement_descriptor ⇒ String?
The statement description you expect to see on the transaction. For ACH payments, this will be the full line item passed from the bank. For wire payments, this will be the OBI field on the wire. For check payments, this will be the memo field.
152 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 152 optional :statement_descriptor, String, nil?: true |
#status ⇒ Symbol, ...
The Expected Payment’s status can be updated from partially_reconciled to reconciled.
159 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 159 optional :status, enum: -> { ModernTreasury::ExpectedPaymentUpdateParams::Status }, nil?: true |
#type ⇒ Symbol, ...
One of: ach, au_becs, bacs, book, check, eft, interac, provxchange, rtp, sen, sepa, signet, wire.
166 |
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 166 optional :type, enum: -> { ModernTreasury::ExpectedPaymentType }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/expected_payment_update_params.rb', line 228
|