Class: ModernTreasury::Models::InternalAccountCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::InternalAccountCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/internal_account_create_params.rb,
sig/modern_treasury/models/internal_account_create_params.rbs
Overview
Defined Under Namespace
Modules: AccountType, Currency, RequestedAccountNumberType Classes: AccountCapability, PartyAddress
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ModernTreasury
Instance Attribute Summary collapse
-
#account_capabilities ⇒ Array<ModernTreasury::Models::InternalAccountCreateParams::AccountCapability>?
An array of AccountCapability objects that list the originating abilities of the internal account and any relevant information for them.
-
#account_type ⇒ Symbol, ...
The account type, used to provision the appropriate account at the financial institution.
-
#connection_id ⇒ String?
The identifier of the financial institution the account belongs to.
-
#counterparty_id ⇒ String?
The Counterparty associated to this account.
-
#currency ⇒ Symbol, ModernTreasury::Models::InternalAccountCreateParams::Currency
The currency of the internal account.
-
#debitable ⇒ Boolean?
Whether this account can receive ACH debits.
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
-
#legal_entity_id ⇒ String?
The LegalEntity associated to this account.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#name ⇒ String
The nickname of the account.
-
#parent_account_id ⇒ String?
The parent internal account of this new account.
-
#party_address ⇒ ModernTreasury::Models::InternalAccountCreateParams::PartyAddress?
The address associated with the owner or null.
-
#party_name ⇒ String?
The legal name of the entity which owns the account.
-
#requested_account_number_types ⇒ Array<Symbol, ModernTreasury::Models::InternalAccountCreateParams::RequestedAccountNumberType>?
An array of account number types requested for provisioning.
-
#vendor_attributes ⇒ Hash{Symbol=>String}?
A hash of vendor specific attributes that will be used when creating the account at the vendor specified by the given connection.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(country:, line1:, locality:, postal_code:, region:, line2: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PartyAddress for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(country:, line1:, locality:, postal_code:, region:, line2: nil) ⇒ Object
Some parameter documentations has been truncated, see PartyAddress for more details.
The address associated with the owner or null.
|
|
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 111
|
Instance Attribute Details
#account_capabilities ⇒ Array<ModernTreasury::Models::InternalAccountCreateParams::AccountCapability>?
An array of AccountCapability objects that list the originating abilities of the internal account and any relevant information for them.
27 28 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 27 optional :account_capabilities, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::InternalAccountCreateParams::AccountCapability] } |
#account_type ⇒ Symbol, ...
The account type, used to provision the appropriate account at the financial institution.
35 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 35 optional :account_type, enum: -> { ModernTreasury::InternalAccountCreateParams::AccountType } |
#connection_id ⇒ String?
The identifier of the financial institution the account belongs to. If not provided, defaults to the default connection, or the sole connection if only one exists.
43 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 43 optional :connection_id, String |
#counterparty_id ⇒ String?
The Counterparty associated to this account.
49 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 49 optional :counterparty_id, String |
#currency ⇒ Symbol, ModernTreasury::Models::InternalAccountCreateParams::Currency
The currency of the internal account. Supports fiat and stablecoin currencies.
14 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 14 required :currency, enum: -> { ModernTreasury::InternalAccountCreateParams::Currency } |
#debitable ⇒ Boolean?
Whether this account can receive ACH debits. Only applicable to accounts created
under a Modern Treasury PSP connection, or null for Bring Your Own Bank
accounts. Defaults to false. Configurable only on creation. Please reach out
to your customer success manager to enable this capability for your connection.
58 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 58 optional :debitable, ModernTreasury::Internal::Type::Boolean, nil?: true |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
64 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 64 optional :external_id, String, nil?: true |
#legal_entity_id ⇒ String?
The LegalEntity associated to this account.
70 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 70 optional :legal_entity_id, String |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
77 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 77 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#name ⇒ String
The nickname of the account.
20 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 20 required :name, String |
#parent_account_id ⇒ String?
The parent internal account of this new account.
83 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 83 optional :parent_account_id, String |
#party_address ⇒ ModernTreasury::Models::InternalAccountCreateParams::PartyAddress?
The address associated with the owner or null.
89 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 89 optional :party_address, -> { ModernTreasury::InternalAccountCreateParams::PartyAddress } |
#party_name ⇒ String?
The legal name of the entity which owns the account.
95 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 95 optional :party_name, String, nil?: true |
#requested_account_number_types ⇒ Array<Symbol, ModernTreasury::Models::InternalAccountCreateParams::RequestedAccountNumberType>?
An array of account number types requested for provisioning.
101 102 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 101 optional :requested_account_number_types, -> { ModernTreasury::Internal::Type::ArrayOf[enum: ModernTreasury::InternalAccountCreateParams::RequestedAccountNumberType] } |
#vendor_attributes ⇒ Hash{Symbol=>String}?
A hash of vendor specific attributes that will be used when creating the account at the vendor specified by the given connection.
109 |
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 109 optional :vendor_attributes, ModernTreasury::Internal::Type::HashOf[String] |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 158
|
Instance Method Details
#to_hash ⇒ {
104 |
# File 'sig/modern_treasury/models/internal_account_create_params.rbs', line 104
def to_hash: -> {
|