Class: ModernTreasury::Models::InternalAccountCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/modern_treasury/models/internal_account_create_params.rb,
sig/modern_treasury/models/internal_account_create_params.rbs

Overview

See Also:

  • ModernTreasury::Resources::InternalAccounts#create

Defined Under Namespace

Modules: AccountType, Currency Classes: AccountCapability, PartyAddress

Constant Summary

Constants included from Internal::Type::RequestParameters

Internal::Type::RequestParameters::ModernTreasury

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(currency:, name:, account_capabilities: nil, account_type: nil, connection_id: nil, counterparty_id: nil, debitable: nil, external_id: nil, legal_entity_id: nil, metadata: nil, parent_account_id: nil, party_address: nil, party_name: nil, vendor_attributes: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::InternalAccountCreateParams for more details.

Parameters:

  • currency (Symbol, ModernTreasury::Models::InternalAccountCreateParams::Currency)

    The currency of the internal account. Supports fiat and stablecoin currencies.

  • name (String)

    The nickname of the account.

  • account_capabilities (Array<ModernTreasury::Models::InternalAccountCreateParams::AccountCapability>) (defaults to: nil)

    An array of AccountCapability objects that list the originating abilities of the

  • account_type (Symbol, ModernTreasury::Models::InternalAccountCreateParams::AccountType) (defaults to: nil)

    The account type, used to provision the appropriate account at the financial ins

  • connection_id (String) (defaults to: nil)

    The identifier of the financial institution the account belongs to. If not provi

  • counterparty_id (String) (defaults to: nil)

    The Counterparty associated to this account.

  • debitable (Boolean, nil) (defaults to: nil)

    Whether this account can receive ACH debits. Only applicable to accounts created

  • external_id (String, nil) (defaults to: nil)

    An optional user-defined 180 character unique identifier.

  • legal_entity_id (String) (defaults to: nil)

    The LegalEntity associated to this account.

  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    Additional data represented as key-value pairs. Both the key and value must be s

  • parent_account_id (String) (defaults to: nil)

    The parent internal account of this new account.

  • party_address (ModernTreasury::Models::InternalAccountCreateParams::PartyAddress) (defaults to: nil)

    The address associated with the owner or null.

  • party_name (String, nil) (defaults to: nil)

    The legal name of the entity which owns the account.

  • vendor_attributes (Hash{Symbol=>String}) (defaults to: nil)

    A hash of vendor specific attributes that will be used when creating the account

  • request_options (ModernTreasury::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 104

Instance Attribute Details

#account_capabilitiesArray<ModernTreasury::Models::InternalAccountCreateParams::AccountCapability>?

An array of AccountCapability objects that list the originating abilities of the internal account and any relevant information for them.



27
28
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 27

optional :account_capabilities,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::InternalAccountCreateParams::AccountCapability] }

#account_typeSymbol, ...

The account type, used to provision the appropriate account at the financial institution.



35
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 35

optional :account_type, enum: -> { ModernTreasury::InternalAccountCreateParams::AccountType }

#connection_idString?

The identifier of the financial institution the account belongs to. If not provided, defaults to the default connection, or the sole connection if only one exists.

Parameters:

  • (String)

Returns:

  • (String, nil)


43
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 43

optional :connection_id, String

#counterparty_idString?

The Counterparty associated to this account.

Parameters:

  • (String)

Returns:

  • (String, nil)


49
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 49

optional :counterparty_id, String

#currencySymbol, ModernTreasury::Models::InternalAccountCreateParams::Currency

The currency of the internal account. Supports fiat and stablecoin currencies.

Parameters:

  • value (ModernTreasury::Models::InternalAccountCreateParams::currency)

Returns:



14
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 14

required :currency, enum: -> { ModernTreasury::InternalAccountCreateParams::Currency }

#debitableBoolean?

Whether this account can receive ACH debits. Only applicable to accounts created under a Modern Treasury PSP connection, or null for Bring Your Own Bank accounts. Defaults to false. Configurable only on creation. Please reach out to your customer success manager to enable this capability for your connection.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


58
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 58

optional :debitable, ModernTreasury::Internal::Type::Boolean, nil?: true

#external_idString?

An optional user-defined 180 character unique identifier.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


64
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 64

optional :external_id, String, nil?: true

The LegalEntity associated to this account.

Parameters:

  • (String)

Returns:

  • (String, nil)


70
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 70

optional :legal_entity_id, String

#metadataHash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


77
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 77

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#nameString

The nickname of the account.

Parameters:

  • value (String)

Returns:

  • (String)


20
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 20

required :name, String

#parent_account_idString?

The parent internal account of this new account.

Parameters:

  • (String)

Returns:

  • (String, nil)


83
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 83

optional :parent_account_id, String

#party_addressModernTreasury::Models::InternalAccountCreateParams::PartyAddress?

The address associated with the owner or null.



89
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 89

optional :party_address, -> { ModernTreasury::InternalAccountCreateParams::PartyAddress }

#party_nameString?

The legal name of the entity which owns the account.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


95
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 95

optional :party_name, String, nil?: true

#vendor_attributesHash{Symbol=>String}?

A hash of vendor specific attributes that will be used when creating the account at the vendor specified by the given connection.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


102
# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 102

optional :vendor_attributes, ModernTreasury::Internal::Type::HashOf[String]

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/internal_account_create_params.rb', line 149

Instance Method Details

#to_hash{

Returns:

  • ({)


96
# File 'sig/modern_treasury/models/internal_account_create_params.rbs', line 96

def to_hash: -> {