Class: ModernTreasury::Models::InternalAccountUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::InternalAccountUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/internal_account_update_params.rb,
sig/modern_treasury/models/internal_account_update_params.rbs
Overview
Defined Under Namespace
Modules: Status
Constant Summary collapse
- ModernTreasury =
Instance Attribute Summary collapse
-
#contra_ledger_account_id ⇒ String?
The Contra Ledger Account associated to this account.
-
#counterparty_id ⇒ String?
The Counterparty associated to this account.
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
- #id ⇒ String
-
#ledger_account_id ⇒ String?
The Ledger Account associated to this account.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data in the form of key-value pairs.
-
#name ⇒ String?
The nickname for the internal account.
-
#parent_account_id ⇒ String?
The parent internal account for this account.
-
#party_address ⇒ ModernTreasury::Models::AddressRequest?
The address associated with the owner of the internal account.
-
#status ⇒ Symbol, ...
Requests closure of the internal account.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, contra_ledger_account_id: nil, counterparty_id: nil, external_id: nil, ledger_account_id: nil, metadata: nil, name: nil, parent_account_id: nil, party_address: nil, status: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see InternalAccountUpdateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, contra_ledger_account_id: nil, counterparty_id: nil, external_id: nil, ledger_account_id: nil, metadata: nil, name: nil, parent_account_id: nil, party_address: nil, status: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::InternalAccountUpdateParams for more details.
|
|
# File 'lib/modern_treasury/models/internal_account_update_params.rb', line 74
|
Instance Attribute Details
#contra_ledger_account_id ⇒ String?
The Contra Ledger Account associated to this account.
19 |
# File 'lib/modern_treasury/models/internal_account_update_params.rb', line 19 optional :contra_ledger_account_id, String |
#counterparty_id ⇒ String?
The Counterparty associated to this account.
25 |
# File 'lib/modern_treasury/models/internal_account_update_params.rb', line 25 optional :counterparty_id, String |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
31 |
# File 'lib/modern_treasury/models/internal_account_update_params.rb', line 31 optional :external_id, String, nil?: true |
#id ⇒ String
13 |
# File 'lib/modern_treasury/models/internal_account_update_params.rb', line 13 required :id, String |
#ledger_account_id ⇒ String?
The Ledger Account associated to this account.
37 |
# File 'lib/modern_treasury/models/internal_account_update_params.rb', line 37 optional :ledger_account_id, String |
#metadata ⇒ Hash{Symbol=>String}?
Additional data in the form of key-value pairs. Pairs can be removed by passing
an empty string or null as the value.
44 |
# File 'lib/modern_treasury/models/internal_account_update_params.rb', line 44 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#name ⇒ String?
The nickname for the internal account.
50 |
# File 'lib/modern_treasury/models/internal_account_update_params.rb', line 50 optional :name, String |
#parent_account_id ⇒ String?
The parent internal account for this account.
56 |
# File 'lib/modern_treasury/models/internal_account_update_params.rb', line 56 optional :parent_account_id, String |
#party_address ⇒ ModernTreasury::Models::AddressRequest?
The address associated with the owner of the internal account. Updating this value does not guarantee that the new address matches the address on record with the account's bank; you are responsible for verifying that the address is accurate.
65 |
# File 'lib/modern_treasury/models/internal_account_update_params.rb', line 65 optional :party_address, -> { ModernTreasury::AddressRequest } |
#status ⇒ Symbol, ...
Requests closure of the internal account. The resulting status may be closed
for vendors that close synchronously.
72 |
# File 'lib/modern_treasury/models/internal_account_update_params.rb', line 72 optional :status, enum: -> { ModernTreasury::InternalAccountUpdateParams::Status } |
Instance Method Details
#to_hash ⇒ {
76 |
# File 'sig/modern_treasury/models/internal_account_update_params.rbs', line 76
def to_hash: -> {
|