Class: ModernTreasury::Models::InternalAccounts::BalanceReport::Balance
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::InternalAccounts::BalanceReport::Balance
- Defined in:
- lib/modern_treasury/models/internal_accounts/balance_report.rb,
sig/modern_treasury/models/internal_accounts/balance_report.rbs
Defined Under Namespace
Modules: BalanceType
Instance Attribute Summary collapse
-
#amount ⇒ Integer
The balance amount.
-
#amount_string ⇒ String
The amount of the balance as a string, preserving full precision for values that may exceed safe integer limits in some languages.
-
#as_of_date ⇒ Date?
The date on which the balance became true for the account.
-
#as_of_time ⇒ Time?
The time on which the balance became true for the account.
-
#balance_type ⇒ Symbol, ModernTreasury::Models::InternalAccounts::BalanceReport::Balance::BalanceType
The specific type of balance reported.
- #created_at ⇒ Time
-
#currency ⇒ Symbol, ModernTreasury::Models::Currency
The currency of the balance.
- #id ⇒ String
-
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
- #object ⇒ String
- #updated_at ⇒ Time
-
#value_date ⇒ Date?
The date on which the balance becomes available.
-
#vendor_code ⇒ String
The code used by the bank when reporting this specific balance.
-
#vendor_code_type ⇒ String?
The type of
vendor_codebeing reported.
Instance Method Summary collapse
-
#initialize(id:, amount:, amount_string:, as_of_date:, as_of_time:, balance_type:, created_at:, currency:, live_mode:, object:, updated_at:, value_date:, vendor_code:, vendor_code_type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Balance for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, amount:, amount_string:, as_of_date:, as_of_time:, balance_type:, created_at:, currency:, live_mode:, object:, updated_at:, value_date:, vendor_code:, vendor_code_type:) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::InternalAccounts::BalanceReport::Balance for more details.
|
|
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 197
|
Instance Attribute Details
#amount ⇒ Integer
The balance amount.
118 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 118 required :amount, Integer |
#amount_string ⇒ String
The amount of the balance as a string, preserving full precision for values that may exceed safe integer limits in some languages.
125 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 125 required :amount_string, String |
#as_of_date ⇒ Date?
The date on which the balance became true for the account.
131 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 131 required :as_of_date, Date, nil?: true |
#as_of_time ⇒ Time?
The time on which the balance became true for the account.
137 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 137 required :as_of_time, Time, nil?: true |
#balance_type ⇒ Symbol, ModernTreasury::Models::InternalAccounts::BalanceReport::Balance::BalanceType
The specific type of balance reported. One of opening_ledger,
closing_ledger, current_ledger, opening_available,
opening_available_next_business_day, closing_available, current_available,
'previously_closed_book', or other.
146 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 146 required :balance_type, enum: -> { ModernTreasury::InternalAccounts::BalanceReport::Balance::BalanceType } |
#created_at ⇒ Time
151 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 151 required :created_at, Time |
#currency ⇒ Symbol, ModernTreasury::Models::Currency
The currency of the balance.
157 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 157 required :currency, enum: -> { ModernTreasury::Currency } |
#id ⇒ String
112 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 112 required :id, String |
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
164 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 164 required :live_mode, ModernTreasury::Internal::Type::Boolean |
#object ⇒ String
169 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 169 required :object, String |
#updated_at ⇒ Time
174 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 174 required :updated_at, Time |
#value_date ⇒ Date?
The date on which the balance becomes available.
180 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 180 required :value_date, Date, nil?: true |
#vendor_code ⇒ String
The code used by the bank when reporting this specific balance.
186 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 186 required :vendor_code, String |
#vendor_code_type ⇒ String?
The type of vendor_code being reported. Can be one of bai2, bankprov,
bnk_dev, cleartouch, currencycloud, cross_river, dc_bank, dwolla,
evolve, goldman_sachs, iso20022, jpmc, mx, silvergate, swift, or
us_bank.
195 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report.rb', line 195 required :vendor_code_type, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
143 |
# File 'sig/modern_treasury/models/internal_accounts/balance_report.rbs', line 143
def to_hash: -> {
|