Class: ModernTreasury::Models::InternalAccounts::BalanceReportCreateParams::Balance
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::InternalAccounts::BalanceReportCreateParams::Balance
- Defined in:
- lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb,
sig/modern_treasury/models/internal_accounts/balance_report_create_params.rbs
Defined Under Namespace
Modules: BalanceType
Instance Attribute Summary collapse
-
#amount ⇒ Integer?
The balance amount.
-
#amount_string ⇒ String?
The amount of the balance as a string, preserving full precision for values that may exceed safe integer limits in some languages.
-
#balance_type ⇒ Symbol, ModernTreasury::Models::InternalAccounts::BalanceReportCreateParams::Balance::BalanceType
The specific type of balance reported.
-
#vendor_code ⇒ String
The code used by the bank when reporting this specific balance.
-
#vendor_code_type ⇒ String?
The type of
vendor_codebeing reported.
Instance Method Summary collapse
-
#initialize(balance_type:, vendor_code:, vendor_code_type:, amount: nil, amount_string: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Balance for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(balance_type:, vendor_code:, vendor_code_type:, amount: nil, amount_string: nil) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::InternalAccounts::BalanceReportCreateParams::Balance for more details.
|
|
# File 'lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb', line 113
|
Instance Attribute Details
#amount ⇒ Integer?
The balance amount.
104 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb', line 104 optional :amount, Integer |
#amount_string ⇒ String?
The amount of the balance as a string, preserving full precision for values that may exceed safe integer limits in some languages.
111 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb', line 111 optional :amount_string, String |
#balance_type ⇒ Symbol, ModernTreasury::Models::InternalAccounts::BalanceReportCreateParams::Balance::BalanceType
The specific type of balance reported. One of opening_ledger,
closing_ledger, current_ledger, opening_available,
opening_available_next_business_day, closing_available, current_available,
'previously_closed_book', or other.
82 83 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb', line 82 required :balance_type, enum: -> { ModernTreasury::InternalAccounts::BalanceReportCreateParams::Balance::BalanceType } |
#vendor_code ⇒ String
The code used by the bank when reporting this specific balance.
89 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb', line 89 required :vendor_code, String |
#vendor_code_type ⇒ String?
The type of vendor_code being reported. Can be one of bai2, bankprov,
bnk_dev, cleartouch, currencycloud, cross_river, dc_bank, dwolla,
evolve, goldman_sachs, iso20022, jpmc, mx, silvergate, swift, or
us_bank.
98 |
# File 'lib/modern_treasury/models/internal_accounts/balance_report_create_params.rb', line 98 required :vendor_code_type, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
92 |
# File 'sig/modern_treasury/models/internal_accounts/balance_report_create_params.rbs', line 92
def to_hash: -> {
|