Class: ModernTreasury::Models::InvoiceUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::InvoiceUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/invoice_update_params.rb
Overview
Defined Under Namespace
Modules: PaymentMethod Classes: CounterpartyBillingAddress, CounterpartyShippingAddress, InvoiceLineItem, InvoicerAddress
Instance Attribute Summary collapse
-
#contact_details ⇒ Array<ModernTreasury::Models::ContactDetail>?
The invoicer’s contact details displayed at the top of the invoice.
-
#counterparty_billing_address ⇒ ModernTreasury::Models::InvoiceUpdateParams::CounterpartyBillingAddress?
The counterparty’s billing address.
-
#counterparty_id ⇒ String?
The ID of the counterparty receiving the invoice.
-
#counterparty_shipping_address ⇒ ModernTreasury::Models::InvoiceUpdateParams::CounterpartyShippingAddress?
The counterparty’s shipping address where physical goods should be delivered.
-
#currency ⇒ Symbol, ...
Currency that the invoice is denominated in.
-
#description ⇒ String?
A free-form description of the invoice.
-
#due_date ⇒ Time?
A future date by when the invoice needs to be paid.
-
#fallback_payment_method ⇒ String?
When payment_method is automatic, the fallback payment method to use when an automatic payment fails.
- #id ⇒ String
-
#invoice_line_items ⇒ Array<ModernTreasury::Models::InvoiceUpdateParams::InvoiceLineItem>?
An array of invoice line items.
-
#invoicer_address ⇒ ModernTreasury::Models::InvoiceUpdateParams::InvoicerAddress?
The invoice issuer’s business address.
-
#invoicer_name ⇒ String?
The name of the issuer for the invoice.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#notification_email_addresses ⇒ Array<String>?
Emails in addition to the counterparty email to send invoice status notifications to.
-
#notifications_enabled ⇒ Boolean?
If true, the invoice will send email notifications to the invoice recipients about invoice status changes.
-
#originating_account_id ⇒ String?
The ID of the internal account the invoice should be paid to.
-
#payment_effective_date ⇒ Date?
Date transactions are to be posted to the participants’ account.
-
#payment_method ⇒ Symbol, ...
The method by which the invoice can be paid.
-
#payment_type ⇒ Symbol, ...
One of ‘ach`, `se_bankgirot`, `eft`, `wire`, `check`, `sen`, `book`, `rtp`, `sepa`, `bacs`, `au_becs`, `interac`, `neft`, `nics`, `nz_national_clearing_code`, `sic`, `signet`, `provexchange`, `zengin`.
-
#receiving_account_id ⇒ String?
The receiving account ID.
-
#recipient_email ⇒ String?
The email of the recipient of the invoice.
-
#recipient_name ⇒ String?
The name of the recipient of the invoice.
-
#remind_after_overdue_days ⇒ Array<Integer>?
Number of days after due date when overdue reminder emails will be sent out to invoice recipients.
-
#status ⇒ String?
Invoice status must be updated in a ‘PATCH` request that does not modify any other invoice attributes.
-
#virtual_account_id ⇒ String?
The ID of the virtual account the invoice should be paid to.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(country:, line1:, locality:, postal_code:, region:, line2: nil) ⇒ Object
constructor
The invoice issuer’s business address.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(country:, line1:, locality:, postal_code:, region:, line2: nil) ⇒ Object
The invoice issuer’s business address.
|
|
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 280
|
Instance Attribute Details
#contact_details ⇒ Array<ModernTreasury::Models::ContactDetail>?
The invoicer’s contact details displayed at the top of the invoice.
19 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 19 optional :contact_details, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ContactDetail] } |
#counterparty_billing_address ⇒ ModernTreasury::Models::InvoiceUpdateParams::CounterpartyBillingAddress?
The counterparty’s billing address.
25 26 27 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 25 optional :counterparty_billing_address, -> { ModernTreasury::InvoiceUpdateParams::CounterpartyBillingAddress }, nil?: true |
#counterparty_id ⇒ String?
The ID of the counterparty receiving the invoice.
33 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 33 optional :counterparty_id, String |
#counterparty_shipping_address ⇒ ModernTreasury::Models::InvoiceUpdateParams::CounterpartyShippingAddress?
The counterparty’s shipping address where physical goods should be delivered.
39 40 41 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 39 optional :counterparty_shipping_address, -> { ModernTreasury::InvoiceUpdateParams::CounterpartyShippingAddress }, nil?: true |
#currency ⇒ Symbol, ...
Currency that the invoice is denominated in. Defaults to ‘USD` if not provided.
47 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 47 optional :currency, enum: -> { ModernTreasury::Currency } |
#description ⇒ String?
A free-form description of the invoice.
53 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 53 optional :description, String |
#due_date ⇒ Time?
A future date by when the invoice needs to be paid.
59 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 59 optional :due_date, Time |
#fallback_payment_method ⇒ String?
When payment_method is automatic, the fallback payment method to use when an automatic payment fails. One of ‘manual` or `ui`.
66 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 66 optional :fallback_payment_method, String, nil?: true |
#id ⇒ String
13 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 13 required :id, String |
#invoice_line_items ⇒ Array<ModernTreasury::Models::InvoiceUpdateParams::InvoiceLineItem>?
An array of invoice line items. The API supports a maximum of 50 invoice line items per invoice. If a greater number of invoice line items is required, please contact support.
74 75 76 77 78 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 74 optional :invoice_line_items, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::InvoiceUpdateParams::InvoiceLineItem] }, nil?: true |
#invoicer_address ⇒ ModernTreasury::Models::InvoiceUpdateParams::InvoicerAddress?
The invoice issuer’s business address.
84 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 84 optional :invoicer_address, -> { ModernTreasury::InvoiceUpdateParams::InvoicerAddress }, nil?: true |
#invoicer_name ⇒ String?
The name of the issuer for the invoice. Defaults to the name of the Organization.
91 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 91 optional :invoicer_name, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
98 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 98 optional :metadata, ModernTreasury::Internal::Type::HashOf[String], nil?: true |
#notification_email_addresses ⇒ Array<String>?
Emails in addition to the counterparty email to send invoice status notifications to. At least one email is required if notifications are enabled and the counterparty doesn’t have an email.
106 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 106 optional :notification_email_addresses, ModernTreasury::Internal::Type::ArrayOf[String], nil?: true |
#notifications_enabled ⇒ Boolean?
If true, the invoice will send email notifications to the invoice recipients about invoice status changes.
113 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 113 optional :notifications_enabled, ModernTreasury::Internal::Type::Boolean |
#originating_account_id ⇒ String?
The ID of the internal account the invoice should be paid to.
119 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 119 optional :originating_account_id, String |
#payment_effective_date ⇒ Date?
Date transactions are to be posted to the participants’ account. Defaults to the current business day or the next business day if the current day is a bank holiday or weekend. Format: yyyy-mm-dd.
127 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 127 optional :payment_effective_date, Date |
#payment_method ⇒ Symbol, ...
The method by which the invoice can be paid. ‘ui` will show the embedded payment collection flow. `automatic` will automatically initiate payment based upon the account details of the receiving_account id.nIf the invoice amount is positive, the automatically initiated payment order’s direction will be debit. If the invoice amount is negative, the automatically initiated payment order’s direction will be credit. One of ‘manual`, `ui`, or `automatic`.
138 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 138 optional :payment_method, enum: -> { ModernTreasury::InvoiceUpdateParams::PaymentMethod } |
#payment_type ⇒ Symbol, ...
One of ‘ach`, `se_bankgirot`, `eft`, `wire`, `check`, `sen`, `book`, `rtp`, `sepa`, `bacs`, `au_becs`, `interac`, `neft`, `nics`, `nz_national_clearing_code`, `sic`, `signet`, `provexchange`, `zengin`.
146 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 146 optional :payment_type, enum: -> { ModernTreasury::PaymentOrderType } |
#receiving_account_id ⇒ String?
The receiving account ID. Can be an ‘external_account`.
152 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 152 optional :receiving_account_id, String |
#recipient_email ⇒ String?
The email of the recipient of the invoice. Leaving this value as null will fallback to using the counterparty’s name.
159 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 159 optional :recipient_email, String, nil?: true |
#recipient_name ⇒ String?
The name of the recipient of the invoice. Leaving this value as null will fallback to using the counterparty’s name.
166 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 166 optional :recipient_name, String, nil?: true |
#remind_after_overdue_days ⇒ Array<Integer>?
Number of days after due date when overdue reminder emails will be sent out to invoice recipients.
173 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 173 optional :remind_after_overdue_days, ModernTreasury::Internal::Type::ArrayOf[Integer], nil?: true |
#status ⇒ String?
Invoice status must be updated in a ‘PATCH` request that does not modify any other invoice attributes. Valid state transitions are `draft` to `unpaid`, `draft` or `unpaid` to `voided`, and `draft` or `unpaid` to `paid`.
181 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 181 optional :status, String |
#virtual_account_id ⇒ String?
The ID of the virtual account the invoice should be paid to.
187 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 187 optional :virtual_account_id, String, nil?: true |