Class: ModernTreasury::Models::InvoiceUpdateParams::InvoiceLineItem
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::InvoiceUpdateParams::InvoiceLineItem
- Defined in:
- lib/modern_treasury/models/invoice_update_params.rb
Instance Attribute Summary collapse
-
#description ⇒ String?
An optional free-form description of the line item.
-
#direction ⇒ String?
Either ‘debit` or `credit`.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#name ⇒ String
The name of the line item, typically a product or SKU name.
-
#quantity ⇒ Integer?
The number of units of a product or service that this line item is for.
-
#unit_amount ⇒ Integer
The cost per unit of the product or service that this line item is for, specified in the invoice currency’s smallest unit.
-
#unit_amount_decimal ⇒ String?
The cost per unit of the product or service that this line item is for, specified in the invoice currency’s smallest unit.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from ModernTreasury::Internal::Type::BaseModel
Instance Attribute Details
#description ⇒ String?
An optional free-form description of the line item.
365 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 365 optional :description, String |
#direction ⇒ String?
Either ‘debit` or `credit`. `debit` indicates that a client owes the business money and increases the invoice’s ‘total_amount` due. `credit` has the opposite intention and effect.
373 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 373 optional :direction, String |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
380 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 380 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#name ⇒ String
The name of the line item, typically a product or SKU name.
352 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 352 required :name, String |
#quantity ⇒ Integer?
The number of units of a product or service that this line item is for. Must be a whole number. Defaults to 1 if not provided.
387 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 387 optional :quantity, Integer |
#unit_amount ⇒ Integer
The cost per unit of the product or service that this line item is for, specified in the invoice currency’s smallest unit.
359 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 359 required :unit_amount, Integer |
#unit_amount_decimal ⇒ String?
The cost per unit of the product or service that this line item is for, specified in the invoice currency’s smallest unit. Accepts decimal strings with up to 12 decimals
395 |
# File 'lib/modern_treasury/models/invoice_update_params.rb', line 395 optional :unit_amount_decimal, String |