Class: ModernTreasury::Models::Invoices::LineItemUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::Invoices::LineItemUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/invoices/line_item_update_params.rb,
sig/modern_treasury/models/invoices/line_item_update_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ModernTreasury
Instance Attribute Summary collapse
-
#description ⇒ String?
An optional free-form description of the line item.
-
#direction ⇒ String?
Either
debitorcredit. - #id ⇒ String
- #invoice_id ⇒ String
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#name ⇒ String?
The name of the line item, typically a product or SKU name.
-
#quantity ⇒ Integer?
The number of units of a product or service that this line item is for.
-
#unit_amount ⇒ Integer?
The cost per unit of the product or service that this line item is for, specified in the invoice currency's smallest unit.
-
#unit_amount_decimal ⇒ String?
The cost per unit of the product or service that this line item is for, specified in the invoice currency's smallest unit.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(invoice_id:, id:, description: nil, direction: nil, metadata: nil, name: nil, quantity: nil, unit_amount: nil, unit_amount_decimal: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see LineItemUpdateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(invoice_id:, id:, description: nil, direction: nil, metadata: nil, name: nil, quantity: nil, unit_amount: nil, unit_amount_decimal: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::Invoices::LineItemUpdateParams for more details.
|
|
# File 'lib/modern_treasury/models/invoices/line_item_update_params.rb', line 70
|
Instance Attribute Details
#description ⇒ String?
An optional free-form description of the line item.
25 |
# File 'lib/modern_treasury/models/invoices/line_item_update_params.rb', line 25 optional :description, String |
#direction ⇒ String?
Either debit or credit. debit indicates that a client owes the business
money and increases the invoice's total_amount due. credit has the opposite
intention and effect.
33 |
# File 'lib/modern_treasury/models/invoices/line_item_update_params.rb', line 33 optional :direction, String |
#id ⇒ String
19 |
# File 'lib/modern_treasury/models/invoices/line_item_update_params.rb', line 19 required :id, String |
#invoice_id ⇒ String
14 |
# File 'lib/modern_treasury/models/invoices/line_item_update_params.rb', line 14 required :invoice_id, String |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
40 |
# File 'lib/modern_treasury/models/invoices/line_item_update_params.rb', line 40 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#name ⇒ String?
The name of the line item, typically a product or SKU name.
46 |
# File 'lib/modern_treasury/models/invoices/line_item_update_params.rb', line 46 optional :name, String |
#quantity ⇒ Integer?
The number of units of a product or service that this line item is for. Must be a whole number. Defaults to 1 if not provided.
53 |
# File 'lib/modern_treasury/models/invoices/line_item_update_params.rb', line 53 optional :quantity, Integer |
#unit_amount ⇒ Integer?
The cost per unit of the product or service that this line item is for, specified in the invoice currency's smallest unit.
60 |
# File 'lib/modern_treasury/models/invoices/line_item_update_params.rb', line 60 optional :unit_amount, Integer |
#unit_amount_decimal ⇒ String?
The cost per unit of the product or service that this line item is for, specified in the invoice currency's smallest unit. Accepts decimal strings with up to 12 decimals
68 |
# File 'lib/modern_treasury/models/invoices/line_item_update_params.rb', line 68 optional :unit_amount_decimal, String |
Instance Method Details
#to_hash ⇒ {
67 |
# File 'sig/modern_treasury/models/invoices/line_item_update_params.rbs', line 67
def to_hash: -> {
|