Class: ModernTreasury::Models::LedgerAccountBalanceMonitor::AlertCondition
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::LedgerAccountBalanceMonitor::AlertCondition
- Defined in:
- lib/modern_treasury/models/ledger_account_balance_monitor.rb,
sig/modern_treasury/models/ledger_account_balance_monitor.rbs
Overview
Instance Attribute Summary collapse
-
#field ⇒ String
One of
available_balance_amount,pending_balance_amount,posted_balance_amount,ledger_account_lock_version. -
#operator ⇒ String
A logical operator to compare the
fieldagainst thevalue. -
#value ⇒ Integer
The monitor's
current_ledger_account_balance_state.triggeredwill betruewhen comparing thefieldto this integer value using theoperatoris logically true.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
78 |
# File 'sig/modern_treasury/models/ledger_account_balance_monitor.rbs', line 78
def initialize: (
|
Instance Attribute Details
#field ⇒ String
One of available_balance_amount, pending_balance_amount,
posted_balance_amount, ledger_account_lock_version.
105 |
# File 'lib/modern_treasury/models/ledger_account_balance_monitor.rb', line 105 required :field, String |
#operator ⇒ String
A logical operator to compare the field against the value. One of
less_than, less_than_or_equals, equals, greater_than_or_equals,
greater_than.
113 |
# File 'lib/modern_treasury/models/ledger_account_balance_monitor.rb', line 113 required :operator, String |
#value ⇒ Integer
The monitor's current_ledger_account_balance_state.triggered will be true
when comparing the field to this integer value using the operator is
logically true.
121 |
# File 'lib/modern_treasury/models/ledger_account_balance_monitor.rb', line 121 required :value, Integer |
Instance Method Details
#to_hash ⇒ { field: String, operator: String, value: Integer }
84 |
# File 'sig/modern_treasury/models/ledger_account_balance_monitor.rbs', line 84
def to_hash: -> { field: String, operator: String, value: Integer }
|