Class: ModernTreasury::Models::LedgerAccountBalanceMonitorCreateParams::AlertCondition
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::LedgerAccountBalanceMonitorCreateParams::AlertCondition
- Defined in:
- lib/modern_treasury/models/ledger_account_balance_monitor_create_params.rb,
sig/modern_treasury/models/ledger_account_balance_monitor_create_params.rbs
Instance Attribute Summary collapse
-
#field ⇒ String
One of
available_balance_amount,pending_balance_amount,posted_balance_amount,ledger_account_lock_version. -
#operator ⇒ String
A logical operator to compare the
fieldagainst thevalue. -
#value ⇒ Integer
The monitor's
current_ledger_account_balance_state.triggeredwill betruewhen comparing thefieldto this integer value using theoperatoris logically true.
Instance Method Summary collapse
-
#initialize(field:, operator:, value:) ⇒ Object
constructor
Some parameter documentations has been truncated, see AlertCondition for more details.
- #to_hash ⇒ { field: String, operator: String, value: Integer }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(field:, operator:, value:) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::LedgerAccountBalanceMonitorCreateParams::AlertCondition for more details.
Describes the condition that must be satisfied for the monitor to be triggered.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/modern_treasury/models/ledger_account_balance_monitor_create_params.rb', line 50 class AlertCondition < ModernTreasury::Internal::Type::BaseModel # @!attribute field # One of `available_balance_amount`, `pending_balance_amount`, # `posted_balance_amount`, `ledger_account_lock_version`. # # @return [String] required :field, String # @!attribute operator # A logical operator to compare the `field` against the `value`. One of # `less_than`, `less_than_or_equals`, `equals`, `greater_than_or_equals`, # `greater_than`. # # @return [String] required :operator, String # @!attribute value # The monitor's `current_ledger_account_balance_state.triggered` will be `true` # when comparing the `field` to this integer value using the `operator` is # logically true. # # @return [Integer] required :value, Integer # @!method initialize(field:, operator:, value:) # Some parameter documentations has been truncated, see # {ModernTreasury::Models::LedgerAccountBalanceMonitorCreateParams::AlertCondition} # for more details. # # Describes the condition that must be satisfied for the monitor to be triggered. # # @param field [String] One of `available_balance_amount`, `pending_balance_amount`, `posted_balance_amo # # @param operator [String] A logical operator to compare the `field` against the `value`. One of `less_than # # @param value [Integer] The monitor's `current_ledger_account_balance_state.triggered` will be `true` wh end |
Instance Attribute Details
#field ⇒ String
One of available_balance_amount, pending_balance_amount,
posted_balance_amount, ledger_account_lock_version.
56 |
# File 'lib/modern_treasury/models/ledger_account_balance_monitor_create_params.rb', line 56 required :field, String |
#operator ⇒ String
A logical operator to compare the field against the value. One of
less_than, less_than_or_equals, equals, greater_than_or_equals,
greater_than.
64 |
# File 'lib/modern_treasury/models/ledger_account_balance_monitor_create_params.rb', line 64 required :operator, String |
#value ⇒ Integer
The monitor's current_ledger_account_balance_state.triggered will be true
when comparing the field to this integer value using the operator is
logically true.
72 |
# File 'lib/modern_treasury/models/ledger_account_balance_monitor_create_params.rb', line 72 required :value, Integer |
Instance Method Details
#to_hash ⇒ { field: String, operator: String, value: Integer }
59 |
# File 'sig/modern_treasury/models/ledger_account_balance_monitor_create_params.rbs', line 59
def to_hash: -> { field: String, operator: String, value: Integer }
|