Class: ModernTreasury::Models::LedgerAccountCreateRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::LedgerAccountCreateRequest
- Defined in:
- lib/modern_treasury/models/ledger_account_create_request.rb
Direct Known Subclasses
Defined Under Namespace
Modules: LedgerableType
Instance Attribute Summary collapse
-
#currency ⇒ String
The currency of the ledger account.
-
#currency_exponent ⇒ Integer?
The currency exponent of the ledger account.
-
#description ⇒ String?
The description of the ledger account.
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
-
#ledger_account_category_ids ⇒ Array<String>?
The array of ledger account category ids that this ledger account should be a child of.
-
#ledger_id ⇒ String
The id of the ledger that this account belongs to.
-
#ledgerable_id ⇒ String?
If the ledger account links to another object in Modern Treasury, the id will be populated here, otherwise null.
-
#ledgerable_type ⇒ Symbol, ...
If the ledger account links to another object in Modern Treasury, the type will be populated here, otherwise null.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#name ⇒ String
The name of the ledger account.
-
#normal_balance ⇒ Symbol, ModernTreasury::Models::TransactionDirection
The normal balance of the ledger account.
Instance Method Summary collapse
-
#initialize(currency:, ledger_id:, name:, normal_balance:, currency_exponent: nil, description: nil, external_id: nil, ledger_account_category_ids: nil, ledgerable_id: nil, ledgerable_type: nil, metadata: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see LedgerAccountCreateRequest for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(currency:, ledger_id:, name:, normal_balance:, currency_exponent: nil, description: nil, external_id: nil, ledger_account_category_ids: nil, ledgerable_id: nil, ledgerable_type: nil, metadata: nil) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::LedgerAccountCreateRequest for more details.
|
|
# File 'lib/modern_treasury/models/ledger_account_create_request.rb', line 77
|
Instance Attribute Details
#currency ⇒ String
The currency of the ledger account.
10 |
# File 'lib/modern_treasury/models/ledger_account_create_request.rb', line 10 required :currency, String |
#currency_exponent ⇒ Integer?
The currency exponent of the ledger account.
34 |
# File 'lib/modern_treasury/models/ledger_account_create_request.rb', line 34 optional :currency_exponent, Integer, nil?: true |
#description ⇒ String?
The description of the ledger account.
40 |
# File 'lib/modern_treasury/models/ledger_account_create_request.rb', line 40 optional :description, String, nil?: true |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
46 |
# File 'lib/modern_treasury/models/ledger_account_create_request.rb', line 46 optional :external_id, String, nil?: true |
#ledger_account_category_ids ⇒ Array<String>?
The array of ledger account category ids that this ledger account should be a child of.
53 |
# File 'lib/modern_treasury/models/ledger_account_create_request.rb', line 53 optional :ledger_account_category_ids, ModernTreasury::Internal::Type::ArrayOf[String] |
#ledger_id ⇒ String
The id of the ledger that this account belongs to.
16 |
# File 'lib/modern_treasury/models/ledger_account_create_request.rb', line 16 required :ledger_id, String |
#ledgerable_id ⇒ String?
If the ledger account links to another object in Modern Treasury, the id will be populated here, otherwise null.
60 |
# File 'lib/modern_treasury/models/ledger_account_create_request.rb', line 60 optional :ledgerable_id, String |
#ledgerable_type ⇒ Symbol, ...
If the ledger account links to another object in Modern Treasury, the type will be populated here, otherwise null. The value is one of internal_account or external_account.
68 |
# File 'lib/modern_treasury/models/ledger_account_create_request.rb', line 68 optional :ledgerable_type, enum: -> { ModernTreasury::LedgerAccountCreateRequest::LedgerableType } |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
75 |
# File 'lib/modern_treasury/models/ledger_account_create_request.rb', line 75 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#name ⇒ String
The name of the ledger account.
22 |
# File 'lib/modern_treasury/models/ledger_account_create_request.rb', line 22 required :name, String |
#normal_balance ⇒ Symbol, ModernTreasury::Models::TransactionDirection
The normal balance of the ledger account.
28 |
# File 'lib/modern_treasury/models/ledger_account_create_request.rb', line 28 required :normal_balance, enum: -> { ModernTreasury::TransactionDirection } |