Class: ModernTreasury::Models::LedgerAccountRetrieveParams::Balances
Instance Attribute Summary collapse
Instance Method Summary
collapse
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(as_of_date: nil, as_of_lock_version: nil, effective_at: nil, effective_at_lower_bound: nil, effective_at_upper_bound: nil) ⇒ Object
Use ‘balances` and `balances` to get the balances change between the two timestamps. The lower bound is inclusive while the upper bound is exclusive of the provided timestamps. If no value is supplied the balances will be retrieved not including that bound. Use `balances` to retrieve a balance as of a specific Ledger Account `lock_version`.
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
|
# File 'lib/modern_treasury/models/ledger_account_retrieve_params.rb', line 36
class Balances < ModernTreasury::Internal::Type::BaseModel
optional :as_of_date, Date
optional :as_of_lock_version, Integer
optional :effective_at, Time
optional :effective_at_lower_bound, Time
optional :effective_at_upper_bound, Time
end
|
Instance Attribute Details
#as_of_date ⇒ Date?
40
|
# File 'lib/modern_treasury/models/ledger_account_retrieve_params.rb', line 40
optional :as_of_date, Date
|
#as_of_lock_version ⇒ Integer?
45
|
# File 'lib/modern_treasury/models/ledger_account_retrieve_params.rb', line 45
optional :as_of_lock_version, Integer
|
#effective_at ⇒ Time?
50
|
# File 'lib/modern_treasury/models/ledger_account_retrieve_params.rb', line 50
optional :effective_at, Time
|
#effective_at_lower_bound ⇒ Time?
55
|
# File 'lib/modern_treasury/models/ledger_account_retrieve_params.rb', line 55
optional :effective_at_lower_bound, Time
|
#effective_at_upper_bound ⇒ Time?
60
|
# File 'lib/modern_treasury/models/ledger_account_retrieve_params.rb', line 60
optional :effective_at_upper_bound, Time
|