Class: ModernTreasury::Models::LedgerAccountSettlement
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::LedgerAccountSettlement
- Defined in:
- lib/modern_treasury/models/ledger_account_settlement.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#amount ⇒ Integer?
The amount of the ledger account settlement.
-
#contra_ledger_account_id ⇒ String
The id of the contra ledger account that sends to or receives funds from the settled ledger account.
- #created_at ⇒ Time
-
#currency ⇒ String
The currency of the ledger account settlement.
-
#currency_exponent ⇒ Integer?
The currency exponent of the ledger account settlement.
-
#description ⇒ String?
The description of the ledger account settlement.
-
#effective_at_upper_bound ⇒ Time?
The exclusive upper bound of the effective_at timestamp of the ledger entries to be included in the ledger account settlement.
- #id ⇒ String
-
#ledger_id ⇒ String
The id of the ledger that this ledger account settlement belongs to.
-
#ledger_transaction_id ⇒ String?
The id of the ledger transaction that this settlement is associated with.
-
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
-
#metadata ⇒ Hash{Symbol=>String}
Additional data represented as key-value pairs.
- #object ⇒ String
-
#settled_ledger_account_id ⇒ String
The id of the settled ledger account whose ledger entries are queried against, and its balance is reduced as a result.
-
#settlement_entry_direction ⇒ String?
The direction of the ledger entry with the settlement_ledger_account.
-
#status ⇒ Symbol, ModernTreasury::Models::LedgerAccountSettlement::Status
The status of the ledger account settlement.
- #updated_at ⇒ Time
Instance Method Summary collapse
-
#initialize(id:, amount:, contra_ledger_account_id:, created_at:, currency:, currency_exponent:, description:, effective_at_upper_bound:, ledger_id:, ledger_transaction_id:, live_mode:, metadata:, object:, settled_ledger_account_id:, settlement_entry_direction:, status:, updated_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see LedgerAccountSettlement for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, amount:, contra_ledger_account_id:, created_at:, currency:, currency_exponent:, description:, effective_at_upper_bound:, ledger_id:, ledger_transaction_id:, live_mode:, metadata:, object:, settled_ledger_account_id:, settlement_entry_direction:, status:, updated_at:) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::LedgerAccountSettlement for more details.
|
|
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 112
|
Instance Attribute Details
#amount ⇒ Integer?
The amount of the ledger account settlement.
16 |
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 16 required :amount, Integer, nil?: true |
#contra_ledger_account_id ⇒ String
The id of the contra ledger account that sends to or receives funds from the settled ledger account.
23 |
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 23 required :contra_ledger_account_id, String |
#created_at ⇒ Time
28 |
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 28 required :created_at, Time |
#currency ⇒ String
The currency of the ledger account settlement.
34 |
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 34 required :currency, String |
#currency_exponent ⇒ Integer?
The currency exponent of the ledger account settlement.
40 |
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 40 required :currency_exponent, Integer, nil?: true |
#description ⇒ String?
The description of the ledger account settlement.
46 |
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 46 required :description, String, nil?: true |
#effective_at_upper_bound ⇒ Time?
The exclusive upper bound of the effective_at timestamp of the ledger entries to be included in the ledger account settlement. The default value is the created_at timestamp of the ledger account settlement.
54 |
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 54 required :effective_at_upper_bound, Time, nil?: true |
#id ⇒ String
10 |
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 10 required :id, String |
#ledger_id ⇒ String
The id of the ledger that this ledger account settlement belongs to.
60 |
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 60 required :ledger_id, String |
#ledger_transaction_id ⇒ String?
The id of the ledger transaction that this settlement is associated with.
66 |
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 66 required :ledger_transaction_id, String, nil?: true |
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
73 |
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 73 required :live_mode, ModernTreasury::Internal::Type::Boolean |
#metadata ⇒ Hash{Symbol=>String}
Additional data represented as key-value pairs. Both the key and value must be strings.
80 |
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 80 required :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#object ⇒ String
85 |
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 85 required :object, String |
#settled_ledger_account_id ⇒ String
The id of the settled ledger account whose ledger entries are queried against, and its balance is reduced as a result.
92 |
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 92 required :settled_ledger_account_id, String |
#settlement_entry_direction ⇒ String?
The direction of the ledger entry with the settlement_ledger_account.
98 |
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 98 required :settlement_entry_direction, String, nil?: true |
#status ⇒ Symbol, ModernTreasury::Models::LedgerAccountSettlement::Status
The status of the ledger account settlement. One of ‘processing`, `pending`, `posted`, `archiving` or `archived`.
105 |
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 105 required :status, enum: -> { ModernTreasury::LedgerAccountSettlement::Status } |
#updated_at ⇒ Time
110 |
# File 'lib/modern_treasury/models/ledger_account_settlement.rb', line 110 required :updated_at, Time |