Class: ModernTreasury::Models::LegalEntity::Address
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::LegalEntity::Address
- Defined in:
- lib/modern_treasury/models/legal_entity.rb,
sig/modern_treasury/models/legal_entity.rbs
Defined Under Namespace
Modules: AddressType
Instance Attribute Summary collapse
-
#address_types ⇒ Array<Symbol, ModernTreasury::Models::LegalEntity::Address::AddressType>
The types of this address.
-
#country ⇒ String?
Country code conforms to [ISO 3166-1 alpha-2].
- #created_at ⇒ Time
- #discarded_at ⇒ Time?
- #id ⇒ String
- #line1 ⇒ String?
- #line2 ⇒ String?
-
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
-
#locality ⇒ String?
Locality or City.
- #object ⇒ String
-
#postal_code ⇒ String?
The postal code of the address.
-
#primary ⇒ Boolean?
Whether this address is the primary address for the legal entity.
-
#region ⇒ String?
Region or State.
- #updated_at ⇒ Time
Instance Method Summary collapse
-
#initialize(id:, addresses:, bank_settings:, business_description:, business_name:, citizenship_country:, compliance_details:, country_of_incorporation:, created_at:, date_formed:, date_of_birth:, discarded_at:, documents:, doing_business_as_names:, email:, expected_activity_volume:, external_id:, first_name:, identifications:, industry_classifications:, intended_use:, last_name:, legal_entity_type:, legal_structure:, listed_exchange:, live_mode:, metadata:, middle_name:, object:, operating_jurisdictions:, phone_numbers:, politically_exposed_person:, preferred_name:, prefix:, primary_social_media_sites:, regulators:, risk_rating:, service_provider_legal_entity_id:, status:, suffix:, terms_of_use:, third_party_verification:, third_party_verifications:, ticker_symbol:, updated_at:, wealth_and_employment_details:, website:, legal_entity_associations: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ModernTreasury::Models::LegalEntity for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, addresses:, bank_settings:, business_description:, business_name:, citizenship_country:, compliance_details:, country_of_incorporation:, created_at:, date_formed:, date_of_birth:, discarded_at:, documents:, doing_business_as_names:, email:, expected_activity_volume:, external_id:, first_name:, identifications:, industry_classifications:, intended_use:, last_name:, legal_entity_type:, legal_structure:, listed_exchange:, live_mode:, metadata:, middle_name:, object:, operating_jurisdictions:, phone_numbers:, politically_exposed_person:, preferred_name:, prefix:, primary_social_media_sites:, regulators:, risk_rating:, service_provider_legal_entity_id:, status:, suffix:, terms_of_use:, third_party_verification:, third_party_verifications:, ticker_symbol:, updated_at:, wealth_and_employment_details:, website:, legal_entity_associations: nil) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::LegalEntity for more details.
402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'lib/modern_treasury/models/legal_entity.rb', line 402 class Address < ModernTreasury::Internal::Type::BaseModel # @!attribute id # # @return [String] required :id, String # @!attribute address_types # The types of this address. # # @return [Array<Symbol, ModernTreasury::Models::LegalEntity::Address::AddressType>] required :address_types, -> { ModernTreasury::Internal::Type::ArrayOf[enum: ModernTreasury::LegalEntity::Address::AddressType] } # @!attribute country # Country code conforms to [ISO 3166-1 alpha-2] # # @return [String, nil] required :country, String, nil?: true # @!attribute created_at # # @return [Time] required :created_at, Time # @!attribute discarded_at # # @return [Time, nil] required :discarded_at, Time, nil?: true # @!attribute line1 # # @return [String, nil] required :line1, String, nil?: true # @!attribute line2 # # @return [String, nil] required :line2, String, nil?: true # @!attribute live_mode # This field will be true if this object exists in the live environment or false # if it exists in the test environment. # # @return [Boolean] required :live_mode, ModernTreasury::Internal::Type::Boolean # @!attribute locality # Locality or City. # # @return [String, nil] required :locality, String, nil?: true # @!attribute object # # @return [String] required :object, String # @!attribute postal_code # The postal code of the address. # # @return [String, nil] required :postal_code, String, nil?: true # @!attribute primary # Whether this address is the primary address for the legal entity. Optional; when # omitted it is inferred from the address types. # # @return [Boolean, nil] required :primary, ModernTreasury::Internal::Type::Boolean, nil?: true # @!attribute region # Region or State. # # @return [String, nil] required :region, String, nil?: true # @!attribute updated_at # # @return [Time] required :updated_at, Time # @!method initialize(id:, address_types:, country:, created_at:, discarded_at:, line1:, line2:, live_mode:, locality:, object:, postal_code:, primary:, region:, updated_at:) # Some parameter documentations has been truncated, see # {ModernTreasury::Models::LegalEntity::Address} for more details. # # @param id [String] # # @param address_types [Array<Symbol, ModernTreasury::Models::LegalEntity::Address::AddressType>] The types of this address. # # @param country [String, nil] Country code conforms to [ISO 3166-1 alpha-2] # # @param created_at [Time] # # @param discarded_at [Time, nil] # # @param line1 [String, nil] # # @param line2 [String, nil] # # @param live_mode [Boolean] This field will be true if this object exists in the live environment or false i # # @param locality [String, nil] Locality or City. # # @param object [String] # # @param postal_code [String, nil] The postal code of the address. # # @param primary [Boolean, nil] Whether this address is the primary address for the legal entity. Optional; when # # @param region [String, nil] Region or State. # # @param updated_at [Time] module AddressType extend ModernTreasury::Internal::Type::Enum BUSINESS = :business BUSINESS_PHYSICAL = :business_physical BUSINESS_REGISTERED = :business_registered MAILING = :mailing OTHER = :other PO_BOX = :po_box RESIDENTIAL = :residential # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#address_types ⇒ Array<Symbol, ModernTreasury::Models::LegalEntity::Address::AddressType>
The types of this address.
412 413 |
# File 'lib/modern_treasury/models/legal_entity.rb', line 412 required :address_types, -> { ModernTreasury::Internal::Type::ArrayOf[enum: ModernTreasury::LegalEntity::Address::AddressType] } |
#country ⇒ String?
Country code conforms to [ISO 3166-1 alpha-2]
419 |
# File 'lib/modern_treasury/models/legal_entity.rb', line 419 required :country, String, nil?: true |
#created_at ⇒ Time
424 |
# File 'lib/modern_treasury/models/legal_entity.rb', line 424 required :created_at, Time |
#discarded_at ⇒ Time?
429 |
# File 'lib/modern_treasury/models/legal_entity.rb', line 429 required :discarded_at, Time, nil?: true |
#id ⇒ String
406 |
# File 'lib/modern_treasury/models/legal_entity.rb', line 406 required :id, String |
#line1 ⇒ String?
434 |
# File 'lib/modern_treasury/models/legal_entity.rb', line 434 required :line1, String, nil?: true |
#line2 ⇒ String?
439 |
# File 'lib/modern_treasury/models/legal_entity.rb', line 439 required :line2, String, nil?: true |
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
446 |
# File 'lib/modern_treasury/models/legal_entity.rb', line 446 required :live_mode, ModernTreasury::Internal::Type::Boolean |
#locality ⇒ String?
Locality or City.
452 |
# File 'lib/modern_treasury/models/legal_entity.rb', line 452 required :locality, String, nil?: true |
#object ⇒ String
457 |
# File 'lib/modern_treasury/models/legal_entity.rb', line 457 required :object, String |
#postal_code ⇒ String?
The postal code of the address.
463 |
# File 'lib/modern_treasury/models/legal_entity.rb', line 463 required :postal_code, String, nil?: true |
#primary ⇒ Boolean?
Whether this address is the primary address for the legal entity. Optional; when omitted it is inferred from the address types.
470 |
# File 'lib/modern_treasury/models/legal_entity.rb', line 470 required :primary, ModernTreasury::Internal::Type::Boolean, nil?: true |
#region ⇒ String?
Region or State.
476 |
# File 'lib/modern_treasury/models/legal_entity.rb', line 476 required :region, String, nil?: true |
#updated_at ⇒ Time
481 |
# File 'lib/modern_treasury/models/legal_entity.rb', line 481 required :updated_at, Time |
Instance Method Details
#to_hash ⇒ {
318 |
# File 'sig/modern_treasury/models/legal_entity.rbs', line 318
def to_hash: -> {
|