Class: ModernTreasury::Models::LegalEntityAssociation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::LegalEntityAssociation
- Defined in:
- lib/modern_treasury/models/legal_entity_association.rb,
sig/modern_treasury/models/legal_entity_association.rbs
Defined Under Namespace
Modules: RelationshipType
Instance Attribute Summary collapse
-
#child_legal_entity ⇒ ModernTreasury::Models::ChildLegalEntity
The child legal entity.
- #created_at ⇒ Time
- #discarded_at ⇒ Time?
- #id ⇒ String
-
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
- #object ⇒ String
-
#ownership_percentage ⇒ Integer?
The child entity's ownership percentage iff they are a beneficial owner.
-
#parent_legal_entity_id ⇒ String
The ID of the parent legal entity.
- #relationship_types ⇒ Array<Symbol, ModernTreasury::Models::LegalEntityAssociation::RelationshipType>
-
#title ⇒ String?
The job title of the child entity at the parent entity.
- #updated_at ⇒ Time
Instance Method Summary collapse
-
#initialize(id:, child_legal_entity:, created_at:, discarded_at:, live_mode:, object:, ownership_percentage:, parent_legal_entity_id:, relationship_types:, title:, updated_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see LegalEntityAssociation for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, child_legal_entity:, created_at:, discarded_at:, live_mode:, object:, ownership_percentage:, parent_legal_entity_id:, relationship_types:, title:, updated_at:) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::LegalEntityAssociation for more details.
|
|
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 68
|
Instance Attribute Details
#child_legal_entity ⇒ ModernTreasury::Models::ChildLegalEntity
The child legal entity.
15 |
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 15 required :child_legal_entity, -> { ModernTreasury::ChildLegalEntity } |
#created_at ⇒ Time
20 |
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 20 required :created_at, Time |
#discarded_at ⇒ Time?
25 |
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 25 required :discarded_at, Time, nil?: true |
#id ⇒ String
9 |
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 9 required :id, String |
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
32 |
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 32 required :live_mode, ModernTreasury::Internal::Type::Boolean |
#object ⇒ String
37 |
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 37 required :object, String |
#ownership_percentage ⇒ Integer?
The child entity's ownership percentage iff they are a beneficial owner.
43 |
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 43 required :ownership_percentage, Integer, nil?: true |
#parent_legal_entity_id ⇒ String
The ID of the parent legal entity. This must be a business legal entity.
49 |
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 49 required :parent_legal_entity_id, String |
#relationship_types ⇒ Array<Symbol, ModernTreasury::Models::LegalEntityAssociation::RelationshipType>
54 55 |
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 54 required :relationship_types, -> { ModernTreasury::Internal::Type::ArrayOf[enum: ModernTreasury::LegalEntityAssociation::RelationshipType] } |
#title ⇒ String?
The job title of the child entity at the parent entity.
61 |
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 61 required :title, String, nil?: true |
#updated_at ⇒ Time
66 |
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 66 required :updated_at, Time |
Instance Method Details
#to_hash ⇒ {
55 |
# File 'sig/modern_treasury/models/legal_entity_association.rbs', line 55
def to_hash: -> {
|