Class: ModernTreasury::Models::LegalEntityAssociation

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/legal_entity_association.rb

Defined Under Namespace

Modules: RelationshipType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, child_legal_entity:, created_at:, discarded_at:, live_mode:, object:, ownership_percentage:, parent_legal_entity_id:, relationship_types:, title:, updated_at:) ⇒ Object

Some parameter documentations has been truncated, see ModernTreasury::Models::LegalEntityAssociation for more details.

Parameters:

  • id (String)
  • child_legal_entity (ModernTreasury::Models::ChildLegalEntity)

    The child legal entity.

  • created_at (Time)
  • discarded_at (Time, nil)
  • live_mode (Boolean)

    This field will be true if this object exists in the live environment or false i

  • object (String)
  • ownership_percentage (Integer, nil)

    The child entity’s ownership percentage iff they are a beneficial owner.

  • parent_legal_entity_id (String)

    The ID of the parent legal entity. This must be a business or joint legal entity

  • relationship_types (Array<Symbol, ModernTreasury::Models::LegalEntityAssociation::RelationshipType>)
  • title (String, nil)

    The job title of the child entity at the parent entity.

  • updated_at (Time)


# File 'lib/modern_treasury/models/legal_entity_association.rb', line 69

Instance Attribute Details

The child legal entity.



15
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 15

required :child_legal_entity, -> { ModernTreasury::ChildLegalEntity }

#created_atTime

Returns:

  • (Time)


20
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 20

required :created_at, Time

#discarded_atTime?

Returns:

  • (Time, nil)


25
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 25

required :discarded_at, Time, nil?: true

#idString

Returns:

  • (String)


9
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 9

required :id, String

#live_modeBoolean

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Returns:

  • (Boolean)


32
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 32

required :live_mode, ModernTreasury::Internal::Type::Boolean

#objectString

Returns:

  • (String)


37
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 37

required :object, String

#ownership_percentageInteger?

The child entity’s ownership percentage iff they are a beneficial owner.

Returns:

  • (Integer, nil)


43
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 43

required :ownership_percentage, Integer, nil?: true

The ID of the parent legal entity. This must be a business or joint legal entity.

Returns:

  • (String)


50
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 50

required :parent_legal_entity_id, String

#relationship_typesArray<Symbol, ModernTreasury::Models::LegalEntityAssociation::RelationshipType>



55
56
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 55

required :relationship_types,
-> { ModernTreasury::Internal::Type::ArrayOf[enum: ModernTreasury::LegalEntityAssociation::RelationshipType] }

#titleString?

The job title of the child entity at the parent entity.

Returns:

  • (String, nil)


62
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 62

required :title, String, nil?: true

#updated_atTime

Returns:

  • (Time)


67
# File 'lib/modern_treasury/models/legal_entity_association.rb', line 67

required :updated_at, Time