Class: ModernTreasury::Models::LegalEntityAssociationCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::LegalEntityAssociationCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/legal_entity_association_create_params.rb,
sig/modern_treasury/models/legal_entity_association_create_params.rbs
Overview
Defined Under Namespace
Modules: RelationshipType
Constant Summary collapse
- ModernTreasury =
Instance Attribute Summary collapse
-
#child_legal_entity ⇒ ModernTreasury::Models::ChildLegalEntityCreate?
The child legal entity.
-
#child_legal_entity_id ⇒ String?
The ID of the child legal entity.
-
#ownership_percentage ⇒ Integer?
The child entity's ownership percentage iff they are a beneficial owner.
-
#parent_legal_entity_id ⇒ String
The ID of the parent legal entity.
- #relationship_types ⇒ Array<Symbol, ModernTreasury::Models::LegalEntityAssociationCreateParams::RelationshipType>
-
#title ⇒ String?
The job title of the child entity at the parent entity.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(parent_legal_entity_id:, relationship_types:, child_legal_entity: nil, child_legal_entity_id: nil, ownership_percentage: nil, title: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(parent_legal_entity_id:, relationship_types:, child_legal_entity: nil, child_legal_entity_id: nil, ownership_percentage: nil, title: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/modern_treasury/models/legal_entity_association_create_params.rb', line 46
|
Instance Attribute Details
#child_legal_entity ⇒ ModernTreasury::Models::ChildLegalEntityCreate?
The child legal entity.
26 |
# File 'lib/modern_treasury/models/legal_entity_association_create_params.rb', line 26 optional :child_legal_entity, -> { ModernTreasury::ChildLegalEntityCreate } |
#child_legal_entity_id ⇒ String?
The ID of the child legal entity.
32 |
# File 'lib/modern_treasury/models/legal_entity_association_create_params.rb', line 32 optional :child_legal_entity_id, String |
#ownership_percentage ⇒ Integer?
The child entity's ownership percentage iff they are a beneficial owner.
38 |
# File 'lib/modern_treasury/models/legal_entity_association_create_params.rb', line 38 optional :ownership_percentage, Integer, nil?: true |
#parent_legal_entity_id ⇒ String
The ID of the parent legal entity. This must be a business legal entity.
14 |
# File 'lib/modern_treasury/models/legal_entity_association_create_params.rb', line 14 required :parent_legal_entity_id, String |
#relationship_types ⇒ Array<Symbol, ModernTreasury::Models::LegalEntityAssociationCreateParams::RelationshipType>
19 20 |
# File 'lib/modern_treasury/models/legal_entity_association_create_params.rb', line 19 required :relationship_types, -> { ModernTreasury::Internal::Type::ArrayOf[enum: ModernTreasury::LegalEntityAssociationCreateParams::RelationshipType] } |
#title ⇒ String?
The job title of the child entity at the parent entity.
44 |
# File 'lib/modern_treasury/models/legal_entity_association_create_params.rb', line 44 optional :title, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
46 |
# File 'sig/modern_treasury/models/legal_entity_association_create_params.rbs', line 46
def to_hash: -> {
|