Class: ModernTreasury::Models::LegalEntityCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/modern_treasury/models/legal_entity_create_params.rb

Overview

Defined Under Namespace

Modules: LegalEntityType, LegalStructure, RiskRating Classes: Document, PhoneNumber, Regulator

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(jurisdiction:, name:, registration_number:) ⇒ Object

Some parameter documentations has been truncated, see Regulator for more details.

Parameters:

  • jurisdiction (String)

    The country code where the regulator operates in the ISO 3166-1 alpha-2 format (

  • name (String)

    Full name of the regulatory body.

  • registration_number (String)

    Registration or identification number with the regulator.



# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 280

Instance Attribute Details

#addressesArray<ModernTreasury::Models::LegalEntityAddressCreateRequest>?

A list of addresses for the entity.



20
21
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 20

optional :addresses,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAddressCreateRequest] }

#bank_settingsModernTreasury::Models::LegalEntityBankSettings?



26
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 26

optional :bank_settings, -> { ModernTreasury::LegalEntityBankSettings }, nil?: true

#business_descriptionString?

A description of the business.

Returns:

  • (String, nil)


32
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 32

optional :business_description, String, nil?: true

#business_nameString?

The business’s legal business name.

Returns:

  • (String, nil)


38
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 38

optional :business_name, String, nil?: true

#citizenship_countryString?

The country of citizenship for an individual.

Returns:

  • (String, nil)


44
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 44

optional :citizenship_country, String, nil?: true

#compliance_detailsObject?

Deprecated.

Returns:

  • (Object, nil)


50
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 50

optional :compliance_details, ModernTreasury::Internal::Type::Unknown, nil?: true

#connection_idString?

The connection ID for the connection the legal entity is associated with. Defaults to the id of the connection designated with an is_default value of true or the id of an existing operational connection if only one is available. Pass in a value of null to prevent the connection from being associated with the legal entity.

Returns:

  • (String, nil)


60
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 60

optional :connection_id, String, nil?: true

#country_of_incorporationString?

The country code where the business is incorporated in the ISO 3166-1 alpha-2 or alpha-3 formats.

Returns:

  • (String, nil)


67
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 67

optional :country_of_incorporation, String, nil?: true

#date_formedDate?

A business’s formation date (YYYY-MM-DD).

Returns:

  • (Date, nil)


73
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 73

optional :date_formed, Date, nil?: true

#date_of_birthDate?

An individual’s date of birth (YYYY-MM-DD).

Returns:

  • (Date, nil)


79
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 79

optional :date_of_birth, Date, nil?: true

#documentsArray<ModernTreasury::Models::LegalEntityCreateParams::Document>?

A list of documents to attach to the legal entity (e.g. articles of incorporation, certificate of good standing, proof of address).



86
87
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 86

optional :documents,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityCreateParams::Document] }

#doing_business_as_namesArray<String>?

Returns:

  • (Array<String>, nil)


92
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 92

optional :doing_business_as_names, ModernTreasury::Internal::Type::ArrayOf[String]

#emailString?

The entity’s primary email.

Returns:

  • (String, nil)


98
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 98

optional :email, String, nil?: true

#expected_activity_volumeInteger?

Monthly expected transaction volume in USD.

Returns:

  • (Integer, nil)


104
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 104

optional :expected_activity_volume, Integer, nil?: true

#external_idString?

An optional user-defined 180 character unique identifier.

Returns:

  • (String, nil)


110
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 110

optional :external_id, String, nil?: true

#first_nameString?

An individual’s first name.

Returns:

  • (String, nil)


116
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 116

optional :first_name, String, nil?: true

#identificationsArray<ModernTreasury::Models::IdentificationCreateRequest>?

A list of identifications for the legal entity.



122
123
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 122

optional :identifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::IdentificationCreateRequest] }

#industry_classificationsArray<ModernTreasury::Models::LegalEntityIndustryClassification>?

A list of industry classifications for the legal entity.



129
130
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 129

optional :industry_classifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityIndustryClassification] }

#intended_useString?

A description of the intended use of the legal entity.

Returns:

  • (String, nil)


136
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 136

optional :intended_use, String, nil?: true

#last_nameString?

An individual’s last name.

Returns:

  • (String, nil)


142
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 142

optional :last_name, String, nil?: true

The legal entity associations and its child legal entities.



148
149
150
151
152
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 148

optional :legal_entity_associations,
-> {
  ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAssociationInlineCreate]
},
nil?: true

The type of legal entity.



14
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 14

required :legal_entity_type, enum: -> { ModernTreasury::LegalEntityCreateParams::LegalEntityType }

The business’s legal structure.



158
159
160
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 158

optional :legal_structure,
enum: -> { ModernTreasury::LegalEntityCreateParams::LegalStructure },
nil?: true

#listed_exchangeString?

ISO 10383 market identifier code.

Returns:

  • (String, nil)


166
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 166

optional :listed_exchange, String, nil?: true

#metadataHash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Returns:

  • (Hash{Symbol=>String}, nil)


173
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 173

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#middle_nameString?

An individual’s middle name.

Returns:

  • (String, nil)


179
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 179

optional :middle_name, String, nil?: true

#operating_jurisdictionsArray<String>?

A list of countries where the business operates (ISO 3166-1 alpha-2 or alpha-3 codes).

Returns:

  • (Array<String>, nil)


186
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 186

optional :operating_jurisdictions, ModernTreasury::Internal::Type::ArrayOf[String]

#phone_numbersArray<ModernTreasury::Models::LegalEntityCreateParams::PhoneNumber>?



191
192
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 191

optional :phone_numbers,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityCreateParams::PhoneNumber] }

#politically_exposed_personBoolean?

Whether the individual is a politically exposed person.

Returns:

  • (Boolean, nil)


198
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 198

optional :politically_exposed_person, ModernTreasury::Internal::Type::Boolean, nil?: true

#preferred_nameString?

An individual’s preferred name.

Returns:

  • (String, nil)


204
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 204

optional :preferred_name, String, nil?: true

#prefixString?

An individual’s prefix.

Returns:

  • (String, nil)


210
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 210

optional :prefix, String, nil?: true

#primary_social_media_sitesArray<String>?

A list of primary social media URLs for the business.

Returns:

  • (Array<String>, nil)


216
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 216

optional :primary_social_media_sites, ModernTreasury::Internal::Type::ArrayOf[String]

#regulatorsArray<ModernTreasury::Models::LegalEntityCreateParams::Regulator>?

Array of regulatory bodies overseeing this institution.



222
223
224
225
226
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 222

optional :regulators,
-> {
  ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityCreateParams::Regulator]
},
nil?: true

#risk_ratingSymbol, ...

The risk rating of the legal entity. One of low, medium, high.



232
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 232

optional :risk_rating, enum: -> { ModernTreasury::LegalEntityCreateParams::RiskRating }, nil?: true

The UUID of the parent legal entity in the service provider tree.

Returns:

  • (String, nil)


238
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 238

optional :service_provider_legal_entity_id, String, nil?: true

#suffixString?

An individual’s suffix.

Returns:

  • (String, nil)


244
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 244

optional :suffix, String, nil?: true

#third_party_verificationModernTreasury::Models::ThirdPartyVerification?

Deprecated.

Deprecated. Use ‘third_party_verifications` instead.



252
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 252

optional :third_party_verification, -> { ModernTreasury::ThirdPartyVerification }, nil?: true

#third_party_verificationsArray<ModernTreasury::Models::ThirdPartyVerification>?

A list of third-party verifications run by external vendors.



258
259
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 258

optional :third_party_verifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ThirdPartyVerification] }

#ticker_symbolString?

Stock ticker symbol for publicly traded companies.

Returns:

  • (String, nil)


265
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 265

optional :ticker_symbol, String, nil?: true

#wealth_and_employment_detailsModernTreasury::Models::LegalEntityWealthEmploymentDetail?



270
271
272
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 270

optional :wealth_and_employment_details,
-> { ModernTreasury::LegalEntityWealthEmploymentDetail },
nil?: true

#websiteString?

The entity’s primary website URL.

Returns:

  • (String, nil)


278
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 278

optional :website, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 375