Class: ModernTreasury::Models::LegalEntityCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::LegalEntityCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/legal_entity_create_params.rb,
sig/modern_treasury/models/legal_entity_create_params.rbs
Overview
Defined Under Namespace
Modules: BusinessDesignation, LegalEntityType, LegalStructure, RiskRating Classes: Document, PhoneNumber, Regulator, TermsOfUse
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ModernTreasury
Instance Attribute Summary collapse
-
#addresses ⇒ Array<ModernTreasury::Models::LegalEntityAddressCreateRequest>?
A list of addresses for the entity.
- #bank_settings ⇒ ModernTreasury::Models::LegalEntityBankSettings?
-
#business_description ⇒ String?
A description of the business.
-
#business_designation ⇒ Symbol, ...
Legal designation associated with the business.
-
#business_name ⇒ String?
The business's legal business name.
-
#citizenship_country ⇒ String?
The country of citizenship for an individual.
- #compliance_details ⇒ Object? deprecated Deprecated.
-
#connection_id ⇒ String?
The connection ID for the connection the legal entity is associated with.
-
#country_of_incorporation ⇒ String?
The country where the business is incorporated, as an ISO 3166-1 alpha-2 country code (e.g. US).
-
#date_formed ⇒ Date?
A business's formation date (YYYY-MM-DD).
-
#date_of_birth ⇒ Date?
An individual's date of birth (YYYY-MM-DD).
-
#documents ⇒ Array<ModernTreasury::Models::LegalEntityCreateParams::Document>?
A list of documents to attach to the legal entity (e.g. articles of incorporation, certificate of good standing, proof of address).
- #doing_business_as_names ⇒ Array<String>?
-
#email ⇒ String?
The entity's primary email.
-
#expected_activity_volume ⇒ Integer?
Monthly expected transaction volume in USD.
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
-
#first_name ⇒ String?
An individual's first name.
-
#identifications ⇒ Array<ModernTreasury::Models::IdentificationCreateRequest>?
A list of identifications for the legal entity.
-
#industry_classifications ⇒ Array<ModernTreasury::Models::LegalEntityIndustryClassification>?
A list of industry classifications for the legal entity.
-
#intended_use ⇒ String?
A description of the intended use of the legal entity.
-
#last_name ⇒ String?
An individual's last name.
-
#legal_entity_associations ⇒ Array<ModernTreasury::Models::LegalEntityAssociationInlineCreate>?
The legal entity associations and its child legal entities.
-
#legal_entity_type ⇒ Symbol, ModernTreasury::Models::LegalEntityCreateParams::LegalEntityType
The type of legal entity.
-
#legal_structure ⇒ Symbol, ...
The business's legal structure.
-
#listed_exchange ⇒ String?
ISO 10383 market identifier code.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#middle_name ⇒ String?
An individual's middle name.
-
#operating_jurisdictions ⇒ Array<String>?
A list of countries where the business operates, as ISO 3166-1 alpha-2 country codes (e.g. ["US", "CA"]).
- #phone_numbers ⇒ Array<ModernTreasury::Models::LegalEntityCreateParams::PhoneNumber>?
-
#politically_exposed_person ⇒ Boolean?
Whether the individual is a politically exposed person.
-
#preferred_name ⇒ String?
An individual's preferred name.
-
#prefix ⇒ String?
An individual's prefix.
-
#primary_social_media_sites ⇒ Array<String>?
A list of the entity's primary social media URLs.
-
#regulators ⇒ Array<ModernTreasury::Models::LegalEntityCreateParams::Regulator>?
Array of regulatory bodies overseeing this institution.
-
#risk_rating ⇒ Symbol, ...
The risk rating of the legal entity.
-
#service_provider_legal_entity_id ⇒ String?
The UUID of the parent legal entity in the service provider tree.
-
#suffix ⇒ String?
An individual's suffix.
-
#terms_of_use ⇒ ModernTreasury::Models::LegalEntityCreateParams::TermsOfUse?
Acceptance of terms of use by the legal entity.
- #third_party_verification ⇒ ModernTreasury::Models::ThirdPartyVerification? deprecated Deprecated.
-
#third_party_verifications ⇒ Array<ModernTreasury::Models::ThirdPartyVerification>?
A list of third-party verifications run by external vendors.
-
#ticker_symbol ⇒ String?
Stock ticker symbol for publicly traded companies.
- #wealth_and_employment_details ⇒ ModernTreasury::Models::LegalEntityWealthEmploymentDetail?
-
#website ⇒ String?
The entity's primary website URL.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(jurisdiction:, name:, registration_number:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Regulator for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(jurisdiction:, name:, registration_number:) ⇒ Object
Some parameter documentations has been truncated, see Regulator for more details.
|
|
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 294
|
Instance Attribute Details
#addresses ⇒ Array<ModernTreasury::Models::LegalEntityAddressCreateRequest>?
A list of addresses for the entity.
20 21 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 20 optional :addresses, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAddressCreateRequest] } |
#bank_settings ⇒ ModernTreasury::Models::LegalEntityBankSettings?
26 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 26 optional :bank_settings, -> { ModernTreasury::LegalEntityBankSettings }, nil?: true |
#business_description ⇒ String?
A description of the business.
32 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 32 optional :business_description, String, nil?: true |
#business_designation ⇒ Symbol, ...
Legal designation associated with the business.
38 39 40 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 38 optional :business_designation, enum: -> { ModernTreasury::LegalEntityCreateParams::BusinessDesignation }, nil?: true |
#business_name ⇒ String?
The business's legal business name.
46 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 46 optional :business_name, String, nil?: true |
#citizenship_country ⇒ String?
The country of citizenship for an individual.
52 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 52 optional :citizenship_country, String, nil?: true |
#compliance_details ⇒ Object?
58 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 58 optional :compliance_details, ModernTreasury::Internal::Type::Unknown, nil?: true |
#connection_id ⇒ String?
The connection ID for the connection the legal entity is associated with. Defaults to the id of the connection designated with an is_default value of true or the id of an existing operational connection if only one is available. Pass in a value of null to prevent the connection from being associated with the legal entity.
68 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 68 optional :connection_id, String, nil?: true |
#country_of_incorporation ⇒ String?
The country where the business is incorporated, as an ISO 3166-1 alpha-2 country code (e.g. US).
75 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 75 optional :country_of_incorporation, String, nil?: true |
#date_formed ⇒ Date?
A business's formation date (YYYY-MM-DD).
81 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 81 optional :date_formed, Date, nil?: true |
#date_of_birth ⇒ Date?
An individual's date of birth (YYYY-MM-DD).
87 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 87 optional :date_of_birth, Date, nil?: true |
#documents ⇒ Array<ModernTreasury::Models::LegalEntityCreateParams::Document>?
A list of documents to attach to the legal entity (e.g. articles of incorporation, certificate of good standing, proof of address).
94 95 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 94 optional :documents, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityCreateParams::Document] } |
#doing_business_as_names ⇒ Array<String>?
100 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 100 optional :doing_business_as_names, ModernTreasury::Internal::Type::ArrayOf[String] |
#email ⇒ String?
The entity's primary email.
106 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 106 optional :email, String, nil?: true |
#expected_activity_volume ⇒ Integer?
Monthly expected transaction volume in USD.
112 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 112 optional :expected_activity_volume, Integer, nil?: true |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
118 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 118 optional :external_id, String, nil?: true |
#first_name ⇒ String?
An individual's first name.
124 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 124 optional :first_name, String, nil?: true |
#identifications ⇒ Array<ModernTreasury::Models::IdentificationCreateRequest>?
A list of identifications for the legal entity.
130 131 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 130 optional :identifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::IdentificationCreateRequest] } |
#industry_classifications ⇒ Array<ModernTreasury::Models::LegalEntityIndustryClassification>?
A list of industry classifications for the legal entity.
137 138 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 137 optional :industry_classifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityIndustryClassification] } |
#intended_use ⇒ String?
A description of the intended use of the legal entity.
144 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 144 optional :intended_use, String, nil?: true |
#last_name ⇒ String?
An individual's last name.
150 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 150 optional :last_name, String, nil?: true |
#legal_entity_associations ⇒ Array<ModernTreasury::Models::LegalEntityAssociationInlineCreate>?
The legal entity associations and its child legal entities.
156 157 158 159 160 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 156 optional :legal_entity_associations, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAssociationInlineCreate] }, nil?: true |
#legal_entity_type ⇒ Symbol, ModernTreasury::Models::LegalEntityCreateParams::LegalEntityType
The type of legal entity.
14 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 14 required :legal_entity_type, enum: -> { ModernTreasury::LegalEntityCreateParams::LegalEntityType } |
#legal_structure ⇒ Symbol, ...
The business's legal structure.
166 167 168 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 166 optional :legal_structure, enum: -> { ModernTreasury::LegalEntityCreateParams::LegalStructure }, nil?: true |
#listed_exchange ⇒ String?
ISO 10383 market identifier code.
174 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 174 optional :listed_exchange, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
181 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 181 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#middle_name ⇒ String?
An individual's middle name.
187 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 187 optional :middle_name, String, nil?: true |
#operating_jurisdictions ⇒ Array<String>?
A list of countries where the business operates, as ISO 3166-1 alpha-2 country codes (e.g. ["US", "CA"]).
194 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 194 optional :operating_jurisdictions, ModernTreasury::Internal::Type::ArrayOf[String] |
#phone_numbers ⇒ Array<ModernTreasury::Models::LegalEntityCreateParams::PhoneNumber>?
199 200 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 199 optional :phone_numbers, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityCreateParams::PhoneNumber] } |
#politically_exposed_person ⇒ Boolean?
Whether the individual is a politically exposed person.
206 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 206 optional :politically_exposed_person, ModernTreasury::Internal::Type::Boolean, nil?: true |
#preferred_name ⇒ String?
An individual's preferred name.
212 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 212 optional :preferred_name, String, nil?: true |
#prefix ⇒ String?
An individual's prefix.
218 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 218 optional :prefix, String, nil?: true |
#primary_social_media_sites ⇒ Array<String>?
A list of the entity's primary social media URLs.
224 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 224 optional :primary_social_media_sites, ModernTreasury::Internal::Type::ArrayOf[String] |
#regulators ⇒ Array<ModernTreasury::Models::LegalEntityCreateParams::Regulator>?
Array of regulatory bodies overseeing this institution.
230 231 232 233 234 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 230 optional :regulators, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityCreateParams::Regulator] }, nil?: true |
#risk_rating ⇒ Symbol, ...
The risk rating of the legal entity. One of low, medium, high.
240 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 240 optional :risk_rating, enum: -> { ModernTreasury::LegalEntityCreateParams::RiskRating }, nil?: true |
#service_provider_legal_entity_id ⇒ String?
The UUID of the parent legal entity in the service provider tree.
246 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 246 optional :service_provider_legal_entity_id, String, nil?: true |
#suffix ⇒ String?
An individual's suffix.
252 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 252 optional :suffix, String, nil?: true |
#terms_of_use ⇒ ModernTreasury::Models::LegalEntityCreateParams::TermsOfUse?
Acceptance of terms of use by the legal entity.
258 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 258 optional :terms_of_use, -> { ModernTreasury::LegalEntityCreateParams::TermsOfUse }, nil?: true |
#third_party_verification ⇒ ModernTreasury::Models::ThirdPartyVerification?
Deprecated. Use third_party_verifications instead.
266 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 266 optional :third_party_verification, -> { ModernTreasury::ThirdPartyVerification }, nil?: true |
#third_party_verifications ⇒ Array<ModernTreasury::Models::ThirdPartyVerification>?
A list of third-party verifications run by external vendors.
272 273 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 272 optional :third_party_verifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ThirdPartyVerification] } |
#ticker_symbol ⇒ String?
Stock ticker symbol for publicly traded companies.
279 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 279 optional :ticker_symbol, String, nil?: true |
#wealth_and_employment_details ⇒ ModernTreasury::Models::LegalEntityWealthEmploymentDetail?
284 285 286 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 284 optional :wealth_and_employment_details, -> { ModernTreasury::LegalEntityWealthEmploymentDetail }, nil?: true |
#website ⇒ String?
The entity's primary website URL.
292 |
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 292 optional :website, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/legal_entity_create_params.rb', line 393
|
Instance Method Details
#to_hash ⇒ {
220 |
# File 'sig/modern_treasury/models/legal_entity_create_params.rbs', line 220
def to_hash: -> {
|