Class: ModernTreasury::Models::LegalEntityUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/modern_treasury/models/legal_entity_update_params.rb

Overview

Defined Under Namespace

Modules: LegalStructure, RiskRating Classes: PhoneNumber, Regulator

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(jurisdiction:, name:, registration_number:) ⇒ Object

Some parameter documentations has been truncated, see Regulator for more details.

Parameters:

  • jurisdiction (String)

    The country code where the regulator operates in the ISO 3166-1 alpha-2 format (

  • name (String)

    Full name of the regulatory body.

  • registration_number (String)

    Registration or identification number with the regulator.



# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 245

Instance Attribute Details

#addressesArray<ModernTreasury::Models::LegalEntityAddressCreateRequest>?

A list of addresses for the entity.



19
20
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 19

optional :addresses,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAddressCreateRequest] }

#bank_settingsModernTreasury::Models::LegalEntityBankSettings?



25
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 25

optional :bank_settings, -> { ModernTreasury::LegalEntityBankSettings }, nil?: true

#business_descriptionString?

A description of the business.

Returns:

  • (String, nil)


31
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 31

optional :business_description, String, nil?: true

#business_nameString?

The business’s legal business name.

Returns:

  • (String, nil)


37
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 37

optional :business_name, String, nil?: true

#citizenship_countryString?

The country of citizenship for an individual.

Returns:

  • (String, nil)


43
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 43

optional :citizenship_country, String, nil?: true

#country_of_incorporationString?

The country code where the business is incorporated in the ISO 3166-1 alpha-2 or alpha-3 formats.

Returns:

  • (String, nil)


50
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 50

optional :country_of_incorporation, String, nil?: true

#date_formedDate?

A business’s formation date (YYYY-MM-DD).

Returns:

  • (Date, nil)


56
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 56

optional :date_formed, Date, nil?: true

#date_of_birthDate?

An individual’s date of birth (YYYY-MM-DD).

Returns:

  • (Date, nil)


62
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 62

optional :date_of_birth, Date, nil?: true

#doing_business_as_namesArray<String>?

Returns:

  • (Array<String>, nil)


67
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 67

optional :doing_business_as_names, ModernTreasury::Internal::Type::ArrayOf[String]

#emailString?

The entity’s primary email.

Returns:

  • (String, nil)


73
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 73

optional :email, String, nil?: true

#expected_activity_volumeInteger?

Monthly expected transaction volume in USD.

Returns:

  • (Integer, nil)


79
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 79

optional :expected_activity_volume, Integer, nil?: true

#external_idString?

An optional user-defined 180 character unique identifier.

Returns:

  • (String, nil)


85
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 85

optional :external_id, String, nil?: true

#first_nameString?

An individual’s first name.

Returns:

  • (String, nil)


91
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 91

optional :first_name, String, nil?: true

#idString

Returns:

  • (String)


13
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 13

required :id, String

#identificationsArray<ModernTreasury::Models::IdentificationCreateRequest>?

A list of identifications for the legal entity.



97
98
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 97

optional :identifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::IdentificationCreateRequest] }

#industry_classificationsArray<ModernTreasury::Models::LegalEntityIndustryClassification>?

A list of industry classifications for the legal entity.



104
105
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 104

optional :industry_classifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityIndustryClassification] }

#intended_useString?

A description of the intended use of the legal entity.

Returns:

  • (String, nil)


111
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 111

optional :intended_use, String, nil?: true

#last_nameString?

An individual’s last name.

Returns:

  • (String, nil)


117
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 117

optional :last_name, String, nil?: true

The business’s legal structure.



123
124
125
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 123

optional :legal_structure,
enum: -> { ModernTreasury::LegalEntityUpdateParams::LegalStructure },
nil?: true

#listed_exchangeString?

ISO 10383 market identifier code.

Returns:

  • (String, nil)


131
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 131

optional :listed_exchange, String, nil?: true

#metadataHash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Returns:

  • (Hash{Symbol=>String}, nil)


138
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 138

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#middle_nameString?

An individual’s middle name.

Returns:

  • (String, nil)


144
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 144

optional :middle_name, String, nil?: true

#operating_jurisdictionsArray<String>?

A list of countries where the business operates (ISO 3166-1 alpha-2 or alpha-3 codes).

Returns:

  • (Array<String>, nil)


151
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 151

optional :operating_jurisdictions, ModernTreasury::Internal::Type::ArrayOf[String]

#phone_numbersArray<ModernTreasury::Models::LegalEntityUpdateParams::PhoneNumber>?



156
157
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 156

optional :phone_numbers,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityUpdateParams::PhoneNumber] }

#politically_exposed_personBoolean?

Whether the individual is a politically exposed person.

Returns:

  • (Boolean, nil)


163
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 163

optional :politically_exposed_person, ModernTreasury::Internal::Type::Boolean, nil?: true

#preferred_nameString?

An individual’s preferred name.

Returns:

  • (String, nil)


169
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 169

optional :preferred_name, String, nil?: true

#prefixString?

An individual’s prefix.

Returns:

  • (String, nil)


175
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 175

optional :prefix, String, nil?: true

#primary_social_media_sitesArray<String>?

A list of primary social media URLs for the business.

Returns:

  • (Array<String>, nil)


181
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 181

optional :primary_social_media_sites, ModernTreasury::Internal::Type::ArrayOf[String]

#regulatorsArray<ModernTreasury::Models::LegalEntityUpdateParams::Regulator>?

Array of regulatory bodies overseeing this institution.



187
188
189
190
191
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 187

optional :regulators,
-> {
  ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityUpdateParams::Regulator]
},
nil?: true

#risk_ratingSymbol, ...

The risk rating of the legal entity. One of low, medium, high.



197
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 197

optional :risk_rating, enum: -> { ModernTreasury::LegalEntityUpdateParams::RiskRating }, nil?: true

The UUID of the parent legal entity in the service provider tree.

Returns:

  • (String, nil)


203
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 203

optional :service_provider_legal_entity_id, String, nil?: true

#suffixString?

An individual’s suffix.

Returns:

  • (String, nil)


209
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 209

optional :suffix, String, nil?: true

#third_party_verificationModernTreasury::Models::ThirdPartyVerification?

Deprecated.

Deprecated. Use ‘third_party_verifications` instead.



217
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 217

optional :third_party_verification, -> { ModernTreasury::ThirdPartyVerification }, nil?: true

#third_party_verificationsArray<ModernTreasury::Models::ThirdPartyVerification>?

A list of third-party verifications run by external vendors.



223
224
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 223

optional :third_party_verifications,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ThirdPartyVerification] }

#ticker_symbolString?

Stock ticker symbol for publicly traded companies.

Returns:

  • (String, nil)


230
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 230

optional :ticker_symbol, String, nil?: true

#wealth_and_employment_detailsModernTreasury::Models::LegalEntityWealthEmploymentDetail?



235
236
237
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 235

optional :wealth_and_employment_details,
-> { ModernTreasury::LegalEntityWealthEmploymentDetail },
nil?: true

#websiteString?

The entity’s primary website URL.

Returns:

  • (String, nil)


243
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 243

optional :website, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 336