Class: ModernTreasury::Models::LegalEntityUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::LegalEntityUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/legal_entity_update_params.rb
Overview
Defined Under Namespace
Modules: LegalStructure, RiskRating Classes: PhoneNumber, Regulator
Instance Attribute Summary collapse
-
#addresses ⇒ Array<ModernTreasury::Models::LegalEntityAddressCreateRequest>?
A list of addresses for the entity.
- #bank_settings ⇒ ModernTreasury::Models::LegalEntityBankSettings?
-
#business_description ⇒ String?
A description of the business.
-
#business_name ⇒ String?
The business’s legal business name.
-
#citizenship_country ⇒ String?
The country of citizenship for an individual.
-
#country_of_incorporation ⇒ String?
The country code where the business is incorporated in the ISO 3166-1 alpha-2 or alpha-3 formats.
-
#date_formed ⇒ Date?
A business’s formation date (YYYY-MM-DD).
-
#date_of_birth ⇒ Date?
An individual’s date of birth (YYYY-MM-DD).
- #doing_business_as_names ⇒ Array<String>?
-
#email ⇒ String?
The entity’s primary email.
-
#expected_activity_volume ⇒ Integer?
Monthly expected transaction volume in USD.
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
-
#first_name ⇒ String?
An individual’s first name.
- #id ⇒ String
-
#identifications ⇒ Array<ModernTreasury::Models::IdentificationCreateRequest>?
A list of identifications for the legal entity.
-
#industry_classifications ⇒ Array<ModernTreasury::Models::LegalEntityIndustryClassification>?
A list of industry classifications for the legal entity.
-
#intended_use ⇒ String?
A description of the intended use of the legal entity.
-
#last_name ⇒ String?
An individual’s last name.
-
#legal_structure ⇒ Symbol, ...
The business’s legal structure.
-
#listed_exchange ⇒ String?
ISO 10383 market identifier code.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#middle_name ⇒ String?
An individual’s middle name.
-
#operating_jurisdictions ⇒ Array<String>?
A list of countries where the business operates (ISO 3166-1 alpha-2 or alpha-3 codes).
- #phone_numbers ⇒ Array<ModernTreasury::Models::LegalEntityUpdateParams::PhoneNumber>?
-
#politically_exposed_person ⇒ Boolean?
Whether the individual is a politically exposed person.
-
#preferred_name ⇒ String?
An individual’s preferred name.
-
#prefix ⇒ String?
An individual’s prefix.
-
#primary_social_media_sites ⇒ Array<String>?
A list of primary social media URLs for the business.
-
#regulators ⇒ Array<ModernTreasury::Models::LegalEntityUpdateParams::Regulator>?
Array of regulatory bodies overseeing this institution.
-
#risk_rating ⇒ Symbol, ...
The risk rating of the legal entity.
-
#service_provider_legal_entity_id ⇒ String?
The UUID of the parent legal entity in the service provider tree.
-
#suffix ⇒ String?
An individual’s suffix.
- #third_party_verification ⇒ ModernTreasury::Models::ThirdPartyVerification? deprecated Deprecated.
-
#third_party_verifications ⇒ Array<ModernTreasury::Models::ThirdPartyVerification>?
A list of third-party verifications run by external vendors.
-
#ticker_symbol ⇒ String?
Stock ticker symbol for publicly traded companies.
- #wealth_and_employment_details ⇒ ModernTreasury::Models::LegalEntityWealthEmploymentDetail?
-
#website ⇒ String?
The entity’s primary website URL.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(jurisdiction:, name:, registration_number:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Regulator for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(jurisdiction:, name:, registration_number:) ⇒ Object
Some parameter documentations has been truncated, see Regulator for more details.
|
|
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 245
|
Instance Attribute Details
#addresses ⇒ Array<ModernTreasury::Models::LegalEntityAddressCreateRequest>?
A list of addresses for the entity.
19 20 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 19 optional :addresses, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAddressCreateRequest] } |
#bank_settings ⇒ ModernTreasury::Models::LegalEntityBankSettings?
25 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 25 optional :bank_settings, -> { ModernTreasury::LegalEntityBankSettings }, nil?: true |
#business_description ⇒ String?
A description of the business.
31 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 31 optional :business_description, String, nil?: true |
#business_name ⇒ String?
The business’s legal business name.
37 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 37 optional :business_name, String, nil?: true |
#citizenship_country ⇒ String?
The country of citizenship for an individual.
43 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 43 optional :citizenship_country, String, nil?: true |
#country_of_incorporation ⇒ String?
The country code where the business is incorporated in the ISO 3166-1 alpha-2 or alpha-3 formats.
50 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 50 optional :country_of_incorporation, String, nil?: true |
#date_formed ⇒ Date?
A business’s formation date (YYYY-MM-DD).
56 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 56 optional :date_formed, Date, nil?: true |
#date_of_birth ⇒ Date?
An individual’s date of birth (YYYY-MM-DD).
62 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 62 optional :date_of_birth, Date, nil?: true |
#doing_business_as_names ⇒ Array<String>?
67 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 67 optional :doing_business_as_names, ModernTreasury::Internal::Type::ArrayOf[String] |
#email ⇒ String?
The entity’s primary email.
73 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 73 optional :email, String, nil?: true |
#expected_activity_volume ⇒ Integer?
Monthly expected transaction volume in USD.
79 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 79 optional :expected_activity_volume, Integer, nil?: true |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
85 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 85 optional :external_id, String, nil?: true |
#first_name ⇒ String?
An individual’s first name.
91 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 91 optional :first_name, String, nil?: true |
#id ⇒ String
13 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 13 required :id, String |
#identifications ⇒ Array<ModernTreasury::Models::IdentificationCreateRequest>?
A list of identifications for the legal entity.
97 98 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 97 optional :identifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::IdentificationCreateRequest] } |
#industry_classifications ⇒ Array<ModernTreasury::Models::LegalEntityIndustryClassification>?
A list of industry classifications for the legal entity.
104 105 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 104 optional :industry_classifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityIndustryClassification] } |
#intended_use ⇒ String?
A description of the intended use of the legal entity.
111 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 111 optional :intended_use, String, nil?: true |
#last_name ⇒ String?
An individual’s last name.
117 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 117 optional :last_name, String, nil?: true |
#legal_structure ⇒ Symbol, ...
The business’s legal structure.
123 124 125 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 123 optional :legal_structure, enum: -> { ModernTreasury::LegalEntityUpdateParams::LegalStructure }, nil?: true |
#listed_exchange ⇒ String?
ISO 10383 market identifier code.
131 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 131 optional :listed_exchange, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
138 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 138 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#middle_name ⇒ String?
An individual’s middle name.
144 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 144 optional :middle_name, String, nil?: true |
#operating_jurisdictions ⇒ Array<String>?
A list of countries where the business operates (ISO 3166-1 alpha-2 or alpha-3 codes).
151 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 151 optional :operating_jurisdictions, ModernTreasury::Internal::Type::ArrayOf[String] |
#phone_numbers ⇒ Array<ModernTreasury::Models::LegalEntityUpdateParams::PhoneNumber>?
156 157 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 156 optional :phone_numbers, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityUpdateParams::PhoneNumber] } |
#politically_exposed_person ⇒ Boolean?
Whether the individual is a politically exposed person.
163 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 163 optional :politically_exposed_person, ModernTreasury::Internal::Type::Boolean, nil?: true |
#preferred_name ⇒ String?
An individual’s preferred name.
169 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 169 optional :preferred_name, String, nil?: true |
#prefix ⇒ String?
An individual’s prefix.
175 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 175 optional :prefix, String, nil?: true |
#primary_social_media_sites ⇒ Array<String>?
A list of primary social media URLs for the business.
181 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 181 optional :primary_social_media_sites, ModernTreasury::Internal::Type::ArrayOf[String] |
#regulators ⇒ Array<ModernTreasury::Models::LegalEntityUpdateParams::Regulator>?
Array of regulatory bodies overseeing this institution.
187 188 189 190 191 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 187 optional :regulators, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityUpdateParams::Regulator] }, nil?: true |
#risk_rating ⇒ Symbol, ...
The risk rating of the legal entity. One of low, medium, high.
197 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 197 optional :risk_rating, enum: -> { ModernTreasury::LegalEntityUpdateParams::RiskRating }, nil?: true |
#service_provider_legal_entity_id ⇒ String?
The UUID of the parent legal entity in the service provider tree.
203 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 203 optional :service_provider_legal_entity_id, String, nil?: true |
#suffix ⇒ String?
An individual’s suffix.
209 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 209 optional :suffix, String, nil?: true |
#third_party_verification ⇒ ModernTreasury::Models::ThirdPartyVerification?
Deprecated. Use ‘third_party_verifications` instead.
217 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 217 optional :third_party_verification, -> { ModernTreasury::ThirdPartyVerification }, nil?: true |
#third_party_verifications ⇒ Array<ModernTreasury::Models::ThirdPartyVerification>?
A list of third-party verifications run by external vendors.
223 224 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 223 optional :third_party_verifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ThirdPartyVerification] } |
#ticker_symbol ⇒ String?
Stock ticker symbol for publicly traded companies.
230 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 230 optional :ticker_symbol, String, nil?: true |
#wealth_and_employment_details ⇒ ModernTreasury::Models::LegalEntityWealthEmploymentDetail?
235 236 237 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 235 optional :wealth_and_employment_details, -> { ModernTreasury::LegalEntityWealthEmploymentDetail }, nil?: true |
#website ⇒ String?
The entity’s primary website URL.
243 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 243 optional :website, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 336
|