Class: ModernTreasury::Models::LegalEntityUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::LegalEntityUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/legal_entity_update_params.rb,
sig/modern_treasury/models/legal_entity_update_params.rbs
Overview
Defined Under Namespace
Modules: BusinessDesignation, LegalStructure, RiskRating Classes: PhoneNumber, Regulator, TermsOfUse
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ModernTreasury
Instance Attribute Summary collapse
-
#addresses ⇒ Array<ModernTreasury::Models::LegalEntityAddressCreateRequest>?
A list of addresses for the entity.
- #bank_settings ⇒ ModernTreasury::Models::LegalEntityBankSettings?
-
#business_description ⇒ String?
A description of the business.
-
#business_designation ⇒ Symbol, ...
Legal designation associated with the business.
-
#business_name ⇒ String?
The business's legal business name.
-
#citizenship_country ⇒ String?
The country of citizenship for an individual.
-
#country_of_incorporation ⇒ String?
The country where the business is incorporated, as an ISO 3166-1 alpha-2 country code (e.g. US).
-
#date_formed ⇒ Date?
A business's formation date (YYYY-MM-DD).
-
#date_of_birth ⇒ Date?
An individual's date of birth (YYYY-MM-DD).
- #doing_business_as_names ⇒ Array<String>?
-
#email ⇒ String?
The entity's primary email.
-
#expected_activity_volume ⇒ Integer?
Monthly expected transaction volume in USD.
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
-
#first_name ⇒ String?
An individual's first name.
- #id ⇒ String
-
#identifications ⇒ Array<ModernTreasury::Models::IdentificationCreateRequest>?
A list of identifications for the legal entity.
-
#industry_classifications ⇒ Array<ModernTreasury::Models::LegalEntityIndustryClassification>?
A list of industry classifications for the legal entity.
-
#intended_use ⇒ String?
A description of the intended use of the legal entity.
-
#last_name ⇒ String?
An individual's last name.
-
#legal_structure ⇒ Symbol, ...
The business's legal structure.
-
#listed_exchange ⇒ String?
ISO 10383 market identifier code.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#middle_name ⇒ String?
An individual's middle name.
-
#operating_jurisdictions ⇒ Array<String>?
A list of countries where the business operates, as ISO 3166-1 alpha-2 country codes (e.g. ["US", "CA"]).
- #phone_numbers ⇒ Array<ModernTreasury::Models::LegalEntityUpdateParams::PhoneNumber>?
-
#politically_exposed_person ⇒ Boolean?
Whether the individual is a politically exposed person.
-
#preferred_name ⇒ String?
An individual's preferred name.
-
#prefix ⇒ String?
An individual's prefix.
-
#primary_social_media_sites ⇒ Array<String>?
A list of the entity's primary social media URLs.
-
#regulators ⇒ Array<ModernTreasury::Models::LegalEntityUpdateParams::Regulator>?
Array of regulatory bodies overseeing this institution.
-
#risk_rating ⇒ Symbol, ...
The risk rating of the legal entity.
-
#service_provider_legal_entity_id ⇒ String?
The UUID of the parent legal entity in the service provider tree.
-
#suffix ⇒ String?
An individual's suffix.
-
#terms_of_use ⇒ ModernTreasury::Models::LegalEntityUpdateParams::TermsOfUse?
Acceptance of terms of use by the legal entity.
- #third_party_verification ⇒ ModernTreasury::Models::ThirdPartyVerification? deprecated Deprecated.
-
#third_party_verifications ⇒ Array<ModernTreasury::Models::ThirdPartyVerification>?
A list of third-party verifications run by external vendors.
-
#ticker_symbol ⇒ String?
Stock ticker symbol for publicly traded companies.
- #wealth_and_employment_details ⇒ ModernTreasury::Models::LegalEntityWealthEmploymentDetail?
-
#website ⇒ String?
The entity's primary website URL.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(jurisdiction:, name:, registration_number:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Regulator for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(jurisdiction:, name:, registration_number:) ⇒ Object
Some parameter documentations has been truncated, see Regulator for more details.
|
|
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 259
|
Instance Attribute Details
#addresses ⇒ Array<ModernTreasury::Models::LegalEntityAddressCreateRequest>?
A list of addresses for the entity.
19 20 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 19 optional :addresses, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityAddressCreateRequest] } |
#bank_settings ⇒ ModernTreasury::Models::LegalEntityBankSettings?
25 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 25 optional :bank_settings, -> { ModernTreasury::LegalEntityBankSettings }, nil?: true |
#business_description ⇒ String?
A description of the business.
31 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 31 optional :business_description, String, nil?: true |
#business_designation ⇒ Symbol, ...
Legal designation associated with the business.
37 38 39 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 37 optional :business_designation, enum: -> { ModernTreasury::LegalEntityUpdateParams::BusinessDesignation }, nil?: true |
#business_name ⇒ String?
The business's legal business name.
45 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 45 optional :business_name, String, nil?: true |
#citizenship_country ⇒ String?
The country of citizenship for an individual.
51 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 51 optional :citizenship_country, String, nil?: true |
#country_of_incorporation ⇒ String?
The country where the business is incorporated, as an ISO 3166-1 alpha-2 country code (e.g. US).
58 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 58 optional :country_of_incorporation, String, nil?: true |
#date_formed ⇒ Date?
A business's formation date (YYYY-MM-DD).
64 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 64 optional :date_formed, Date, nil?: true |
#date_of_birth ⇒ Date?
An individual's date of birth (YYYY-MM-DD).
70 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 70 optional :date_of_birth, Date, nil?: true |
#doing_business_as_names ⇒ Array<String>?
75 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 75 optional :doing_business_as_names, ModernTreasury::Internal::Type::ArrayOf[String] |
#email ⇒ String?
The entity's primary email.
81 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 81 optional :email, String, nil?: true |
#expected_activity_volume ⇒ Integer?
Monthly expected transaction volume in USD.
87 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 87 optional :expected_activity_volume, Integer, nil?: true |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
93 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 93 optional :external_id, String, nil?: true |
#first_name ⇒ String?
An individual's first name.
99 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 99 optional :first_name, String, nil?: true |
#id ⇒ String
13 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 13 required :id, String |
#identifications ⇒ Array<ModernTreasury::Models::IdentificationCreateRequest>?
A list of identifications for the legal entity.
105 106 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 105 optional :identifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::IdentificationCreateRequest] } |
#industry_classifications ⇒ Array<ModernTreasury::Models::LegalEntityIndustryClassification>?
A list of industry classifications for the legal entity.
112 113 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 112 optional :industry_classifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityIndustryClassification] } |
#intended_use ⇒ String?
A description of the intended use of the legal entity.
119 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 119 optional :intended_use, String, nil?: true |
#last_name ⇒ String?
An individual's last name.
125 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 125 optional :last_name, String, nil?: true |
#legal_structure ⇒ Symbol, ...
The business's legal structure.
131 132 133 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 131 optional :legal_structure, enum: -> { ModernTreasury::LegalEntityUpdateParams::LegalStructure }, nil?: true |
#listed_exchange ⇒ String?
ISO 10383 market identifier code.
139 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 139 optional :listed_exchange, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
146 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 146 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#middle_name ⇒ String?
An individual's middle name.
152 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 152 optional :middle_name, String, nil?: true |
#operating_jurisdictions ⇒ Array<String>?
A list of countries where the business operates, as ISO 3166-1 alpha-2 country codes (e.g. ["US", "CA"]).
159 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 159 optional :operating_jurisdictions, ModernTreasury::Internal::Type::ArrayOf[String] |
#phone_numbers ⇒ Array<ModernTreasury::Models::LegalEntityUpdateParams::PhoneNumber>?
164 165 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 164 optional :phone_numbers, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityUpdateParams::PhoneNumber] } |
#politically_exposed_person ⇒ Boolean?
Whether the individual is a politically exposed person.
171 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 171 optional :politically_exposed_person, ModernTreasury::Internal::Type::Boolean, nil?: true |
#preferred_name ⇒ String?
An individual's preferred name.
177 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 177 optional :preferred_name, String, nil?: true |
#prefix ⇒ String?
An individual's prefix.
183 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 183 optional :prefix, String, nil?: true |
#primary_social_media_sites ⇒ Array<String>?
A list of the entity's primary social media URLs.
189 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 189 optional :primary_social_media_sites, ModernTreasury::Internal::Type::ArrayOf[String] |
#regulators ⇒ Array<ModernTreasury::Models::LegalEntityUpdateParams::Regulator>?
Array of regulatory bodies overseeing this institution.
195 196 197 198 199 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 195 optional :regulators, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::LegalEntityUpdateParams::Regulator] }, nil?: true |
#risk_rating ⇒ Symbol, ...
The risk rating of the legal entity. One of low, medium, high.
205 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 205 optional :risk_rating, enum: -> { ModernTreasury::LegalEntityUpdateParams::RiskRating }, nil?: true |
#service_provider_legal_entity_id ⇒ String?
The UUID of the parent legal entity in the service provider tree.
211 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 211 optional :service_provider_legal_entity_id, String, nil?: true |
#suffix ⇒ String?
An individual's suffix.
217 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 217 optional :suffix, String, nil?: true |
#terms_of_use ⇒ ModernTreasury::Models::LegalEntityUpdateParams::TermsOfUse?
Acceptance of terms of use by the legal entity.
223 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 223 optional :terms_of_use, -> { ModernTreasury::LegalEntityUpdateParams::TermsOfUse }, nil?: true |
#third_party_verification ⇒ ModernTreasury::Models::ThirdPartyVerification?
Deprecated. Use third_party_verifications instead.
231 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 231 optional :third_party_verification, -> { ModernTreasury::ThirdPartyVerification }, nil?: true |
#third_party_verifications ⇒ Array<ModernTreasury::Models::ThirdPartyVerification>?
A list of third-party verifications run by external vendors.
237 238 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 237 optional :third_party_verifications, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ThirdPartyVerification] } |
#ticker_symbol ⇒ String?
Stock ticker symbol for publicly traded companies.
244 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 244 optional :ticker_symbol, String, nil?: true |
#wealth_and_employment_details ⇒ ModernTreasury::Models::LegalEntityWealthEmploymentDetail?
249 250 251 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 249 optional :wealth_and_employment_details, -> { ModernTreasury::LegalEntityWealthEmploymentDetail }, nil?: true |
#website ⇒ String?
The entity's primary website URL.
257 |
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 257 optional :website, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/legal_entity_update_params.rb', line 350
|
Instance Method Details
#to_hash ⇒ {
200 |
# File 'sig/modern_treasury/models/legal_entity_update_params.rbs', line 200
def to_hash: -> {
|