Class: ModernTreasury::Models::PaymentOrder::Accounting Deprecated
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::PaymentOrder::Accounting
- Defined in:
- lib/modern_treasury/models/payment_order.rb,
sig/modern_treasury/models/payment_order.rbs
Overview
Instance Attribute Summary collapse
- #account_id ⇒ String? deprecated Deprecated.
- #class_id ⇒ String? deprecated Deprecated.
Instance Method Summary collapse
-
#initialize ⇒ Accounting
constructor
A new instance of Accounting.
- #to_hash ⇒ { account_id: String?, class_id: String? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Accounting
Returns a new instance of Accounting.
276 |
# File 'sig/modern_treasury/models/payment_order.rbs', line 276
def initialize: (?account_id: String?, ?class_id: String?) -> void
|
Instance Attribute Details
#account_id ⇒ String?
The ID of one of your accounting categories. Note that these will only be accessible if your accounting system has been connected.
482 |
# File 'lib/modern_treasury/models/payment_order.rb', line 482 optional :account_id, String, nil?: true |
#class_id ⇒ String?
The ID of one of the class objects in your accounting system. Class objects track segments of your business independent of client or project. Note that these will only be accessible if your accounting system has been connected.
492 |
# File 'lib/modern_treasury/models/payment_order.rb', line 492 optional :class_id, String, nil?: true |
Instance Method Details
#to_hash ⇒ { account_id: String?, class_id: String? }
278 |
# File 'sig/modern_treasury/models/payment_order.rbs', line 278
def to_hash: -> { account_id: String?, class_id: String? }
|