Class: ModernTreasury::Models::PaymentOrderCreateAsyncParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::PaymentOrderCreateAsyncParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/payment_order_create_async_params.rb,
sig/modern_treasury/models/payment_order_create_async_params.rbs
Overview
Defined Under Namespace
Modules: ChargeBearer, Direction, FallbackType, ForeignExchangeIndicator, Priority, ReconciliationStatus Classes: Accounting, LineItem, OriginatingPartyAddress, ReceivingAccount, UltimateOriginatingPartyAddress
Constant Summary collapse
- ModernTreasury =
Instance Attribute Summary collapse
- #accounting ⇒ ModernTreasury::Models::PaymentOrderCreateAsyncParams::Accounting? deprecated Deprecated.
- #accounting_category_id ⇒ String? deprecated Deprecated.
- #accounting_ledger_class_id ⇒ String? deprecated Deprecated.
-
#amount ⇒ Integer
Value in specified currency's smallest unit.
-
#charge_bearer ⇒ Symbol, ...
The party that will pay the fees for the payment order.
-
#currency ⇒ Symbol, ...
Defaults to the currency of the originating account.
-
#description ⇒ String?
An optional description for internal use.
-
#direction ⇒ Symbol, ModernTreasury::Models::PaymentOrderCreateAsyncParams::Direction
One of
credit,debit. -
#effective_date ⇒ Date?
Date transactions are to be posted to the participants' account.
-
#expires_at ⇒ Time?
RFP payments require an expires_at.
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
-
#fallback_type ⇒ Symbol, ...
A payment type to fallback to if the original type is not valid for the receiving account.
-
#foreign_exchange_contract ⇒ String?
If present, indicates a specific foreign exchange contract number that has been generated by your financial institution.
-
#foreign_exchange_indicator ⇒ Symbol, ...
Indicates the type of FX transfer to initiate, can be either
variable_to_fixed,fixed_to_variable, ornullif the payment order currency matches the originating account currency. -
#ledger_transaction ⇒ ModernTreasury::Models::LedgerTransactionCreateRequest?
Specifies a ledger transaction object that will be created with the payment order.
-
#ledger_transaction_id ⇒ String?
Either ledger_transaction or ledger_transaction_id can be provided.
-
#line_items ⇒ Array<ModernTreasury::Models::PaymentOrderCreateAsyncParams::LineItem>?
An array of line items that must sum up to the amount of the payment order.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#nsf_protected ⇒ Boolean?
A boolean to determine if NSF Protection is enabled for this payment order.
-
#originating_account_id ⇒ String
The ID of one of your organization's internal accounts.
-
#originating_party_address ⇒ ModernTreasury::Models::PaymentOrderCreateAsyncParams::OriginatingPartyAddress?
If present, this address will override the default originating party address used on the payment order.
-
#originating_party_name ⇒ String?
If present, this will replace your default company name on receiver's bank statement.
-
#priority ⇒ Symbol, ...
Either
normalorhigh. -
#process_after ⇒ Time?
If present, Modern Treasury will not process the payment until after this time.
-
#purpose ⇒ String?
For
wire, this is usually the purpose which is transmitted via the "InstrForDbtrAgt" field in the ISO20022 file. -
#receiving_account ⇒ ModernTreasury::Models::PaymentOrderCreateAsyncParams::ReceivingAccount?
Either
receiving_accountorreceiving_account_idmust be present. -
#receiving_account_id ⇒ String?
Either
receiving_accountorreceiving_account_idmust be present. -
#reconciliation_status ⇒ Symbol, ...
One of
unreconciled,tentatively_reconciledorreconciled. -
#remittance_information ⇒ String?
For
ach, this field will be passed through on an addenda record. -
#send_remittance_advice ⇒ Boolean?
Send an email to the counterparty when the payment order is sent to the bank.
-
#statement_descriptor ⇒ String?
An optional descriptor which will appear in the receiver's statement.
-
#subtype ⇒ Symbol, ...
An additional layer of classification for the type of payment order you are doing.
- #transaction_monitoring_enabled ⇒ Boolean? deprecated Deprecated.
-
#type ⇒ Symbol, ModernTreasury::Models::PaymentOrderType
One of
ach,se_bankgirot,eft,wire,check,book,rtp,sepa,bacs,au_becs,neft,nics,nz_national_clearing_code,sic,zengin. -
#ultimate_originating_account_id ⇒ String?
The ultimate originating account ID.
-
#ultimate_originating_party_address ⇒ ModernTreasury::Models::PaymentOrderCreateAsyncParams::UltimateOriginatingPartyAddress?
Address of the ultimate originator of the payment order.
-
#ultimate_originating_party_identifier ⇒ String?
Identifier of the ultimate originator of the payment order.
-
#ultimate_originating_party_name ⇒ String?
Name of the ultimate originator of the payment order.
-
#ultimate_receiving_party_identifier ⇒ String?
Identifier of the ultimate funds recipient.
-
#ultimate_receiving_party_name ⇒ String?
Name of the ultimate funds recipient.
-
#vendor_attributes ⇒ Hash{Symbol=>Object}?
Additional vendor specific fields for this payment.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(country: nil, line1: nil, line2: nil, locality: nil, postal_code: nil, region: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see OriginatingPartyAddress for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(country: nil, line1: nil, line2: nil, locality: nil, postal_code: nil, region: nil) ⇒ Object
Some parameter documentations has been truncated, see OriginatingPartyAddress for more details.
If present, this address will override the default originating party address used on the payment order. This works across all payment types.
|
|
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 327
|
Instance Attribute Details
#accounting ⇒ ModernTreasury::Models::PaymentOrderCreateAsyncParams::Accounting?
43 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 43 optional :accounting, -> { ModernTreasury::PaymentOrderCreateAsyncParams::Accounting } |
#accounting_category_id ⇒ String?
The ID of one of your accounting categories. Note that these will only be accessible if your accounting system has been connected.
52 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 52 optional :accounting_category_id, String, nil?: true |
#accounting_ledger_class_id ⇒ String?
The ID of one of your accounting ledger classes. Note that these will only be accessible if your accounting system has been connected.
61 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 61 optional :accounting_ledger_class_id, String, nil?: true |
#amount ⇒ Integer
Value in specified currency's smallest unit. e.g. $10 would be represented as 1000 (cents). For RTP, the maximum amount allowed by the network is $10,000,000.
15 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 15 required :amount, Integer |
#charge_bearer ⇒ Symbol, ...
The party that will pay the fees for the payment order. See https://docs.moderntreasury.com/payments/docs/charge-bearer to understand the differences between the options.
69 70 71 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 69 optional :charge_bearer, enum: -> { ModernTreasury::PaymentOrderCreateAsyncParams::ChargeBearer }, nil?: true |
#currency ⇒ Symbol, ...
Defaults to the currency of the originating account.
77 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 77 optional :currency, enum: -> { ModernTreasury::Currency } |
#description ⇒ String?
An optional description for internal use.
83 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 83 optional :description, String, nil?: true |
#direction ⇒ Symbol, ModernTreasury::Models::PaymentOrderCreateAsyncParams::Direction
One of credit, debit. Describes the direction money is flowing in the
transaction. A credit moves money from your account to someone else's. A
debit pulls money from someone else's account to your own. Note that wire,
rtp, and check payments will always be credit.
24 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 24 required :direction, enum: -> { ModernTreasury::PaymentOrderCreateAsyncParams::Direction } |
#effective_date ⇒ Date?
Date transactions are to be posted to the participants' account. Defaults to the current business day or the next business day if the current day is a bank holiday or weekend. Format: yyyy-mm-dd.
91 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 91 optional :effective_date, Date |
#expires_at ⇒ Time?
RFP payments require an expires_at. This value must be past the effective_date.
97 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 97 optional :expires_at, Time, nil?: true |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
103 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 103 optional :external_id, String, nil?: true |
#fallback_type ⇒ Symbol, ...
A payment type to fallback to if the original type is not valid for the receiving account. Currently, this only supports falling back from RTP to ACH (type=rtp and fallback_type=ach)
111 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 111 optional :fallback_type, enum: -> { ModernTreasury::PaymentOrderCreateAsyncParams::FallbackType } |
#foreign_exchange_contract ⇒ String?
If present, indicates a specific foreign exchange contract number that has been generated by your financial institution.
118 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 118 optional :foreign_exchange_contract, String, nil?: true |
#foreign_exchange_indicator ⇒ Symbol, ...
Indicates the type of FX transfer to initiate, can be either
variable_to_fixed, fixed_to_variable, or null if the payment order
currency matches the originating account currency.
126 127 128 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 126 optional :foreign_exchange_indicator, enum: -> { ModernTreasury::PaymentOrderCreateAsyncParams::ForeignExchangeIndicator }, nil?: true |
#ledger_transaction ⇒ ModernTreasury::Models::LedgerTransactionCreateRequest?
Specifies a ledger transaction object that will be created with the payment order. If the ledger transaction cannot be created, then the payment order creation will fail. The resulting ledger transaction will mirror the status of the payment order.
137 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 137 optional :ledger_transaction, -> { ModernTreasury::LedgerTransactionCreateRequest } |
#ledger_transaction_id ⇒ String?
Either ledger_transaction or ledger_transaction_id can be provided. Only a pending ledger transaction can be attached upon payment order creation. Once the payment order is created, the status of the ledger transaction tracks the payment order automatically.
146 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 146 optional :ledger_transaction_id, String |
#line_items ⇒ Array<ModernTreasury::Models::PaymentOrderCreateAsyncParams::LineItem>?
An array of line items that must sum up to the amount of the payment order.
152 153 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 152 optional :line_items, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::PaymentOrderCreateAsyncParams::LineItem] } |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
160 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 160 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#nsf_protected ⇒ Boolean?
A boolean to determine if NSF Protection is enabled for this payment order. Note that this setting must also be turned on in your organization settings page.
167 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 167 optional :nsf_protected, ModernTreasury::Internal::Type::Boolean |
#originating_account_id ⇒ String
The ID of one of your organization's internal accounts.
30 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 30 required :originating_account_id, String |
#originating_party_address ⇒ ModernTreasury::Models::PaymentOrderCreateAsyncParams::OriginatingPartyAddress?
If present, this address will override the default originating party address used on the payment order. This works across all payment types.
174 175 176 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 174 optional :originating_party_address, -> { ModernTreasury::PaymentOrderCreateAsyncParams::OriginatingPartyAddress }, nil?: true |
#originating_party_name ⇒ String?
If present, this will replace your default company name on receiver's bank statement. This field can only be used for ACH payments currently. For ACH, only the first 16 characters of this string will be used. Any additional characters will be truncated.
185 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 185 optional :originating_party_name, String, nil?: true |
#priority ⇒ Symbol, ...
Either normal or high. For ACH and EFT payments, high represents a
same-day ACH or EFT transfer, respectively. For check payments, high can mean
an overnight check rather than standard mail.
193 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 193 optional :priority, enum: -> { ModernTreasury::PaymentOrderCreateAsyncParams::Priority } |
#process_after ⇒ Time?
If present, Modern Treasury will not process the payment until after this time.
If process_after is past the cutoff for effective_date, process_after will
take precedence and effective_date will automatically update to reflect the
earliest possible sending date after process_after. Format is ISO8601
timestamp.
203 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 203 optional :process_after, Time, nil?: true |
#purpose ⇒ String?
For wire, this is usually the purpose which is transmitted via the
"InstrForDbtrAgt" field in the ISO20022 file. For eft, this field is the 3
digit CPA Code that will be attached to the payment.
211 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 211 optional :purpose, String, nil?: true |
#receiving_account ⇒ ModernTreasury::Models::PaymentOrderCreateAsyncParams::ReceivingAccount?
Either receiving_account or receiving_account_id must be present. When using
receiving_account_id, you may pass the id of an external account or an
internal account.
219 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 219 optional :receiving_account, -> { ModernTreasury::PaymentOrderCreateAsyncParams::ReceivingAccount } |
#receiving_account_id ⇒ String?
Either receiving_account or receiving_account_id must be present. When using
receiving_account_id, you may pass the id of an external account or an
internal account.
227 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 227 optional :receiving_account_id, String |
#reconciliation_status ⇒ Symbol, ...
One of unreconciled, tentatively_reconciled or reconciled.
233 234 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 233 optional :reconciliation_status, enum: -> { ModernTreasury::PaymentOrderCreateAsyncParams::ReconciliationStatus } |
#remittance_information ⇒ String?
For ach, this field will be passed through on an addenda record. For wire
payments the field will be passed through as the "Originator to Beneficiary
Information", also known as OBI or Fedwire tag 6000.
242 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 242 optional :remittance_information, String, nil?: true |
#send_remittance_advice ⇒ Boolean?
Send an email to the counterparty when the payment order is sent to the bank. If
null, send_remittance_advice on the Counterparty is used.
249 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 249 optional :send_remittance_advice, ModernTreasury::Internal::Type::Boolean, nil?: true |
#statement_descriptor ⇒ String?
An optional descriptor which will appear in the receiver's statement. For
check payments this field will be used as the memo line. For ach the maximum
length is 10 characters. Note that for ACH payments, the name on your bank
account will be included automatically by the bank, so you can use the
characters for other useful information. For eft the maximum length is 15
characters.
260 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 260 optional :statement_descriptor, String, nil?: true |
#subtype ⇒ Symbol, ...
An additional layer of classification for the type of payment order you are
doing. This field is only used for ach payment orders currently. For ach
payment orders, the subtype represents the SEC code. We currently support
CCD, PPD, IAT, CTX, WEB, CIE, and TEL.
269 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 269 optional :subtype, enum: -> { ModernTreasury::PaymentOrderSubtype }, nil?: true |
#transaction_monitoring_enabled ⇒ Boolean?
A flag that determines whether a payment order should go through transaction monitoring.
278 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 278 optional :transaction_monitoring_enabled, ModernTreasury::Internal::Type::Boolean |
#type ⇒ Symbol, ModernTreasury::Models::PaymentOrderType
One of ach, se_bankgirot, eft, wire, check, book, rtp, sepa,
bacs, au_becs, neft, nics, nz_national_clearing_code, sic, zengin.
37 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 37 required :type, enum: -> { ModernTreasury::PaymentOrderType } |
#ultimate_originating_account_id ⇒ String?
The ultimate originating account ID. Can be a virtual_account or
internal_account.
285 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 285 optional :ultimate_originating_account_id, String |
#ultimate_originating_party_address ⇒ ModernTreasury::Models::PaymentOrderCreateAsyncParams::UltimateOriginatingPartyAddress?
Address of the ultimate originator of the payment order.
291 292 293 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 291 optional :ultimate_originating_party_address, -> { ModernTreasury::PaymentOrderCreateAsyncParams::UltimateOriginatingPartyAddress }, nil?: true |
#ultimate_originating_party_identifier ⇒ String?
Identifier of the ultimate originator of the payment order.
299 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 299 optional :ultimate_originating_party_identifier, String, nil?: true |
#ultimate_originating_party_name ⇒ String?
Name of the ultimate originator of the payment order.
305 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 305 optional :ultimate_originating_party_name, String, nil?: true |
#ultimate_receiving_party_identifier ⇒ String?
Identifier of the ultimate funds recipient.
311 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 311 optional :ultimate_receiving_party_identifier, String, nil?: true |
#ultimate_receiving_party_name ⇒ String?
Name of the ultimate funds recipient.
317 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 317 optional :ultimate_receiving_party_name, String, nil?: true |
#vendor_attributes ⇒ Hash{Symbol=>Object}?
Additional vendor specific fields for this payment. Data must be represented as key-value pairs.
324 325 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 324 optional :vendor_attributes, ModernTreasury::Internal::Type::HashOf[ModernTreasury::Internal::Type::Unknown] |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 425
|
Instance Method Details
#to_hash ⇒ {
228 |
# File 'sig/modern_treasury/models/payment_order_create_async_params.rbs', line 228
def to_hash: -> {
|