Class: ModernTreasury::Models::PaymentOrderCreateAsyncParams::UltimateOriginatingPartyAddress
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::PaymentOrderCreateAsyncParams::UltimateOriginatingPartyAddress
- Defined in:
- lib/modern_treasury/models/payment_order_create_async_params.rb
Instance Attribute Summary collapse
-
#country ⇒ String?
Country code conforms to [ISO 3166-1 alpha-2].
- #line1 ⇒ String?
- #line2 ⇒ String?
-
#locality ⇒ String?
Locality or City.
-
#postal_code ⇒ String?
The postal code of the address.
-
#region ⇒ String?
Region or State.
Instance Method Summary collapse
-
#initialize(country: nil, line1: nil, line2: nil, locality: nil, postal_code: nil, region: nil) ⇒ Object
constructor
Address of the ultimate originator of the payment order.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(country: nil, line1: nil, line2: nil, locality: nil, postal_code: nil, region: nil) ⇒ Object
Address of the ultimate originator of the payment order.
|
|
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 863
|
Instance Attribute Details
#country ⇒ String?
Country code conforms to [ISO 3166-1 alpha-2]
833 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 833 optional :country, String |
#line1 ⇒ String?
838 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 838 optional :line1, String |
#line2 ⇒ String?
843 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 843 optional :line2, String |
#locality ⇒ String?
Locality or City.
849 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 849 optional :locality, String |
#postal_code ⇒ String?
The postal code of the address.
855 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 855 optional :postal_code, String |
#region ⇒ String?
Region or State.
861 |
# File 'lib/modern_treasury/models/payment_order_create_async_params.rb', line 861 optional :region, String |