Class: ModernTreasury::Models::PaymentOrderCreateParams::ReceivingAccount
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::PaymentOrderCreateParams::ReceivingAccount
- Defined in:
- lib/modern_treasury/models/payment_order_create_params.rb,
sig/modern_treasury/models/payment_order_create_params.rbs
Defined Under Namespace
Modules: PartyType Classes: AccountDetail, RoutingDetail
Constant Summary collapse
- ModernTreasury =
Instance Attribute Summary collapse
- #account_details ⇒ Array<ModernTreasury::Models::PaymentOrderCreateParams::ReceivingAccount::AccountDetail>?
-
#account_type ⇒ Symbol, ...
Can be
checking,savingsorother. - #contact_details ⇒ Array<ModernTreasury::Models::ContactDetailCreateRequest>?
-
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
-
#ledger_account ⇒ ModernTreasury::Models::LedgerAccountCreateRequest?
Specifies a ledger account object that will be created with the external account.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#name ⇒ String?
A nickname for the external account.
-
#party_address ⇒ ModernTreasury::Models::AddressRequest?
Required if receiving wire payments.
- #party_identifier ⇒ String?
-
#party_name ⇒ String?
If this value isn't provided, it will be inherited from the counterparty's name.
-
#party_type ⇒ Symbol, ...
Either
individualorbusiness. -
#plaid_processor_token ⇒ String?
If you've enabled the Modern Treasury + Plaid integration in your Plaid account, you can pass the processor token in this field.
- #routing_details ⇒ Array<ModernTreasury::Models::PaymentOrderCreateParams::ReceivingAccount::RoutingDetail>?
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
570 |
# File 'sig/modern_treasury/models/payment_order_create_params.rbs', line 570 def initialize: ( |
Instance Attribute Details
#account_details ⇒ Array<ModernTreasury::Models::PaymentOrderCreateParams::ReceivingAccount::AccountDetail>?
675 676 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 675 optional :account_details, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::PaymentOrderCreateParams::ReceivingAccount::AccountDetail] } |
#account_type ⇒ Symbol, ...
Can be checking, savings or other.
682 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 682 optional :account_type, enum: -> { ModernTreasury::ExternalAccountType } |
#contact_details ⇒ Array<ModernTreasury::Models::ContactDetailCreateRequest>?
687 688 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 687 optional :contact_details, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ContactDetailCreateRequest] } |
#external_id ⇒ String?
An optional user-defined 180 character unique identifier.
694 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 694 optional :external_id, String, nil?: true |
#ledger_account ⇒ ModernTreasury::Models::LedgerAccountCreateRequest?
Specifies a ledger account object that will be created with the external account. The resulting ledger account is linked to the external account for auto-ledgering Payment objects. See https://docs.moderntreasury.com/docs/linking-to-other-modern-treasury-objects for more details.
704 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 704 optional :ledger_account, -> { ModernTreasury::LedgerAccountCreateRequest } |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
711 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 711 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#name ⇒ String?
A nickname for the external account. This is only for internal usage and won't affect any payments
718 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 718 optional :name, String, nil?: true |
#party_address ⇒ ModernTreasury::Models::AddressRequest?
Required if receiving wire payments.
724 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 724 optional :party_address, -> { ModernTreasury::AddressRequest } |
#party_identifier ⇒ String?
729 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 729 optional :party_identifier, String |
#party_name ⇒ String?
If this value isn't provided, it will be inherited from the counterparty's name.
735 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 735 optional :party_name, String |
#party_type ⇒ Symbol, ...
Either individual or business.
741 742 743 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 741 optional :party_type, enum: -> { ModernTreasury::PaymentOrderCreateParams::ReceivingAccount::PartyType }, nil?: true |
#plaid_processor_token ⇒ String?
If you've enabled the Modern Treasury + Plaid integration in your Plaid account, you can pass the processor token in this field.
750 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 750 optional :plaid_processor_token, String |
#routing_details ⇒ Array<ModernTreasury::Models::PaymentOrderCreateParams::ReceivingAccount::RoutingDetail>?
755 756 |
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 755 optional :routing_details, -> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::PaymentOrderCreateParams::ReceivingAccount::RoutingDetail] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/payment_order_create_params.rb', line 829
|
Instance Method Details
#to_hash ⇒ {
586 |
# File 'sig/modern_treasury/models/payment_order_create_params.rbs', line 586 def to_hash: -> { |