Module: ModernTreasury::Models::PaymentOrderSubtype
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/modern_treasury/models/payment_order_subtype.rb,
sig/modern_treasury/models/payment_order_subtype.rbs
Overview
An additional layer of classification for the type of payment order you are
doing. This field is only used for ach payment orders currently. For ach
payment orders, the subtype represents the SEC code. We currently support
CCD, PPD, IAT, CTX, WEB, CIE, and TEL.
Constant Summary collapse
- BACS_NEW_INSTRUCTION =
:"0C"- BACS_CANCELLATION_INSTRUCTION =
:"0N"- BACS_CONVERSION_INSTRUCTION =
:"0S"- CCD =
:CCD- CIE =
:CIE- CTX =
:CTX- IAT =
:IAT- PPD =
:PPD- TEL =
:TEL- WEB =
:WEB- AU_BECS =
:au_becs- BACS =
:bacs- BASE =
:base- CHATS =
:chats- DIGITAL =
:digital- DK_NETS =
:dk_nets- EFT =
:eft- ETHEREUM =
:ethereum- MASAV =
:masav- MX_CCEN =
:mx_ccen- NEFT =
:neft- NICS =
:nics- NZ_BECS =
:nz_becs- PL_ELIXIR =
:pl_elixir- POLYGON =
:polygon- PRINT =
:print- SE_BANKGIROT =
:se_bankgirot- SEPA =
:sepa- SG_GIRO =
:sg_giro- SIC =
:sic- SOLANA =
:solana- ZENGIN =
:zengin
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/payment_order_subtype.rb', line 45
|
Instance Method Details
#self?.values ⇒ ::Array[ModernTreasury::Models::payment_order_subtype]
73 |
# File 'sig/modern_treasury/models/payment_order_subtype.rbs', line 73
def self?.values: -> ::Array[ModernTreasury::Models::payment_order_subtype]
|