Class: ModernTreasury::Models::PaymentOrderUpdateParams::ReceivingAccount

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/modern_treasury/models/payment_order_update_params.rb

Defined Under Namespace

Modules: PartyType Classes: AccountDetail, RoutingDetail

Instance Attribute Summary collapse

Class Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from ModernTreasury::Internal::Type::BaseModel

Instance Attribute Details

#account_detailsArray<ModernTreasury::Models::PaymentOrderUpdateParams::ReceivingAccount::AccountDetail>?



515
516
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 515

optional :account_details,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::PaymentOrderUpdateParams::ReceivingAccount::AccountDetail] }

#account_typeSymbol, ...

Can be ‘checking`, `savings` or `other`.



522
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 522

optional :account_type, enum: -> { ModernTreasury::ExternalAccountType }

#contact_detailsArray<ModernTreasury::Models::ContactDetailCreateRequest>?



527
528
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 527

optional :contact_details,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::ContactDetailCreateRequest] }

#external_idString?

An optional user-defined 180 character unique identifier.

Returns:

  • (String, nil)


534
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 534

optional :external_id, String, nil?: true

#ledger_accountModernTreasury::Models::LedgerAccountCreateRequest?

Specifies a ledger account object that will be created with the external account. The resulting ledger account is linked to the external account for auto-ledgering Payment objects. See docs.moderntreasury.com/docs/linking-to-other-modern-treasury-objects for more details.



544
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 544

optional :ledger_account, -> { ModernTreasury::LedgerAccountCreateRequest }

#metadataHash{Symbol=>String}?

Additional data represented as key-value pairs. Both the key and value must be strings.

Returns:

  • (Hash{Symbol=>String}, nil)


551
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 551

optional :metadata, ModernTreasury::Internal::Type::HashOf[String]

#nameString?

A nickname for the external account. This is only for internal usage and won’t affect any payments

Returns:

  • (String, nil)


558
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 558

optional :name, String, nil?: true

#party_addressModernTreasury::Models::AddressRequest?

Required if receiving wire payments.



564
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 564

optional :party_address, -> { ModernTreasury::AddressRequest }

#party_identifierString?

Returns:

  • (String, nil)


569
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 569

optional :party_identifier, String

#party_nameString?

If this value isn’t provided, it will be inherited from the counterparty’s name.

Returns:

  • (String, nil)


575
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 575

optional :party_name, String

#party_typeSymbol, ...

Either ‘individual` or `business`.



581
582
583
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 581

optional :party_type,
enum: -> { ModernTreasury::PaymentOrderUpdateParams::ReceivingAccount::PartyType },
nil?: true

#plaid_processor_tokenString?

If you’ve enabled the Modern Treasury + Plaid integration in your Plaid account, you can pass the processor token in this field.

Returns:

  • (String, nil)


590
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 590

optional :plaid_processor_token, String

#routing_detailsArray<ModernTreasury::Models::PaymentOrderUpdateParams::ReceivingAccount::RoutingDetail>?



595
596
# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 595

optional :routing_details,
-> { ModernTreasury::Internal::Type::ArrayOf[ModernTreasury::PaymentOrderUpdateParams::ReceivingAccount::RoutingDetail] }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/modern_treasury/models/payment_order_update_params.rb', line 669