Class: ModernTreasury::Models::PaymentOrders::Reversal
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::PaymentOrders::Reversal
- Defined in:
- lib/modern_treasury/models/payment_orders/reversal.rb
Overview
Defined Under Namespace
Modules: Reason, ReconciliationStatus, Status
Instance Attribute Summary collapse
- #created_at ⇒ Time
- #id ⇒ String
-
#internal_account_id ⇒ String?
The ID of the relevant Internal Account.
-
#ledger_transaction_id ⇒ String?
The ID of the ledger transaction linked to the reversal.
-
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
-
#metadata ⇒ Hash{Symbol=>String}
Additional data represented as key-value pairs.
- #object ⇒ String
-
#payment_order_id ⇒ String?
The ID of the relevant Payment Order.
-
#reason ⇒ Symbol, ModernTreasury::Models::PaymentOrders::Reversal::Reason
The reason for the reversal.
-
#reconciliation_status ⇒ Symbol, ModernTreasury::Models::PaymentOrders::Reversal::ReconciliationStatus
One of ‘unreconciled`, `tentatively_reconciled` or `reconciled`.
-
#status ⇒ Symbol, ModernTreasury::Models::PaymentOrders::Reversal::Status
The current status of the reversal.
- #transaction_ids ⇒ Array<String, nil>
- #updated_at ⇒ Time
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, created_at:, internal_account_id:, ledger_transaction_id:, live_mode:, metadata:, object:, payment_order_id:, reason:, reconciliation_status:, status:, transaction_ids:, updated_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Reversal for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, internal_account_id:, ledger_transaction_id:, live_mode:, metadata:, object:, payment_order_id:, reason:, reconciliation_status:, status:, transaction_ids:, updated_at:) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::PaymentOrders::Reversal for more details.
|
|
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 84
|
Instance Attribute Details
#created_at ⇒ Time
16 |
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 16 required :created_at, Time |
#id ⇒ String
11 |
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 11 required :id, String |
#internal_account_id ⇒ String?
The ID of the relevant Internal Account.
22 |
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 22 required :internal_account_id, String, nil?: true |
#ledger_transaction_id ⇒ String?
The ID of the ledger transaction linked to the reversal.
28 |
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 28 required :ledger_transaction_id, String, nil?: true |
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment or false if it exists in the test environment.
35 |
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 35 required :live_mode, ModernTreasury::Internal::Type::Boolean |
#metadata ⇒ Hash{Symbol=>String}
Additional data represented as key-value pairs. Both the key and value must be strings.
42 |
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 42 required :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#object ⇒ String
47 |
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 47 required :object, String |
#payment_order_id ⇒ String?
The ID of the relevant Payment Order.
53 |
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 53 required :payment_order_id, String, nil?: true |
#reason ⇒ Symbol, ModernTreasury::Models::PaymentOrders::Reversal::Reason
The reason for the reversal.
59 |
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 59 required :reason, enum: -> { ModernTreasury::PaymentOrders::Reversal::Reason } |
#reconciliation_status ⇒ Symbol, ModernTreasury::Models::PaymentOrders::Reversal::ReconciliationStatus
One of ‘unreconciled`, `tentatively_reconciled` or `reconciled`.
65 66 |
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 65 required :reconciliation_status, enum: -> { ModernTreasury::PaymentOrders::Reversal::ReconciliationStatus } |
#status ⇒ Symbol, ModernTreasury::Models::PaymentOrders::Reversal::Status
The current status of the reversal.
72 |
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 72 required :status, enum: -> { ModernTreasury::PaymentOrders::Reversal::Status } |
#transaction_ids ⇒ Array<String, nil>
77 |
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 77 required :transaction_ids, ModernTreasury::Internal::Type::ArrayOf[String, nil?: true] |
#updated_at ⇒ Time
82 |
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 82 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/payment_orders/reversal.rb', line 126
|