Class: ModernTreasury::Models::TransactionCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::TransactionCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/transaction_create_params.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#amount ⇒ Integer
Value in specified currency’s smallest unit.
-
#as_of_date ⇒ Date?
The date on which the transaction occurred.
-
#direction ⇒ String
Either ‘credit` or `debit`.
-
#internal_account_id ⇒ String
The ID of the relevant Internal Account.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs.
-
#posted ⇒ Boolean?
This field will be ‘true` if the transaction has posted to the account.
-
#type ⇒ Symbol, ...
The type of the transaction.
-
#vendor_code ⇒ String?
When applicable, the bank-given code that determines the transaction’s category.
-
#vendor_code_type ⇒ String?
The type of ‘vendor_code` being reported.
-
#vendor_customer_id ⇒ String?
An identifier given to this transaction by the bank, often ‘null`.
-
#vendor_description ⇒ String?
The transaction detail text that often appears in on your bank statement and in your banking portal.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(amount:, as_of_date:, direction:, internal_account_id:, vendor_code:, vendor_code_type:, metadata: nil, posted: nil, type: nil, vendor_customer_id: nil, vendor_description: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see TransactionCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, as_of_date:, direction:, internal_account_id:, vendor_code:, vendor_code_type:, metadata: nil, posted: nil, type: nil, vendor_customer_id: nil, vendor_description: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::TransactionCreateParams for more details.
|
|
# File 'lib/modern_treasury/models/transaction_create_params.rb', line 84
|
Instance Attribute Details
#amount ⇒ Integer
Value in specified currency’s smallest unit. e.g. $10 would be represented as 1000.
15 |
# File 'lib/modern_treasury/models/transaction_create_params.rb', line 15 required :amount, Integer |
#as_of_date ⇒ Date?
The date on which the transaction occurred.
21 |
# File 'lib/modern_treasury/models/transaction_create_params.rb', line 21 required :as_of_date, Date, nil?: true |
#direction ⇒ String
Either ‘credit` or `debit`.
27 |
# File 'lib/modern_treasury/models/transaction_create_params.rb', line 27 required :direction, String |
#internal_account_id ⇒ String
The ID of the relevant Internal Account.
33 |
# File 'lib/modern_treasury/models/transaction_create_params.rb', line 33 required :internal_account_id, String |
#metadata ⇒ Hash{Symbol=>String}?
Additional data represented as key-value pairs. Both the key and value must be strings.
56 |
# File 'lib/modern_treasury/models/transaction_create_params.rb', line 56 optional :metadata, ModernTreasury::Internal::Type::HashOf[String] |
#posted ⇒ Boolean?
This field will be ‘true` if the transaction has posted to the account.
62 |
# File 'lib/modern_treasury/models/transaction_create_params.rb', line 62 optional :posted, ModernTreasury::Internal::Type::Boolean |
#type ⇒ Symbol, ...
The type of the transaction. Examples could be ‘card, `ach`, `wire`, `check`, `rtp`, `book`, or `sen`.
69 |
# File 'lib/modern_treasury/models/transaction_create_params.rb', line 69 optional :type, enum: -> { ModernTreasury::TransactionCreateParams::Type }, nil?: true |
#vendor_code ⇒ String?
When applicable, the bank-given code that determines the transaction’s category. For most banks this is the BAI2/BTRS transaction code.
40 |
# File 'lib/modern_treasury/models/transaction_create_params.rb', line 40 required :vendor_code, String, nil?: true |
#vendor_code_type ⇒ String?
The type of ‘vendor_code` being reported. Can be one of `bai2`, `bankprov`, `bnk_dev`, `cleartouch`, `currencycloud`, `cross_river`, `dc_bank`, `dwolla`, `evolve`, `goldman_sachs`, `iso20022`, `jpmc`, `mx`, `signet`, `silvergate`, `swift`, `us_bank`, or others.
49 |
# File 'lib/modern_treasury/models/transaction_create_params.rb', line 49 required :vendor_code_type, String, nil?: true |
#vendor_customer_id ⇒ String?
An identifier given to this transaction by the bank, often ‘null`.
75 |
# File 'lib/modern_treasury/models/transaction_create_params.rb', line 75 optional :vendor_customer_id, String, nil?: true |
#vendor_description ⇒ String?
The transaction detail text that often appears in on your bank statement and in your banking portal.
82 |
# File 'lib/modern_treasury/models/transaction_create_params.rb', line 82 optional :vendor_description, String, nil?: true |