Class: ModernTreasury::Models::Transactions::TransactionLineItem
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::Transactions::TransactionLineItem
- Defined in:
- lib/modern_treasury/models/transactions/transaction_line_item.rb,
sig/modern_treasury/models/transactions/transaction_line_item.rbs
Overview
Defined Under Namespace
Modules: TransactableType, Type
Instance Attribute Summary collapse
-
#amount ⇒ Integer
If a matching object exists in Modern Treasury,
amountwill be populated. -
#counterparty_id ⇒ String?
The ID for the counterparty for this transaction line item.
- #created_at ⇒ Time
-
#description ⇒ String
If no matching object is found,
descriptionwill be a free-form text field describing the line item. - #discarded_at ⇒ Time?
-
#expected_payment_id ⇒ String?
The ID of the reconciled Expected Payment, otherwise
null. - #id ⇒ String
-
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment, or false if it exists in the test environment.
- #object ⇒ String
-
#reconcilable ⇒ Boolean
Describes whether this line item should be counted towards the corresponding transaction’s reconciliation.
-
#reconciliation_group_id ⇒ String?
The ID of the reconciliation group this line item belongs to, otherwise
null. -
#transactable_id ⇒ String?
If a matching object exists in Modern Treasury, the ID will be populated here, otherwise
null. -
#transactable_type ⇒ Symbol, ...
If a matching object exists in Modern Treasury, the type will be populated here, otherwise
null. -
#transaction_id ⇒ String
The ID of the parent transaction.
-
#type ⇒ Symbol, ModernTreasury::Models::Transactions::TransactionLineItem::Type
Indicates whether the line item is
originatingorreceiving(see https://www.moderntreasury.com/journal/beginners-guide-to-ach for more). - #updated_at ⇒ Time
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, amount:, counterparty_id:, created_at:, description:, discarded_at:, expected_payment_id:, live_mode:, object:, reconcilable:, reconciliation_group_id:, transactable_id:, transactable_type:, transaction_id:, type:, updated_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see TransactionLineItem for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, amount:, counterparty_id:, created_at:, description:, discarded_at:, expected_payment_id:, live_mode:, object:, reconcilable:, reconciliation_group_id:, transactable_id:, transactable_type:, transaction_id:, type:, updated_at:) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::Transactions::TransactionLineItem for more details.
|
|
# File 'lib/modern_treasury/models/transactions/transaction_line_item.rb', line 111
|
Instance Attribute Details
#amount ⇒ Integer
If a matching object exists in Modern Treasury, amount will be populated.
Value in specified currency's smallest unit (taken from parent Transaction).
18 |
# File 'lib/modern_treasury/models/transactions/transaction_line_item.rb', line 18 required :amount, Integer |
#counterparty_id ⇒ String?
The ID for the counterparty for this transaction line item.
24 |
# File 'lib/modern_treasury/models/transactions/transaction_line_item.rb', line 24 required :counterparty_id, String, nil?: true |
#created_at ⇒ Time
29 |
# File 'lib/modern_treasury/models/transactions/transaction_line_item.rb', line 29 required :created_at, Time |
#description ⇒ String
If no matching object is found, description will be a free-form text field
describing the line item. This field may contain personally identifiable
information (PII) and is not included in API responses by default. Learn more
about changing your settings at
https://docs.moderntreasury.com/reference/personally-identifiable-information.
39 |
# File 'lib/modern_treasury/models/transactions/transaction_line_item.rb', line 39 required :description, String |
#discarded_at ⇒ Time?
44 |
# File 'lib/modern_treasury/models/transactions/transaction_line_item.rb', line 44 required :discarded_at, Time, nil?: true |
#expected_payment_id ⇒ String?
The ID of the reconciled Expected Payment, otherwise null.
50 |
# File 'lib/modern_treasury/models/transactions/transaction_line_item.rb', line 50 required :expected_payment_id, String, nil?: true |
#id ⇒ String
11 |
# File 'lib/modern_treasury/models/transactions/transaction_line_item.rb', line 11 required :id, String |
#live_mode ⇒ Boolean
This field will be true if this object exists in the live environment, or false if it exists in the test environment.
57 |
# File 'lib/modern_treasury/models/transactions/transaction_line_item.rb', line 57 required :live_mode, ModernTreasury::Internal::Type::Boolean |
#object ⇒ String
62 |
# File 'lib/modern_treasury/models/transactions/transaction_line_item.rb', line 62 required :object, String |
#reconcilable ⇒ Boolean
Describes whether this line item should be counted towards the corresponding transaction’s reconciliation.
69 |
# File 'lib/modern_treasury/models/transactions/transaction_line_item.rb', line 69 required :reconcilable, ModernTreasury::Internal::Type::Boolean |
#reconciliation_group_id ⇒ String?
The ID of the reconciliation group this line item belongs to, otherwise null.
75 |
# File 'lib/modern_treasury/models/transactions/transaction_line_item.rb', line 75 required :reconciliation_group_id, String, nil?: true |
#transactable_id ⇒ String?
If a matching object exists in Modern Treasury, the ID will be populated here,
otherwise null.
82 |
# File 'lib/modern_treasury/models/transactions/transaction_line_item.rb', line 82 required :transactable_id, String, nil?: true |
#transactable_type ⇒ Symbol, ...
If a matching object exists in Modern Treasury, the type will be populated here,
otherwise null.
89 90 91 |
# File 'lib/modern_treasury/models/transactions/transaction_line_item.rb', line 89 required :transactable_type, enum: -> { ModernTreasury::Transactions::TransactionLineItem::TransactableType }, nil?: true |
#transaction_id ⇒ String
The ID of the parent transaction.
97 |
# File 'lib/modern_treasury/models/transactions/transaction_line_item.rb', line 97 required :transaction_id, String |
#type ⇒ Symbol, ModernTreasury::Models::Transactions::TransactionLineItem::Type
Indicates whether the line item is originating or receiving (see
https://www.moderntreasury.com/journal/beginners-guide-to-ach for more).
104 |
# File 'lib/modern_treasury/models/transactions/transaction_line_item.rb', line 104 required :type, enum: -> { ModernTreasury::Transactions::TransactionLineItem::Type } |
#updated_at ⇒ Time
109 |
# File 'lib/modern_treasury/models/transactions/transaction_line_item.rb', line 109 required :updated_at, Time |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/modern_treasury/models/transactions/transaction_line_item.rb', line 160
|
Instance Method Details
#to_hash ⇒ {
78 |
# File 'sig/modern_treasury/models/transactions/transaction_line_item.rbs', line 78
def to_hash: -> {
|