Class: ModernTreasury::Models::VirtualAccountSettingCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- ModernTreasury::Models::VirtualAccountSettingCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/modern_treasury/models/virtual_account_setting_create_params.rb,
sig/modern_treasury/models/virtual_account_setting_create_params.rbs
Overview
Constant Summary
Constants included from Internal::Type::RequestParameters
Internal::Type::RequestParameters::ModernTreasury
Instance Attribute Summary collapse
-
#allocation_identifier ⇒ String?
The prefix, suffix, or bank-assigned identifier for the virtual account numbers.
-
#allocation_length ⇒ Integer?
The total length of generated virtual account numbers.
-
#allocation_range_end ⇒ String?
The inclusive end of the virtual account number range.
-
#allocation_range_start ⇒ String?
The inclusive start of the virtual account number range.
-
#allocation_type ⇒ String
The method used to allocate virtual account numbers.
-
#external_id ⇒ String?
A user-defined identifier for the virtual account setting.
-
#generated_allocation_identifier_length ⇒ Integer?
The length of a generated virtual account setting prefix.
-
#internal_account_id ⇒ String
The ID of the internal account for the virtual account setting.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(allocation_type:, internal_account_id:, allocation_identifier: nil, allocation_length: nil, allocation_range_end: nil, allocation_range_start: nil, external_id: nil, generated_allocation_identifier_length: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see VirtualAccountSettingCreateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(allocation_type:, internal_account_id:, allocation_identifier: nil, allocation_length: nil, allocation_range_end: nil, allocation_range_start: nil, external_id: nil, generated_allocation_identifier_length: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see ModernTreasury::Models::VirtualAccountSettingCreateParams for more details.
|
|
# File 'lib/modern_treasury/models/virtual_account_setting_create_params.rb', line 58
|
Instance Attribute Details
#allocation_identifier ⇒ String?
The prefix, suffix, or bank-assigned identifier for the virtual account numbers.
26 |
# File 'lib/modern_treasury/models/virtual_account_setting_create_params.rb', line 26 optional :allocation_identifier, String, nil?: true |
#allocation_length ⇒ Integer?
The total length of generated virtual account numbers.
32 |
# File 'lib/modern_treasury/models/virtual_account_setting_create_params.rb', line 32 optional :allocation_length, Integer, nil?: true |
#allocation_range_end ⇒ String?
The inclusive end of the virtual account number range.
38 |
# File 'lib/modern_treasury/models/virtual_account_setting_create_params.rb', line 38 optional :allocation_range_end, String, nil?: true |
#allocation_range_start ⇒ String?
The inclusive start of the virtual account number range.
44 |
# File 'lib/modern_treasury/models/virtual_account_setting_create_params.rb', line 44 optional :allocation_range_start, String, nil?: true |
#allocation_type ⇒ String
The method used to allocate virtual account numbers.
14 |
# File 'lib/modern_treasury/models/virtual_account_setting_create_params.rb', line 14 required :allocation_type, String |
#external_id ⇒ String?
A user-defined identifier for the virtual account setting.
50 |
# File 'lib/modern_treasury/models/virtual_account_setting_create_params.rb', line 50 optional :external_id, String, nil?: true |
#generated_allocation_identifier_length ⇒ Integer?
The length of a generated virtual account setting prefix.
56 |
# File 'lib/modern_treasury/models/virtual_account_setting_create_params.rb', line 56 optional :generated_allocation_identifier_length, Integer, nil?: true |
#internal_account_id ⇒ String
The ID of the internal account for the virtual account setting.
20 |
# File 'lib/modern_treasury/models/virtual_account_setting_create_params.rb', line 20 required :internal_account_id, String |
Instance Method Details
#to_hash ⇒ {
48 |
# File 'sig/modern_treasury/models/virtual_account_setting_create_params.rbs', line 48
def to_hash: -> {
|